"""Per-prefix data, mapping each prefix to a dict of locale:name.

Auto-generated file, do not edit by hand.
"""
from ..util import u

# Copyright (C) 2011-2018 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

data = {
 '55183265':{'en': 'Rancharia - SP', 'pt': 'Rancharia - SP'},
 '55123631':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '498761':{'de': 'Moosburg an der Isar', 'en': 'Moosburg an der Isar'},
 '55273401':{'en': 'Baixo Guandu - ES', 'pt': 'Baixo Guandu - ES'},
 '55123633':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55173292':{'en': 'Paulo de Faria - SP', 'pt': 'Paulo de Faria - SP'},
 '55173293':{'en': 'Palestina - SP', 'pt': 'Palestina - SP'},
 '55114473':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55173291':{'en': u('Riol\u00e2ndia - SP'), 'pt': u('Riol\u00e2ndia - SP')},
 '55114474':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114477':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55173295':{'en': u('Monte Apraz\u00edvel - SP'), 'pt': u('Monte Apraz\u00edvel - SP')},
 '497551':{'de': u('\u00dcberlingen Bodensee'), 'en': u('\u00dcberlingen Bodensee')},
 '497552':{'de': 'Pfullendorf', 'en': 'Pfullendorf'},
 '497553':{'de': 'Salem Baden', 'en': 'Salem Baden'},
 '497554':{'de': 'Heiligenberg Baden', 'en': 'Heiligenberg Baden'},
 '497555':{'de': 'Deggenhausertal', 'en': 'Deggenhausertal'},
 '497556':{'de': u('Uhldingen-M\u00fchlhofen'), 'en': u('Uhldingen-M\u00fchlhofen')},
 '497557':{'de': u('Herdwangen-Sch\u00f6nach'), 'en': u('Herdwangen-Sch\u00f6nach')},
 '497558':{'de': 'Illmensee', 'en': 'Illmensee'},
 '55133461':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '494928':{'de': 'Ihlow-Riepe', 'en': 'Ihlow-Riepe'},
 '494929':{'de': 'Ihlow Kreis Aurich', 'en': 'Ihlow Kreis Aurich'},
 '55224105':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '494920':{'de': 'Wirdum', 'en': 'Wirdum'},
 '494921':{'de': 'Emden Stadt', 'en': 'Emden Stadt'},
 '494922':{'de': 'Borkum', 'en': 'Borkum'},
 '494923':{'de': u('Krummh\u00f6rn-Pewsum'), 'en': u('Krummh\u00f6rn-Pewsum')},
 '494924':{'de': 'Moormerland-Oldersum', 'en': 'Moormerland-Oldersum'},
 '494925':{'de': 'Hinte', 'en': 'Hinte'},
 '494926':{'de': u('Krummh\u00f6rn-Greetsiel'), 'en': u('Krummh\u00f6rn-Greetsiel')},
 '494927':{'de': u('Krummh\u00f6rn-Loquard'), 'en': u('Krummh\u00f6rn-Loquard')},
 '55133278':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133279':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133271':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133272':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133273':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55114699':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55242291':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55114044':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '52468':{'en': 'San Luis de la Paz, GTO', 'es': 'San Luis de la Paz, GTO'},
 '52469':{'en': 'Buenavista de Cortez/Penjamo, GTO', 'es': u('Buenavista de Cort\u00e9s/P\u00e9njamo, GTO')},
 '55114047':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55212703':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '494641':{'de': u('S\u00fcderbrarup'), 'en': u('S\u00fcderbrarup')},
 '52462':{'en': 'Irapuato, GTO', 'es': 'Irapuato, GTO'},
 '52463':{'en': 'Jalpa/Tabasco, ZAC', 'es': 'Jalpa/Tabasco, ZAC'},
 '52464':{'en': 'Salamanca, GTO', 'es': 'Salamanca, GTO'},
 '52465':{'en': 'Aguascalientes', 'es': 'Aguascalientes'},
 '52466':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '52467':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '55112622':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112623':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112621':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115906':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494643':{'de': 'Gelting Angeln', 'en': 'Gelting Angeln'},
 '55115904':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112625':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112628':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114043':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55123527':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123521':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123522':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '49561':{'de': 'Kassel', 'en': 'Kassel'},
 '55212108':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55242491':{'en': 'Vassouras - RJ', 'pt': 'Vassouras - RJ'},
 '55212103':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163434':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163432':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '499264':{'de': u('K\u00fcps'), 'en': u('K\u00fcps')},
 '499265':{'de': 'Pressig', 'en': 'Pressig'},
 '499266':{'de': 'Mitwitz', 'en': 'Mitwitz'},
 '499267':{'de': 'Nordhalben', 'en': 'Nordhalben'},
 '499260':{'de': 'Wilhelmsthal Oberfranken', 'en': 'Wilhelmsthal Oberfranken'},
 '499261':{'de': 'Kronach', 'en': 'Kronach'},
 '499262':{'de': 'Wallenfels', 'en': 'Wallenfels'},
 '499263':{'de': 'Ludwigsstadt', 'en': 'Ludwigsstadt'},
 '499268':{'de': 'Teuschnitz', 'en': 'Teuschnitz'},
 '499269':{'de': 'Tettau Kreis Kronach', 'en': 'Tettau Kreis Kronach'},
 '55112488':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112489':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55212249':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143261':{'en': 'Agudos - SP', 'pt': 'Agudos - SP'},
 '55143262':{'en': 'Agudos - SP', 'pt': 'Agudos - SP'},
 '55143263':{'en': u('Len\u00e7\u00f3is Paulista - SP'), 'pt': u('Len\u00e7\u00f3is Paulista - SP')},
 '55143264':{'en': u('Len\u00e7\u00f3is Paulista - SP'), 'pt': u('Len\u00e7\u00f3is Paulista - SP')},
 '55143265':{'en': 'Piratininga - SP', 'pt': 'Piratininga - SP'},
 '55143267':{'en': 'Borebi - SP', 'pt': 'Borebi - SP'},
 '55143268':{'en': 'Macatuba - SP', 'pt': 'Macatuba - SP'},
 '55143269':{'en': u('Len\u00e7\u00f3is Paulista - SP'), 'pt': u('Len\u00e7\u00f3is Paulista - SP')},
 '55212243':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212242':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212244':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212247':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212246':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113689':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113688':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113683':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113682':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113681':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113687':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113686':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113685':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113684':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55242566':{'en': 'Bom Jardim - RJ', 'pt': 'Bom Jardim - RJ'},
 '55183229':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55143404':{'en': u('Tup\u00e3 - SP'), 'pt': u('Tup\u00e3 - SP')},
 '55143405':{'en': u('Pomp\u00e9ia - SP'), 'pt': u('Pomp\u00e9ia - SP')},
 '55143406':{'en': u('Gar\u00e7a - SP'), 'pt': u('Gar\u00e7a - SP')},
 '55143407':{'en': u('Gar\u00e7a - SP'), 'pt': u('Gar\u00e7a - SP')},
 '55183282':{'en': 'Teodoro Sampaio - SP', 'pt': 'Teodoro Sampaio - SP'},
 '55183283':{'en': 'Euclides da Cunha Paulista - SP', 'pt': 'Euclides da Cunha Paulista - SP'},
 '55143402':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55183281':{'en': u('Presidente Epit\u00e1cio - SP'), 'pt': u('Presidente Epit\u00e1cio - SP')},
 '55143408':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55183288':{'en': 'Rosana - SP', 'pt': 'Rosana - SP'},
 '55183289':{'en': 'Tarabai - SP', 'pt': 'Tarabai - SP'},
 '55113531':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113533':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113532':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113535':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113534':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113537':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113536':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113539':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113538':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313395':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55183222':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55222101':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222103':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '543476':{'en': 'San Lorenzo, Santa Fe', 'es': 'San Lorenzo, Santa Fe'},
 '543471':{'en': u('Ca\u00f1ada de G\u00f3mez, Santa Fe'), 'es': u('Ca\u00f1ada de G\u00f3mez, Santa Fe')},
 '55123426':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '543472':{'en': u('Marcos Ju\u00e1rez, C\u00f3rdoba'), 'es': u('Marcos Ju\u00e1rez, C\u00f3rdoba')},
 '55312535':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55162101':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55162102':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55162105':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55162106':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55162107':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55162108':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55162109':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55213198':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193527':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55213194':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323444':{'en': 'Recreio - MG', 'pt': 'Recreio - MG'},
 '55323445':{'en': 'Argirita - MG', 'pt': 'Argirita - MG'},
 '55323446':{'en': 'Palma - MG', 'pt': 'Palma - MG'},
 '55323447':{'en': 'Leopoldina - MG', 'pt': 'Leopoldina - MG'},
 '55163851':{'en': 'Morro Agudo - SP', 'pt': 'Morro Agudo - SP'},
 '55323441':{'en': 'Leopoldina - MG', 'pt': 'Leopoldina - MG'},
 '55323442':{'en': 'Leopoldina - MG', 'pt': 'Leopoldina - MG'},
 '55163852':{'en': 'Sales Oliveira - SP', 'pt': 'Sales Oliveira - SP'},
 '495725':{'de': 'Lindhorst bei Stadthagen', 'en': 'Lindhorst bei Stadthagen'},
 '495724':{'de': 'Obernkirchen', 'en': 'Obernkirchen'},
 '495726':{'de': 'Wiedensahl', 'en': 'Wiedensahl'},
 '495721':{'de': 'Stadthagen', 'en': 'Stadthagen'},
 '55323449':{'en': 'Leopoldina - MG', 'pt': 'Leopoldina - MG'},
 '495723':{'de': 'Bad Nenndorf', 'en': 'Bad Nenndorf'},
 '495722':{'de': u('B\u00fcckeburg'), 'en': u('B\u00fcckeburg')},
 '511':{'en': 'Lima/Callao'},
 '497765':{'de': 'Rickenbach Hotzenwald', 'en': 'Rickenbach Hotzenwald'},
 '497764':{'de': 'Herrischried', 'en': 'Herrischried'},
 '497763':{'de': 'Murg', 'en': 'Murg'},
 '497762':{'de': 'Wehr Baden', 'en': 'Wehr Baden'},
 '497761':{'de': u('Bad S\u00e4ckingen'), 'en': u('Bad S\u00e4ckingen')},
 '55195657':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163663':{'en': u('Jardin\u00f3polis - SP'), 'pt': u('Jardin\u00f3polis - SP')},
 '495541':{'de': u('Hann. M\u00fcnden'), 'en': u('Hann. M\u00fcnden')},
 '55185821':{'en': 'Dracena - SP', 'pt': 'Dracena - SP'},
 '495543':{'de': 'Staufenberg Niedersachsen', 'en': 'Staufenberg Niedersachsen'},
 '495542':{'de': 'Witzenhausen', 'en': 'Witzenhausen'},
 '495545':{'de': u('Hedem\u00fcnden'), 'en': u('Hedem\u00fcnden')},
 '495544':{'de': 'Reinhardshagen', 'en': 'Reinhardshagen'},
 '495546':{'de': 'Scheden', 'en': 'Scheden'},
 '5521':{'en': 'Rio de Janeiro', 'pt': 'Rio de Janeiro'},
 '55333243':{'en': 'Central de Minas - MG', 'pt': 'Central de Minas - MG'},
 '55113916':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115685':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115687':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115686':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115681':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115683':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115682':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55322152':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '499805':{'de': 'Burgoberbach', 'en': 'Burgoberbach'},
 '55143764':{'en': 'Iaras - SP', 'pt': 'Iaras - SP'},
 '55213323':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497943':{'de': u('Sch\u00f6ntal Jagst'), 'en': u('Sch\u00f6ntal Jagst')},
 '497942':{'de': u('Neuenstein W\u00fcrttemberg'), 'en': u('Neuenstein W\u00fcrttemberg')},
 '497941':{'de': u('\u00d6hringen'), 'en': u('\u00d6hringen')},
 '497940':{'de': u('K\u00fcnzelsau'), 'en': u('K\u00fcnzelsau')},
 '497947':{'de': 'Forchtenberg', 'en': 'Forchtenberg'},
 '497946':{'de': 'Bretzfeld', 'en': 'Bretzfeld'},
 '497945':{'de': u('W\u00fcstenrot'), 'en': u('W\u00fcstenrot')},
 '497944':{'de': 'Kupferzell', 'en': 'Kupferzell'},
 '497949':{'de': 'Pfedelbach-Untersteinbach', 'en': 'Pfedelbach-Untersteinbach'},
 '497948':{'de': u('\u00d6hringen-Ohrnberg'), 'en': u('\u00d6hringen-Ohrnberg')},
 '55163221':{'en': u('Mat\u00e3o - SP'), 'pt': u('Mat\u00e3o - SP')},
 '55313858':{'en': u('Dion\u00edsio - MG'), 'pt': u('Dion\u00edsio - MG')},
 '55313779':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55313771':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55313775':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55183502':{'en': 'Adamantina - SP', 'pt': 'Adamantina - SP'},
 '495302':{'de': 'Vechelde', 'en': 'Vechelde'},
 '55313824':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '55313855':{'en': u('Alvin\u00f3polis - MG'), 'pt': u('Alvin\u00f3polis - MG')},
 '55113057':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113054':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273337':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55113052':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113050':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113051':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113059':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183871':{'en': 'Panorama - SP', 'pt': 'Panorama - SP'},
 '495444':{'de': 'Wagenfeld', 'en': 'Wagenfeld'},
 '55313559':{'en': 'Ouro Preto - MG', 'pt': 'Ouro Preto - MG'},
 '55273332':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55213104':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313554':{'en': 'Lavras Novas - MG', 'pt': 'Lavras Novas - MG'},
 '55313557':{'en': 'Mariana - MG', 'pt': 'Mariana - MG'},
 '55273333':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55313551':{'en': 'Ouro Preto - MG', 'pt': 'Ouro Preto - MG'},
 '55213107':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313553':{'en': 'Cachoeira do Campo - MG', 'pt': 'Cachoeira do Campo - MG'},
 '55313552':{'en': 'Ouro Preto - MG', 'pt': 'Ouro Preto - MG'},
 '499721':{'de': 'Schweinfurt', 'en': 'Schweinfurt'},
 '55114225':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '499723':{'de': u('R\u00f6thlein'), 'en': u('R\u00f6thlein')},
 '499722':{'de': 'Werneck', 'en': 'Werneck'},
 '499725':{'de': 'Poppenhausen Unterfranken', 'en': 'Poppenhausen Unterfranken'},
 '499724':{'de': 'Stadtlauringen', 'en': 'Stadtlauringen'},
 '499727':{'de': 'Schonungen-Marktsteinach', 'en': 'Schonungen-Marktsteinach'},
 '499726':{'de': 'Euerbach', 'en': 'Euerbach'},
 '499729':{'de': 'Grettstadt', 'en': 'Grettstadt'},
 '499728':{'de': u('W\u00fclfershausen Unterfranken'), 'en': u('W\u00fclfershausen Unterfranken')},
 '496321':{'de': u('Neustadt an der Weinstra\u00dfe'), 'en': 'Neustadt an der Weinstrasse'},
 '55114228':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55114229':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55113948':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113949':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193304':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193305':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193302':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55213103':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55193301':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55113941':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113942':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113943':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113237':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113234':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113235':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213978':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213970':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213974':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213976':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213977':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153298':{'en': 'Pilar do Sul - SP', 'pt': 'Pilar do Sul - SP'},
 '55153299':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55153291':{'en': u('Ara\u00e7oiaba da Serra - SP'), 'pt': u('Ara\u00e7oiaba da Serra - SP')},
 '55153292':{'en': 'Salto de Pirapora - SP', 'pt': 'Salto de Pirapora - SP'},
 '55153293':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153294':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55153297':{'en': u('Ara\u00e7oiaba da Serra - SP'), 'pt': u('Ara\u00e7oiaba da Serra - SP')},
 '499099':{'de': 'Kaisheim', 'en': 'Kaisheim'},
 '55313859':{'en': u('Jo\u00e3o Monlevade - MG'), 'pt': u('Jo\u00e3o Monlevade - MG')},
 '55242236':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '499093':{'de': 'Polsingen', 'en': 'Polsingen'},
 '499092':{'de': 'Wemding', 'en': 'Wemding'},
 '499091':{'de': 'Monheim Schwaben', 'en': 'Monheim Schwaben'},
 '499090':{'de': 'Rain Lech', 'en': 'Rain Lech'},
 '499097':{'de': 'Marxheim', 'en': 'Marxheim'},
 '55313338':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '499094':{'de': 'Tagmersheim', 'en': 'Tagmersheim'},
 '55182102':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55193336':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55212256':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55182103':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55112549':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112019':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112018':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112015':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112547':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112010':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112013':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113068':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55182101':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '49791':{'de': u('Schw\u00e4bisch Hall'), 'en': u('Schw\u00e4bisch Hall')},
 '55183349':{'en': 'Frutal do Campo - SP', 'pt': 'Frutal do Campo - SP'},
 '55183341':{'en': u('C\u00e2ndido Mota - SP'), 'pt': u('C\u00e2ndido Mota - SP')},
 '55183345':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55143492':{'en': 'Vera Cruz - SP', 'pt': 'Vera Cruz - SP'},
 '55323233':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323232':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '495971':{'de': 'Rheine', 'en': 'Rheine'},
 '495973':{'de': 'Neuenkirchen Kreis Steinfurt', 'en': 'Neuenkirchen Kreis Steinfurt'},
 '495975':{'de': 'Rheine-Mesum', 'en': 'Rheine-Mesum'},
 '495976':{'de': 'Salzbergen', 'en': 'Salzbergen'},
 '495977':{'de': 'Spelle', 'en': 'Spelle'},
 '495978':{'de': u('H\u00f6rstel-Dreierwalde'), 'en': u('H\u00f6rstel-Dreierwalde')},
 '55323235':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55123848':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123849':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123845':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123842':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123843':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55214503':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212768':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55212769':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '496373':{'de': u('Sch\u00f6nenberg-K\u00fcbelberg'), 'en': u('Sch\u00f6nenberg-K\u00fcbelberg')},
 '496372':{'de': u('Bruchm\u00fchlbach-Miesau'), 'en': u('Bruchm\u00fchlbach-Miesau')},
 '496371':{'de': 'Landstuhl', 'en': 'Landstuhl'},
 '55212767':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '496375':{'de': 'Wallhalben', 'en': 'Wallhalben'},
 '496374':{'de': 'Weilerbach', 'en': 'Weilerbach'},
 '55114255':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114256':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55273071':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '52461':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55134002':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55134003':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55134004':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133422':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55193444':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55193447':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55115555':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173272':{'en': 'Tanabi - SP', 'pt': 'Tanabi - SP'},
 '55193446':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55173274':{'en': 'Tanabi - SP', 'pt': 'Tanabi - SP'},
 '55173275':{'en': u('Monte Apraz\u00edvel - SP'), 'pt': u('Monte Apraz\u00edvel - SP')},
 '55114419':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114418':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114417':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114416':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114415':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114414':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114413':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114412':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114411':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55115907':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193443':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55193442':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55213419':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213418':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497532':{'de': 'Meersburg', 'en': 'Meersburg'},
 '497021':{'de': 'Kirchheim unter Teck', 'en': 'Kirchheim unter Teck'},
 '497022':{'de': u('N\u00fcrtingen'), 'en': u('N\u00fcrtingen')},
 '497023':{'de': 'Weilheim an der Teck', 'en': 'Weilheim an der Teck'},
 '497024':{'de': 'Wendlingen am Neckar', 'en': 'Wendlingen am Neckar'},
 '497025':{'de': 'Neuffen', 'en': 'Neuffen'},
 '497026':{'de': 'Lenningen', 'en': 'Lenningen'},
 '494942':{'de': u('S\u00fcdbrookmerland'), 'en': u('S\u00fcdbrookmerland')},
 '494943':{'de': 'Grossefehn', 'en': 'Grossefehn'},
 '55153461':{'en': 'Porto Feliz - SP', 'pt': 'Porto Feliz - SP'},
 '494941':{'de': 'Aurich', 'en': 'Aurich'},
 '494946':{'de': 'Grossefehn-Bagband', 'en': 'Grossefehn-Bagband'},
 '494947':{'de': 'Aurich-Ogenbargen', 'en': 'Aurich-Ogenbargen'},
 '494944':{'de': 'Wiesmoor', 'en': 'Wiesmoor'},
 '494945':{'de': 'Grossefehn-Timmel', 'en': 'Grossefehn-Timmel'},
 '494948':{'de': 'Wiesmoor-Marcardsmoor', 'en': 'Wiesmoor-Marcardsmoor'},
 '55113206':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113205':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133251':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55115090':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113203':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115092':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115094':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115095':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115097':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113201':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313123':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313128':{'en': 'Jaboticatubas - MG', 'pt': 'Jaboticatubas - MG'},
 '55222644':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '55222645':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '55313651':{'en': u('Caet\u00e9 - MG'), 'pt': u('Caet\u00e9 - MG')},
 '498624':{'de': 'Obing', 'en': 'Obing'},
 '498623':{'de': 'Kirchweidach', 'en': 'Kirchweidach'},
 '498622':{'de': 'Tacherting-Peterskirchen', 'en': 'Tacherting-Peterskirchen'},
 '498621':{'de': 'Trostberg', 'en': 'Trostberg'},
 '498629':{'de': 'Palling', 'en': 'Palling'},
 '498628':{'de': 'Kienberg Oberbayern', 'en': 'Kienberg Oberbayern'},
 '494366':{'de': u('Gr\u00f6mitz-Cismar'), 'en': u('Gr\u00f6mitz-Cismar')},
 '494367':{'de': 'Grossenbrode', 'en': 'Grossenbrode'},
 '494364':{'de': 'Dahme Kreis Ostholstein', 'en': 'Dahme Kreis Ostholstein'},
 '494365':{'de': 'Heringsdorf Holstein', 'en': 'Heringsdorf Holstein'},
 '494362':{'de': 'Heiligenhafen', 'en': 'Heiligenhafen'},
 '494363':{'de': 'Lensahn', 'en': 'Lensahn'},
 '494361':{'de': 'Oldenburg in Holstein', 'en': 'Oldenburg in Holstein'},
 '55213325':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323578':{'en': 'Guidoval - MG', 'pt': 'Guidoval - MG'},
 '49541':{'de': u('Osnabr\u00fcck'), 'en': u('Osnabr\u00fcck')},
 '55273744':{'en': 'Governador Lindenberg - ES', 'pt': 'Governador Lindenberg - ES'},
 '55163415':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55115855':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163411':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163413':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163412':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '499288':{'de': 'Bad Steben', 'en': 'Bad Steben'},
 '499289':{'de': 'Schwarzenbach am Wald', 'en': 'Schwarzenbach am Wald'},
 '499286':{'de': 'Oberkotzau', 'en': 'Oberkotzau'},
 '499287':{'de': 'Selb', 'en': 'Selb'},
 '499284':{'de': 'Schwarzenbach an der Saale', 'en': 'Schwarzenbach an der Saale'},
 '499285':{'de': 'Kirchenlamitz', 'en': 'Kirchenlamitz'},
 '499282':{'de': 'Naila', 'en': 'Naila'},
 '499283':{'de': 'Rehau', 'en': 'Rehau'},
 '499280':{'de': 'Selbitz Oberfranken', 'en': 'Selbitz Oberfranken'},
 '499281':{'de': 'Hof Saale', 'en': 'Hof Saale'},
 '542296':{'en': 'Ayacucho, Buenos Aires', 'es': 'Ayacucho, Buenos Aires'},
 '55193798':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '542297':{'en': 'Rauch, Buenos Aires', 'es': 'Rauch, Buenos Aires'},
 '55193795':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193794':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193797':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193796':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113834':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212222':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212221':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193792':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '499088':{'de': u('M\u00f6nchsdeggingen'), 'en': u('M\u00f6nchsdeggingen')},
 '499089':{'de': 'Bissingen-Unterringingen', 'en': 'Bissingen-Unterringingen'},
 '55213321':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143425':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55212595':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499084':{'de': 'Bissingen Schwaben', 'en': 'Bissingen Schwaben'},
 '55212591':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212590':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212593':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212592':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113836':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113556':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113555':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113554':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113552':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113559':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112978':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112979':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112972':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112973':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112970':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55112971':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112976':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112977':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112974':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112975':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115852':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112486':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114789':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55112487':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114787':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '543456':{'en': u('Chajar\u00ed, Entre R\u00edos'), 'es': u('Chajar\u00ed, Entre R\u00edos')},
 '543455':{'en': u('Villaguay, Entre R\u00edos'), 'es': u('Villaguay, Entre R\u00edos')},
 '543454':{'en': u('Federal, Entre R\u00edos'), 'es': u('Federal, Entre R\u00edos')},
 '55114783':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55112484':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112954':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313757':{'en': 'Itaverava - MG', 'pt': 'Itaverava - MG'},
 '55112485':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112950':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213322':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55115853':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112483':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '495707':{'de': 'Petershagen Weser', 'en': 'Petershagen Weser'},
 '495706':{'de': 'Porta Westfalica', 'en': 'Porta Westfalica'},
 '495705':{'de': 'Petershagen-Windheim', 'en': 'Petershagen-Windheim'},
 '495704':{'de': 'Petershagen-Friedewalde', 'en': 'Petershagen-Friedewalde'},
 '495703':{'de': 'Hille', 'en': 'Hille'},
 '495702':{'de': 'Petershagen-Lahde', 'en': 'Petershagen-Lahde'},
 '55323462':{'en': u('Al\u00e9m Para\u00edba - MG'), 'pt': u('Al\u00e9m Para\u00edba - MG')},
 '55323463':{'en': 'Volta Grande - MG', 'pt': 'Volta Grande - MG'},
 '55112481':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112955':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323464':{'en': 'Estrela Dalva - MG', 'pt': 'Estrela Dalva - MG'},
 '55323465':{'en': 'Pirapetinga - MG', 'pt': 'Pirapetinga - MG'},
 '55112958':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112956':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112959':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497703':{'de': 'Bonndorf im Schwarzwald', 'en': 'Bonndorf im Schwarzwald'},
 '497702':{'de': 'Blumberg Baden', 'en': 'Blumberg Baden'},
 '497705':{'de': 'Wolterdingen Schwarzw', 'en': 'Wolterdingen Schwarzw'},
 '497704':{'de': 'Geisingen Baden', 'en': 'Geisingen Baden'},
 '497707':{'de': u('Br\u00e4unlingen'), 'en': u('Br\u00e4unlingen')},
 '497706':{'de': 'Oberbaldingen', 'en': 'Oberbaldingen'},
 '497709':{'de': 'Wutach', 'en': 'Wutach'},
 '497708':{'de': 'Geisingen-Leipferdingen', 'en': 'Geisingen-Leipferdingen'},
 '495563':{'de': 'Kreiensen', 'en': 'Kreiensen'},
 '495562':{'de': 'Dassel-Markoldendorf', 'en': 'Dassel-Markoldendorf'},
 '495561':{'de': 'Einbeck', 'en': 'Einbeck'},
 '495565':{'de': 'Einbeck-Wenzen', 'en': 'Einbeck-Wenzen'},
 '495564':{'de': 'Dassel', 'en': 'Dassel'},
 '55112957':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112201':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115522':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112203':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112204':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112205':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112206':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112207':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123108':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '5042239':{'en': 'Miraflores'},
 '55123103':{'en': 'Cachoeira Paulista - SP', 'pt': 'Cachoeira Paulista - SP'},
 '55123102':{'en': 'Silveiras - SP', 'pt': 'Silveiras - SP'},
 '5042235':{'en': 'Miraflores'},
 '55123107':{'en': 'Areias - SP', 'pt': 'Areias - SP'},
 '5042232':{'en': 'Miraflores'},
 '5042231':{'en': 'Miraflores'},
 '5042230':{'en': 'Kennedy, Tegucigalpa'},
 '55212241':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212240':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55115663':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115661':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115660':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112951':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115666':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52728':{'en': 'Lerma/Santa Maria Atarasquillo, MEX', 'es': u('Lerma/Santa Mar\u00eda Atarasquillo, MEX')},
 '55115669':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115668':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543873':{'en': 'Tartagal, Salta', 'es': 'Tartagal, Salta'},
 '55242243':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242244':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242245':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '543877':{'en': u('Joaqu\u00edn V\u00edctor Gonz\u00e1lez, Salta'), 'es': u('Joaqu\u00edn V\u00edctor Gonz\u00e1lez, Salta')},
 '543876':{'en': u('San Jos\u00e9 de Met\u00e1n, Salta'), 'es': u('San Jos\u00e9 de Met\u00e1n, Salta')},
 '55242248':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '543878':{'en': u('Or\u00e1n, Salta'), 'es': u('Or\u00e1n, Salta')},
 '52836':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52835':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52834':{'en': 'Ciudad Victoria, TAMPS', 'es': 'Ciudad Victoria, TAMPS'},
 '52833':{'en': 'Tampico, TAMPS', 'es': 'Tampico, TAMPS'},
 '52832':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52831':{'en': 'Ciudad Mante/Los Aztecas, TAMPS', 'es': 'Ciudad Mante/Los Aztecas, TAMPS'},
 '55112953':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496031':{'de': 'Friedberg Hessen', 'en': 'Friedberg Hessen'},
 '496032':{'de': 'Bad Nauheim', 'en': 'Bad Nauheim'},
 '496033':{'de': 'Butzbach', 'en': 'Butzbach'},
 '496034':{'de': u('W\u00f6llstadt'), 'en': u('W\u00f6llstadt')},
 '496035':{'de': 'Reichelsheim Wetterau', 'en': 'Reichelsheim Wetterau'},
 '496036':{'de': u('W\u00f6lfersheim'), 'en': u('W\u00f6lfersheim')},
 '496039':{'de': 'Karben', 'en': 'Karben'},
 '55133284':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '542477':{'en': 'Pergamino, Buenos Aires', 'es': 'Pergamino, Buenos Aires'},
 '542474':{'en': 'Salto, Buenos Aires', 'es': 'Salto, Buenos Aires'},
 '542475':{'en': 'Rojas, Buenos Aires', 'es': 'Rojas, Buenos Aires'},
 '542473':{'en': u('Col\u00f3n, Buenos Aires'), 'es': u('Col\u00f3n, Buenos Aires')},
 '55313718':{'en': 'Baldim - MG', 'pt': 'Baldim - MG'},
 '55313717':{'en': 'Santana de Pirapama - MG', 'pt': 'Santana de Pirapama - MG'},
 '55313716':{'en': u('Inha\u00fama - MG'), 'pt': u('Inha\u00fama - MG')},
 '55313715':{'en': 'Cordisburgo - MG', 'pt': 'Cordisburgo - MG'},
 '55313714':{'en': 'Paraopeba - MG', 'pt': 'Paraopeba - MG'},
 '55313713':{'en': 'Capim Branco - MG', 'pt': 'Capim Branco - MG'},
 '55313712':{'en': 'Matozinhos - MG', 'pt': 'Matozinhos - MG'},
 '542478':{'en': 'Arrecifes, Buenos Aires', 'es': 'Arrecifes, Buenos Aires'},
 '52349':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52348':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52345':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52344':{'en': 'Mexticacan/Yahualica, JAL', 'es': 'Mexticacan/Yahualica, JAL'},
 '52347':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55113037':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52341':{'en': 'Ciudad Guzman, JAL', 'es': u('Ciudad Guzm\u00e1n, JAL')},
 '55113031':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52343':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52342':{'en': 'Gomez Farias/Sayula, JAL', 'es': u('G\u00f3mez Far\u00edas/Sayula, JAL')},
 '55323264':{'en': u('Guarar\u00e1 - MG'), 'pt': u('Guarar\u00e1 - MG')},
 '55323265':{'en': 'Descoberto - MG', 'pt': 'Descoberto - MG'},
 '55173489':{'en': u('Brasit\u00e2nia - SP'), 'pt': u('Brasit\u00e2nia - SP')},
 '55114209':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55194113':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55323262':{'en': 'Rochedo de Minas - MG', 'pt': 'Rochedo de Minas - MG'},
 '55323263':{'en': u('Marip\u00e1 de Minas - MG'), 'pt': u('Marip\u00e1 de Minas - MG')},
 '55114202':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55173482':{'en': 'Auriflama - SP', 'pt': 'Auriflama - SP'},
 '55173481':{'en': u('S\u00e3o Jo\u00e3o das Duas Pontes - SP'), 'pt': u('S\u00e3o Jo\u00e3o das Duas Pontes - SP')},
 '55114201':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114206':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55173486':{'en': u('\u00c1lvares Florence - SP'), 'pt': u('\u00c1lvares Florence - SP')},
 '55114204':{'en': u('Ara\u00e7ariguama - SP'), 'pt': u('Ara\u00e7ariguama - SP')},
 '55114205':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '499708':{'de': 'Bad Bocklet', 'en': 'Bad Bocklet'},
 '494559':{'de': 'Wensin', 'en': 'Wensin'},
 '494558':{'de': 'Todesfelde', 'en': 'Todesfelde'},
 '494555':{'de': 'Seedorf bei Bad Segeberg', 'en': 'Seedorf bei Bad Segeberg'},
 '494554':{'de': 'Wahlstedt', 'en': 'Wahlstedt'},
 '494885':{'de': 'Bergenhusen', 'en': 'Bergenhusen'},
 '494884':{'de': 'Schwabstedt', 'en': 'Schwabstedt'},
 '494883':{'de': u('S\u00fcderstapel'), 'en': u('S\u00fcderstapel')},
 '494882':{'de': 'Lunden', 'en': 'Lunden'},
 '499873':{'de': 'Abenberg-Wassermungenau', 'en': 'Abenberg-Wassermungenau'},
 '494552':{'de': 'Leezen', 'en': 'Leezen'},
 '55113782':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113783':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113781':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113787':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113784':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113785':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113966':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113788':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113965':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113962':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113961':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55314111':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '494779':{'de': 'Freiburg Elbe', 'en': 'Freiburg Elbe'},
 '494778':{'de': 'Wingst', 'en': 'Wingst'},
 '494771':{'de': 'Hemmoor', 'en': 'Hemmoor'},
 '494770':{'de': 'Wischhafen', 'en': 'Wischhafen'},
 '494773':{'de': 'Lamstedt', 'en': 'Lamstedt'},
 '494772':{'de': 'Oberndorf Oste', 'en': 'Oberndorf Oste'},
 '494775':{'de': u('Grossenw\u00f6rden'), 'en': u('Grossenw\u00f6rden')},
 '494774':{'de': 'Hechthausen', 'en': 'Hechthausen'},
 '494777':{'de': 'Cadenberge', 'en': 'Cadenberge'},
 '494776':{'de': 'Osten-Altendorf', 'en': 'Osten-Altendorf'},
 '55323694':{'en': 'Leopoldina - MG', 'pt': 'Leopoldina - MG'},
 '55323696':{'en': u('Muria\u00e9 - MG'), 'pt': u('Muria\u00e9 - MG')},
 '55323691':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323693':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55112785':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112784':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112787':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112781':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112783':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183286':{'en': 'Anhumas - SP', 'pt': 'Anhumas - SP'},
 '55153141':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55183287':{'en': 'Campinal - SP', 'pt': 'Campinal - SP'},
 '55183284':{'en': 'Rosana - SP', 'pt': 'Rosana - SP'},
 '55114606':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55143656':{'en': 'Torrinha - SP', 'pt': 'Torrinha - SP'},
 '55183981':{'en': 'Mirante do Paranapanema - SP', 'pt': 'Mirante do Paranapanema - SP'},
 '55133351':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55143653':{'en': 'Brotas - SP', 'pt': 'Brotas - SP'},
 '55114607':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55193366':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55114604':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55193362':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55193363':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55114605':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114602':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55112561':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112562':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112565':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193883':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55112567':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112566':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112569':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112568':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114601':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55163601':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163603':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163604':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163605':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163607':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163951':{'en': 'Cravinhos - SP', 'pt': 'Cravinhos - SP'},
 '55163952':{'en': 'Pitangueiras - SP', 'pt': 'Pitangueiras - SP'},
 '55163953':{'en': 'Pontal - SP', 'pt': 'Pontal - SP'},
 '55163954':{'en': 'Santa Rosa de Viterbo - SP', 'pt': 'Santa Rosa de Viterbo - SP'},
 '55163956':{'en': 'Pontal - SP', 'pt': 'Pontal - SP'},
 '55163957':{'en': u('Ibiti\u00fava - SP'), 'pt': u('Ibiti\u00fava - SP')},
 '55163958':{'en': 'Taquaral - SP', 'pt': 'Taquaral - SP'},
 '499155':{'de': 'Simmelsdorf', 'en': 'Simmelsdorf'},
 '55183361':{'en': u('Paragua\u00e7u Paulista - SP'), 'pt': u('Paragua\u00e7u Paulista - SP')},
 '55193589':{'en': 'Porto Ferreira - SP', 'pt': 'Porto Ferreira - SP'},
 '55183362':{'en': u('Paragua\u00e7u Paulista - SP'), 'pt': u('Paragua\u00e7u Paulista - SP')},
 '55183367':{'en': u('Bor\u00e1 - SP'), 'pt': u('Bor\u00e1 - SP')},
 '55183366':{'en': u('Quat\u00e1 - SP'), 'pt': u('Quat\u00e1 - SP')},
 '55183368':{'en': u('Lut\u00e9cia - SP'), 'pt': u('Lut\u00e9cia - SP')},
 '55193582':{'en': 'Santa Rita do Passa Quatro - SP', 'pt': 'Santa Rita do Passa Quatro - SP'},
 '55193583':{'en': 'Descalvado - SP', 'pt': 'Descalvado - SP'},
 '55193584':{'en': 'Santa Rita do Passa Quatro - SP', 'pt': 'Santa Rita do Passa Quatro - SP'},
 '55193585':{'en': 'Porto Ferreira - SP', 'pt': 'Porto Ferreira - SP'},
 '5269':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '55124104':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55124109':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55212780':{'en': 'Mangaratiba - RJ', 'pt': 'Mangaratiba - RJ'},
 '55212787':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55212789':{'en': 'Mangaratiba - RJ', 'pt': 'Mangaratiba - RJ'},
 '55194002':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193979':{'en': 'Monte Mor - SP', 'pt': 'Monte Mor - SP'},
 '542648':{'en': 'Calingasta, San Juan', 'es': 'Calingasta, San Juan'},
 '542647':{'en': u('San Jos\u00e9 de J\u00e1chal, San Juan'), 'es': u('San Jos\u00e9 de J\u00e1chal, San Juan')},
 '542646':{'en': u('Villa San Agust\u00edn, San Juan'), 'es': u('Villa San Agust\u00edn, San Juan')},
 '55193977':{'en': 'Artur Nogueira - SP', 'pt': 'Artur Nogueira - SP'},
 '55213789':{'en': 'Mangaratiba - RJ', 'pt': 'Mangaratiba - RJ'},
 '55213781':{'en': u('Itagua\u00ed - RJ'), 'pt': u('Itagua\u00ed - RJ')},
 '55213780':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55213787':{'en': u('Serop\u00e9dica - RJ'), 'pt': u('Serop\u00e9dica - RJ')},
 '55114435':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114434':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114437':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114436':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114431':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55173253':{'en': 'Mirassol - SP', 'pt': 'Mirassol - SP'},
 '55114433':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114432':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55222105':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55114439':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114438':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55173258':{'en': 'Bady Bassitt - SP', 'pt': 'Bady Bassitt - SP'},
 '497042':{'de': 'Vaihingen an der Enz', 'en': 'Vaihingen an der Enz'},
 '497043':{'de': 'Maulbronn', 'en': 'Maulbronn'},
 '497041':{'de': u('M\u00fchlacker'), 'en': u('M\u00fchlacker')},
 '497046':{'de': 'Zaberfeld', 'en': 'Zaberfeld'},
 '497044':{'de': u('M\u00f6nsheim'), 'en': u('M\u00f6nsheim')},
 '497045':{'de': 'Oberderdingen', 'en': 'Oberderdingen'},
 '55222106':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55213431':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213433':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213432':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213434':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494968':{'de': 'Neulehe', 'en': 'Neulehe'},
 '494964':{'de': 'Rhede Ems', 'en': 'Rhede Ems'},
 '494965':{'de': 'Surwold', 'en': 'Surwold'},
 '494966':{'de': u('Neub\u00f6rger'), 'en': u('Neub\u00f6rger')},
 '494967':{'de': 'Rhauderfehn-Burlage', 'en': 'Rhauderfehn-Burlage'},
 '494961':{'de': 'Papenburg', 'en': 'Papenburg'},
 '494962':{'de': 'Papenburg-Aschendorf', 'en': 'Papenburg-Aschendorf'},
 '494963':{'de': u('D\u00f6rpen'), 'en': u('D\u00f6rpen')},
 '55133506':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133507':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133505':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133500':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55153624':{'en': 'Itapeva - SP', 'pt': 'Itapeva - SP'},
 '55242471':{'en': 'Vassouras - RJ', 'pt': 'Vassouras - RJ'},
 '55163389':{'en': u('S\u00e3o Louren\u00e7o do Turvo - SP'), 'pt': u('S\u00e3o Louren\u00e7o do Turvo - SP')},
 '55163385':{'en': 'Tabatinga - SP', 'pt': 'Tabatinga - SP'},
 '55163384':{'en': u('Mat\u00e3o - SP'), 'pt': u('Mat\u00e3o - SP')},
 '55163387':{'en': 'Nova Europa - SP', 'pt': 'Nova Europa - SP'},
 '55163386':{'en': 'Dobrada - SP', 'pt': 'Dobrada - SP'},
 '55242237':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55163383':{'en': u('Mat\u00e3o - SP'), 'pt': u('Mat\u00e3o - SP')},
 '55163382':{'en': u('Mat\u00e3o - SP'), 'pt': u('Mat\u00e3o - SP')},
 '498641':{'de': 'Grassau Kreis Traunstein', 'en': 'Grassau Kreis Traunstein'},
 '498640':{'de': 'Reit Im Winkl', 'en': 'Reit Im Winkl'},
 '498867':{'de': 'Rottenbuch Oberbayern', 'en': 'Rottenbuch Oberbayern'},
 '498642':{'de': u('\u00dcbersee'), 'en': u('\u00dcbersee')},
 '498861':{'de': 'Schongau', 'en': 'Schongau'},
 '498860':{'de': 'Bernbeuren', 'en': 'Bernbeuren'},
 '498862':{'de': 'Steingaden Oberbayern', 'en': 'Steingaden Oberbayern'},
 '498649':{'de': 'Schleching', 'en': 'Schleching'},
 '55242231':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '498869':{'de': 'Kinsau', 'en': 'Kinsau'},
 '498868':{'de': 'Schwabsoien', 'en': 'Schwabsoien'},
 '494340':{'de': 'Achterwehr', 'en': 'Achterwehr'},
 '494342':{'de': u('Preetz Kreis Pl\u00f6n'), 'en': u('Preetz Kreis Pl\u00f6n')},
 '494343':{'de': 'Laboe', 'en': 'Laboe'},
 '494344':{'de': u('Sch\u00f6nberg Holstein'), 'en': u('Sch\u00f6nberg Holstein')},
 '55242233':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '494346':{'de': 'Gettorf', 'en': 'Gettorf'},
 '494347':{'de': 'Flintbek', 'en': 'Flintbek'},
 '494348':{'de': u('Sch\u00f6nkirchen'), 'en': u('Sch\u00f6nkirchen')},
 '494349':{'de': u('D\u00e4nischenhagen'), 'en': u('D\u00e4nischenhagen')},
 '55242232':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55332102':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55332101':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55113345':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313458':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213899':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183351':{'en': 'Palmital - SP', 'pt': 'Palmital - SP'},
 '55132101':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55213896':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55213895':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313453':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55132105':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55313107':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55213891':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213890':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112069':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143224':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143226':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143227':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143221':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55143222':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143223':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55193773':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193772':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212206':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212201':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193775':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193779':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193778':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212209':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212208':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193306':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55213844':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55213845':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55213847':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193307':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55323293':{'en': 'Liberdade - MG', 'pt': 'Liberdade - MG'},
 '55323295':{'en': 'Passa-Vinte - MG', 'pt': 'Passa-Vinte - MG'},
 '55113578':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113576':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113572':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213239':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213238':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213233':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163859':{'en': u('Orl\u00e2ndia - SP'), 'pt': u('Orl\u00e2ndia - SP')},
 '55213231':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213237':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213236':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55213235':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213234':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112990':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112991':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112992':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112993':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112994':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112995':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112996':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112997':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112998':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323296':{'en': 'Arantina - MG', 'pt': 'Arantina - MG'},
 '543438':{'en': u('Bovril, Entre R\u00edos'), 'es': u('Bovril, Entre R\u00edos')},
 '543435':{'en': u('Nogoy\u00e1, Entre R\u00edos'), 'es': u('Nogoy\u00e1, Entre R\u00edos')},
 '543437':{'en': u('La Paz, Entre R\u00edos'), 'es': u('La Paz, Entre R\u00edos')},
 '543436':{'en': u('Victoria, Entre R\u00edos'), 'es': u('Victoria, Entre R\u00edos')},
 '499463':{'de': 'Wald Oberpfalz', 'en': 'Wald Oberpfalz'},
 '495761':{'de': 'Stolzenau', 'en': 'Stolzenau'},
 '55213157':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495763':{'de': 'Uchte', 'en': 'Uchte'},
 '55213155':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495765':{'de': 'Raddestorf', 'en': 'Raddestorf'},
 '495764':{'de': 'Steyerberg', 'en': 'Steyerberg'},
 '495767':{'de': 'Warmsen', 'en': 'Warmsen'},
 '495766':{'de': 'Rehburg-Loccum', 'en': 'Rehburg-Loccum'},
 '495769':{'de': 'Steyerberg-Voigtei', 'en': 'Steyerberg-Voigtei'},
 '495768':{'de': 'Petershagen-Heimsen', 'en': 'Petershagen-Heimsen'},
 '55112192':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112193':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112195':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112196':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112197':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313846':{'en': 'Coronel Fabriciano - MG', 'pt': 'Coronel Fabriciano - MG'},
 '497729':{'de': 'Tennenbronn', 'en': 'Tennenbronn'},
 '497728':{'de': 'Niedereschach', 'en': 'Niedereschach'},
 '497723':{'de': 'Furtwangen im Schwarzwald', 'en': 'Furtwangen im Schwarzwald'},
 '497722':{'de': 'Triberg im Schwarzwald', 'en': 'Triberg im Schwarzwald'},
 '497721':{'de': 'Villingen im Schwarzwald', 'en': 'Villingen im Schwarzwald'},
 '497720':{'de': 'Schwenningen am Neckar', 'en': 'Schwenningen am Neckar'},
 '497727':{'de': u('V\u00f6hrenbach'), 'en': u('V\u00f6hrenbach')},
 '497726':{'de': u('Bad D\u00fcrrheim'), 'en': u('Bad D\u00fcrrheim')},
 '497725':{'de': u('K\u00f6nigsfeld im Schwarzwald'), 'en': u('K\u00f6nigsfeld im Schwarzwald')},
 '497724':{'de': 'St Georgen im Schwarzwald', 'en': 'St Georgen im Schwarzwald'},
 '55112228':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112229':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112226':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495584':{'de': 'Hattorf am Harz', 'en': 'Hattorf am Harz'},
 '55112224':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495586':{'de': 'Wieda', 'en': 'Wieda'},
 '55115502':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112223':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495583':{'de': 'Braunlage-Hohegeiss', 'en': 'Braunlage-Hohegeiss'},
 '55112221':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123123':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123122':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123125':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123127':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123126':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '5042211':{'en': 'El Picacho'},
 '55123128':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55222630':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '55313844':{'en': 'Cava Grande - MG', 'pt': 'Cava Grande - MG'},
 '55115641':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115643':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115642':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115645':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115646':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496580':{'de': 'Zemmer', 'en': 'Zemmer'},
 '496581':{'de': 'Saarburg', 'en': 'Saarburg'},
 '496582':{'de': 'Freudenburg', 'en': 'Freudenburg'},
 '496583':{'de': 'Palzem', 'en': 'Palzem'},
 '496584':{'de': 'Wellen Mosel', 'en': 'Wellen Mosel'},
 '496585':{'de': 'Ralingen', 'en': 'Ralingen'},
 '496586':{'de': 'Beuren Hochwald', 'en': 'Beuren Hochwald'},
 '496587':{'de': 'Zerf', 'en': 'Zerf'},
 '496588':{'de': 'Pluwig', 'en': 'Pluwig'},
 '496589':{'de': 'Kell am See', 'en': 'Kell am See'},
 '496234':{'de': 'Mutterstadt', 'en': 'Mutterstadt'},
 '496235':{'de': 'Schifferstadt', 'en': 'Schifferstadt'},
 '496232':{'de': 'Speyer', 'en': 'Speyer'},
 '496233':{'de': 'Frankenthal Pfalz', 'en': 'Frankenthal Pfalz'},
 '496231':{'de': 'Hochdorf-Assenheim', 'en': 'Hochdorf-Assenheim'},
 '55242266':{'en': 'Werneck - RJ', 'pt': 'Werneck - RJ'},
 '543858':{'en': u('Termas de R\u00edo Hondo, Santiago del Estero'), 'es': u('Termas de R\u00edo Hondo, Santiago del Estero')},
 '55242263':{'en': u('Para\u00edba do Sul - RJ'), 'pt': u('Para\u00edba do Sul - RJ')},
 '55313842':{'en': 'Coronel Fabriciano - MG', 'pt': 'Coronel Fabriciano - MG'},
 '55133034':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '497184':{'de': 'Kaisersbach', 'en': 'Kaisersbach'},
 '543857':{'en': 'Bandera, Santiago del Estero', 'es': 'Bandera, Santiago del Estero'},
 '543856':{'en': 'Villa Ojo de Agua, Santiago del Estero', 'es': 'Villa Ojo de Agua, Santiago del Estero'},
 '497181':{'de': u('Schorndorf W\u00fcrttemberg'), 'en': u('Schorndorf W\u00fcrttemberg')},
 '543854':{'en': u('Fr\u00edas, Santiago del Estero'), 'es': u('Fr\u00edas, Santiago del Estero')},
 '55273248':{'en': u('Arac\u00ea - ES'), 'pt': u('Arac\u00ea - ES')},
 '55273249':{'en': 'Paraju - ES', 'pt': 'Paraju - ES'},
 '55313841':{'en': 'Coronel Fabriciano - MG', 'pt': 'Coronel Fabriciano - MG'},
 '55273242':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55273245':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55114893':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '496058':{'de': u('Gr\u00fcndau'), 'en': u('Gr\u00fcndau')},
 '496059':{'de': 'Jossgrund', 'en': 'Jossgrund'},
 '55333082':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '496052':{'de': 'Bad Orb', 'en': 'Bad Orb'},
 '496053':{'de': u('W\u00e4chtersbach'), 'en': u('W\u00e4chtersbach')},
 '496050':{'de': u('Biebergem\u00fcnd'), 'en': u('Biebergem\u00fcnd')},
 '496051':{'de': 'Gelnhausen', 'en': 'Gelnhausen'},
 '496056':{'de': u('Bad Soden-Salm\u00fcnster'), 'en': u('Bad Soden-Salm\u00fcnster')},
 '496057':{'de': u('Fl\u00f6rsbachtal'), 'en': u('Fl\u00f6rsbachtal')},
 '496054':{'de': 'Birstein', 'en': 'Birstein'},
 '496055':{'de': 'Freigericht', 'en': 'Freigericht'},
 '55114895':{'en': u('Nazar\u00e9 Paulista - SP'), 'pt': u('Nazar\u00e9 Paulista - SP')},
 '55114894':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55313735':{'en': 'Jeceaba - MG', 'pt': 'Jeceaba - MG'},
 '55313734':{'en': 'Belo Vale - MG', 'pt': 'Belo Vale - MG'},
 '55114598':{'en': 'Vargem - SP', 'pt': 'Vargem - SP'},
 '55114599':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55313731':{'en': 'Congonhas - MG', 'pt': 'Congonhas - MG'},
 '55313733':{'en': 'Joaquim Murtinho - MG', 'pt': 'Joaquim Murtinho - MG'},
 '55313732':{'en': 'Congonhas - MG', 'pt': 'Congonhas - MG'},
 '55114592':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114593':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114591':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114596':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55114597':{'en': u('Nazar\u00e9 Paulista - SP'), 'pt': u('Nazar\u00e9 Paulista - SP')},
 '55114594':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114595':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55115908':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193308':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113011':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113016':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113014':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113015':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313599':{'en': u('Ibirit\u00e9 - MG'), 'pt': u('Ibirit\u00e9 - MG')},
 '55313591':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313593':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313592':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313595':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313594':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313597':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313596':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '499857':{'de': 'Schopfloch Mittelfranken', 'en': 'Schopfloch Mittelfranken'},
 '499856':{'de': u('D\u00fcrrwangen'), 'en': u('D\u00fcrrwangen')},
 '499855':{'de': 'Dentlein am Forst', 'en': 'Dentlein am Forst'},
 '499854':{'de': 'Wittelshofen', 'en': 'Wittelshofen'},
 '499853':{'de': 'Wilburgstetten', 'en': 'Wilburgstetten'},
 '499852':{'de': 'Feuchtwangen', 'en': 'Feuchtwangen'},
 '499851':{'de': u('Dinkelsb\u00fchl'), 'en': u('Dinkelsb\u00fchl')},
 '55313872':{'en': 'Abre Campo - MG', 'pt': 'Abre Campo - MG'},
 '498454':{'de': 'Karlshuld', 'en': 'Karlshuld'},
 '55113905':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113906':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113907':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '498450':{'de': 'Ingolstadt-Zuchering', 'en': 'Ingolstadt-Zuchering'},
 '498323':{'de': u('Immenstadt im Allg\u00e4u'), 'en': u('Immenstadt im Allg\u00e4u')},
 '55113902':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498321':{'de': 'Sonthofen', 'en': 'Sonthofen'},
 '498458':{'de': 'Gaimersheim', 'en': 'Gaimersheim'},
 '498459':{'de': 'Manching', 'en': 'Manching'},
 '498328':{'de': 'Balderschwang', 'en': 'Balderschwang'},
 '55123023':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55213938':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494753':{'de': 'Balje', 'en': 'Balje'},
 '494752':{'de': 'Neuhaus Oste', 'en': 'Neuhaus Oste'},
 '494751':{'de': 'Otterndorf', 'en': 'Otterndorf'},
 '494757':{'de': 'Wanna', 'en': 'Wanna'},
 '494756':{'de': 'Odisheim', 'en': 'Odisheim'},
 '494755':{'de': 'Ihlienworth', 'en': 'Ihlienworth'},
 '494754':{'de': u('B\u00fclkau'), 'en': u('B\u00fclkau')},
 '494758':{'de': 'Nordleda', 'en': 'Nordleda'},
 '55312571':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55324141':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323343':{'en': u('Senhora dos Rem\u00e9dios - MG'), 'pt': u('Senhora dos Rem\u00e9dios - MG')},
 '55193341':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193345':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55112507':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499324':{'de': 'Dettelbach', 'en': 'Dettelbach'},
 '55112504':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499321':{'de': 'Kitzingen', 'en': 'Kitzingen'},
 '55323345':{'en': 'Alto Rio Doce - MG', 'pt': 'Alto Rio Doce - MG'},
 '55112501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323344':{'en': 'Bias Fortes - MG', 'pt': 'Bias Fortes - MG'},
 '55143844':{'en': u('Prat\u00e2nia - SP'), 'pt': u('Prat\u00e2nia - SP')},
 '55143845':{'en': 'Conchas - SP', 'pt': 'Conchas - SP'},
 '55143846':{'en': u('Arei\u00f3polis - SP'), 'pt': u('Arei\u00f3polis - SP')},
 '55143847':{'en': 'Itatinga - SP', 'pt': 'Itatinga - SP'},
 '55163628':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163629':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163626':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163627':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163624':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163625':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163622':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163623':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163620':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55143841':{'en': u('S\u00e3o Manuel - SP'), 'pt': u('S\u00e3o Manuel - SP')},
 '55163976':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163977':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163974':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163975':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163972':{'en': 'Bonfim Paulista - SP', 'pt': 'Bonfim Paulista - SP'},
 '55143842':{'en': u('S\u00e3o Manuel - SP'), 'pt': u('S\u00e3o Manuel - SP')},
 '542936':{'en': u('Carhu\u00e9, Buenos Aires'), 'es': u('Carhu\u00e9, Buenos Aires')},
 '542935':{'en': 'Rivera, Buenos Aires', 'es': 'Rivera, Buenos Aires'},
 '542934':{'en': u('San Antonio Oeste, R\u00edo Negro'), 'es': u('San Antonio Oeste, R\u00edo Negro')},
 '542933':{'en': u('Huanguel\u00e9n, Buenos Aires'), 'es': u('Huanguel\u00e9n, Buenos Aires')},
 '542932':{'en': 'Punta Alta, Buenos Aires', 'es': 'Punta Alta, Buenos Aires'},
 '542931':{'en': u('R\u00edo Colorado, R\u00edo Negro'), 'es': u('R\u00edo Colorado, R\u00edo Negro')},
 '55163979':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55212410':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212411':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212412':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212413':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212414':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '5248':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '55183301':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55212417':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212418':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143848':{'en': 'Itatinga - SP', 'pt': 'Itatinga - SP'},
 '55143849':{'en': 'Bairro de Santana - SP', 'pt': 'Bairro de Santana - SP'},
 '55143343':{'en': 'Canitar - SP', 'pt': 'Canitar - SP'},
 '55193717':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55273033':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55273032':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55273031':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55112431':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55193713':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55112437':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112715':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55112436':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55193249':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193917':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55193913':{'en': 'Itapira - SP', 'pt': 'Itapira - SP'},
 '55193911':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '49841':{'de': 'Ingolstadt Donau', 'en': 'Ingolstadt Donau'},
 '495246':{'de': 'Verl', 'en': 'Verl'},
 '495935':{'de': u('Twist-Sch\u00f6ninghsdorf'), 'en': u('Twist-Sch\u00f6ninghsdorf')},
 '495244':{'de': 'Rietberg', 'en': 'Rietberg'},
 '495245':{'de': 'Herzebrock-Clarholz', 'en': 'Herzebrock-Clarholz'},
 '495242':{'de': u('Rheda-Wiedenbr\u00fcck'), 'en': u('Rheda-Wiedenbr\u00fcck')},
 '495931':{'de': 'Meppen', 'en': 'Meppen'},
 '495932':{'de': 'Haren Ems', 'en': 'Haren Ems'},
 '495241':{'de': u('G\u00fctersloh'), 'en': u('G\u00fctersloh')},
 '55242437':{'en': 'Ipiabas - RJ', 'pt': 'Ipiabas - RJ'},
 '495939':{'de': 'Sustrum', 'en': 'Sustrum'},
 '495248':{'de': u('Langenberg Kreis G\u00fctersloh'), 'en': u('Langenberg Kreis G\u00fctersloh')},
 '55173238':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173234':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173235':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173236':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173237':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173231':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173232':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173233':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55222734':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222735':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55323538':{'en': 'Presidente Bernardes - MG', 'pt': 'Presidente Bernardes - MG'},
 '497066':{'de': 'Bad Rappenau-Bonfeld', 'en': 'Bad Rappenau-Bonfeld'},
 '497062':{'de': u('Beilstein W\u00fcrttemberg'), 'en': u('Beilstein W\u00fcrttemberg')},
 '497063':{'de': 'Bad Wimpfen', 'en': 'Bad Wimpfen'},
 '55213455':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213454':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213453':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213452':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213451':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213450':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213458':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55173587':{'en': 'Palmares Paulista - SP', 'pt': 'Palmares Paulista - SP'},
 '543533':{'en': u('Las Varillas, C\u00f3rdoba'), 'es': u('Las Varillas, C\u00f3rdoba')},
 '55133568':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133569':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133564':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133565':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133566':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133567':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55163024':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55133561':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55163026':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55133563':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55153394':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55153392':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55242453':{'en': u('Valen\u00e7a - RJ'), 'pt': u('Valen\u00e7a - RJ')},
 '55242452':{'en': u('Valen\u00e7a - RJ'), 'pt': u('Valen\u00e7a - RJ')},
 '55242457':{'en': 'Santa Isabel do Rio Preto - RJ', 'pt': 'Santa Isabel do Rio Preto - RJ'},
 '55173284':{'en': 'Ribeiro dos Santos - SP', 'pt': 'Ribeiro dos Santos - SP'},
 '55242458':{'en': 'Rio das Flores - RJ', 'pt': 'Rio das Flores - RJ'},
 '499842':{'de': 'Uffenheim', 'en': 'Uffenheim'},
 '55163363':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163362':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163361':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163367':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163366':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '494671':{'de': 'Bredstedt', 'en': 'Bredstedt'},
 '55163368':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '494672':{'de': 'Langenhorn', 'en': 'Langenhorn'},
 '498669':{'de': 'Traunreut', 'en': 'Traunreut'},
 '494673':{'de': 'Joldelund', 'en': 'Joldelund'},
 '55173283':{'en': 'Jaci - SP', 'pt': 'Jaci - SP'},
 '498663':{'de': 'Ruhpolding', 'en': 'Ruhpolding'},
 '498846':{'de': 'Uffing am Staffelsee', 'en': 'Uffing am Staffelsee'},
 '498661':{'de': u('Grabenst\u00e4tt Chiemsee'), 'en': u('Grabenst\u00e4tt Chiemsee')},
 '55173282':{'en': u('Ic\u00e9m - SP'), 'pt': u('Ic\u00e9m - SP')},
 '498667':{'de': 'Seeon-Seebruck', 'en': 'Seeon-Seebruck'},
 '498666':{'de': 'Teisendorf', 'en': 'Teisendorf'},
 '498665':{'de': 'Inzell', 'en': 'Inzell'},
 '498664':{'de': 'Chieming', 'en': 'Chieming'},
 '494328':{'de': 'Rickling', 'en': 'Rickling'},
 '494329':{'de': 'Langwedel Holstein', 'en': 'Langwedel Holstein'},
 '494322':{'de': 'Bordesholm', 'en': 'Bordesholm'},
 '494323':{'de': u('Bornh\u00f6ved'), 'en': u('Bornh\u00f6ved')},
 '494320':{'de': u('Heidm\u00fchlen'), 'en': u('Heidm\u00fchlen')},
 '494321':{'de': u('Neum\u00fcnster'), 'en': u('Neum\u00fcnster')},
 '494326':{'de': 'Wankendorf', 'en': 'Wankendorf'},
 '494327':{'de': 'Grossenaspe', 'en': 'Grossenaspe'},
 '494324':{'de': 'Brokstedt', 'en': 'Brokstedt'},
 '55133382':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133383':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133384':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133386':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133387':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55222781':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '499172':{'de': u('Georgensgm\u00fcnd'), 'en': u('Georgensgm\u00fcnd')},
 '55313478':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313476':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313477':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313474':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313475':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313473':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313471':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55143202':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '499354':{'de': 'Rieneck', 'en': 'Rieneck'},
 '5012':{'en': 'Belize District'},
 '5013':{'en': 'Orange Walk District'},
 '5014':{'en': 'Corozal District'},
 '5015':{'en': 'Stann Creek District'},
 '499355':{'de': 'Frammersbach', 'en': 'Frammersbach'},
 '5018':{'en': 'Cayo District'},
 '55193753':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193755':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '499356':{'de': 'Burgsinn', 'en': 'Burgsinn'},
 '55193757':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193756':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193287':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193285':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193284':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193283':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193282':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193281':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '499350':{'de': 'Eussenheim-Hundsbach', 'en': 'Eussenheim-Hundsbach'},
 '55222783':{'en': 'Italva - RJ', 'pt': 'Italva - RJ'},
 '55193289':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '499351':{'de': u('Gem\u00fcnden am Main'), 'en': u('Gem\u00fcnden am Main')},
 '499352':{'de': 'Lohr am Main', 'en': 'Lohr am Main'},
 '55213409':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499353':{'de': 'Karlstadt', 'en': 'Karlstadt'},
 '55114019':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114018':{'en': 'Pinhalzinho - SP', 'pt': 'Pinhalzinho - SP'},
 '55114013':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114012':{'en': u('Bom Jesus dos Perd\u00f5es - SP'), 'pt': u('Bom Jesus dos Perd\u00f5es - SP')},
 '55114011':{'en': 'Piracaia - SP', 'pt': 'Piracaia - SP'},
 '55114017':{'en': 'Jarinu - SP', 'pt': 'Jarinu - SP'},
 '55114016':{'en': 'Jarinu - SP', 'pt': 'Jarinu - SP'},
 '55114015':{'en': 'Tuiuti - SP', 'pt': 'Tuiuti - SP'},
 '55114014':{'en': 'Morungaba - SP', 'pt': 'Morungaba - SP'},
 '55243302':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55113596':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113595':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113594':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113599':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55213402':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323711':{'en': 'Vermelho - MG', 'pt': 'Vermelho - MG'},
 '55213213':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213212':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213219':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213404':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323533':{'en': u('Col\u00f4nia Padre Dami\u00e3o - MG'), 'pt': u('Col\u00f4nia Padre Dami\u00e3o - MG')},
 '55213405':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213406':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213138':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213139':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193321':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55213137':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213131':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213133':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323535':{'en': u('Divin\u00e9sia - MG'), 'pt': u('Divin\u00e9sia - MG')},
 '495743':{'de': 'Espelkamp-Gestringen', 'en': 'Espelkamp-Gestringen'},
 '495742':{'de': 'Preussisch Oldendorf', 'en': 'Preussisch Oldendorf'},
 '495741':{'de': u('L\u00fcbbecke'), 'en': u('L\u00fcbbecke')},
 '495036':{'de': 'Neustadt-Schneeren', 'en': 'Neustadt-Schneeren'},
 '495031':{'de': 'Wunstorf', 'en': 'Wunstorf'},
 '495746':{'de': u('R\u00f6dinghausen'), 'en': u('R\u00f6dinghausen')},
 '495745':{'de': 'Stemwede-Levern', 'en': 'Stemwede-Levern'},
 '495744':{'de': u('H\u00fcllhorst'), 'en': u('H\u00fcllhorst')},
 '55123322':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123321':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55212527':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '54220':{'en': 'Merlo, Buenos Aires', 'es': 'Merlo, Buenos Aires'},
 '54221':{'en': 'La Plata, Buenos Aires', 'es': 'La Plata, Buenos Aires'},
 '54223':{'en': 'Mar del Plata, Buenos Aires', 'es': 'Mar del Plata, Buenos Aires'},
 '55323753':{'en': 'Miradouro - MG', 'pt': 'Miradouro - MG'},
 '495333':{'de': 'Dettum', 'en': 'Dettum'},
 '55213688':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55115564':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112245':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112246':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112247':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112240':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112241':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112242':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112243':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495336':{'de': 'Semmenstedt', 'en': 'Semmenstedt'},
 '55185841':{'en': u('Junqueir\u00f3polis - SP'), 'pt': u('Junqueir\u00f3polis - SP')},
 '55112248':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112249':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495337':{'de': u('Kissenbr\u00fcck'), 'en': u('Kissenbr\u00fcck')},
 '55123147':{'en': 'Queluz - SP', 'pt': 'Queluz - SP'},
 '55123146':{'en': 'Lavrinhas - SP', 'pt': 'Lavrinhas - SP'},
 '55123145':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55123144':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55123143':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '495334':{'de': u('Hornburg Kreis Wolfenb\u00fcttel'), 'en': u('Hornburg Kreis Wolfenb\u00fcttel')},
 '55123141':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55313821':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '55153026':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55115626':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115625':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115624':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115623':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115622':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115621':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115620':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212629':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212622':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212621':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212620':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212627':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212626':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212625':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313823':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '496074':{'de': u('R\u00f6dermark'), 'en': u('R\u00f6dermark')},
 '496071':{'de': 'Dieburg', 'en': 'Dieburg'},
 '55273268':{'en': 'Domingos Martins - ES', 'pt': 'Domingos Martins - ES'},
 '496073':{'de': 'Babenhausen Hessen', 'en': 'Babenhausen Hessen'},
 '55273266':{'en': 'Santa Leopoldina - ES', 'pt': 'Santa Leopoldina - ES'},
 '55273267':{'en': u('Fund\u00e3o - ES'), 'pt': u('Fund\u00e3o - ES')},
 '55273264':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55273265':{'en': 'Rio Bananal - ES', 'pt': 'Rio Bananal - ES'},
 '496078':{'de': 'Gross-Umstadt', 'en': 'Gross-Umstadt'},
 '55273263':{'en': u('Santa Maria de Jetib\u00e1 - ES'), 'pt': u('Santa Maria de Jetib\u00e1 - ES')},
 '55273260':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55273261':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55313825':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '55314122':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55193955':{'en': 'Socorro - SP', 'pt': 'Socorro - SP'},
 '55114571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114573':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114576':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114577':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114578':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55273327':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273326':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55313845':{'en': u('Jaguara\u00e7u - MG'), 'pt': u('Jaguara\u00e7u - MG')},
 '55273324':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55313843':{'en': u('Ant\u00f4nio Dias - MG'), 'pt': u('Ant\u00f4nio Dias - MG')},
 '55173837':{'en': u('Sebastian\u00f3polis do Sul - SP'), 'pt': u('Sebastian\u00f3polis do Sul - SP')},
 '499831':{'de': 'Gunzenhausen', 'en': 'Gunzenhausen'},
 '499833':{'de': 'Heidenheim Mittelfranken', 'en': 'Heidenheim Mittelfranken'},
 '499832':{'de': u('Wassertr\u00fcdingen'), 'en': u('Wassertr\u00fcdingen')},
 '499835':{'de': 'Ehingen Mittelfranken', 'en': 'Ehingen Mittelfranken'},
 '499834':{'de': 'Theilenhofen', 'en': 'Theilenhofen'},
 '499837':{'de': 'Haundorf', 'en': 'Haundorf'},
 '499836':{'de': 'Gunzenhausen-Cronheim', 'en': 'Gunzenhausen-Cronheim'},
 '497305':{'de': 'Erbach Donau', 'en': 'Erbach Donau'},
 '497304':{'de': u('Blaustein W\u00fcrttemberg'), 'en': u('Blaustein W\u00fcrttemberg')},
 '497307':{'de': 'Senden Iller', 'en': 'Senden Iller'},
 '497306':{'de': u('V\u00f6hringen Iller'), 'en': u('V\u00f6hringen Iller')},
 '497300':{'de': 'Roggenburg', 'en': 'Roggenburg'},
 '497303':{'de': 'Illertissen', 'en': 'Illertissen'},
 '497302':{'de': 'Pfaffenhofen an der Roth', 'en': 'Pfaffenhofen an der Roth'},
 '497309':{'de': 'Weissenhorn', 'en': 'Weissenhorn'},
 '497308':{'de': 'Nersingen', 'en': 'Nersingen'},
 '498302':{'de': u('G\u00f6risried'), 'en': u('G\u00f6risried')},
 '498303':{'de': 'Waltenhofen', 'en': 'Waltenhofen'},
 '498304':{'de': 'Wildpoldsried', 'en': 'Wildpoldsried'},
 '498306':{'de': 'Ronsberg', 'en': 'Ronsberg'},
 '55213913':{'en': u('Itabora\u00ed - RJ'), 'pt': u('Itabora\u00ed - RJ')},
 '55212448':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213916':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213917':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '498324':{'de': 'Hindelang', 'en': 'Hindelang'},
 '55313159':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55112749':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112748':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313318':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55115817':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112741':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313312':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112743':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112742':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112745':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112747':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112746':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498322':{'de': 'Oberstdorf', 'en': 'Oberstdorf'},
 '55113929':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113299':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113294':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113295':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113296':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113921':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113926':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113291':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113924':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113293':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112528':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112524':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112521':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112523':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213555':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499307':{'de': 'Altertheim', 'en': 'Altertheim'},
 '499306':{'de': 'Kist', 'en': 'Kist'},
 '499305':{'de': 'Estenfeld', 'en': 'Estenfeld'},
 '499303':{'de': 'Eibelstadt', 'en': 'Eibelstadt'},
 '499302':{'de': 'Rottendorf Unterfranken', 'en': 'Rottendorf Unterfranken'},
 '542953':{'en': u('Macach\u00edn, La Pampa'), 'es': u('Macach\u00edn, La Pampa')},
 '542952':{'en': 'General Acha, La Pampa', 'es': 'General Acha, La Pampa'},
 '542954':{'en': 'Santa Rosa, La Pampa', 'es': 'Santa Rosa, La Pampa'},
 '55183329':{'en': u('Tarum\u00e3 - SP'), 'pt': u('Tarum\u00e3 - SP')},
 '55183325':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55183324':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55183851':{'en': 'Tupi Paulista - SP', 'pt': 'Tupi Paulista - SP'},
 '55183321':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55183856':{'en': 'Nova Guataporanga - SP', 'pt': 'Nova Guataporanga - SP'},
 '55183323':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55183322':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55113438':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55113439':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55212434':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212435':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212432':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212433':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212430':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212431':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113431':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113432':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55113433':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55113434':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113435':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55113436':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55113437':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55313556':{'en': 'Mariana - MG', 'pt': 'Mariana - MG'},
 '55243111':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55323202':{'en': 'Cataguases - MG', 'pt': 'Cataguases - MG'},
 '55273015':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55114805':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114806':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '496683':{'de': u('Ehrenberg Rh\u00f6n'), 'en': u('Ehrenberg Rh\u00f6n')},
 '496682':{'de': u('Tann Rh\u00f6n'), 'en': u('Tann Rh\u00f6n')},
 '496681':{'de': 'Hilders', 'en': 'Hilders'},
 '55323201':{'en': 'Cataguases - MG', 'pt': 'Cataguases - MG'},
 '496684':{'de': 'Hofbieber-Schwarzbach', 'en': 'Hofbieber-Schwarzbach'},
 '55114224':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55273044':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '499720':{'de': u('\u00dcchtelhausen'), 'en': u('\u00dcchtelhausen')},
 '55114226':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '495484':{'de': 'Lienen-Kattenvenne', 'en': 'Lienen-Kattenvenne'},
 '495485':{'de': 'Ladbergen', 'en': 'Ladbergen'},
 '55114227':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '495481':{'de': 'Lengerich Westfalen', 'en': 'Lengerich Westfalen'},
 '495482':{'de': 'Tecklenburg', 'en': 'Tecklenburg'},
 '495483':{'de': 'Lienen', 'en': 'Lienen'},
 '55163914':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55114220':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55163916':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163917':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163911':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163913':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55114222':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55114223':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55193935':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193934':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193937':{'en': u('Jaguari\u00fana - SP'), 'pt': u('Jaguari\u00fana - SP')},
 '55193936':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193933':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55193938':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55115583':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495261':{'de': 'Lemgo', 'en': 'Lemgo'},
 '495262':{'de': 'Extertal', 'en': 'Extertal'},
 '495263':{'de': 'Barntrup', 'en': 'Barntrup'},
 '495264':{'de': 'Kalletal', 'en': 'Kalletal'},
 '495265':{'de': u('D\u00f6rentrup'), 'en': u('D\u00f6rentrup')},
 '495266':{'de': 'Lemgo-Kirchheide', 'en': 'Lemgo-Kirchheide'},
 '55173212':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173213':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173211':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173216':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173217':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173214':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55112634':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173218':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55115839':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143281':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143286':{'en': u('Lucian\u00f3polis - SP'), 'pt': u('Lucian\u00f3polis - SP')},
 '55312591':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55113231':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113946':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113947':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123186':{'en': 'Cachoeira Paulista - SP', 'pt': 'Cachoeira Paulista - SP'},
 '55222654':{'en': 'Sampaio Correia - RJ', 'pt': 'Sampaio Correia - RJ'},
 '55112482':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55143285':{'en': u('Cabr\u00e1lia Paulista - SP'), 'pt': u('Cabr\u00e1lia Paulista - SP')},
 '55163349':{'en': 'Trabiju - SP', 'pt': 'Trabiju - SP'},
 '55163348':{'en': 'Motuca - SP', 'pt': 'Motuca - SP'},
 '55242433':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55242431':{'en': u('Pira\u00ed - RJ'), 'pt': u('Pira\u00ed - RJ')},
 '55242430':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55163341':{'en': 'Ibitinga - SP', 'pt': 'Ibitinga - SP'},
 '55163343':{'en': u('Ibat\u00e9 - SP'), 'pt': u('Ibat\u00e9 - SP')},
 '55163342':{'en': 'Ibitinga - SP', 'pt': 'Ibitinga - SP'},
 '55163345':{'en': 'Dourado - SP', 'pt': 'Dourado - SP'},
 '55163344':{'en': u('Ribeir\u00e3o Bonito - SP'), 'pt': u('Ribeir\u00e3o Bonito - SP')},
 '55163347':{'en': 'Cambaratiba - SP', 'pt': 'Cambaratiba - SP'},
 '55163346':{'en': u('Boa Esperan\u00e7a do Sul - SP'), 'pt': u('Boa Esperan\u00e7a do Sul - SP')},
 '55313671':{'en': u('Sabar\u00e1 - MG'), 'pt': u('Sabar\u00e1 - MG')},
 '55313672':{'en': u('Sabar\u00e1 - MG'), 'pt': u('Sabar\u00e1 - MG')},
 '55313673':{'en': u('Sabar\u00e1 - MG'), 'pt': u('Sabar\u00e1 - MG')},
 '55313674':{'en': u('Sabar\u00e1 - MG'), 'pt': u('Sabar\u00e1 - MG')},
 '55313675':{'en': u('Sabar\u00e1 - MG'), 'pt': u('Sabar\u00e1 - MG')},
 '498821':{'de': 'Garmisch-Partenkirchen', 'en': 'Garmisch-Partenkirchen'},
 '55313679':{'en': u('Sabar\u00e1 - MG'), 'pt': u('Sabar\u00e1 - MG')},
 '498823':{'de': 'Mittenwald', 'en': 'Mittenwald'},
 '498822':{'de': 'Oberammergau', 'en': 'Oberammergau'},
 '498825':{'de': u('Kr\u00fcn'), 'en': u('Kr\u00fcn')},
 '498824':{'de': 'Oberau Loisach', 'en': 'Oberau Loisach'},
 '55112480':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55212186':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55323537':{'en': u('Paula C\u00e2ndido - MG'), 'pt': u('Paula C\u00e2ndido - MG')},
 '495471':{'de': 'Bohmte', 'en': 'Bohmte'},
 '55313415':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313416':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313417':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313412':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313413':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313418':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55173346':{'en': 'Bebedouro - SP', 'pt': 'Bebedouro - SP'},
 '55193739':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193738':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193737':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193736':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193735':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55173347':{'en': 'Jaborandi - SP', 'pt': 'Jaborandi - SP'},
 '55193733':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193732':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193731':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113603':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113602':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113601':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113607':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55114346':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113608':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55223723':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '542286':{'en': 'General La Madrid, Buenos Aires', 'es': 'General La Madrid, Buenos Aires'},
 '55114343':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114031':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '499153':{'de': 'Schnaittach', 'en': 'Schnaittach'},
 '55114033':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '499151':{'de': 'Hersbruck', 'en': 'Hersbruck'},
 '55114035':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55114034':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55114037':{'en': 'Pedra Bela - SP', 'pt': 'Pedra Bela - SP'},
 '55114036':{'en': 'Piracaia - SP', 'pt': 'Piracaia - SP'},
 '55114039':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '55114038':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '499158':{'de': 'Offenhausen Mittelfranken', 'en': 'Offenhausen Mittelfranken'},
 '494308':{'de': 'Schwedeneck', 'en': 'Schwedeneck'},
 '55313832':{'en': u('Santa B\u00e1rbara - MG'), 'pt': u('Santa B\u00e1rbara - MG')},
 '55213274':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213279':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112947':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112946':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112945':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213113':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499270':{'de': 'Creussen', 'en': 'Creussen'},
 '55213116':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213114':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112943':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213118':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213119':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '499276':{'de': u('Bischofsgr\u00fcn'), 'en': u('Bischofsgr\u00fcn')},
 '55112941':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123301':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '55112940':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543382':{'en': 'Rufino, Santa Fe', 'es': 'Rufino, Santa Fe'},
 '543387':{'en': u('Buchardo, C\u00f3rdoba'), 'es': u('Buchardo, C\u00f3rdoba')},
 '55143489':{'en': 'Iacri - SP', 'pt': 'Iacri - SP'},
 '543385':{'en': u('Laboulaye, C\u00f3rdoba'), 'es': u('Laboulaye, C\u00f3rdoba')},
 '55143484':{'en': u('\u00c1lvaro de Carvalho - SP'), 'pt': u('\u00c1lvaro de Carvalho - SP')},
 '55143486':{'en': u('Hercul\u00e2ndia - SP'), 'pt': u('Hercul\u00e2ndia - SP')},
 '54249':{'en': 'Tandil, Buenos Aires', 'es': 'Tandil, Buenos Aires'},
 '55143481':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '499278':{'de': 'Weidenberg', 'en': 'Weidenberg'},
 '55115818':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115819':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115548':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115549':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112262':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112263':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115812':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112261':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115546':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112267':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112264':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112265':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49921':{'de': 'Bayreuth', 'en': 'Bayreuth'},
 '5042255':{'en': 'El Hato'},
 '496254':{'de': 'Lautertal Odenwald', 'en': 'Lautertal Odenwald'},
 '55222674':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55222673':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '496255':{'de': 'Lindenfels', 'en': 'Lindenfels'},
 '55212238':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496524':{'de': 'Rodershausen', 'en': 'Rodershausen'},
 '55212239':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496257':{'de': 'Seeheim-Jugenheim', 'en': 'Seeheim-Jugenheim'},
 '55273198':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55143274':{'en': u('G\u00e1lia - SP'), 'pt': u('G\u00e1lia - SP')},
 '496251':{'de': 'Bensheim', 'en': 'Bensheim'},
 '55212234':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212235':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212236':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496272':{'de': 'Hirschhorn Neckar', 'en': 'Hirschhorn Neckar'},
 '496271':{'de': 'Eberbach Baden', 'en': 'Eberbach Baden'},
 '496276':{'de': 'Hesseneck', 'en': 'Hesseneck'},
 '496274':{'de': 'Waldbrunn Odenwald', 'en': 'Waldbrunn Odenwald'},
 '496275':{'de': 'Rothenberg Odenwald', 'en': 'Rothenberg Odenwald'},
 '55243065':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55243064':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55212231':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212601':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212603':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212602':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212605':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212604':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212606':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212609':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212608':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212233':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55114639':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55114638':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '496096':{'de': 'Wiesen Unterfranken', 'en': 'Wiesen Unterfranken'},
 '55193893':{'en': 'Pedreira - SP', 'pt': 'Pedreira - SP'},
 '496094':{'de': 'Weibersbrunn', 'en': 'Weibersbrunn'},
 '496095':{'de': 'Bessenbach', 'en': 'Bessenbach'},
 '496092':{'de': 'Heimbuchenthal', 'en': 'Heimbuchenthal'},
 '496093':{'de': 'Laufach', 'en': 'Laufach'},
 '55193894':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55114634':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55212669':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55173692':{'en': 'Santana da Ponte Pensa - SP', 'pt': 'Santana da Ponte Pensa - SP'},
 '55173693':{'en': u('S\u00e3o Francisco - SP'), 'pt': u('S\u00e3o Francisco - SP')},
 '55133481':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55173691':{'en': u('Tr\u00eas Fronteiras - SP'), 'pt': u('Tr\u00eas Fronteiras - SP')},
 '496897':{'de': 'Sulzbach Saar', 'en': 'Sulzbach Saar'},
 '496894':{'de': 'St Ingbert', 'en': 'St Ingbert'},
 '496893':{'de': u('Saarbr\u00fccken-Ensheim'), 'en': u('Saarbr\u00fccken-Ensheim')},
 '55183581':{'en': u('Fl\u00f3rida Paulista - SP'), 'pt': u('Fl\u00f3rida Paulista - SP')},
 '55183583':{'en': u('Rin\u00f3polis - SP'), 'pt': u('Rin\u00f3polis - SP')},
 '55183582':{'en': u('Parapu\u00e3 - SP'), 'pt': u('Parapu\u00e3 - SP')},
 '496898':{'de': u('V\u00f6lklingen'), 'en': u('V\u00f6lklingen')},
 '55183586':{'en': u('Mari\u00e1polis - SP'), 'pt': u('Mari\u00e1polis - SP')},
 '55114555':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55242222':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242223':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242220':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242221':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242224':{'en': u('S\u00e3o Jos\u00e9 do Vale do Rio Preto - RJ'), 'pt': u('S\u00e3o Jos\u00e9 do Vale do Rio Preto - RJ')},
 '55242225':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242228':{'en': u('Secret\u00e1rio - RJ'), 'pt': u('Secret\u00e1rio - RJ')},
 '498146':{'de': 'Moorenweis', 'en': 'Moorenweis'},
 '498144':{'de': 'Grafrath', 'en': 'Grafrath'},
 '498145':{'de': 'Mammendorf', 'en': 'Mammendorf'},
 '498142':{'de': 'Olching', 'en': 'Olching'},
 '498143':{'de': 'Inning am Ammersee', 'en': 'Inning am Ammersee'},
 '498141':{'de': u('F\u00fcrstenfeldbruck'), 'en': u('F\u00fcrstenfeldbruck')},
 '55323286':{'en': u('Santo Ant\u00f4nio do Aventureiro - MG'), 'pt': u('Santo Ant\u00f4nio do Aventureiro - MG')},
 '55323287':{'en': 'Senador Cortes - MG', 'pt': 'Senador Cortes - MG'},
 '55323284':{'en': 'Belmiro Braga - MG', 'pt': 'Belmiro Braga - MG'},
 '55323285':{'en': 'Chiador - MG', 'pt': 'Chiador - MG'},
 '55323282':{'en': 'Pedro Teixeira - MG', 'pt': 'Pedro Teixeira - MG'},
 '55323283':{'en': 'Rio Preto - MG', 'pt': 'Rio Preto - MG'},
 '55323281':{'en': 'Lima Duarte - MG', 'pt': 'Lima Duarte - MG'},
 '55323288':{'en': 'Olaria - MG', 'pt': 'Olaria - MG'},
 '494539':{'de': 'Westerau', 'en': 'Westerau'},
 '494829':{'de': 'Wewelsfleth', 'en': 'Wewelsfleth'},
 '494828':{'de': u('L\u00e4gerdorf'), 'en': u('L\u00e4gerdorf')},
 '494533':{'de': 'Reinfeld Holstein', 'en': 'Reinfeld Holstein'},
 '494824':{'de': 'Krempe', 'en': 'Krempe'},
 '494827':{'de': 'Wacken', 'en': 'Wacken'},
 '494826':{'de': 'Hohenlockstedt', 'en': 'Hohenlockstedt'},
 '494537':{'de': u('S\u00fclfeld Holstein'), 'en': u('S\u00fclfeld Holstein')},
 '494536':{'de': 'Steinhorst Lauenburg', 'en': 'Steinhorst Lauenburg'},
 '494535':{'de': 'Nahe', 'en': 'Nahe'},
 '494534':{'de': 'Steinburg Kreis Storman', 'en': 'Steinburg Kreis Storman'},
 '497329':{'de': 'Steinheim am Albuch', 'en': 'Steinheim am Albuch'},
 '497328':{'de': u('K\u00f6nigsbronn'), 'en': u('K\u00f6nigsbronn')},
 '497327':{'de': 'Dischingen', 'en': 'Dischingen'},
 '497326':{'de': 'Neresheim', 'en': 'Neresheim'},
 '497325':{'de': 'Sontheim an der Brenz', 'en': 'Sontheim an der Brenz'},
 '497324':{'de': 'Herbrechtingen', 'en': 'Herbrechtingen'},
 '497323':{'de': 'Gerstetten', 'en': 'Gerstetten'},
 '497322':{'de': 'Giengen an der Brenz', 'en': 'Giengen an der Brenz'},
 '497321':{'de': 'Heidenheim an der Brenz', 'en': 'Heidenheim an der Brenz'},
 '498368':{'de': 'Halblech', 'en': 'Halblech'},
 '498369':{'de': u('R\u00fcckholz'), 'en': u('R\u00fcckholz')},
 '498362':{'de': u('F\u00fcssen'), 'en': u('F\u00fcssen')},
 '498363':{'de': 'Pfronten', 'en': 'Pfronten'},
 '498361':{'de': 'Nesselwang', 'en': 'Nesselwang'},
 '498366':{'de': 'Oy-Mittelberg', 'en': 'Oy-Mittelberg'},
 '498367':{'de': u('Ro\u00dfhaupten Forggensee'), 'en': 'Rosshaupten Forggensee'},
 '498364':{'de': 'Seeg', 'en': 'Seeg'},
 '498365':{'de': 'Wertach', 'en': 'Wertach'},
 '494796':{'de': 'Teufelsmoor', 'en': 'Teufelsmoor'},
 '494795':{'de': 'Garlstedt', 'en': 'Garlstedt'},
 '494794':{'de': 'Worpswede-Ostersode', 'en': 'Worpswede-Ostersode'},
 '494793':{'de': 'Hambergen', 'en': 'Hambergen'},
 '494792':{'de': 'Worpswede', 'en': 'Worpswede'},
 '494791':{'de': 'Osterholz-Scharmbeck', 'en': 'Osterholz-Scharmbeck'},
 '55153217':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153218':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153219':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '52983':{'en': 'Quintana Roo', 'es': 'Quintana Roo'},
 '52982':{'en': 'Campeche', 'es': 'Campeche'},
 '52981':{'en': 'Campeche, CAMP', 'es': 'Campeche, CAMP'},
 '52987':{'en': 'Cozumel, QRO', 'es': 'Cozumel, QRO'},
 '52986':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52985':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52984':{'en': 'Quintana Roo', 'es': 'Quintana Roo'},
 '52327':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52326':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52325':{'en': 'Acaponeta, NAY', 'es': 'Acaponeta, NAY'},
 '52988':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52323':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52322':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52321':{'en': 'El Grullo/El Limon, JAL', 'es': 'El Grullo/El Limon, JAL'},
 '55313330':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313335':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313337':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112728':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112727':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112894':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112897':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112896':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112891':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55112722':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112893':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112892':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193873':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '49711':{'de': 'Stuttgart', 'en': 'Stuttgart'},
 '55193874':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55193875':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193876':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55193877':{'en': 'Artur Nogueira - SP', 'pt': 'Artur Nogueira - SP'},
 '55212580':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193878':{'en': 'Louveira - SP', 'pt': 'Louveira - SP'},
 '55193879':{'en': 'Monte Mor - SP', 'pt': 'Monte Mor - SP'},
 '55212586':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212587':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112095':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112094':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112097':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112091':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112090':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112093':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112092':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112099':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112098':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499369':{'de': 'Uettingen', 'en': 'Uettingen'},
 '499360':{'de': u('Th\u00fcngen'), 'en': u('Th\u00fcngen')},
 '499363':{'de': 'Arnstein Unterfranken', 'en': 'Arnstein Unterfranken'},
 '499365':{'de': 'Rimpar', 'en': 'Rimpar'},
 '499364':{'de': 'Zellingen', 'en': 'Zellingen'},
 '499367':{'de': 'Unterpleichfeld', 'en': 'Unterpleichfeld'},
 '499366':{'de': 'Geroldshausen Unterfranken', 'en': 'Geroldshausen Unterfranken'},
 '55163668':{'en': u('Santo Ant\u00f4nio da Alegria - SP'), 'pt': u('Santo Ant\u00f4nio da Alegria - SP')},
 '55163669':{'en': u('C\u00e1ssia dos Coqueiros - SP'), 'pt': u('C\u00e1ssia dos Coqueiros - SP')},
 '55163662':{'en': 'Batatais - SP', 'pt': 'Batatais - SP'},
 '55112011':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163660':{'en': 'Batatais - SP', 'pt': 'Batatais - SP'},
 '55163661':{'en': 'Batatais - SP', 'pt': 'Batatais - SP'},
 '55163666':{'en': u('Santa Cruz da Esperan\u00e7a - SP'), 'pt': u('Santa Cruz da Esperan\u00e7a - SP')},
 '55163667':{'en': 'Cajuru - SP', 'pt': 'Cajuru - SP'},
 '55163664':{'en': 'Brodowski - SP', 'pt': 'Brodowski - SP'},
 '55163665':{'en': u('Altin\u00f3polis - SP'), 'pt': u('Altin\u00f3polis - SP')},
 '55143487':{'en': u('J\u00falio Mesquita - SP'), 'pt': u('J\u00falio Mesquita - SP')},
 '55212273':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143541':{'en': u('Promiss\u00e3o - SP'), 'pt': u('Promiss\u00e3o - SP')},
 '55143543':{'en': u('Promiss\u00e3o - SP'), 'pt': u('Promiss\u00e3o - SP')},
 '55143542':{'en': u('Promiss\u00e3o - SP'), 'pt': u('Promiss\u00e3o - SP')},
 '55183875':{'en': 'Santa Mercedes - SP', 'pt': 'Santa Mercedes - SP'},
 '55143547':{'en': u('Guai\u00e7ara - SP'), 'pt': u('Guai\u00e7ara - SP')},
 '55143014':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55212454':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212455':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212456':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212457':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212450':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212452':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212453':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496659':{'de': 'Eichenzell', 'en': 'Eichenzell'},
 '55113418':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113416':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113414':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55113412':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113413':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55113411':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55152108':{'en': u('Tiet\u00ea - SP'), 'pt': u('Tiet\u00ea - SP')},
 '55152107':{'en': 'Porto Feliz - SP', 'pt': 'Porto Feliz - SP'},
 '55152105':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55152104':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55152102':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55152101':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55273079':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55273076':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '55273072':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55212438':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55114826':{'en': 'Rio Grande da Serra - SP', 'pt': 'Rio Grande da Serra - SP'},
 '55114827':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114824':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114825':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114823':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114820':{'en': 'Rio Grande da Serra - SP', 'pt': 'Rio Grande da Serra - SP'},
 '55114821':{'en': 'Rio Grande da Serra - SP', 'pt': 'Rio Grande da Serra - SP'},
 '55114828':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114829':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55193268':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '542972':{'en': u('San Mart\u00edn de los Andes, Neuqu\u00e9n'), 'es': u('San Mart\u00edn de los Andes, Neuqu\u00e9n')},
 '55163931':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '495468':{'de': 'Bramsche-Engter', 'en': 'Bramsche-Engter'},
 '495466':{'de': 'Merzen', 'en': 'Merzen'},
 '495467':{'de': 'Voltlage', 'en': 'Voltlage'},
 '495464':{'de': 'Alfhausen', 'en': 'Alfhausen'},
 '495465':{'de': 'Neuenkirchen bei Bramsche', 'en': 'Neuenkirchen bei Bramsche'},
 '495462':{'de': 'Ankum', 'en': 'Ankum'},
 '495461':{'de': 'Bramsche Hase', 'en': 'Bramsche Hase'},
 '55115531':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542622':{'en': u('Tunuy\u00e1n, Mendoza'), 'es': u('Tunuy\u00e1n, Mendoza')},
 '542626':{'en': 'La Paz, Mendoza', 'es': 'La Paz, Mendoza'},
 '542625':{'en': 'General Alvear, Mendoza', 'es': 'General Alvear, Mendoza'},
 '542624':{'en': 'Uspallata, Mendoza', 'es': 'Uspallata, Mendoza'},
 '55212473':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495208':{'de': u('Leopoldsh\u00f6he'), 'en': u('Leopoldsh\u00f6he')},
 '495209':{'de': u('G\u00fctersloh-Friedrichsdorf'), 'en': u('G\u00fctersloh-Friedrichsdorf')},
 '495202':{'de': 'Oerlinghausen', 'en': 'Oerlinghausen'},
 '495203':{'de': 'Werther Westfalen', 'en': 'Werther Westfalen'},
 '495201':{'de': 'Halle Westfalen', 'en': 'Halle Westfalen'},
 '495206':{'de': u('Bielefeld-J\u00f6llenbeck'), 'en': u('Bielefeld-J\u00f6llenbeck')},
 '495207':{'de': 'Schloss Holte-Stukenbrock', 'en': 'Schloss Holte-Stukenbrock'},
 '495204':{'de': 'Steinhagen Westfalen', 'en': 'Steinhagen Westfalen'},
 '495205':{'de': 'Bielefeld-Sennestadt', 'en': 'Bielefeld-Sennestadt'},
 '55173893':{'en': 'Palestina - SP', 'pt': 'Palestina - SP'},
 '55114798':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114799':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55213492':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55273382':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55114795':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114163':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114791':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55115010':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115011':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115012':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115013':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115014':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115015':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115016':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115017':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115018':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499622':{'de': 'Hirschau Oberpfalz', 'en': 'Hirschau Oberpfalz'},
 '55212475':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55242411':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55163326':{'en': u('Boa Esperan\u00e7a do Sul - SP'), 'pt': u('Boa Esperan\u00e7a do Sul - SP')},
 '55163324':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163323':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163322':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163321':{'en': 'Tabatinga - SP', 'pt': 'Tabatinga - SP'},
 '498803':{'de': 'Peissenberg', 'en': 'Peissenberg'},
 '498802':{'de': 'Huglfing', 'en': 'Huglfing'},
 '498801':{'de': 'Seeshaupt', 'en': 'Seeshaupt'},
 '498807':{'de': u('Die\u00dfen am Ammersee'), 'en': 'Diessen am Ammersee'},
 '498806':{'de': 'Utting am Ammersee', 'en': 'Utting am Ammersee'},
 '498805':{'de': 'Hohenpeissenberg', 'en': 'Hohenpeissenberg'},
 '498809':{'de': 'Wessobrunn', 'en': 'Wessobrunn'},
 '498808':{'de': u('P\u00e4hl'), 'en': u('P\u00e4hl')},
 '55183648':{'en': 'Juritis - SP', 'pt': 'Juritis - SP'},
 '55113354':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183646':{'en': 'Brejo Alegre - SP', 'pt': 'Brejo Alegre - SP'},
 '55183647':{'en': u('Glic\u00e9rio - SP'), 'pt': u('Glic\u00e9rio - SP')},
 '55183644':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55183645':{'en': 'Coroados - SP', 'pt': 'Coroados - SP'},
 '55183642':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55183643':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55183641':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55113286':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163491':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55323348':{'en': u('Cipot\u00e2nea - MG'), 'pt': u('Cipot\u00e2nea - MG')},
 '55193023':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55313432':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213534':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323341':{'en': 'Ressaquinha - MG', 'pt': 'Ressaquinha - MG'},
 '55313431':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55323347':{'en': 'Ibertioga - MG', 'pt': 'Ibertioga - MG'},
 '55323346':{'en': u('Ant\u00f4nio Carlos - MG'), 'pt': u('Ant\u00f4nio Carlos - MG')},
 '55313434':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313435':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '494494':{'de': u('B\u00f6sel Oldenburg'), 'en': u('B\u00f6sel Oldenburg')},
 '494495':{'de': u('Friesoythe-Th\u00fcle'), 'en': u('Friesoythe-Th\u00fcle')},
 '494496':{'de': 'Friesoythe-Markhausen', 'en': 'Friesoythe-Markhausen'},
 '494497':{'de': u('Bar\u00dfel-Harkebr\u00fcgge'), 'en': u('Barssel-Harkebr\u00fcgge')},
 '494491':{'de': 'Friesoythe', 'en': 'Friesoythe'},
 '494492':{'de': 'Saterland', 'en': 'Saterland'},
 '494493':{'de': 'Friesoythe-Gehlenberg', 'en': 'Friesoythe-Gehlenberg'},
 '494498':{'de': 'Saterland-Ramsloh', 'en': 'Saterland-Ramsloh'},
 '494499':{'de': 'Barssel', 'en': 'Barssel'},
 '55193243':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113628':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193241':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193716':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193022':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '55193246':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193245':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113621':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113623':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113622':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113625':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113624':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55333225':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '498774':{'de': 'Bayerbach bei Ergoldsbach', 'en': 'Bayerbach bei Ergoldsbach'},
 '498771':{'de': 'Ergoldsbach', 'en': 'Ergoldsbach'},
 '498773':{'de': 'Neufahrn in Niederbayern', 'en': 'Neufahrn in Niederbayern'},
 '498772':{'de': 'Mallersdorf-Pfaffenberg', 'en': 'Mallersdorf-Pfaffenberg'},
 '55183344':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55213851':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55173638':{'en': u('Mes\u00f3polis - SP'), 'pt': u('Mes\u00f3polis - SP')},
 '55173639':{'en': 'Populina - SP', 'pt': 'Populina - SP'},
 '55213326':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55173631':{'en': u('Santa F\u00e9 do Sul - SP'), 'pt': u('Santa F\u00e9 do Sul - SP')},
 '55173632':{'en': 'Jales - SP', 'pt': 'Jales - SP'},
 '55173633':{'en': 'Santa Albertina - SP', 'pt': 'Santa Albertina - SP'},
 '55173634':{'en': u('Ur\u00e2nia - SP'), 'pt': u('Ur\u00e2nia - SP')},
 '55173635':{'en': 'Aparecida D\'Oeste - SP', 'pt': 'Aparecida D\'Oeste - SP'},
 '55173636':{'en': u('Dolcin\u00f3polis - SP'), 'pt': u('Dolcin\u00f3polis - SP')},
 '55173637':{'en': u('Guzol\u00e2ndia - SP'), 'pt': u('Guzol\u00e2ndia - SP')},
 '55114057':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114056':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114055':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114054':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114053':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114052':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114051':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499174':{'de': 'Hilpoltstein', 'en': 'Hilpoltstein'},
 '499175':{'de': 'Spalt', 'en': 'Spalt'},
 '499176':{'de': 'Allersberg', 'en': 'Allersberg'},
 '499177':{'de': 'Heideck', 'en': 'Heideck'},
 '499170':{'de': 'Schwanstetten', 'en': 'Schwanstetten'},
 '499171':{'de': 'Roth Mittelfranken', 'en': 'Roth Mittelfranken'},
 '55114059':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499173':{'de': u('Thalm\u00e4ssing'), 'en': u('Thalm\u00e4ssing')},
 '55323754':{'en': u('S\u00e3o Francisco do Gl\u00f3ria - MG'), 'pt': u('S\u00e3o Francisco do Gl\u00f3ria - MG')},
 '55323755':{'en': 'Vieiras - MG', 'pt': 'Vieiras - MG'},
 '55323751':{'en': 'Tombos - MG', 'pt': 'Tombos - MG'},
 '55213252':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153022':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '494805':{'de': 'Schafstedt', 'en': 'Schafstedt'},
 '55143714':{'en': u('Cerqueira C\u00e9sar - SP'), 'pt': u('Cerqueira C\u00e9sar - SP')},
 '55143711':{'en': u('Avar\u00e9 - SP'), 'pt': u('Avar\u00e9 - SP')},
 '55143713':{'en': 'Paranapanema - SP', 'pt': 'Paranapanema - SP'},
 '55173405':{'en': 'Votuporanga - SP', 'pt': 'Votuporanga - SP'},
 '55115536':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495071':{'de': 'Schwarmstedt', 'en': 'Schwarmstedt'},
 '495073':{'de': 'Neustadt-Esperke', 'en': 'Neustadt-Esperke'},
 '495072':{'de': 'Neustadt-Mandelsloh', 'en': 'Neustadt-Mandelsloh'},
 '495074':{'de': 'Rodewald', 'en': 'Rodewald'},
 '54260':{'en': 'San Rafael, Mendoza', 'es': 'San Rafael, Mendoza'},
 '54261':{'en': 'Mendoza, Mendoza', 'es': 'Mendoza, Mendoza'},
 '54263':{'en': u('San Mart\u00edn, Mendoza'), 'es': u('San Mart\u00edn, Mendoza')},
 '54264':{'en': 'San Juan, San Juan', 'es': 'San Juan, San Juan'},
 '54266':{'en': 'San Luis, San Luis', 'es': 'San Luis, San Luis'},
 '55223308':{'en': u('S\u00e3o Pedro da Aldeia - RJ'), 'pt': u('S\u00e3o Pedro da Aldeia - RJ')},
 '55112280':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112281':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112282':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112283':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112284':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55112285':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112286':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112287':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112288':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112289':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115833':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49906':{'de': u('Donauw\u00f6rth'), 'en': u('Donauw\u00f6rth')},
 '55123185':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '55123184':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55222655':{'en': 'Saquarema - RJ', 'pt': 'Saquarema - RJ'},
 '499956':{'de': 'Eichendorf-Aufhausen', 'en': 'Eichendorf-Aufhausen'},
 '55222651':{'en': 'Saquarema - RJ', 'pt': 'Saquarema - RJ'},
 '55222653':{'en': 'Saquarema - RJ', 'pt': 'Saquarema - RJ'},
 '55222652':{'en': 'Saquarema - RJ', 'pt': 'Saquarema - RJ'},
 '495695':{'de': 'Twistetal', 'en': 'Twistetal'},
 '495694':{'de': 'Diemelstadt', 'en': 'Diemelstadt'},
 '495696':{'de': 'Bad Arolsen-Landau', 'en': 'Bad Arolsen-Landau'},
 '495691':{'de': 'Bad Arolsen', 'en': 'Bad Arolsen'},
 '495693':{'de': 'Volkmarsen', 'en': 'Volkmarsen'},
 '495692':{'de': 'Wolfhagen', 'en': 'Wolfhagen'},
 '55193029':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55123981':{'en': 'Cedro - SP', 'pt': 'Cedro - SP'},
 '55273194':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '496258':{'de': 'Gernsheim', 'en': 'Gernsheim'},
 '5411':{'en': 'Buenos Aires', 'es': 'Buenos Aires'},
 '496526':{'de': 'Bollendorf', 'en': 'Bollendorf'},
 '496527':{'de': 'Oberweis', 'en': 'Oberweis'},
 '496256':{'de': u('Lampertheim-H\u00fcttenfeld'), 'en': u('Lampertheim-H\u00fcttenfeld')},
 '496525':{'de': 'Irrel', 'en': 'Irrel'},
 '496522':{'de': 'Mettendorf', 'en': 'Mettendorf'},
 '496523':{'de': 'Holsthum', 'en': 'Holsthum'},
 '496252':{'de': u('Heppenheim Bergstra\u00dfe'), 'en': 'Heppenheim Bergstrasse'},
 '496253':{'de': u('F\u00fcrth Odenwald'), 'en': u('F\u00fcrth Odenwald')},
 '55212667':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55212666':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55212665':{'en': 'Queimados - RJ', 'pt': 'Queimados - RJ'},
 '55212664':{'en': 'Japeri - RJ', 'pt': 'Japeri - RJ'},
 '55193579':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212668':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55212213':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273229':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55273222':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273223':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55193578':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55273227':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273224':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273225':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55114611':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55193871':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '55193872':{'en': u('Cosm\u00f3polis - SP'), 'pt': u('Cosm\u00f3polis - SP')},
 '55114612':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114615':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114614':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114617':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114616':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114619':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55114618':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55212763':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55212760':{'en': 'Rio das Ostras - RJ', 'pt': 'Rio das Ostras - RJ'},
 '55133829':{'en': 'Registro - SP', 'pt': 'Registro - SP'},
 '55133828':{'en': 'Registro - SP', 'pt': 'Registro - SP'},
 '55114538':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114539':{'en': u('Joan\u00f3polis - SP'), 'pt': u('Joan\u00f3polis - SP')},
 '55114534':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114535':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114537':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114531':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114532':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114533':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '497129':{'de': u('Lichtenstein W\u00fcrttemberg'), 'en': u('Lichtenstein W\u00fcrttemberg')},
 '497128':{'de': u('Sonnenb\u00fchl'), 'en': u('Sonnenb\u00fchl')},
 '497125':{'de': 'Bad Urach', 'en': 'Bad Urach'},
 '497124':{'de': 'Trochtelfingen Hohenz', 'en': 'Trochtelfingen Hohenz'},
 '497127':{'de': 'Neckartenzlingen', 'en': 'Neckartenzlingen'},
 '497126':{'de': 'Burladingen-Melchingen', 'en': 'Burladingen-Melchingen'},
 '497121':{'de': 'Reutlingen', 'en': 'Reutlingen'},
 '497123':{'de': u('Metzingen W\u00fcrttemberg'), 'en': u('Metzingen W\u00fcrttemberg')},
 '497122':{'de': u('St Johann W\u00fcrttemberg'), 'en': u('St Johann W\u00fcrttemberg')},
 '498168':{'de': 'Attenkirchen', 'en': 'Attenkirchen'},
 '498161':{'de': 'Freising', 'en': 'Freising'},
 '498165':{'de': 'Neufahrn bei Freising', 'en': 'Neufahrn bei Freising'},
 '498166':{'de': 'Allershausen Oberbayern', 'en': 'Allershausen Oberbayern'},
 '498167':{'de': 'Zolling', 'en': 'Zolling'},
 '55114282':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494806':{'de': u('Sarzb\u00fcttel'), 'en': u('Sarzb\u00fcttel')},
 '55114280':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '494804':{'de': 'Nordhastedt', 'en': 'Nordhastedt'},
 '494803':{'de': 'Pahlen', 'en': 'Pahlen'},
 '494802':{'de': 'Wrohm', 'en': 'Wrohm'},
 '55114284':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '497348':{'de': 'Beimerstetten', 'en': 'Beimerstetten'},
 '497340':{'de': 'Neenstetten', 'en': 'Neenstetten'},
 '497343':{'de': 'Buch bei Illertissen', 'en': 'Buch bei Illertissen'},
 '497345':{'de': u('Langenau W\u00fcrttemberg'), 'en': u('Langenau W\u00fcrttemberg')},
 '497344':{'de': 'Blaubeuren', 'en': 'Blaubeuren'},
 '497347':{'de': 'Dietenheim', 'en': 'Dietenheim'},
 '497346':{'de': 'Illerkirchberg', 'en': 'Illerkirchberg'},
 '55222542':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55153236':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153237':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153234':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153235':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153232':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153233':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153231':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153238':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153239':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55112705':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112704':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112707':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112876':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55112703':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313358':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '498344':{'de': 'Westendorf bei Kaufbeuren', 'en': 'Westendorf bei Kaufbeuren'},
 '498345':{'de': u('St\u00f6ttwang'), 'en': u('St\u00f6ttwang')},
 '498346':{'de': 'Pforzen', 'en': 'Pforzen'},
 '498347':{'de': 'Friesenried', 'en': 'Friesenried'},
 '498340':{'de': 'Baisweil', 'en': 'Baisweil'},
 '498341':{'de': 'Kaufbeuren', 'en': 'Kaufbeuren'},
 '55113343':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498343':{'de': 'Aitrang', 'en': 'Aitrang'},
 '498348':{'de': 'Bidingen', 'en': 'Bidingen'},
 '498349':{'de': u('St\u00f6tten am Auerberg'), 'en': u('St\u00f6tten am Auerberg')},
 '499435':{'de': 'Schwarzenfeld', 'en': 'Schwarzenfeld'},
 '499342':{'de': 'Wertheim', 'en': 'Wertheim'},
 '499341':{'de': 'Tauberbischofsheim', 'en': 'Tauberbischofsheim'},
 '499436':{'de': 'Nittenau', 'en': 'Nittenau'},
 '499431':{'de': 'Schwandorf', 'en': 'Schwandorf'},
 '49731':{'de': 'Ulm Donau', 'en': 'Ulm Donau'},
 '499345':{'de': u('K\u00fclsheim Baden'), 'en': u('K\u00fclsheim Baden')},
 '499344':{'de': 'Gerchsheim', 'en': 'Gerchsheim'},
 '499349':{'de': 'Werbach-Wenkheim', 'en': 'Werbach-Wenkheim'},
 '499348':{'de': 'Werbach-Gamburg', 'en': 'Werbach-Gamburg'},
 '499439':{'de': 'Neunburg-Kemnath', 'en': 'Neunburg-Kemnath'},
 '499438':{'de': 'Fensterbach', 'en': 'Fensterbach'},
 '55113341':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143032':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55193501':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55193502':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193503':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55143523':{'en': 'Lins - SP', 'pt': 'Lins - SP'},
 '55143522':{'en': 'Lins - SP', 'pt': 'Lins - SP'},
 '55212474':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193507':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55193056':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193055':{'en': 'Pirassununga - SP', 'pt': 'Pirassununga - SP'},
 '55193053':{'en': 'Leme - SP', 'pt': 'Leme - SP'},
 '55143529':{'en': 'Lins - SP', 'pt': 'Lins - SP'},
 '55113474':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113475':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113476':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113477':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113471':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113472':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113473':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113478':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113479':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313357':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55273051':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55222222':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55193277':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193273':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55313351':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '495448':{'de': 'Barver', 'en': 'Barver'},
 '495198':{'de': 'Schneverdingen-Wintermoor', 'en': 'Schneverdingen-Wintermoor'},
 '495199':{'de': 'Schneverdingen-Heber', 'en': 'Schneverdingen-Heber'},
 '495192':{'de': 'Munster', 'en': 'Munster'},
 '495193':{'de': 'Schneverdingen', 'en': 'Schneverdingen'},
 '495190':{'de': 'Soltau-Emmingen', 'en': 'Soltau-Emmingen'},
 '495191':{'de': 'Soltau', 'en': 'Soltau'},
 '495196':{'de': 'Wietzendorf', 'en': 'Wietzendorf'},
 '495445':{'de': 'Drebber', 'en': 'Drebber'},
 '495194':{'de': 'Bispingen', 'en': 'Bispingen'},
 '495447':{'de': 'Lembruch', 'en': 'Lembruch'},
 '543525':{'en': u('Jes\u00fas Mar\u00eda, C\u00f3rdoba'), 'es': u('Jes\u00fas Mar\u00eda, C\u00f3rdoba')},
 '55113875':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113876':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113653':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '495224':{'de': 'Enger Westfalen', 'en': 'Enger Westfalen'},
 '495225':{'de': 'Spenge', 'en': 'Spenge'},
 '495226':{'de': u('Bruchm\u00fchlen Westfalen'), 'en': u('Bruchm\u00fchlen Westfalen')},
 '495221':{'de': 'Herford', 'en': 'Herford'},
 '495222':{'de': 'Bad Salzuflen', 'en': 'Bad Salzuflen'},
 '495223':{'de': u('B\u00fcnde'), 'en': u('B\u00fcnde')},
 '495228':{'de': 'Vlotho-Exter', 'en': 'Vlotho-Exter'},
 '55123648':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123641':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123642':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123643':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123644':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123645':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123646':{'en': 'Roseira - SP', 'pt': 'Roseira - SP'},
 '55123647':{'en': 'Lagoinha - SP', 'pt': 'Lagoinha - SP'},
 '55193453':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55243388':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55243389':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55243381':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55243387':{'en': u('Visconde de Mau\u00e1 - RJ'), 'pt': u('Visconde de Mau\u00e1 - RJ')},
 '55163042':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55163041':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55115034':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115032':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115031':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496755':{'de': 'Odernheim am Glan', 'en': 'Odernheim am Glan'},
 '496754':{'de': 'Martinstein', 'en': 'Martinstein'},
 '496757':{'de': 'Becherbach bei Kirn', 'en': 'Becherbach bei Kirn'},
 '496756':{'de': 'Winterbach Soonwald', 'en': 'Winterbach Soonwald'},
 '496751':{'de': 'Bad Sobernheim', 'en': 'Bad Sobernheim'},
 '496753':{'de': 'Meisenheim', 'en': 'Meisenheim'},
 '496752':{'de': 'Kirn Nahe', 'en': 'Kirn Nahe'},
 '496758':{'de': u('Waldb\u00f6ckelheim'), 'en': u('Waldb\u00f6ckelheim')},
 '55173276':{'en': u('Engenheiro Baldu\u00edno - SP'), 'pt': u('Engenheiro Baldu\u00edno - SP')},
 '55173277':{'en': u('Nipo\u00e3 - SP'), 'pt': u('Nipo\u00e3 - SP')},
 '55212458':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163305':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163304':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163307':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163306':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163301':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163303':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55173279':{'en': u('Ol\u00edmpia - SP'), 'pt': u('Ol\u00edmpia - SP')},
 '55163308':{'en': u('Gavi\u00e3o Peixoto - SP'), 'pt': u('Gavi\u00e3o Peixoto - SP')},
 '55313634':{'en': 'Santa Luzia - MG', 'pt': 'Santa Luzia - MG'},
 '55313637':{'en': 'Santa Luzia - MG', 'pt': 'Santa Luzia - MG'},
 '55193454':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55183624':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183625':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183621':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183622':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183623':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '52281':{'en': 'Loma Bonita, OAX', 'es': 'Loma Bonita, OAX'},
 '52282':{'en': 'Puebla/Veracruz', 'es': 'Puebla/Veracruz'},
 '52283':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52284':{'en': 'Angel Rosario Cabada/Lerdo de Tejada, VER', 'es': u('\u00c1ngel Rosario Cabada/Lerdo de Tejada, VER')},
 '498342':{'de': 'Marktoberdorf', 'en': 'Marktoberdorf'},
 '52287':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '52288':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55133855':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '55133856':{'en': u('Pariquera-A\u00e7u - SP'), 'pt': u('Pariquera-A\u00e7u - SP')},
 '55133851':{'en': u('Canan\u00e9ia - SP'), 'pt': u('Canan\u00e9ia - SP')},
 '55133852':{'en': 'Ariri - SP', 'pt': 'Ariri - SP'},
 '494667':{'de': u('Dageb\u00fcll'), 'en': u('Dageb\u00fcll')},
 '499162':{'de': 'Scheinfeld', 'en': 'Scheinfeld'},
 '499178':{'de': 'Abenberg Mittelfranken', 'en': 'Abenberg Mittelfranken'},
 '499161':{'de': 'Neustadt an der Aisch', 'en': 'Neustadt an der Aisch'},
 '55323361':{'en': u('Caranda\u00ed - MG'), 'pt': u('Caranda\u00ed - MG')},
 '55273732':{'en': 'Baixo Guandu - ES', 'pt': 'Baixo Guandu - ES'},
 '55273733':{'en': 'Brejetuba - ES', 'pt': 'Brejetuba - ES'},
 '55323365':{'en': u('Santa B\u00e1rbara do Tug\u00fario - MG'), 'pt': u('Santa B\u00e1rbara do Tug\u00fario - MG')},
 '55273735':{'en': u('Afonso Cl\u00e1udio - ES'), 'pt': u('Afonso Cl\u00e1udio - ES')},
 '55273736':{'en': 'Laranja da Terra - ES', 'pt': 'Laranja da Terra - ES'},
 '542202':{'en': u('Gonz\u00e1lez Cat\u00e1n/Virrey del Pino, Buenos Aires'), 'es': u('Gonz\u00e1lez Cat\u00e1n/Virrey del Pino, Buenos Aires')},
 '494663':{'de': u('S\u00fcderl\u00fcgum'), 'en': u('S\u00fcderl\u00fcgum')},
 '499166':{'de': u('M\u00fcnchsteinach'), 'en': u('M\u00fcnchsteinach')},
 '499165':{'de': 'Sugenheim', 'en': 'Sugenheim'},
 '494478':{'de': 'Cappeln Oldenburg', 'en': 'Cappeln Oldenburg'},
 '494479':{'de': 'Molbergen-Peheim', 'en': 'Molbergen-Peheim'},
 '499179':{'de': 'Freystadt', 'en': 'Freystadt'},
 '494474':{'de': 'Garrel', 'en': 'Garrel'},
 '494532':{'de': 'Bargteheide', 'en': 'Bargteheide'},
 '494472':{'de': 'Lastrup', 'en': 'Lastrup'},
 '494473':{'de': 'Emstek', 'en': 'Emstek'},
 '494471':{'de': 'Cloppenburg', 'en': 'Cloppenburg'},
 '499343':{'de': u('Lauda-K\u00f6nigshofen'), 'en': u('Lauda-K\u00f6nigshofen')},
 '55113869':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113868':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113649':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113648':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113647':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113862':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113645':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113644':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113643':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113866':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113641':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113864':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499340':{'de': u('K\u00f6nigheim-Brehmen'), 'en': u('K\u00f6nigheim-Brehmen')},
 '499347':{'de': 'Wittighausen', 'en': 'Wittighausen'},
 '498754':{'de': 'Volkenschwand', 'en': 'Volkenschwand'},
 '498753':{'de': 'Elsendorf Niederbayern', 'en': 'Elsendorf Niederbayern'},
 '498752':{'de': 'Au in der Hallertau', 'en': 'Au in der Hallertau'},
 '498751':{'de': 'Mainburg', 'en': 'Mainburg'},
 '499346':{'de': u('Gr\u00fcnsfeld'), 'en': u('Gr\u00fcnsfeld')},
 '55114079':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499433':{'de': 'Nabburg', 'en': 'Nabburg'},
 '55193458':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55114075':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114077':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114076':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114071':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '542345':{'en': '25 de Mayo, Buenos Aires', 'es': '25 de Mayo, Buenos Aires'},
 '542346':{'en': 'Chivilcoy, Buenos Aires', 'es': 'Chivilcoy, Buenos Aires'},
 '55114072':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55312586':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55213413':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497533':{'de': 'Allensbach', 'en': 'Allensbach'},
 '55213411':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '5341':{'en': u('Sancti Sp\u00edritus Province')},
 '55153003':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '497531':{'de': 'Konstanz', 'en': 'Konstanz'},
 '496458':{'de': 'Rosenthal Hessen', 'en': 'Rosenthal Hessen'},
 '55283528':{'en': 'Vargem Alta - ES', 'pt': 'Vargem Alta - ES'},
 '55283529':{'en': 'Itapemirim - ES', 'pt': 'Itapemirim - ES'},
 '55283526':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55213417':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55283524':{'en': 'Vargem Grande do Soturno - ES', 'pt': 'Vargem Grande do Soturno - ES'},
 '55283525':{'en': u('Jacigu\u00e1 - ES'), 'pt': u('Jacigu\u00e1 - ES')},
 '55283522':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55283523':{'en': 'Gironda - ES', 'pt': 'Gironda - ES'},
 '55283520':{'en': u('Pi\u00fama - ES'), 'pt': u('Pi\u00fama - ES')},
 '55283521':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55143732':{'en': u('Avar\u00e9 - SP'), 'pt': u('Avar\u00e9 - SP')},
 '496456':{'de': 'Haina Kloster', 'en': 'Haina Kloster'},
 '55143731':{'en': u('Avar\u00e9 - SP'), 'pt': u('Avar\u00e9 - SP')},
 '497534':{'de': 'Reichenau Baden', 'en': 'Reichenau Baden'},
 '496457':{'de': 'Burgwald Eder', 'en': 'Burgwald Eder'},
 '55193263':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193262':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193265':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '496106':{'de': 'Rodgau', 'en': 'Rodgau'},
 '55193267':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193266':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '496455':{'de': 'Frankenau Hessen', 'en': 'Frankenau Hessen'},
 '5348':{'en': u('Pinar del R\u00edo Province')},
 '55223094':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '496453':{'de': u('Gem\u00fcnden Wohra'), 'en': u('Gem\u00fcnden Wohra')},
 '55112111':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112112':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112113':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112114':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112115':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112117':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495053':{'de': u('Fa\u00dfberg-M\u00fcden'), 'en': u('Fassberg-M\u00fcden')},
 '55112119':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '495051':{'de': 'Bergen Kreis Celle', 'en': 'Bergen Kreis Celle'},
 '496451':{'de': 'Frankenberg Eder', 'en': 'Frankenberg Eder'},
 '495056':{'de': 'Winsen-Meissendorf', 'en': 'Winsen-Meissendorf'},
 '495055':{'de': 'Fassberg', 'en': 'Fassberg'},
 '495054':{'de': u('Bergen-S\u00fclze'), 'en': u('Bergen-S\u00fclze')},
 '55123432':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123431':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123928':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '498457':{'de': 'Vohburg an der Donau', 'en': 'Vohburg an der Donau'},
 '55223321':{'en': 'Rio das Ostras - RJ', 'pt': 'Rio das Ostras - RJ'},
 '55115854':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115587':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115584':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115585':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115582':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5042566':{'en': 'Jardines Del Valle'},
 '5042565':{'en': u('Chamelec\u00f3n')},
 '5042564':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '55123923':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55115588':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115589':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123922':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '49961':{'de': 'Weiden in der Oberpfalz', 'en': 'Weiden in der Oberpfalz'},
 '55163947':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55123924':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55212397':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55212394':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55123927':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55212391':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153467':{'en': 'Capela do Alto - SP', 'pt': 'Capela do Alto - SP'},
 '55123926':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55283511':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55173011':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173012':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55283517':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '496508':{'de': 'Hetzerath Mosel', 'en': 'Hetzerath Mosel'},
 '496509':{'de': u('B\u00fcdlich'), 'en': u('B\u00fcdlich')},
 '55212649':{'en': 'Cachoeiras de Macacu - RJ', 'pt': 'Cachoeiras de Macacu - RJ'},
 '55212648':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '496500':{'de': 'Waldrach', 'en': 'Waldrach'},
 '496501':{'de': 'Konz', 'en': 'Konz'},
 '496502':{'de': 'Schweich', 'en': 'Schweich'},
 '496503':{'de': 'Hermeskeil', 'en': 'Hermeskeil'},
 '496504':{'de': 'Thalfang', 'en': 'Thalfang'},
 '496505':{'de': 'Kordel', 'en': 'Kordel'},
 '496506':{'de': 'Welschbillig', 'en': 'Welschbillig'},
 '496507':{'de': 'Neumagen-Dhron', 'en': 'Neumagen-Dhron'},
 '494275':{'de': 'Ehrenburg', 'en': 'Ehrenburg'},
 '498453':{'de': 'Reichertshofen Oberbayern', 'en': 'Reichertshofen Oberbayern'},
 '55114677':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114676':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114675':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114674':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55193852':{'en': 'Pedreira - SP', 'pt': 'Pedreira - SP'},
 '55193853':{'en': 'Pedreira - SP', 'pt': 'Pedreira - SP'},
 '55193851':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55114679':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114678':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114513':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114511':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55313873':{'en': u('Matip\u00f3 - MG'), 'pt': u('Matip\u00f3 - MG')},
 '55114518':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114519':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55313871':{'en': 'Rio Casca - MG', 'pt': 'Rio Casca - MG'},
 '55313877':{'en': 'Jequeri - MG', 'pt': 'Jequeri - MG'},
 '55313875':{'en': 'Santa Margarida - MG', 'pt': 'Santa Margarida - MG'},
 '55213512':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213513':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55173421':{'en': 'Votuporanga - SP', 'pt': 'Votuporanga - SP'},
 '55173423':{'en': 'Votuporanga - SP', 'pt': 'Votuporanga - SP'},
 '55173422':{'en': 'Votuporanga - SP', 'pt': 'Votuporanga - SP'},
 '55173426':{'en': 'Votuporanga - SP', 'pt': 'Votuporanga - SP'},
 '494861':{'de': u('T\u00f6nning'), 'en': u('T\u00f6nning')},
 '494863':{'de': 'Sankt Peter-Ording', 'en': 'Sankt Peter-Ording'},
 '494862':{'de': 'Garding', 'en': 'Garding'},
 '494865':{'de': 'Osterhever', 'en': 'Osterhever'},
 '494864':{'de': 'Oldenswort', 'en': 'Oldenswort'},
 '55133258':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '497363':{'de': 'Lauchheim', 'en': 'Lauchheim'},
 '497362':{'de': 'Bopfingen', 'en': 'Bopfingen'},
 '497361':{'de': 'Aalen', 'en': 'Aalen'},
 '497367':{'de': 'Aalen-Ebnat', 'en': 'Aalen-Ebnat'},
 '497366':{'de': u('Abtsgm\u00fcnd'), 'en': u('Abtsgm\u00fcnd')},
 '497365':{'de': u('Essingen W\u00fcrttemberg'), 'en': u('Essingen W\u00fcrttemberg')},
 '497364':{'de': 'Oberkochen', 'en': 'Oberkochen'},
 '55212470':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212471':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55133446':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133445':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133448':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55153258':{'en': u('Guare\u00ed - SP'), 'pt': u('Guare\u00ed - SP')},
 '55153259':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '55153255':{'en': 'Angatuba - SP', 'pt': 'Angatuba - SP'},
 '55153256':{'en': 'Campina do Monte Alegre - SP', 'pt': 'Campina do Monte Alegre - SP'},
 '55153257':{'en': 'Porangaba - SP', 'pt': 'Porangaba - SP'},
 '55153251':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '55153252':{'en': 'Torre de Pedra - SP', 'pt': 'Torre de Pedra - SP'},
 '55153253':{'en': 'Quadra - SP', 'pt': 'Quadra - SP'},
 '55193508':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55313121':{'en': u('Igarap\u00e9 - MG'), 'pt': u('Igarap\u00e9 - MG')},
 '55212479':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '498102':{'de': u('H\u00f6henkirchen-Siegertsbrunn'), 'en': u('H\u00f6henkirchen-Siegertsbrunn')},
 '498106':{'de': 'Vaterstetten', 'en': 'Vaterstetten'},
 '498104':{'de': 'Sauerlach', 'en': 'Sauerlach'},
 '498105':{'de': 'Gilching', 'en': 'Gilching'},
 '494285':{'de': 'Rhade bei Zeven', 'en': 'Rhade bei Zeven'},
 '494284':{'de': 'Selsingen', 'en': 'Selsingen'},
 '494287':{'de': 'Heeslingen-Boitzen', 'en': 'Heeslingen-Boitzen'},
 '494286':{'de': 'Gyhum', 'en': 'Gyhum'},
 '494281':{'de': 'Zeven', 'en': 'Zeven'},
 '494283':{'de': 'Tarmstedt', 'en': 'Tarmstedt'},
 '494282':{'de': 'Sittensen', 'en': 'Sittensen'},
 '494289':{'de': 'Kirchtimke', 'en': 'Kirchtimke'},
 '494288':{'de': 'Horstedt Kreis Rotenburg', 'en': 'Horstedt Kreis Rotenburg'},
 '55163511':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55163512':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163513':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55113988':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55113989':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163518':{'en': 'Cravinhos - SP', 'pt': 'Cravinhos - SP'},
 '55113985':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113986':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113987':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113982':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212008':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55183902':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '49751':{'de': 'Ravensburg', 'en': 'Ravensburg'},
 '52495':{'en': 'Aguascalientes/Jalisco', 'es': 'Aguascalientes/Jalisco'},
 '52494':{'en': 'Jerez de Garcia Salinas, ZAC', 'es': u('Jerez de Garc\u00eda Salinas, ZAC')},
 '52496':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '52493':{'en': 'Fresnillo, ZAC', 'es': 'Fresnillo, ZAC'},
 '52492':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '499876':{'de': 'Rohr Mittelfranken', 'en': 'Rohr Mittelfranken'},
 '52499':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '52498':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '55113184':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113180':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113183':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55113188':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112858':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313378':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112851':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313377':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112852':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112855':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112854':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313373':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112856':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183839':{'en': 'Jamaica - SP', 'pt': 'Jamaica - SP'},
 '55212237':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113328':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113329':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52721':{'en': 'Ixtapan de la Sal, MEX', 'es': 'Ixtapan de la Sal, MEX'},
 '55113459':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52727':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52726':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52725':{'en': 'Almoloya de Juarez/Santa Maria Del Monte, MEX', 'es': u('Almoloya de Ju\u00e1rez/Santa Mar\u00eda del Monte, MEX')},
 '52724':{'en': 'Luvianos/Tejupilco de Hidalgo, MEX', 'es': 'Luvianos/Tejupilco de Hidalgo, MEX'},
 '55113452':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113453':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52729':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55113323':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113457':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113326':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113327':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213358':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213359':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55122139':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55213350':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55122134':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55122136':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55122131':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55213355':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213356':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193181':{'en': 'Floresta Escura - SP', 'pt': 'Floresta Escura - SP'},
 '55112589':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112588':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112586':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112583':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112582':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112581':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495422':{'de': 'Melle', 'en': 'Melle'},
 '495423':{'de': 'Versmold', 'en': 'Versmold'},
 '495421':{'de': 'Dissen am Teutoburger Wald', 'en': 'Dissen am Teutoburger Wald'},
 '495426':{'de': 'Glandorf', 'en': 'Glandorf'},
 '495427':{'de': 'Melle-Buer', 'en': 'Melle-Buer'},
 '495424':{'de': 'Bad Rothenfelde', 'en': 'Bad Rothenfelde'},
 '495425':{'de': 'Borgholzhausen', 'en': 'Borgholzhausen'},
 '495428':{'de': 'Melle-Neuenkirchen', 'en': 'Melle-Neuenkirchen'},
 '495429':{'de': 'Melle-Wellingholzhausen', 'en': 'Melle-Wellingholzhausen'},
 '55323541':{'en': u('Ub\u00e1 - MG'), 'pt': u('Ub\u00e1 - MG')},
 '55114234':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55273322':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '499869':{'de': 'Wettringen Mittelfranken', 'en': 'Wettringen Mittelfranken'},
 '55113791':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313493':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '499867':{'de': 'Geslau', 'en': 'Geslau'},
 '55213724':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213726':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '499865':{'de': 'Adelshofen Mittelfranken', 'en': 'Adelshofen Mittelfranken'},
 '55273321':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55112321':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323312':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '499871':{'de': 'Windsbach', 'en': 'Windsbach'},
 '55123882':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123883':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123881':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123886':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123668':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55123669':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55123666':{'en': u('Santo Ant\u00f4nio do Pinhal - SP'), 'pt': u('Santo Ant\u00f4nio do Pinhal - SP')},
 '55222751':{'en': u('S\u00e3o Fid\u00e9lis - RJ'), 'pt': u('S\u00e3o Fid\u00e9lis - RJ')},
 '55123664':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '499861':{'de': 'Rothenburg ob der Tauber', 'en': 'Rothenburg ob der Tauber'},
 '55123662':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55123663':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55112296':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323313':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '496852':{'de': 'Nohfelden', 'en': 'Nohfelden'},
 '55193607':{'en': 'Casa Branca - SP', 'pt': 'Casa Branca - SP'},
 '55222640':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '496677':{'de': 'Neuenstein Hessen', 'en': 'Neuenstein Hessen'},
 '55113953':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496851':{'de': 'St Wendel', 'en': 'St Wendel'},
 '55243364':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '496196':{'de': 'Bad Soden am Taunus', 'en': 'Bad Soden am Taunus'},
 '496195':{'de': 'Kelkheim Taunus', 'en': 'Kelkheim Taunus'},
 '55243367':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55243368':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '496856':{'de': 'St Wendel-Niederkirchen', 'en': 'St Wendel-Niederkirchen'},
 '496198':{'de': 'Eppstein', 'en': 'Eppstein'},
 '55113951':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496857':{'de': 'Namborn', 'en': 'Namborn'},
 '55113365':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496854':{'de': 'Oberthal Saar', 'en': 'Oberthal Saar'},
 '55213660':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55113955':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115054':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115055':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115056':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115051':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115052':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115053':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213664':{'en': 'Belford Roxo - RJ', 'pt': 'Belford Roxo - RJ'},
 '55213665':{'en': 'Queimados - RJ', 'pt': 'Queimados - RJ'},
 '55333267':{'en': u('Aimor\u00e9s - MG'), 'pt': u('Aimor\u00e9s - MG')},
 '496776':{'de': 'Dachsenhausen', 'en': 'Dachsenhausen'},
 '496775':{'de': u('Str\u00fcth Taunus'), 'en': u('Str\u00fcth Taunus')},
 '496774':{'de': 'Kaub', 'en': 'Kaub'},
 '496773':{'de': 'Kamp-Bornhofen', 'en': 'Kamp-Bornhofen'},
 '496772':{'de': u('Nast\u00e4tten'), 'en': u('Nast\u00e4tten')},
 '496771':{'de': 'St Goarshausen', 'en': 'St Goarshausen'},
 '55242107':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55242106':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55242104':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242103':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55242102':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55242109':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55183608':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183609':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55313615':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183602':{'en': 'Gabriel Monteiro - SP', 'pt': 'Gabriel Monteiro - SP'},
 '55183603':{'en': u('Luizi\u00e2nia - SP'), 'pt': u('Luizi\u00e2nia - SP')},
 '55183601':{'en': 'Bento de Abreu - SP', 'pt': 'Bento de Abreu - SP'},
 '55183606':{'en': 'Guararapes - SP', 'pt': 'Guararapes - SP'},
 '55183607':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183604':{'en': u('Vicentin\u00f3polis - SP'), 'pt': u('Vicentin\u00f3polis - SP')},
 '55183605':{'en': u('Sant\u00f3polis do Aguape\u00ed - SP'), 'pt': u('Sant\u00f3polis do Aguape\u00ed - SP')},
 '499152':{'de': 'Hartenstein Mittelfranken', 'en': 'Hartenstein Mittelfranken'},
 '55133872':{'en': 'Sete Barras - SP', 'pt': 'Sete Barras - SP'},
 '55133302':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133871':{'en': 'Eldorado - SP', 'pt': 'Eldorado - SP'},
 '55133305':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133879':{'en': u('Barra do Bra\u00e7o - SP'), 'pt': u('Barra do Bra\u00e7o - SP')},
 '495441':{'de': 'Diepholz', 'en': 'Diepholz'},
 '55323393':{'en': 'Senhora das Dores - MG', 'pt': 'Senhora das Dores - MG'},
 '495442':{'de': 'Barnstorf Kreis Diepholz', 'en': 'Barnstorf Kreis Diepholz'},
 '55143880':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55143881':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55143882':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '495443':{'de': u('Lemf\u00f6rde'), 'en': u('Lemf\u00f6rde')},
 '55143884':{'en': 'Anhembi - SP', 'pt': 'Anhembi - SP'},
 '55143885':{'en': u('Piramb\u00f3ia - SP'), 'pt': u('Piramb\u00f3ia - SP')},
 '542229':{'en': u('Juan Mar\u00eda Guti\u00e9rrez/El Pato, Buenos Aires'), 'es': u('Juan Mar\u00eda Guti\u00e9rrez/El Pato, Buenos Aires')},
 '55273711':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '542227':{'en': 'Lobos, Buenos Aires', 'es': 'Lobos, Buenos Aires'},
 '542226':{'en': u('Ca\u00f1uelas, Buenos Aires'), 'es': u('Ca\u00f1uelas, Buenos Aires')},
 '542225':{'en': 'Alejandro Korn, Buenos Aires', 'es': 'Alejandro Korn, Buenos Aires'},
 '542224':{'en': 'Glew/Guernica, Buenos Aires', 'es': 'Glew/Guernica, Buenos Aires'},
 '542223':{'en': 'Brandsen, Buenos Aires', 'es': 'Brandsen, Buenos Aires'},
 '542221':{'en': u('Magdalena/Ver\u00f3nica, Buenos Aires'), 'es': u('Magdalena/Ver\u00f3nica, Buenos Aires')},
 '495197':{'de': 'Soltau-Frielingen', 'en': 'Soltau-Frielingen'},
 '494458':{'de': 'Wiefelstede-Spohle', 'en': 'Wiefelstede-Spohle'},
 '495446':{'de': 'Rehden', 'en': 'Rehden'},
 '494451':{'de': 'Varel Jadebusen', 'en': 'Varel Jadebusen'},
 '494452':{'de': 'Zetel-Neuenburg', 'en': 'Zetel-Neuenburg'},
 '494453':{'de': 'Zetel', 'en': 'Zetel'},
 '494454':{'de': 'Jade', 'en': 'Jade'},
 '494455':{'de': 'Jade-Schweiburg', 'en': 'Jade-Schweiburg'},
 '494456':{'de': u('Varel-Altj\u00fchrden'), 'en': u('Varel-Altj\u00fchrden')},
 '55113665':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113664':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113667':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113666':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113661':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113844':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113663':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113662':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113849':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113848':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113668':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542323':{'en': u('Luj\u00e1n, Buenos Aires'), 'es': u('Luj\u00e1n, Buenos Aires')},
 '542320':{'en': u('Jos\u00e9 C. Paz, Buenos Aires'), 'es': u('Jos\u00e9 C. Paz, Buenos Aires')},
 '542326':{'en': 'San Antonio de Areco, Buenos Aires', 'es': 'San Antonio de Areco, Buenos Aires'},
 '542324':{'en': 'Mercedes, Buenos Aires', 'es': 'Mercedes, Buenos Aires'},
 '542325':{'en': u('San Andr\u00e9s de Giles, Buenos Aires'), 'es': u('San Andr\u00e9s de Giles, Buenos Aires')},
 '498731':{'de': 'Dingolfing', 'en': 'Dingolfing'},
 '498733':{'de': 'Mengkofen', 'en': 'Mengkofen'},
 '498732':{'de': 'Frontenhausen', 'en': 'Frontenhausen'},
 '498735':{'de': 'Gangkofen-Kollbach', 'en': 'Gangkofen-Kollbach'},
 '498734':{'de': 'Reisbach Niederbayern', 'en': 'Reisbach Niederbayern'},
 '494634':{'de': 'Husby', 'en': 'Husby'},
 '494635':{'de': u('S\u00f6rup'), 'en': u('S\u00f6rup')},
 '494636':{'de': 'Langballig', 'en': 'Langballig'},
 '494637':{'de': 'Sterup', 'en': 'Sterup'},
 '494630':{'de': 'Barderup', 'en': 'Barderup'},
 '494631':{'de': u('Gl\u00fccksburg Ostsee'), 'en': u('Gl\u00fccksburg Ostsee')},
 '494632':{'de': 'Steinbergkirche', 'en': 'Steinbergkirche'},
 '494633':{'de': 'Satrup', 'en': 'Satrup'},
 '55114099':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114098':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '494638':{'de': 'Tarp', 'en': 'Tarp'},
 '494639':{'de': 'Schafflund', 'en': 'Schafflund'},
 '55312564':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55173043':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55213291':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213293':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213292':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213295':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213294':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213296':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55283544':{'en': 'Muniz Freire - ES', 'pt': 'Muniz Freire - ES'},
 '55283545':{'en': u('I\u00fana - ES'), 'pt': u('I\u00fana - ES')},
 '55283546':{'en': 'Venda Nova do Imigrante - ES', 'pt': 'Venda Nova do Imigrante - ES'},
 '55283547':{'en': u('Concei\u00e7\u00e3o do Castelo - ES'), 'pt': u('Concei\u00e7\u00e3o do Castelo - ES')},
 '55283542':{'en': 'Castelo - ES', 'pt': 'Castelo - ES'},
 '55283543':{'en': 'Ibatiba - ES', 'pt': 'Ibatiba - ES'},
 '55283548':{'en': 'Irupi - ES', 'pt': 'Irupi - ES'},
 '499154':{'de': 'Pommelsbrunn', 'en': 'Pommelsbrunn'},
 '55193209':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193208':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193207':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193206':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193203':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193202':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193201':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55112136':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55112137':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112134':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112135':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112132':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112133':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112131':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123411':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123413':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55112138':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112139':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543327':{'en': u('Benav\u00eddez, Buenos Aires'), 'es': u('Benav\u00eddez, Buenos Aires')},
 '543329':{'en': 'San Pedro, Buenos Aires', 'es': 'San Pedro, Buenos Aires'},
 '55163729':{'en': 'Ituverava - SP', 'pt': 'Ituverava - SP'},
 '55163728':{'en': u('S\u00e3o Joaquim da Barra - SP'), 'pt': u('S\u00e3o Joaquim da Barra - SP')},
 '55163723':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163722':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163721':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163726':{'en': u('Orl\u00e2ndia - SP'), 'pt': u('Orl\u00e2ndia - SP')},
 '55163725':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163724':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55115872':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115873':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115870':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115871':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115874':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115875':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49941':{'de': 'Regensburg', 'en': 'Regensburg'},
 '5042545':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5042540':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5182':{'en': 'Madre de Dios'},
 '5183':{'en': u('Apur\u00edmac')},
 '543498':{'en': 'San Justo, Santa Fe', 'es': 'San Justo, Santa Fe'},
 '55273181':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '5184':{'en': 'Cusco'},
 '543493':{'en': 'Sunchales, Santa Fe', 'es': 'Sunchales, Santa Fe'},
 '543492':{'en': 'Rafaela, Santa Fe', 'es': 'Rafaela, Santa Fe'},
 '543491':{'en': 'Ceres, Santa Fe', 'es': 'Ceres, Santa Fe'},
 '543497':{'en': 'Llambi Campbell, Santa Fe', 'es': 'Llambi Campbell, Santa Fe'},
 '543496':{'en': 'Esperanza, Santa Fe', 'es': 'Esperanza, Santa Fe'},
 '496243':{'de': 'Monsheim', 'en': 'Monsheim'},
 '496242':{'de': 'Osthofen', 'en': 'Osthofen'},
 '55173045':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55114994':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114995':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '496247':{'de': 'Worms-Pfeddersheim', 'en': 'Worms-Pfeddersheim'},
 '55212228':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55114993':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '496562':{'de': 'Speicher', 'en': 'Speicher'},
 '496563':{'de': 'Kyllburg', 'en': 'Kyllburg'},
 '496561':{'de': 'Bitburg', 'en': 'Bitburg'},
 '496566':{'de': u('K\u00f6rperich'), 'en': u('K\u00f6rperich')},
 '496567':{'de': 'Oberkail', 'en': 'Oberkail'},
 '496564':{'de': 'Neuerburg Eifel', 'en': 'Neuerburg Eifel'},
 '496565':{'de': 'Dudeldorf', 'en': 'Dudeldorf'},
 '55143311':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '496568':{'de': 'Wolsfeld', 'en': 'Wolsfeld'},
 '496569':{'de': 'Bickendorf', 'en': 'Bickendorf'},
 '55212225':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143316':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '54379':{'en': 'Corrientes, Corrientes', 'es': 'Corrientes, Corrientes'},
 '55212224':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212223':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212088':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55213078':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212220':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '5533':{'en': 'Minas Gerais', 'pt': 'Minas Gerais'},
 '55212436':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '5531':{'en': 'Minas Gerais', 'pt': 'Minas Gerais'},
 '55114658':{'en': u('Igarat\u00e1 - SP'), 'pt': u('Igarat\u00e1 - SP')},
 '55114655':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114654':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114657':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114656':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114651':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55193831':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55114653':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114652':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55153566':{'en': 'Bairro Palmitalzinho - SP', 'pt': 'Bairro Palmitalzinho - SP'},
 '55212437':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153565':{'en': 'Itaporanga - SP', 'pt': 'Itaporanga - SP'},
 '55153563':{'en': 'Guapiara - SP', 'pt': 'Guapiara - SP'},
 '496386':{'de': 'Altenkirchen Pfalz', 'en': 'Altenkirchen Pfalz'},
 '496387':{'de': 'Sankt Julian', 'en': 'Sankt Julian'},
 '496384':{'de': 'Konken', 'en': 'Konken'},
 '496385':{'de': 'Reichenbach-Steegen', 'en': 'Reichenbach-Steegen'},
 '496382':{'de': 'Lauterecken', 'en': 'Lauterecken'},
 '496383':{'de': u('Glan-M\u00fcnchweiler'), 'en': u('Glan-M\u00fcnchweiler')},
 '496381':{'de': 'Kusel', 'en': 'Kusel'},
 '55333284':{'en': u('Frei Inoc\u00eancio - MG'), 'pt': u('Frei Inoc\u00eancio - MG')},
 '497161':{'de': u('G\u00f6ppingen'), 'en': u('G\u00f6ppingen')},
 '55183992':{'en': 'Narandiba - SP', 'pt': 'Narandiba - SP'},
 '497163':{'de': 'Ebersbach an der Fils', 'en': 'Ebersbach an der Fils'},
 '497162':{'de': u('S\u00fc\u00dfen'), 'en': u('S\u00fcssen')},
 '497165':{'de': u('G\u00f6ppingen-Hohenstaufen'), 'en': u('G\u00f6ppingen-Hohenstaufen')},
 '497164':{'de': u('Boll Kreis G\u00f6ppingen'), 'en': u('Boll Kreis G\u00f6ppingen')},
 '497166':{'de': 'Adelberg', 'en': 'Adelberg'},
 '494646':{'de': 'Mohrkirch', 'en': 'Mohrkirch'},
 '55183991':{'en': 'Mirante do Paranapanema - SP', 'pt': 'Mirante do Paranapanema - SP'},
 '55183996':{'en': u('Marab\u00e1 Paulista - SP'), 'pt': u('Marab\u00e1 Paulista - SP')},
 '55183994':{'en': u('Emilian\u00f3polis - SP'), 'pt': u('Emilian\u00f3polis - SP')},
 '55173445':{'en': u('Am\u00e9rico de Campos - SP'), 'pt': u('Am\u00e9rico de Campos - SP')},
 '55173442':{'en': u('Fernand\u00f3polis - SP'), 'pt': u('Fernand\u00f3polis - SP')},
 '55173441':{'en': 'General Salgado - SP', 'pt': 'General Salgado - SP'},
 '494849':{'de': 'Hooge', 'en': 'Hooge'},
 '494848':{'de': 'Rantrum', 'en': 'Rantrum'},
 '494843':{'de': u('Vi\u00f6l'), 'en': u('Vi\u00f6l')},
 '494842':{'de': 'Nordstrand', 'en': 'Nordstrand'},
 '494841':{'de': 'Husum Nordsee', 'en': 'Husum Nordsee'},
 '494847':{'de': 'Oster-Ohrstedt', 'en': 'Oster-Ohrstedt'},
 '494846':{'de': 'Hattstedt', 'en': 'Hattstedt'},
 '494845':{'de': 'Ostenfeld Husum', 'en': 'Ostenfeld Husum'},
 '494844':{'de': 'Pellworm', 'en': 'Pellworm'},
 '55133469':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133468':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55183999':{'en': 'Estrela do Norte - SP', 'pt': 'Estrela do Norte - SP'},
 '497389':{'de': 'Heroldstatt', 'en': 'Heroldstatt'},
 '497388':{'de': 'Pfronstetten', 'en': 'Pfronstetten'},
 '497385':{'de': 'Gomadingen', 'en': 'Gomadingen'},
 '497384':{'de': u('Schelklingen-H\u00fctten'), 'en': u('Schelklingen-H\u00fctten')},
 '497387':{'de': u('Hohenstein W\u00fcrttemberg'), 'en': u('Hohenstein W\u00fcrttemberg')},
 '497386':{'de': 'Hayingen', 'en': 'Hayingen'},
 '497381':{'de': u('M\u00fcnsingen'), 'en': u('M\u00fcnsingen')},
 '55133464':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '497383':{'de': u('M\u00fcnsingen-Buttenhausen'), 'en': u('M\u00fcnsingen-Buttenhausen')},
 '497382':{'de': u('R\u00f6merstein'), 'en': u('R\u00f6merstein')},
 '55153272':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153273':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55112464':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55153271':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153276':{'en': u('Sarapu\u00ed - SP'), 'pt': u('Sarapu\u00ed - SP')},
 '55153277':{'en': u('Tapira\u00ed - SP'), 'pt': u('Tapira\u00ed - SP')},
 '55153274':{'en': 'Alambari - SP', 'pt': 'Alambari - SP'},
 '55153275':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153278':{'en': 'Pilar do Sul - SP', 'pt': 'Pilar do Sul - SP'},
 '55153279':{'en': 'Sao Miguel Arcanjo - SP', 'pt': 'Sao Miguel Arcanjo - SP'},
 '55133375':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '494642':{'de': 'Kappeln Schlei', 'en': 'Kappeln Schlei'},
 '52924':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52921':{'en': 'Coatzacoalcos/Ixhuatlan Del Sureste, VER', 'es': u('Coatzacoalcos/Ixhuatl\u00e1n del Sureste, VER')},
 '52923':{'en': 'Tabasco/Veracruz', 'es': 'Tabasco/Veracruz'},
 '52922':{'en': 'Veracruz', 'es': 'Veracruz'},
 '498124':{'de': 'Forstern Oberbayern', 'en': 'Forstern Oberbayern'},
 '498121':{'de': 'Markt Schwaben', 'en': 'Markt Schwaben'},
 '498122':{'de': 'Erding', 'en': 'Erding'},
 '498123':{'de': 'Moosinning', 'en': 'Moosinning'},
 '55193863':{'en': 'Itapira - SP', 'pt': 'Itapira - SP'},
 '499659':{'de': 'Leuchtenberg', 'en': 'Leuchtenberg'},
 '499658':{'de': 'Georgenberg', 'en': 'Georgenberg'},
 '55193862':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '499655':{'de': u('T\u00e4nnesberg'), 'en': u('T\u00e4nnesberg')},
 '499654':{'de': 'Pleystein', 'en': 'Pleystein'},
 '499657':{'de': 'Waldthurn', 'en': 'Waldthurn'},
 '499656':{'de': u('Moosbach bei Vohenstrau\u00df'), 'en': 'Moosbach bei Vohenstrauss'},
 '499651':{'de': 'Vohenstrauss', 'en': 'Vohenstrauss'},
 '55193861':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '499653':{'de': 'Eslarn', 'en': 'Eslarn'},
 '499652':{'de': 'Waidhaus', 'en': 'Waidhaus'},
 '497839':{'de': 'Schapbach', 'en': 'Schapbach'},
 '497838':{'de': 'Nordrach', 'en': 'Nordrach'},
 '497837':{'de': 'Oberharmersbach', 'en': 'Oberharmersbach'},
 '497836':{'de': 'Schiltach', 'en': 'Schiltach'},
 '497835':{'de': 'Zell am Harmersbach', 'en': 'Zell am Harmersbach'},
 '497834':{'de': 'Wolfach', 'en': 'Wolfach'},
 '497833':{'de': 'Hornberg Schwarzwaldbahn', 'en': 'Hornberg Schwarzwaldbahn'},
 '497832':{'de': 'Haslach im Kinzigtal', 'en': 'Haslach im Kinzigtal'},
 '497831':{'de': 'Hausach', 'en': 'Hausach'},
 '55193866':{'en': 'Conchal - SP', 'pt': 'Conchal - SP'},
 '55193865':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55212594':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55133378':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '498388':{'de': 'Hergensweiler', 'en': 'Hergensweiler'},
 '498389':{'de': 'Weissensberg', 'en': 'Weissensberg'},
 '498380':{'de': 'Achberg', 'en': 'Achberg'},
 '498381':{'de': u('Lindenberg im Allg\u00e4u'), 'en': u('Lindenberg im Allg\u00e4u')},
 '498382':{'de': 'Lindau Bodensee', 'en': 'Lindau Bodensee'},
 '498383':{'de': u('Gr\u00fcnenbach Allg\u00e4u'), 'en': u('Gr\u00fcnenbach Allg\u00e4u')},
 '498384':{'de': u('R\u00f6thenbach Allg\u00e4u'), 'en': u('R\u00f6thenbach Allg\u00e4u')},
 '498385':{'de': 'Hergatz', 'en': 'Hergatz'},
 '498386':{'de': 'Oberstaufen', 'en': 'Oberstaufen'},
 '498387':{'de': 'Weiler-Simmerberg', 'en': 'Weiler-Simmerberg'},
 '499471':{'de': 'Burglengenfeld', 'en': 'Burglengenfeld'},
 '49771':{'de': 'Donaueschingen', 'en': 'Donaueschingen'},
 '499473':{'de': u('Kallm\u00fcnz'), 'en': u('Kallm\u00fcnz')},
 '499472':{'de': 'Hohenfels Oberpfalz', 'en': 'Hohenfels Oberpfalz'},
 '499474':{'de': u('Schmidm\u00fchlen'), 'en': u('Schmidm\u00fchlen')},
 '495382':{'de': 'Bad Gandersheim', 'en': 'Bad Gandersheim'},
 '495381':{'de': 'Seesen', 'en': 'Seesen'},
 '52418':{'en': 'Dolores Hidalgo/San Diego de la Union, GTO', 'es': u('Dolores Hidalgo/San Diego de la Uni\u00f3n, GTO')},
 '55114138':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113104':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313391':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55313397':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55112839':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52414':{'en': 'Tequisquiapan, QRO', 'es': 'Tequisquiapan, QRO'},
 '55112837':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114131':{'en': 'Pirapora do Bom Jesus - SP', 'pt': 'Pirapora do Bom Jesus - SP'},
 '55114132':{'en': 'Pirapora do Bom Jesus - SP', 'pt': 'Pirapora do Bom Jesus - SP'},
 '55112571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114134':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114135':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55112831':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114137':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55193019':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '494724':{'de': u('Cuxhaven-L\u00fcdingworth'), 'en': u('Cuxhaven-L\u00fcdingworth')},
 '55193544':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55113100':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193546':{'en': u('Cordeir\u00f3polis - SP'), 'pt': u('Cordeir\u00f3polis - SP')},
 '55193547':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55193016':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193017':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193542':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55193543':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '52749':{'en': 'Calpulalpan, TLAX', 'es': 'Calpulalpan, TLAX'},
 '52748':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '55113308':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '52741':{'en': 'Guerrero', 'es': 'Guerrero'},
 '55113307':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52743':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52742':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52745':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52744':{'en': 'Acapulco/Xaltianguis, GRO', 'es': 'Acapulco/Xaltianguis, GRO'},
 '52747':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52746':{'en': 'Puebla/Veracruz', 'es': 'Puebla/Veracruz'},
 '55213378':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213376':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213377':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213375':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213372':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213373':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213371':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499386':{'de': 'Prosselsheim', 'en': 'Prosselsheim'},
 '499385':{'de': 'Kolitzheim', 'en': 'Kolitzheim'},
 '499384':{'de': 'Schwanfeld', 'en': 'Schwanfeld'},
 '499383':{'de': 'Wiesentheid', 'en': 'Wiesentheid'},
 '499382':{'de': 'Gerolzhofen', 'en': 'Gerolzhofen'},
 '499381':{'de': 'Volkach', 'en': 'Volkach'},
 '55173694':{'en': 'Dirce Reis - SP', 'pt': 'Dirce Reis - SP'},
 '55193758':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '495409':{'de': 'Hilter am Teutoburger Wald', 'en': 'Hilter am Teutoburger Wald'},
 '495158':{'de': 'Hemeringen', 'en': 'Hemeringen'},
 '495159':{'de': u('Coppenbr\u00fcgge-Bisperode'), 'en': u('Coppenbr\u00fcgge-Bisperode')},
 '495404':{'de': 'Westerkappeln', 'en': 'Westerkappeln'},
 '495157':{'de': u('Emmerthal-B\u00f6rry'), 'en': u('Emmerthal-B\u00f6rry')},
 '495154':{'de': 'Aerzen', 'en': 'Aerzen'},
 '495155':{'de': 'Emmerthal', 'en': 'Emmerthal'},
 '495152':{'de': 'Hessisch Oldendorf', 'en': 'Hessisch Oldendorf'},
 '495153':{'de': 'Salzhemmendorf', 'en': 'Salzhemmendorf'},
 '495402':{'de': u('Bissendorf Kreis Osnabr\u00fcck'), 'en': u('Bissendorf Kreis Osnabr\u00fcck')},
 '495151':{'de': 'Hameln', 'en': 'Hameln'},
 '55113679':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173579':{'en': 'Botelho - SP', 'pt': 'Botelho - SP'},
 '55213748':{'en': 'Belford Roxo - RJ', 'pt': 'Belford Roxo - RJ'},
 '55213747':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213746':{'en': 'Mesquita - RJ', 'pt': 'Mesquita - RJ'},
 '55213745':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55213743':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55213742':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55112301':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112303':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112304':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55123604':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55173573':{'en': 'Roberto - SP', 'pt': 'Roberto - SP'},
 '55123607':{'en': u('Trememb\u00e9 - SP'), 'pt': u('Trememb\u00e9 - SP')},
 '55123600':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123601':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123602':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55173572':{'en': 'Pindorama - SP', 'pt': 'Pindorama - SP'},
 '55222777':{'en': 'Rio das Ostras - RJ', 'pt': 'Rio das Ostras - RJ'},
 '55123608':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123609':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55222771':{'en': 'Rio das Ostras - RJ', 'pt': 'Rio das Ostras - RJ'},
 '55273345':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55173576':{'en': 'Ariranha - SP', 'pt': 'Ariranha - SP'},
 '55273344':{'en': 'Viana - ES', 'pt': 'Viana - ES'},
 '543458':{'en': u('San Jos\u00e9 de Feliciano, Entre R\u00edos'), 'es': u('San Jos\u00e9 de Feliciano, Entre R\u00edos')},
 '55212568':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212569':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55243344':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55243345':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55243342':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55243343':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55114786':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '496175':{'de': 'Friedrichsdorf Taunus', 'en': 'Friedrichsdorf Taunus'},
 '496174':{'de': u('K\u00f6nigstein im Taunus'), 'en': u('K\u00f6nigstein im Taunus')},
 '55212562':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212563':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496171':{'de': 'Oberursel Taunus', 'en': 'Oberursel Taunus'},
 '55114785':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '496173':{'de': 'Kronberg im Taunus', 'en': 'Kronberg im Taunus'},
 '496172':{'de': u('Bad Homburg von der H\u00f6he'), 'en': u('Bad Homburg von der H\u00f6he')},
 '55114784':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55115072':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115073':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115071':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114781':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55115074':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115078':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273369':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55164003':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55273361':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55273364':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55173874':{'en': 'Macaubal - SP', 'pt': 'Macaubal - SP'},
 '55173875':{'en': u('S\u00e3o Jo\u00e3o de Iracema - SP'), 'pt': u('S\u00e3o Jo\u00e3o de Iracema - SP')},
 '55133324':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133323':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133321':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55313498':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313494':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313495':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273776':{'en': u('Barra de S\u00e3o Francisco - ES'), 'pt': u('Barra de S\u00e3o Francisco - ES')},
 '55313497':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273770':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55273771':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '55273772':{'en': u('Nova Ven\u00e9cia - ES'), 'pt': u('Nova Ven\u00e9cia - ES')},
 '55213175':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '494432':{'de': u('D\u00f6tlingen-Brettorf'), 'en': u('D\u00f6tlingen-Brettorf')},
 '55114302':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173386':{'en': 'Pirangi - SP', 'pt': 'Pirangi - SP'},
 '494431':{'de': 'Wildeshausen', 'en': 'Wildeshausen'},
 '494434':{'de': 'Colnrade', 'en': 'Colnrade'},
 '494435':{'de': 'Grossenkneten', 'en': 'Grossenkneten'},
 '542241':{'en': u('Chascom\u00fas, Buenos Aires'), 'es': u('Chascom\u00fas, Buenos Aires')},
 '542243':{'en': 'General Belgrano, Buenos Aires', 'es': 'General Belgrano, Buenos Aires'},
 '542242':{'en': 'Lezama, Buenos Aires', 'es': 'Lezama, Buenos Aires'},
 '542245':{'en': 'Dolores, Buenos Aires', 'es': 'Dolores, Buenos Aires'},
 '542244':{'en': 'Las Flores, Buenos Aires', 'es': 'Las Flores, Buenos Aires'},
 '542246':{'en': 'Santa Teresita, Buenos Aires', 'es': 'Santa Teresita, Buenos Aires'},
 '497446':{'de': 'Lossburg', 'en': 'Lossburg'},
 '497447':{'de': 'Baiersbronn-Schwarzenberg', 'en': 'Baiersbronn-Schwarzenberg'},
 '497444':{'de': 'Alpirsbach', 'en': 'Alpirsbach'},
 '497445':{'de': 'Pfalzgrafenweiler', 'en': 'Pfalzgrafenweiler'},
 '497442':{'de': 'Baiersbronn', 'en': 'Baiersbronn'},
 '497443':{'de': 'Dornstetten', 'en': 'Dornstetten'},
 '497440':{'de': 'Bad Rippoldsau', 'en': 'Bad Rippoldsau'},
 '497441':{'de': 'Freudenstadt', 'en': 'Freudenstadt'},
 '497448':{'de': 'Seewald', 'en': 'Seewald'},
 '497449':{'de': 'Baiersbronn-Obertal', 'en': 'Baiersbronn-Obertal'},
 '498245':{'de': u('T\u00fcrkheim Wertach'), 'en': u('T\u00fcrkheim Wertach')},
 '55113826':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113825':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113824':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498241':{'de': 'Buchloe', 'en': 'Buchloe'},
 '55113822':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498243':{'de': 'Fuchstal', 'en': 'Fuchstal'},
 '55113820':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55323466':{'en': u('Al\u00e9m Para\u00edba - MG'), 'pt': u('Al\u00e9m Para\u00edba - MG')},
 '498249':{'de': 'Ettringen Wertach', 'en': 'Ettringen Wertach'},
 '498248':{'de': 'Lamerdingen', 'en': 'Lamerdingen'},
 '55113829':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113828':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323017':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55213867':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55173121':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173122':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173651':{'en': 'Palmeira D\'Oeste - SP', 'pt': 'Palmeira D\'Oeste - SP'},
 '542302':{'en': 'General Pico, La Pampa', 'es': 'General Pico, La Pampa'},
 '55213865':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494384':{'de': 'Selent', 'en': 'Selent'},
 '494385':{'de': 'Hohenfelde bei Kiel', 'en': 'Hohenfelde bei Kiel'},
 '494381':{'de': u('L\u00fctjenburg'), 'en': u('L\u00fctjenburg')},
 '494382':{'de': 'Wangels', 'en': 'Wangels'},
 '494383':{'de': 'Grebin', 'en': 'Grebin'},
 '52244':{'en': 'Puebla', 'es': 'Puebla'},
 '52245':{'en': 'Puebla', 'es': 'Puebla'},
 '52246':{'en': 'Tlaxcala', 'es': 'Tlaxcala'},
 '52247':{'en': 'Huamantla/San Cosme Xalostoc, TLAX', 'es': 'Huamantla/San Cosme Xalostoc, TLAX'},
 '52241':{'en': 'Tlaxcala', 'es': 'Tlaxcala'},
 '52243':{'en': 'Puebla', 'es': 'Puebla'},
 '55213861':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52248':{'en': 'Puebla', 'es': 'Puebla'},
 '52249':{'en': 'Puebla', 'es': 'Puebla'},
 '55313238':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313239':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313235':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313236':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313237':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55283569':{'en': 'Ibitirama - ES', 'pt': 'Ibitirama - ES'},
 '55283562':{'en': 'Bom Jesus do Norte - ES', 'pt': 'Bom Jesus do Norte - ES'},
 '55283560':{'en': 'Alegre - ES', 'pt': 'Alegre - ES'},
 '494872':{'de': 'Hanerau-Hademarschen', 'en': 'Hanerau-Hademarschen'},
 '55193225':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193224':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193227':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193226':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193221':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193223':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193229':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193228':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55213731':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '55212544':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112158':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112159':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112154':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112155':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112156':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112157':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112151':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112152':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55212227':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163704':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163707':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163706':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163708':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55115891':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115892':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115895':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115896':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115897':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115899':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313694':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '49431':{'de': 'Kiel', 'en': 'Kiel'},
 '55193481':{'en': u('S\u00e3o Pedro - SP'), 'pt': u('S\u00e3o Pedro - SP')},
 '55193483':{'en': u('S\u00e3o Pedro - SP'), 'pt': u('S\u00e3o Pedro - SP')},
 '55193482':{'en': u('\u00c1guas de S\u00e3o Pedro - SP'), 'pt': u('\u00c1guas de S\u00e3o Pedro - SP')},
 '55193484':{'en': 'Nova Odessa - SP', 'pt': 'Nova Odessa - SP'},
 '55193487':{'en': 'Santa Maria da Serra - SP', 'pt': 'Santa Maria da Serra - SP'},
 '55193486':{'en': 'Charqueada - SP', 'pt': 'Charqueada - SP'},
 '55184104':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55212259':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143108':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55212689':{'en': 'Porto Belo - RJ', 'pt': 'Porto Belo - RJ'},
 '55212688':{'en': u('Itagua\u00ed - RJ'), 'pt': u('Itagua\u00ed - RJ')},
 '54358':{'en': u('R\u00edo Cuarto, C\u00f3rdoba'), 'es': u('R\u00edo Cuarto, C\u00f3rdoba')},
 '55273171':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '496544':{'de': 'Rhaunen', 'en': 'Rhaunen'},
 '496545':{'de': 'Blankenrath', 'en': 'Blankenrath'},
 '55212683':{'en': 'Paracambi - RJ', 'pt': 'Paracambi - RJ'},
 '55143335':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '55143332':{'en': 'Santa Cruz do Rio Pardo - SP', 'pt': 'Santa Cruz do Rio Pardo - SP'},
 '54351':{'en': u('C\u00f3rdoba, C\u00f3rdoba'), 'es': u('C\u00f3rdoba, C\u00f3rdoba')},
 '496542':{'de': 'Bullay', 'en': 'Bullay'},
 '496543':{'de': u('B\u00fcchenbeuren'), 'en': u('B\u00fcchenbeuren')},
 '55115528':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273288':{'en': 'Marechal Floriano - ES', 'pt': 'Marechal Floriano - ES'},
 '55273287':{'en': u('Fund\u00e3o - ES'), 'pt': u('Fund\u00e3o - ES')},
 '5519':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5518':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55193811':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55193816':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193817':{'en': 'Amparo - SP', 'pt': 'Amparo - SP'},
 '55193814':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '5511':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5513':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5512':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5515':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5514':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5517':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5516':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55193430':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193431':{'en': 'Tanquinho - SP', 'pt': 'Tanquinho - SP'},
 '55193432':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '495365':{'de': 'Wolfsburg-Neindorf', 'en': 'Wolfsburg-Neindorf'},
 '495364':{'de': 'Velpke', 'en': 'Velpke'},
 '495367':{'de': u('R\u00fchen'), 'en': u('R\u00fchen')},
 '495366':{'de': 'Jembke', 'en': 'Jembke'},
 '495361':{'de': 'Wolfsburg', 'en': 'Wolfsburg'},
 '495363':{'de': 'Wolfsburg-Vorsfelde', 'en': 'Wolfsburg-Vorsfelde'},
 '495362':{'de': 'Wolfsburg-Fallersleben', 'en': 'Wolfsburg-Fallersleben'},
 '55193434':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '495368':{'de': 'Parsau', 'en': 'Parsau'},
 '55115523':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193388':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55115524':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193437':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55323234':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55115525':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115526':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193439':{'en': 'Saltinho - SP', 'pt': 'Saltinho - SP'},
 '52285':{'en': 'Veracruz', 'es': 'Veracruz'},
 '497148':{'de': 'Grossbottwar', 'en': 'Grossbottwar'},
 '497143':{'de': 'Besigheim', 'en': 'Besigheim'},
 '497142':{'de': 'Bietigheim-Bissingen', 'en': 'Bietigheim-Bissingen'},
 '497141':{'de': u('Ludwigsburg W\u00fcrttemberg'), 'en': u('Ludwigsburg W\u00fcrttemberg')},
 '497636':{'de': u('M\u00fcnstertal Schwarzwald'), 'en': u('M\u00fcnstertal Schwarzwald')},
 '497147':{'de': u('Sachsenheim W\u00fcrttemberg'), 'en': u('Sachsenheim W\u00fcrttemberg')},
 '497146':{'de': 'Remseck am Neckar', 'en': 'Remseck am Neckar'},
 '497145':{'de': u('Markgr\u00f6ningen'), 'en': u('Markgr\u00f6ningen')},
 '497144':{'de': 'Marbach am Neckar', 'en': 'Marbach am Neckar'},
 '55193417':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55133854':{'en': 'Cajati - SP', 'pt': 'Cajati - SP'},
 '55173465':{'en': u('Fernand\u00f3polis - SP'), 'pt': u('Fernand\u00f3polis - SP')},
 '55173467':{'en': 'Nhandeara - SP', 'pt': 'Nhandeara - SP'},
 '55173466':{'en': 'Cardoso - SP', 'pt': 'Cardoso - SP'},
 '55173461':{'en': 'General Salgado - SP', 'pt': 'General Salgado - SP'},
 '55173463':{'en': u('Fernand\u00f3polis - SP'), 'pt': u('Fernand\u00f3polis - SP')},
 '55173462':{'en': u('Fernand\u00f3polis - SP'), 'pt': u('Fernand\u00f3polis - SP')},
 '55323214':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55193414':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55123101':{'en': 'Cachoeira Paulista - SP', 'pt': 'Cachoeira Paulista - SP'},
 '55163143':{'en': 'Restinga - SP', 'pt': 'Restinga - SP'},
 '55133406':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55163146':{'en': u('Itirapu\u00e3 - SP'), 'pt': u('Itirapu\u00e3 - SP')},
 '55163145':{'en': u('Patroc\u00ednio Paulista - SP'), 'pt': u('Patroc\u00ednio Paulista - SP')},
 '55123106':{'en': 'Silveiras - SP', 'pt': 'Silveiras - SP'},
 '55153451':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '55123105':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '55123104':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '55213158':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213156':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213381':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212415':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323363':{'en': 'Lagoa Dourada - MG', 'pt': 'Lagoa Dourada - MG'},
 '55323362':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '497851':{'de': 'Kehl', 'en': 'Kehl'},
 '497853':{'de': 'Kehl-Bodersweier', 'en': 'Kehl-Bodersweier'},
 '497852':{'de': u('Willst\u00e4tt'), 'en': u('Willst\u00e4tt')},
 '497854':{'de': 'Kehl-Goldscheuer', 'en': 'Kehl-Goldscheuer'},
 '55323364':{'en': 'Paiva - MG', 'pt': 'Paiva - MG'},
 '55313184':{'en': 'Itaguara - MG', 'pt': 'Itaguara - MG'},
 '55274104':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '55274105':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55274102':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55183748':{'en': 'Ilha Solteira - SP', 'pt': 'Ilha Solteira - SP'},
 '55115506':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113141':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113142':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113144':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113145':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113146':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113147':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113148':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113149':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273120':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55183744':{'en': u('Nova Independ\u00eancia - SP'), 'pt': u('Nova Independ\u00eancia - SP')},
 '55183743':{'en': 'Ilha Solteira - SP', 'pt': 'Ilha Solteira - SP'},
 '55115507':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183742':{'en': 'Ilha Solteira - SP', 'pt': 'Ilha Solteira - SP'},
 '499677':{'de': 'Oberviechtach-Pullenried', 'en': 'Oberviechtach-Pullenried'},
 '499676':{'de': 'Winklarn', 'en': 'Winklarn'},
 '499675':{'de': 'Altendorf am Nabburg', 'en': 'Altendorf am Nabburg'},
 '499674':{'de': u('Sch\u00f6nsee'), 'en': u('Sch\u00f6nsee')},
 '499673':{'de': 'Tiefenbach Oberpfalz', 'en': 'Tiefenbach Oberpfalz'},
 '499672':{'de': 'Neunburg vorm Wald', 'en': 'Neunburg vorm Wald'},
 '499671':{'de': 'Oberviechtach', 'en': 'Oberviechtach'},
 '55112812':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55212419':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112819':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55112818':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '52767':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52766':{'en': 'Gutierrez Zamora/Tecolutla, VER', 'es': u('Guti\u00e9rrez Zamora/Tecolutla, VER')},
 '52765':{'en': 'Alamo Temapache/Alazan/Potrero Del Llano, VER', 'es': u('\u00c1lamo Temapache/Alaz\u00e1n/Potrero del Llano, VER')},
 '52764':{'en': 'Puebla', 'es': 'Puebla'},
 '52763':{'en': 'Tezontepec de Aldama/Tlahuelilpan, HGO', 'es': 'Tezontepec de Aldama/Tlahuelilpan, HGO'},
 '52762':{'en': 'Taxco, GRO', 'es': 'Taxco, GRO'},
 '52761':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '55193565':{'en': 'Pirassununga - SP', 'pt': 'Pirassununga - SP'},
 '5281':{'en': 'Monterrey, NL', 'es': 'Monterrey, NL'},
 '55273129':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55193513':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '52769':{'en': 'Morelos', 'es': 'Morelos'},
 '52768':{'en': 'Veracruz', 'es': 'Veracruz'},
 '498506':{'de': u('Bad H\u00f6henstadt'), 'en': u('Bad H\u00f6henstadt')},
 '498507':{'de': 'Neuburg am Inn', 'en': 'Neuburg am Inn'},
 '498504':{'de': 'Tittling', 'en': 'Tittling'},
 '55113367':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498502':{'de': u('F\u00fcrstenzell'), 'en': u('F\u00fcrstenzell')},
 '55113361':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113362':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113491':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115667':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113368':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113498':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498509':{'de': 'Ruderting', 'en': 'Ruderting'},
 '55213314':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323052':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55213316':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494475':{'de': 'Molbergen', 'en': 'Molbergen'},
 '55115665':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213312':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55115505':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193512':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55213151':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499905':{'de': 'Bernried Niederbayern', 'en': 'Bernried Niederbayern'},
 '499904':{'de': 'Lalling', 'en': 'Lalling'},
 '499451':{'de': 'Schierling', 'en': 'Schierling'},
 '499906':{'de': 'Mariaposching', 'en': 'Mariaposching'},
 '499901':{'de': 'Hengersberg Bayern', 'en': 'Hengersberg Bayern'},
 '499903':{'de': u('Sch\u00f6llnach'), 'en': u('Sch\u00f6llnach')},
 '499454':{'de': 'Aufhausen Oberpfalz', 'en': 'Aufhausen Oberpfalz'},
 '499908':{'de': u('Sch\u00f6fweg'), 'en': u('Sch\u00f6fweg')},
 '494293':{'de': 'Ottersberg-Fischerhude', 'en': 'Ottersberg-Fischerhude'},
 '495171':{'de': 'Peine', 'en': 'Peine'},
 '495172':{'de': 'Ilsede', 'en': 'Ilsede'},
 '495173':{'de': 'Uetze', 'en': 'Uetze'},
 '495174':{'de': 'Lahstedt', 'en': 'Lahstedt'},
 '495175':{'de': 'Lehrte-Arpke', 'en': 'Lehrte-Arpke'},
 '495176':{'de': 'Edemissen', 'en': 'Edemissen'},
 '495177':{'de': 'Edemissen-Abbensen', 'en': 'Edemissen-Abbensen'},
 '55113863':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123042':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55193418':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55113646':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113861':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113867':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113642':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495282':{'de': 'Schieder-Schwalenberg', 'en': 'Schieder-Schwalenberg'},
 '495283':{'de': u('L\u00fcgde-Rischenau'), 'en': u('L\u00fcgde-Rischenau')},
 '495281':{'de': 'Bad Pyrmont', 'en': 'Bad Pyrmont'},
 '495286':{'de': 'Ottenstein Niedersachsen', 'en': 'Ottenstein Niedersachsen'},
 '55113865':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495284':{'de': 'Schwalenberg', 'en': 'Schwalenberg'},
 '495285':{'de': 'Bad Pyrmont-Kleinenberg', 'en': 'Bad Pyrmont-Kleinenberg'},
 '55273084':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55115501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123629':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123622':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123623':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123621':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123626':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123627':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123624':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123625':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55212545':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212518':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55242242':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '498756':{'de': 'Nandlstadt', 'en': 'Nandlstadt'},
 '496157':{'de': 'Pfungstadt', 'en': 'Pfungstadt'},
 '496155':{'de': 'Griesheim Hessen', 'en': 'Griesheim Hessen'},
 '496154':{'de': 'Ober-Ramstadt', 'en': 'Ober-Ramstadt'},
 '55243328':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '496152':{'de': 'Gross-Gerau', 'en': 'Gross-Gerau'},
 '496151':{'de': 'Darmstadt', 'en': 'Darmstadt'},
 '496150':{'de': 'Weiterstadt', 'en': 'Weiterstadt'},
 '55243324':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55243325':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55242247':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55243320':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55243321':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '496159':{'de': 'Messel', 'en': 'Messel'},
 '496158':{'de': 'Riedstadt', 'en': 'Riedstadt'},
 '55212548':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212549':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212546':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212547':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496483':{'de': 'Selters Taunus', 'en': 'Selters Taunus'},
 '496482':{'de': 'Runkel', 'en': 'Runkel'},
 '496485':{'de': 'Nentershausen Westerwald', 'en': 'Nentershausen Westerwald'},
 '496484':{'de': 'Beselich', 'en': 'Beselich'},
 '55212540':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496486':{'de': 'Katzenelnbogen', 'en': 'Katzenelnbogen'},
 '495826':{'de': 'Suderburg', 'en': 'Suderburg'},
 '495827':{'de': u('Unterl\u00fc\u00df'), 'en': u('Unterl\u00fcss')},
 '495824':{'de': 'Bad Bodenteich', 'en': 'Bad Bodenteich'},
 '495825':{'de': 'Wieren', 'en': 'Wieren'},
 '495822':{'de': 'Ebstorf', 'en': 'Ebstorf'},
 '495823':{'de': u('Bienenb\u00fcttel'), 'en': u('Bienenb\u00fcttel')},
 '495820':{'de': 'Suhlendorf', 'en': 'Suhlendorf'},
 '495821':{'de': 'Bad Bevensen', 'en': 'Bad Bevensen'},
 '495828':{'de': 'Himbergen', 'en': 'Himbergen'},
 '495829':{'de': 'Wriedel', 'en': 'Wriedel'},
 '496733':{'de': 'Gau-Odernheim', 'en': 'Gau-Odernheim'},
 '496732':{'de': u('W\u00f6rrstadt'), 'en': u('W\u00f6rrstadt')},
 '496731':{'de': 'Alzey', 'en': 'Alzey'},
 '55313822':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '496737':{'de': u('K\u00f6ngernheim'), 'en': u('K\u00f6ngernheim')},
 '496736':{'de': 'Bechenheim', 'en': 'Bechenheim'},
 '496735':{'de': 'Eppelsheim', 'en': 'Eppelsheim'},
 '496734':{'de': 'Flonheim', 'en': 'Flonheim'},
 '55153213':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55114751':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55173816':{'en': u('Orindi\u00fava - SP'), 'pt': u('Orindi\u00fava - SP')},
 '55173817':{'en': u('Sever\u00ednia - SP'), 'pt': u('Sever\u00ednia - SP')},
 '55114755':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55173812':{'en': u('Ic\u00e9m - SP'), 'pt': u('Ic\u00e9m - SP')},
 '55173813':{'en': 'Jaci - SP', 'pt': 'Jaci - SP'},
 '55212514':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '542342':{'en': 'Bragado, Buenos Aires', 'es': 'Bragado, Buenos Aires'},
 '55173266':{'en': 'Cedral - SP', 'pt': 'Cedral - SP'},
 '542343':{'en': 'Norberto de La Riestra, Buenos Aires', 'es': 'Norberto de La Riestra, Buenos Aires'},
 '55154009':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '542344':{'en': 'Saladillo, Buenos Aires', 'es': 'Saladillo, Buenos Aires'},
 '55212517':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55173269':{'en': u('Ipigu\u00e1 - SP'), 'pt': u('Ipigu\u00e1 - SP')},
 '55212516':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498083':{'de': 'Isen', 'en': 'Isen'},
 '498082':{'de': 'Schwindegg', 'en': 'Schwindegg'},
 '498081':{'de': 'Dorfen Stadt', 'en': 'Dorfen Stadt'},
 '498086':{'de': 'Buchbach Oberbayern', 'en': 'Buchbach Oberbayern'},
 '498085':{'de': 'Sankt Wolfgang', 'en': 'Sankt Wolfgang'},
 '498084':{'de': 'Taufkirchen Vils', 'en': 'Taufkirchen Vils'},
 '55212511':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273752':{'en': u('Nova Ven\u00e9cia - ES'), 'pt': u('Nova Ven\u00e9cia - ES')},
 '542262':{'en': 'Necochea, Buenos Aires', 'es': 'Necochea, Buenos Aires'},
 '542261':{'en': u('Lober\u00eda, Buenos Aires'), 'es': u('Lober\u00eda, Buenos Aires')},
 '55273751':{'en': 'Mucurici - ES', 'pt': 'Mucurici - ES'},
 '542267':{'en': 'General Juan Madariaga, Buenos Aires', 'es': 'General Juan Madariaga, Buenos Aires'},
 '542266':{'en': 'Balcarce, Buenos Aires', 'es': 'Balcarce, Buenos Aires'},
 '542265':{'en': 'Coronel Vidal, Buenos Aires', 'es': 'Coronel Vidal, Buenos Aires'},
 '542264':{'en': 'La Dulce (Nicanor Olivera), Buenos Aires', 'es': 'La Dulce (Nicanor Olivera), Buenos Aires'},
 '55273758':{'en': u('Manten\u00f3polis - ES'), 'pt': u('Manten\u00f3polis - ES')},
 '542268':{'en': u('Maip\u00fa, Buenos Aires'), 'es': u('Maip\u00fa, Buenos Aires')},
 '55212510':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497461':{'de': 'Tuttlingen', 'en': 'Tuttlingen'},
 '497462':{'de': 'Immendingen', 'en': 'Immendingen'},
 '497463':{'de': u('M\u00fchlheim an der Donau'), 'en': u('M\u00fchlheim an der Donau')},
 '497464':{'de': 'Talheim Kreis Tuttlingen', 'en': 'Talheim Kreis Tuttlingen'},
 '497465':{'de': 'Emmingen-Liptingen', 'en': 'Emmingen-Liptingen'},
 '497466':{'de': 'Beuron', 'en': 'Beuron'},
 '497467':{'de': 'Neuhausen ob Eck', 'en': 'Neuhausen ob Eck'},
 '498269':{'de': 'Unteregg bei Mindelheim', 'en': 'Unteregg bei Mindelheim'},
 '498268':{'de': 'Tussenhausen', 'en': 'Tussenhausen'},
 '498267':{'de': 'Dirlewang', 'en': 'Dirlewang'},
 '498266':{'de': 'Kirchheim in Schwaben', 'en': 'Kirchheim in Schwaben'},
 '498265':{'de': 'Pfaffenhausen Schwaben', 'en': 'Pfaffenhausen Schwaben'},
 '498263':{'de': 'Breitenbrunn Schwaben', 'en': 'Breitenbrunn Schwaben'},
 '498262':{'de': 'Mittelneufnach', 'en': 'Mittelneufnach'},
 '498261':{'de': 'Mindelheim', 'en': 'Mindelheim'},
 '55173101':{'en': 'Uchoa - SP', 'pt': 'Uchoa - SP'},
 '55312524':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '52222':{'en': 'Puebla', 'es': 'Puebla'},
 '52223':{'en': 'Puebla', 'es': 'Puebla'},
 '52221':{'en': 'Puebla', 'es': 'Puebla'},
 '52226':{'en': 'Altotonga/Jalacingo, VER', 'es': 'Altotonga/Jalacingo, VER'},
 '52227':{'en': 'Huejotzingo/San Buenaventura Nealtican, PUE', 'es': 'Huejotzingo/San Buenaventura Nealtican, PUE'},
 '52224':{'en': 'Puebla', 'es': 'Puebla'},
 '52225':{'en': 'Tlapacoyan, VER', 'es': 'Tlapacoyan, VER'},
 '52228':{'en': 'Jalapa/Tuzamapan, VER', 'es': 'Jalapa/Tuzamapan, VER'},
 '52229':{'en': 'Veracruz, VER', 'es': 'Veracruz, VER'},
 '55133341':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133342':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133343':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55313218':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313219':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55113245':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313217':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313214':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313212':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313213':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213427':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213425':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495303':{'de': 'Wendeburg', 'en': 'Wendeburg'},
 '55213422':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213423':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52599':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55113809':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113808':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212503':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113805':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52591':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55113807':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52593':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52594':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52595':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52596':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55112172':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112173':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112171':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112176':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112177':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112174':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112175':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212506':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112178':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112179':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212507':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212504':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55173355':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55212505':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49631':{'de': 'Kaiserslautern', 'en': 'Kaiserslautern'},
 '55212653':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55163763':{'en': u('Jardin\u00f3polis - SP'), 'pt': u('Jardin\u00f3polis - SP')},
 '55163761':{'en': 'Batatais - SP', 'pt': 'Batatais - SP'},
 '4989':{'de': u('M\u00fcnchen'), 'en': 'Munich'},
 '49451':{'de': u('L\u00fcbeck'), 'en': u('L\u00fcbeck')},
 '49981':{'de': 'Ansbach', 'en': 'Ansbach'},
 '55113779':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212651':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55113773':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113772':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113771':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113776':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113775':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113774':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183866':{'en': 'Flora Rica - SP', 'pt': 'Flora Rica - SP'},
 '55192516':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55192511':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192513':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55123903':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123902':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123907':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55212656':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55123905':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123904':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55273115':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55123908':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55273111':{'en': 'Aracruz - ES', 'pt': 'Aracruz - ES'},
 '55143354':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55143355':{'en': 'Manduri - SP', 'pt': 'Manduri - SP'},
 '55143356':{'en': 'Manduri - SP', 'pt': 'Manduri - SP'},
 '55143357':{'en': u('\u00d3leo - SP'), 'pt': u('\u00d3leo - SP')},
 '55143351':{'en': 'Piraju - SP', 'pt': 'Piraju - SP'},
 '55143352':{'en': 'Piraju - SP', 'pt': 'Piraju - SP'},
 '55193602':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193601':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '54336':{'en': u('San Nicol\u00e1s, Buenos Aires'), 'es': u('San Nicol\u00e1s, Buenos Aires')},
 '55193269':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55143733':{'en': u('Avar\u00e9 - SP'), 'pt': u('Avar\u00e9 - SP')},
 '55143737':{'en': u('Gar\u00e7a - SP'), 'pt': u('Gar\u00e7a - SP')},
 '543725':{'en': u('General Jos\u00e9 de San Mart\u00edn, Chaco'), 'es': u('General Jos\u00e9 de San Mart\u00edn, Chaco')},
 '55222030':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '543721':{'en': 'Charadai, Chaco', 'es': 'Charadai, Chaco'},
 '55243335':{'en': 'Rio Claro - RJ', 'pt': 'Rio Claro - RJ'},
 '55114693':{'en': 'Guararema - SP', 'pt': 'Guararema - SP'},
 '55114692':{'en': 'Biritiba-Mirim - SP', 'pt': 'Biritiba-Mirim - SP'},
 '55114695':{'en': 'Guararema - SP', 'pt': 'Guararema - SP'},
 '55114694':{'en': 'Biritiba-Mirim - SP', 'pt': 'Biritiba-Mirim - SP'},
 '55114696':{'en': u('Sales\u00f3polis - SP'), 'pt': u('Sales\u00f3polis - SP')},
 '55212655':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55243334':{'en': 'Rio Claro - RJ', 'pt': 'Rio Claro - RJ'},
 '55313558':{'en': 'Mariana - MG', 'pt': 'Mariana - MG'},
 '495347':{'de': 'Burgdorf bei Salzgitter', 'en': 'Burgdorf bei Salzgitter'},
 '495346':{'de': 'Liebenburg', 'en': 'Liebenburg'},
 '495345':{'de': 'Baddeckenstedt', 'en': 'Baddeckenstedt'},
 '495344':{'de': 'Lengede', 'en': 'Lengede'},
 '495341':{'de': 'Salzgitter', 'en': 'Salzgitter'},
 '496838':{'de': 'Saarwellingen', 'en': 'Saarwellingen'},
 '55333242':{'en': u('S\u00e3o Jo\u00e3o do Manteninha - MG'), 'pt': u('S\u00e3o Jo\u00e3o do Manteninha - MG')},
 '55333241':{'en': 'Mantena - MG', 'pt': 'Mantena - MG'},
 '55333247':{'en': 'Itabirinha - MG', 'pt': 'Itabirinha - MG'},
 '55333246':{'en': 'Mendes Pimentel - MG', 'pt': 'Mendes Pimentel - MG'},
 '55333245':{'en': 'Divino das Laranjeiras - MG', 'pt': 'Divino das Laranjeiras - MG'},
 '55333244':{'en': u('Galil\u00e9ia - MG'), 'pt': u('Galil\u00e9ia - MG')},
 '496831':{'de': 'Saarlouis', 'en': 'Saarlouis'},
 '496832':{'de': 'Beckingen-Reimsbach', 'en': 'Beckingen-Reimsbach'},
 '496833':{'de': 'Rehlingen-Siersburg', 'en': 'Rehlingen-Siersburg'},
 '496834':{'de': 'Bous', 'en': 'Bous'},
 '496835':{'de': 'Beckingen', 'en': 'Beckingen'},
 '496836':{'de': u('\u00dcberherrn'), 'en': u('\u00dcberherrn')},
 '496837':{'de': 'Wallerfangen', 'en': 'Wallerfangen'},
 '55313711':{'en': 'Prudente de Morais - MG', 'pt': 'Prudente de Morais - MG'},
 '55313864':{'en': u('Carm\u00e9sia - MG'), 'pt': u('Carm\u00e9sia - MG')},
 '55213584':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55313862':{'en': 'Alvorada de Minas - MG', 'pt': 'Alvorada de Minas - MG'},
 '55133425':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55133424':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55133427':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55133426':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55133421':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '52717':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55133429':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55212467':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193042':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193516':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212462':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112118':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '52967':{'en': 'San Cristobal de las Casas, CHIS', 'es': u('San Crist\u00f3bal de las Casas, CHIS')},
 '52966':{'en': 'Arriaga/Tonala, CHIS', 'es': u('Arriaga/Tonal\u00e1, CHIS')},
 '52969':{'en': 'Flamboyanes/Yucalpeten, YUC', 'es': 'Flamboyanes/Yucalpeten, YUC'},
 '55113039':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113034':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183788':{'en': 'Murutinga do Sul - SP', 'pt': 'Murutinga do Sul - SP'},
 '55214007':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113035':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213826':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183786':{'en': 'Sud Mennucci - SP', 'pt': 'Sud Mennucci - SP'},
 '52346':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '55223053':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '55193433':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55113030':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122128':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55133281':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113464':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133285':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113032':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133286':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133289':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133288':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55313029':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55223811':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55313026':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55122123':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55113167':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113164':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113165':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113163':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113161':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122125':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55113168':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113169':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193436':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55194003':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55194007':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55194009':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55114174':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114176':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114177':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114173':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113493':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114178':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113348':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113349':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52789':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55113342':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52784':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52786':{'en': 'Ciudad Hidalgo/Tuxpan, MICH', 'es': 'Ciudad Hidalgo/Tuxpan, MICH'},
 '52781':{'en': 'Coyuca de Benitez/San Jeronimo de Juarez, GRO', 'es': u('Coyuca de Ben\u00edtez/San Jer\u00f3nimo de Ju\u00e1rez, GRO')},
 '52783':{'en': 'Tuxpan, VER', 'es': 'Tuxpan, VER'},
 '52782':{'en': 'Poza Rica, VER', 'es': 'Poza Rica, VER'},
 '55213849':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213338':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213339':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213332':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213333':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213842':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55213331':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213336':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213337':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213846':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55213335':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153363':{'en': 'Boituva - SP', 'pt': 'Boituva - SP'},
 '55153364':{'en': 'Boituva - SP', 'pt': 'Boituva - SP'},
 '55173483':{'en': u('Nova Luzit\u00e2nia - SP'), 'pt': u('Nova Luzit\u00e2nia - SP')},
 '499929':{'de': 'Ruhmannsfelden', 'en': 'Ruhmannsfelden'},
 '499928':{'de': 'Kirchdorf im Wald', 'en': 'Kirchdorf im Wald'},
 '499927':{'de': 'Kirchberg Wald', 'en': 'Kirchberg Wald'},
 '499926':{'de': 'Frauenau', 'en': 'Frauenau'},
 '499925':{'de': 'Bayerisch Eisenstein', 'en': 'Bayerisch Eisenstein'},
 '499924':{'de': 'Bodenmais', 'en': 'Bodenmais'},
 '499923':{'de': 'Teisnach', 'en': 'Teisnach'},
 '499922':{'de': 'Zwiesel', 'en': 'Zwiesel'},
 '499921':{'de': 'Regen', 'en': 'Regen'},
 '499920':{'de': 'Bischofsmais', 'en': 'Bischofsmais'},
 '55193754':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55115521':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173487':{'en': 'Magda - SP', 'pt': 'Magda - SP'},
 '55173485':{'en': 'Valentim Gentil - SP', 'pt': 'Valentim Gentil - SP'},
 '55173484':{'en': u('Mon\u00e7\u00f5es - SP'), 'pt': u('Mon\u00e7\u00f5es - SP')},
 '55112697':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112696':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112695':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112694':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112693':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112692':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123025':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123026':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123027':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123021':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123022':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55112698':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222556':{'en': u('S\u00e3o Sebasti\u00e3o do Alto - RJ'), 'pt': u('S\u00e3o Sebasti\u00e3o do Alto - RJ')},
 '55222554':{'en': 'Macuco - RJ', 'pt': 'Macuco - RJ'},
 '55222555':{'en': 'Cantagalo - RJ', 'pt': 'Cantagalo - RJ'},
 '55222552':{'en': 'Santa Rita da Floresta - RJ', 'pt': 'Santa Rita da Floresta - RJ'},
 '55222553':{'en': 'Cantagalo - RJ', 'pt': 'Cantagalo - RJ'},
 '55222551':{'en': 'Cordeiro - RJ', 'pt': 'Cordeiro - RJ'},
 '55222559':{'en': u('S\u00e3o Sebasti\u00e3o do Alto - RJ'), 'pt': u('S\u00e3o Sebasti\u00e3o do Alto - RJ')},
 '499875':{'de': 'Wolframs-Eschenbach', 'en': 'Wolframs-Eschenbach'},
 '55112439':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112438':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499874':{'de': 'Neuendettelsau', 'en': 'Neuendettelsau'},
 '55112433':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112432':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112347':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112346':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112341':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494557':{'de': 'Blunk', 'en': 'Blunk'},
 '55112342':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494556':{'de': u('Ahrensb\u00f6k-Gnissau'), 'en': u('Ahrensb\u00f6k-Gnissau')},
 '5042448':{'en': 'Tela'},
 '494550':{'de': u('B\u00fchnsdorf'), 'en': u('B\u00fchnsdorf')},
 '5042444':{'en': u('Tocoa, Col\u00f3n')},
 '494551':{'de': 'Bad Segeberg', 'en': 'Bad Segeberg'},
 '5042446':{'en': 'Olanchito'},
 '55213552':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '5042440':{'en': 'La Ceiba'},
 '5042442':{'en': 'La Ceiba'},
 '5042443':{'en': 'La Ceiba'},
 '494881':{'de': 'Friedrichstadt', 'en': 'Friedrichstadt'},
 '543532':{'en': u('Oliva, C\u00f3rdoba'), 'es': u('Oliva, C\u00f3rdoba')},
 '499704':{'de': 'Euerdorf', 'en': 'Euerdorf'},
 '543537':{'en': u('Bell Ville, C\u00f3rdoba'), 'es': u('Bell Ville, C\u00f3rdoba')},
 '494553':{'de': 'Geschendorf', 'en': 'Geschendorf'},
 '55213553':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55115581':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496131':{'de': 'Mainz', 'en': 'Mainz'},
 '496130':{'de': 'Schwabenheim an der Selz', 'en': 'Schwabenheim an der Selz'},
 '496133':{'de': 'Oppenheim', 'en': 'Oppenheim'},
 '496132':{'de': 'Ingelheim am Rhein', 'en': 'Ingelheim am Rhein'},
 '496135':{'de': 'Bodenheim Rhein', 'en': 'Bodenheim Rhein'},
 '496134':{'de': 'Mainz-Kastel', 'en': 'Mainz-Kastel'},
 '496136':{'de': 'Nieder-Olm', 'en': 'Nieder-Olm'},
 '496139':{'de': 'Budenheim', 'en': 'Budenheim'},
 '496138':{'de': 'Mommenheim', 'en': 'Mommenheim'},
 '55113969':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496667':{'de': 'Steinau-Ulmbach', 'en': 'Steinau-Ulmbach'},
 '55212524':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212525':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212526':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496842':{'de': 'Blieskastel', 'en': 'Blieskastel'},
 '55212520':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212521':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212522':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212523':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212528':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113964':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '496844':{'de': 'Blieskastel-Altheim', 'en': 'Blieskastel-Altheim'},
 '495802':{'de': 'Wrestedt', 'en': 'Wrestedt'},
 '495803':{'de': 'Rosche', 'en': 'Rosche'},
 '495804':{'de': u('R\u00e4tzlingen Kreis Uelzen'), 'en': u('R\u00e4tzlingen Kreis Uelzen')},
 '495805':{'de': 'Oetzen', 'en': 'Oetzen'},
 '495806':{'de': 'Barum bei Bad Bevensen', 'en': 'Barum bei Bad Bevensen'},
 '495807':{'de': 'Altenmedingen', 'en': 'Altenmedingen'},
 '495808':{'de': 'Gerdau', 'en': 'Gerdau'},
 '55323559':{'en': 'Visconde do Rio Branco - MG', 'pt': 'Visconde do Rio Branco - MG'},
 '55333215':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55173832':{'en': 'General Salgado - SP', 'pt': 'General Salgado - SP'},
 '55173833':{'en': 'Estrela D\'Oeste - SP', 'pt': 'Estrela D\'Oeste - SP'},
 '55273325':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55173831':{'en': 'Nova Castilho - SP', 'pt': 'Nova Castilho - SP'},
 '55173836':{'en': 'Cosmorama - SP', 'pt': 'Cosmorama - SP'},
 '55173219':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173834':{'en': 'Guarani D\'Oeste - SP', 'pt': 'Guarani D\'Oeste - SP'},
 '55114779':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114777':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114774':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114775':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114772':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55114773':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55313849':{'en': u('Tim\u00f3teo - MG'), 'pt': u('Tim\u00f3teo - MG')},
 '55323553':{'en': 'Guiricema - MG', 'pt': 'Guiricema - MG'},
 '55173513':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55213674':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55273755':{'en': 'Ecoporanga - ES', 'pt': 'Ecoporanga - ES'},
 '55333238':{'en': u('S\u00e3o Geraldo da Piedade - MG'), 'pt': u('S\u00e3o Geraldo da Piedade - MG')},
 '55323554':{'en': u('Erv\u00e1lia - MG'), 'pt': u('Erv\u00e1lia - MG')},
 '55173512':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55323555':{'en': 'Coimbra - MG', 'pt': 'Coimbra - MG'},
 '55213554':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497268':{'de': 'Bad Rappenau-Obergimpern', 'en': 'Bad Rappenau-Obergimpern'},
 '497269':{'de': 'Sulzfeld Baden', 'en': 'Sulzfeld Baden'},
 '497266':{'de': 'Kirchardt', 'en': 'Kirchardt'},
 '497267':{'de': 'Gemmingen', 'en': 'Gemmingen'},
 '497264':{'de': 'Bad Rappenau', 'en': 'Bad Rappenau'},
 '497265':{'de': 'Angelbachtal', 'en': 'Angelbachtal'},
 '497262':{'de': 'Eppingen', 'en': 'Eppingen'},
 '497263':{'de': 'Waibstadt', 'en': 'Waibstadt'},
 '497260':{'de': 'Sinsheim-Hilsbach', 'en': 'Sinsheim-Hilsbach'},
 '497261':{'de': 'Sinsheim', 'en': 'Sinsheim'},
 '498065':{'de': u('Tuntenhausen-Sch\u00f6nau'), 'en': u('Tuntenhausen-Sch\u00f6nau')},
 '498064':{'de': 'Au bei Bad Aibling', 'en': 'Au bei Bad Aibling'},
 '498067':{'de': 'Tuntenhausen', 'en': 'Tuntenhausen'},
 '498066':{'de': 'Bad Feilnbach', 'en': 'Bad Feilnbach'},
 '498061':{'de': 'Bad Aibling', 'en': 'Bad Aibling'},
 '498063':{'de': 'Feldkirchen-Westerham', 'en': 'Feldkirchen-Westerham'},
 '498062':{'de': u('Bruckm\u00fchl Mangfall'), 'en': u('Bruckm\u00fchl Mangfall')},
 '55173341':{'en': 'Colina - SP', 'pt': 'Colina - SP'},
 '55173342':{'en': 'Bebedouro - SP', 'pt': 'Bebedouro - SP'},
 '55173343':{'en': 'Bebedouro - SP', 'pt': 'Bebedouro - SP'},
 '55173344':{'en': 'Bebedouro - SP', 'pt': 'Bebedouro - SP'},
 '55173345':{'en': 'Bebedouro - SP', 'pt': 'Bebedouro - SP'},
 '55114349':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114348':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542285':{'en': 'Laprida, Buenos Aires', 'es': 'Laprida, Buenos Aires'},
 '542284':{'en': u('Olavarr\u00eda, Buenos Aires'), 'es': u('Olavarr\u00eda, Buenos Aires')},
 '55114345':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114344':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542281':{'en': 'Azul, Buenos Aires', 'es': 'Azul, Buenos Aires'},
 '55114342':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114341':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '497402':{'de': 'Fluorn-Winzeln', 'en': 'Fluorn-Winzeln'},
 '497403':{'de': 'Dunningen', 'en': 'Dunningen'},
 '55173278':{'en': u('Uni\u00e3o Paulista - SP'), 'pt': u('Uni\u00e3o Paulista - SP')},
 '497404':{'de': 'Epfendorf', 'en': 'Epfendorf'},
 '498208':{'de': 'Eurasburg bei Augsburg', 'en': 'Eurasburg bei Augsburg'},
 '498203':{'de': 'Grossaitingen', 'en': 'Grossaitingen'},
 '498202':{'de': 'Althegnenberg', 'en': 'Althegnenberg'},
 '498205':{'de': 'Dasing', 'en': 'Dasing'},
 '498204':{'de': 'Mickhausen', 'en': 'Mickhausen'},
 '498207':{'de': 'Affing', 'en': 'Affing'},
 '498206':{'de': 'Egling an der Paar', 'en': 'Egling an der Paar'},
 '55153553':{'en': u('Ribeir\u00e3o Branco - SP'), 'pt': u('Ribeir\u00e3o Branco - SP')},
 '55153552':{'en': u('Apia\u00ed - SP'), 'pt': u('Apia\u00ed - SP')},
 '55153551':{'en': u('Ribeir\u00e3o Branco - SP'), 'pt': u('Ribeir\u00e3o Branco - SP')},
 '55173695':{'en': u('Marin\u00f3polis - SP'), 'pt': u('Marin\u00f3polis - SP')},
 '55153557':{'en': u('Ita\u00f3ca - SP'), 'pt': u('Ita\u00f3ca - SP')},
 '55153556':{'en': 'Iporanga - SP', 'pt': 'Iporanga - SP'},
 '55153555':{'en': 'Ribeira - SP', 'pt': 'Ribeira - SP'},
 '55153554':{'en': u('Barra do Chap\u00e9u - SP'), 'pt': u('Barra do Chap\u00e9u - SP')},
 '55153558':{'en': u('Apia\u00ed - SP'), 'pt': u('Apia\u00ed - SP')},
 '55173699':{'en': 'Pontalinda - SP', 'pt': 'Pontalinda - SP'},
 '543885':{'en': 'La Quiaca, Jujuy', 'es': 'La Quiaca, Jujuy'},
 '543886':{'en': u('Libertador General San Mart\u00edn, Jujuy'), 'es': u('Libertador General San Mart\u00edn, Jujuy')},
 '543887':{'en': 'Humahuaca, Jujuy', 'es': 'Humahuaca, Jujuy'},
 '543888':{'en': 'San Pedro de Jujuy, Jujuy', 'es': 'San Pedro de Jujuy, Jujuy'},
 '55133362':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133363':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133361':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133367':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133364':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133365':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133369':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55313274':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313275':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313270':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313271':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313272':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313273':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313278':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313279':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '499556':{'de': 'Geiselwind', 'en': 'Geiselwind'},
 '499554':{'de': 'Untersteinbach Unterfranken', 'en': 'Untersteinbach Unterfranken'},
 '499555':{'de': u('Schl\u00fcsselfeld-Aschbach'), 'en': u('Schl\u00fcsselfeld-Aschbach')},
 '499552':{'de': 'Burghaslach', 'en': 'Burghaslach'},
 '499553':{'de': 'Ebrach Oberfranken', 'en': 'Ebrach Oberfranken'},
 '499551':{'de': 'Burgwindheim', 'en': 'Burgwindheim'},
 '49611':{'de': 'Wiesbaden', 'en': 'Wiesbaden'},
 '55163749':{'en': u('Ribeir\u00e3o Corrente - SP'), 'pt': u('Ribeir\u00e3o Corrente - SP')},
 '4969':{'de': 'Frankfurt am Main', 'en': 'Frankfurt am Main'},
 '55213736':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49471':{'de': 'Bremerhaven', 'en': 'Bremerhaven'},
 '55143112':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55213733':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113751':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113750':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113753':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113752':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113755':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113754':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55113757':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113756':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113759':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113758':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499434':{'de': u('Bodenw\u00f6hr'), 'en': u('Bodenw\u00f6hr')},
 '55192532':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55192533':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55223012':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55223013':{'en': 'Campos dos Goitacazes - RJ', 'pt': 'Campos dos Goitacazes - RJ'},
 '55223016':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55212647':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55212217':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273132':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55143378':{'en': 'Salto Grande - SP', 'pt': 'Salto Grande - SP'},
 '55143379':{'en': u('Ribeir\u00e3o do Sul - SP'), 'pt': u('Ribeir\u00e3o do Sul - SP')},
 '55273136':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '55273137':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55143372':{'en': 'Santa Cruz do Rio Pardo - SP', 'pt': 'Santa Cruz do Rio Pardo - SP'},
 '55143373':{'en': 'Santa Cruz do Rio Pardo - SP', 'pt': 'Santa Cruz do Rio Pardo - SP'},
 '55273138':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55273139':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55143376':{'en': u('Sodr\u00e9lia - SP'), 'pt': u('Sodr\u00e9lia - SP')},
 '55143377':{'en': u('S\u00e3o Pedro do Turvo - SP'), 'pt': u('S\u00e3o Pedro do Turvo - SP')},
 '55143374':{'en': 'Caporanga - SP', 'pt': 'Caporanga - SP'},
 '55143375':{'en': u('Esp\u00edrito Santo do Turvo - SP'), 'pt': u('Esp\u00edrito Santo do Turvo - SP')},
 '55193621':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55193623':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193622':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193625':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193624':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193626':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55193629':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55193628':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55212642':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55115077':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495636':{'de': 'Lichtenfels-Goddelsheim', 'en': 'Lichtenfels-Goddelsheim'},
 '495635':{'de': u('V\u00f6hl'), 'en': u('V\u00f6hl')},
 '495634':{'de': 'Waldeck-Sachsenhausen', 'en': 'Waldeck-Sachsenhausen'},
 '495633':{'de': 'Diemelsee', 'en': 'Diemelsee'},
 '495632':{'de': 'Willingen Upland', 'en': 'Willingen Upland'},
 '495631':{'de': 'Korbach', 'en': 'Korbach'},
 '495329':{'de': 'Schulenberg im Oberharz', 'en': 'Schulenberg im Oberharz'},
 '495328':{'de': 'Altenau Harz', 'en': 'Altenau Harz'},
 '495321':{'de': 'Goslar', 'en': 'Goslar'},
 '495320':{'de': 'Torfhaus', 'en': 'Torfhaus'},
 '495323':{'de': 'Clausthal-Zellerfeld', 'en': 'Clausthal-Zellerfeld'},
 '495322':{'de': 'Bad Harzburg', 'en': 'Bad Harzburg'},
 '495325':{'de': 'Goslar-Hahnenklee', 'en': 'Goslar-Hahnenklee'},
 '495324':{'de': 'Vienenburg', 'en': 'Vienenburg'},
 '495327':{'de': 'Bad Grund Harz', 'en': 'Bad Grund Harz'},
 '495326':{'de': 'Langelsheim', 'en': 'Langelsheim'},
 '497671':{'de': 'Todtnau', 'en': 'Todtnau'},
 '497673':{'de': u('Sch\u00f6nau im Schwarzwald'), 'en': u('Sch\u00f6nau im Schwarzwald')},
 '497672':{'de': 'St Blasien', 'en': 'St Blasien'},
 '497675':{'de': 'Bernau Baden', 'en': 'Bernau Baden'},
 '497674':{'de': 'Todtmoos', 'en': 'Todtmoos'},
 '497676':{'de': 'Feldberg Schwarzwald', 'en': 'Feldberg Schwarzwald'},
 '55143654':{'en': 'Brotas - SP', 'pt': 'Brotas - SP'},
 '5042651':{'en': u('Cucuyagua/Cop\u00e1n')},
 '5042650':{'en': 'San Manuel/Rio Lindo'},
 '5042653':{'en': 'Nueva Ocotepeque'},
 '5042652':{'en': 'Agua Caliente'},
 '5042654':{'en': 'Santa Cruz'},
 '55143652':{'en': u('Dois C\u00f3rregos - SP'), 'pt': u('Dois C\u00f3rregos - SP')},
 '55313071':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313074':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55163101':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55193361':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '496676':{'de': 'Hohenroda Hessen', 'en': 'Hohenroda Hessen'},
 '496853':{'de': 'Marpingen', 'en': 'Marpingen'},
 '496674':{'de': 'Friedewald Hessen', 'en': 'Friedewald Hessen'},
 '496675':{'de': 'Breitenbach am Herzberg', 'en': 'Breitenbach am Herzberg'},
 '496672':{'de': 'Eiterfeld', 'en': 'Eiterfeld'},
 '496673':{'de': 'Haunetal', 'en': 'Haunetal'},
 '496670':{'de': 'Ludwigsau Hessen', 'en': 'Ludwigsau Hessen'},
 '496855':{'de': 'Freisen', 'en': 'Freisen'},
 '55333261':{'en': 'Conselheiro Pena - MG', 'pt': 'Conselheiro Pena - MG'},
 '496858':{'de': u('Ottweiler-F\u00fcrth'), 'en': u('Ottweiler-F\u00fcrth')},
 '55333262':{'en': 'Goiabeira - MG', 'pt': 'Goiabeira - MG'},
 '55333265':{'en': 'Santa Rita do Itueto - MG', 'pt': 'Santa Rita do Itueto - MG'},
 '496678':{'de': u('Wildeck-H\u00f6nebach'), 'en': u('Wildeck-H\u00f6nebach')},
 '55333266':{'en': 'Quatituba - MG', 'pt': 'Quatituba - MG'},
 '55213171':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212886':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '494477':{'de': 'Lastrup-Hemmelte', 'en': 'Lastrup-Hemmelte'},
 '55212882':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55214062':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193856':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55193857':{'en': 'Engenheiro Coelho - SP', 'pt': 'Engenheiro Coelho - SP'},
 '55112506':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193855':{'en': 'Socorro - SP', 'pt': 'Socorro - SP'},
 '55313049':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55313048':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313045':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55223835':{'en': u('Carabu\u00e7u - RJ'), 'pt': u('Carabu\u00e7u - RJ')},
 '55223832':{'en': 'Rosal - RJ', 'pt': 'Rosal - RJ'},
 '55223833':{'en': 'Bom Jesus do Itabapoana - RJ', 'pt': 'Bom Jesus do Itabapoana - RJ'},
 '55223831':{'en': 'Bom Jesus do Itabapoana - RJ', 'pt': 'Bom Jesus do Itabapoana - RJ'},
 '55114484':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114485':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114486':{'en': 'Terra Preta - SP', 'pt': 'Terra Preta - SP'},
 '55114487':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114481':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55114482':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114483':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114488':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55114489':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '52419':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55113109':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '52415':{'en': 'San Miguel Allende, GTO', 'es': 'San Miguel Allende, GTO'},
 '55113105':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113106':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113107':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52411':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55113101':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52413':{'en': 'Apaseo el Alto/Apaseo el Grande, GTO', 'es': 'Apaseo el Alto/Apaseo el Grande, GTO'},
 '52412':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55193858':{'en': 'Engenheiro Coelho - SP', 'pt': 'Engenheiro Coelho - SP'},
 '55193859':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '55173826':{'en': 'Uchoa - SP', 'pt': 'Uchoa - SP'},
 '55114158':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55114159':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55114152':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114153':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55173571':{'en': u('Santa Ad\u00e9lia - SP'), 'pt': u('Santa Ad\u00e9lia - SP')},
 '55114151':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114156':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114157':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114154':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114155':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55133036':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '499639':{'de': u('M\u00e4hring'), 'en': u('M\u00e4hring')},
 '499638':{'de': 'Neualbenreuth', 'en': 'Neualbenreuth'},
 '55312191':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '499633':{'de': 'Mitterteich', 'en': 'Mitterteich'},
 '499632':{'de': 'Waldsassen', 'en': 'Waldsassen'},
 '499631':{'de': 'Tirschenreuth', 'en': 'Tirschenreuth'},
 '499637':{'de': 'Falkenberg Oberpfalz', 'en': 'Falkenberg Oberpfalz'},
 '499636':{'de': u('Pl\u00f6\u00dfberg'), 'en': u('Pl\u00f6ssberg')},
 '499635':{'de': u('B\u00e4rnau'), 'en': u('B\u00e4rnau')},
 '499634':{'de': 'Wiesau', 'en': 'Wiesau'},
 '498548':{'de': 'Vilshofen-Sandbach', 'en': 'Vilshofen-Sandbach'},
 '498549':{'de': 'Vilshofen-Pleinting', 'en': 'Vilshofen-Pleinting'},
 '55213868':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213869':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498542':{'de': 'Ortenburg', 'en': 'Ortenburg'},
 '498543':{'de': 'Aidenbach', 'en': 'Aidenbach'},
 '55323015':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '498541':{'de': 'Vilshofen Niederbayern', 'en': 'Vilshofen Niederbayern'},
 '498546':{'de': 'Windorf-Otterskirchen', 'en': 'Windorf-Otterskirchen'},
 '498547':{'de': 'Osterhofen-Gergweis', 'en': 'Osterhofen-Gergweis'},
 '498544':{'de': 'Eging am See', 'en': 'Eging am See'},
 '498545':{'de': 'Hofkirchen Bayern', 'en': 'Hofkirchen Bayern'},
 '499497':{'de': 'Seubersdorf in der Oberpfalz', 'en': 'Seubersdorf in der Oberpfalz'},
 '499495':{'de': 'Breitenbrunn Oberpfalz', 'en': 'Breitenbrunn Oberpfalz'},
 '499493':{'de': 'Beratzhausen', 'en': 'Beratzhausen'},
 '499492':{'de': 'Parsberg', 'en': 'Parsberg'},
 '499491':{'de': 'Hemau', 'en': 'Hemau'},
 '55153349':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55153344':{'en': 'Piedade - SP', 'pt': 'Piedade - SP'},
 '55153342':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153343':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '499499':{'de': 'Painten', 'en': 'Painten'},
 '499498':{'de': 'Laaber', 'en': 'Laaber'},
 '499948':{'de': 'Eschlkam', 'en': 'Eschlkam'},
 '499941':{'de': u('K\u00f6tzting'), 'en': u('K\u00f6tzting')},
 '55184101':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '499943':{'de': 'Lam Oberpfalz', 'en': 'Lam Oberpfalz'},
 '499942':{'de': 'Viechtach', 'en': 'Viechtach'},
 '499945':{'de': 'Arnbruck', 'en': 'Arnbruck'},
 '499944':{'de': 'Miltach', 'en': 'Miltach'},
 '499947':{'de': 'Neukirchen bei Hl Blut', 'en': 'Neukirchen bei Hl Blut'},
 '499946':{'de': u('Hohenwarth bei K\u00f6tzing'), 'en': u('Hohenwarth bei K\u00f6tzing')},
 '495138':{'de': 'Sehnde', 'en': 'Sehnde'},
 '495139':{'de': 'Burgwedel', 'en': 'Burgwedel'},
 '495135':{'de': 'Burgwedel-Fuhrberg', 'en': 'Burgwedel-Fuhrberg'},
 '495136':{'de': 'Burgdorf Kreis Hannover', 'en': 'Burgdorf Kreis Hannover'},
 '495137':{'de': 'Seelze', 'en': 'Seelze'},
 '495130':{'de': 'Wedemark', 'en': 'Wedemark'},
 '495131':{'de': 'Garbsen', 'en': 'Garbsen'},
 '495132':{'de': 'Lehrte', 'en': 'Lehrte'},
 '55123003':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123004':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55222534':{'en': 'Duas Barras - RJ', 'pt': 'Duas Barras - RJ'},
 '55222537':{'en': 'Carmo - RJ', 'pt': 'Carmo - RJ'},
 '55222531':{'en': 'Sumidouro - RJ', 'pt': 'Sumidouro - RJ'},
 '55222533':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55143585':{'en': u('Piraju\u00ed - SP'), 'pt': u('Piraju\u00ed - SP')},
 '55143584':{'en': u('Piraju\u00ed - SP'), 'pt': u('Piraju\u00ed - SP')},
 '55143587':{'en': 'Presidente Alves - SP', 'pt': 'Presidente Alves - SP'},
 '55143586':{'en': u('Guarant\u00e3 - SP'), 'pt': u('Guarant\u00e3 - SP')},
 '55143581':{'en': u('Ponga\u00ed - SP'), 'pt': u('Ponga\u00ed - SP')},
 '55143583':{'en': 'Balbinos - SP', 'pt': 'Balbinos - SP'},
 '55143582':{'en': 'Uru - SP', 'pt': 'Uru - SP'},
 '55143589':{'en': u('Regin\u00f3polis - SP'), 'pt': u('Regin\u00f3polis - SP')},
 '55112411':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112413':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112412':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112414':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112419':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '49861':{'de': 'Traunstein', 'en': 'Traunstein'},
 '55112960':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173546':{'en': 'Itajobi - SP', 'pt': 'Itajobi - SP'},
 '55313574':{'en': u('Crucil\u00e2ndia - MG'), 'pt': u('Crucil\u00e2ndia - MG')},
 '55173547':{'en': 'Itajobi - SP', 'pt': 'Itajobi - SP'},
 '55163820':{'en': u('Orl\u00e2ndia - SP'), 'pt': u('Orl\u00e2ndia - SP')},
 '55163821':{'en': u('Orl\u00e2ndia - SP'), 'pt': u('Orl\u00e2ndia - SP')},
 '55163829':{'en': 'Ituverava - SP', 'pt': 'Ituverava - SP'},
 '55183211':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55212508':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212509':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496449':{'de': 'Ehringshausen-Katzenfurt', 'en': 'Ehringshausen-Katzenfurt'},
 '55183217':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '496445':{'de': u('Sch\u00f6ffengrund'), 'en': u('Sch\u00f6ffengrund')},
 '496444':{'de': 'Bischoffen', 'en': 'Bischoffen'},
 '496447':{'de': u('Langg\u00f6ns-Niederkleen'), 'en': u('Langg\u00f6ns-Niederkleen')},
 '496446':{'de': 'Hohenahr', 'en': 'Hohenahr'},
 '496441':{'de': 'Wetzlar', 'en': 'Wetzlar'},
 '496440':{'de': u('K\u00f6lschhausen'), 'en': u('K\u00f6lschhausen')},
 '496443':{'de': 'Ehringshausen Dill', 'en': 'Ehringshausen Dill'},
 '496442':{'de': 'Braunfels', 'en': 'Braunfels'},
 '495862':{'de': 'Hitzacker Elbe', 'en': 'Hitzacker Elbe'},
 '495863':{'de': 'Zernien', 'en': 'Zernien'},
 '495861':{'de': 'Dannenberg Elbe', 'en': 'Dannenberg Elbe'},
 '495864':{'de': 'Jameln', 'en': 'Jameln'},
 '495865':{'de': 'Gusborn', 'en': 'Gusborn'},
 '55313869':{'en': 'Congonhas do Norte - MG', 'pt': 'Congonhas do Norte - MG'},
 '55313868':{'en': u('Concei\u00e7\u00e3o do Mato Dentro - MG'), 'pt': u('Concei\u00e7\u00e3o do Mato Dentro - MG')},
 '55313865':{'en': 'Coronel Fabriciano - MG', 'pt': 'Coronel Fabriciano - MG'},
 '55213634':{'en': 'Rio Bonito - RJ', 'pt': 'Rio Bonito - RJ'},
 '55313867':{'en': u('S\u00e3o Sebasti\u00e3o do Rio Preto - MG'), 'pt': u('S\u00e3o Sebasti\u00e3o do Rio Preto - MG')},
 '55313866':{'en': 'Dom Joaquim - MG', 'pt': 'Dom Joaquim - MG'},
 '55313861':{'en': 'Nova Era - MG', 'pt': 'Nova Era - MG'},
 '55313863':{'en': 'Ferros - MG', 'pt': 'Ferros - MG'},
 '55273302':{'en': 'Aracruz - ES', 'pt': 'Aracruz - ES'},
 '55114714':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114715':{'en': u('Alum\u00ednio - SP'), 'pt': u('Alum\u00ednio - SP')},
 '55114716':{'en': u('S\u00e3o Jo\u00e3o Novo - SP'), 'pt': u('S\u00e3o Jo\u00e3o Novo - SP')},
 '55114717':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114711':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114712':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114713':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114718':{'en': 'Mairinque - SP', 'pt': 'Mairinque - SP'},
 '55114719':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55123896':{'en': 'Ilhabela - SP', 'pt': 'Ilhabela - SP'},
 '55323003':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55193849':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '496761':{'de': u('Simmern Hunsr\u00fcck'), 'en': u('Simmern Hunsr\u00fcck')},
 '497248':{'de': 'Marxzell', 'en': 'Marxzell'},
 '497249':{'de': 'Stutensee', 'en': 'Stutensee'},
 '497240':{'de': 'Pfinztal', 'en': 'Pfinztal'},
 '497242':{'de': 'Rheinstetten', 'en': 'Rheinstetten'},
 '497243':{'de': 'Ettlingen', 'en': 'Ettlingen'},
 '497244':{'de': 'Weingarten Baden', 'en': 'Weingarten Baden'},
 '497245':{'de': 'Durmersheim', 'en': 'Durmersheim'},
 '497246':{'de': 'Malsch Kreis Karlsruhe', 'en': 'Malsch Kreis Karlsruhe'},
 '497247':{'de': 'Linkenheim-Hochstetten', 'en': 'Linkenheim-Hochstetten'},
 '55193588':{'en': 'Porto Ferreira - SP', 'pt': 'Porto Ferreira - SP'},
 '55213162':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55114365':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114367':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114366':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114361':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114360':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114363':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114362':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55213167':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55114368':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '497424':{'de': 'Spaichingen', 'en': 'Spaichingen'},
 '497425':{'de': 'Trossingen', 'en': 'Trossingen'},
 '497426':{'de': 'Gosheim', 'en': 'Gosheim'},
 '497427':{'de': u('Sch\u00f6mberg bei Balingen'), 'en': u('Sch\u00f6mberg bei Balingen')},
 '497420':{'de': 'Deisslingen', 'en': 'Deisslingen'},
 '497422':{'de': 'Schramberg', 'en': 'Schramberg'},
 '497423':{'de': 'Oberndorf am Neckar', 'en': 'Oberndorf am Neckar'},
 '497428':{'de': 'Rosenfeld', 'en': 'Rosenfeld'},
 '497429':{'de': 'Egesheim', 'en': 'Egesheim'},
 '55323021':{'en': u('Ub\u00e1 - MG'), 'pt': u('Ub\u00e1 - MG')},
 '55193581':{'en': 'Porto Ferreira - SP', 'pt': 'Porto Ferreira - SP'},
 '55323026':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55153571':{'en': 'Riversul - SP', 'pt': 'Riversul - SP'},
 '55153573':{'en': u('Bar\u00e3o de Antonina - SP'), 'pt': u('Bar\u00e3o de Antonina - SP')},
 '55153572':{'en': u('Itaber\u00e1 - SP'), 'pt': u('Itaber\u00e1 - SP')},
 '55153577':{'en': 'Barra do Turvo - SP', 'pt': 'Barra do Turvo - SP'},
 '55213879':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193586':{'en': 'Itirapina - SP', 'pt': 'Itirapina - SP'},
 '55213878':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498046':{'de': 'Bad Heilbrunn', 'en': 'Bad Heilbrunn'},
 '498045':{'de': 'Lenggries-Fall', 'en': 'Lenggries-Fall'},
 '498043':{'de': 'Jachenau', 'en': 'Jachenau'},
 '498042':{'de': 'Lenggries', 'en': 'Lenggries'},
 '498041':{'de': u('Bad T\u00f6lz'), 'en': u('Bad T\u00f6lz')},
 '55153353':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '497936':{'de': 'Schrozberg-Bartenstein', 'en': 'Schrozberg-Bartenstein'},
 '497937':{'de': u('D\u00f6rzbach'), 'en': u('D\u00f6rzbach')},
 '497934':{'de': 'Weikersheim', 'en': 'Weikersheim'},
 '497935':{'de': 'Schrozberg', 'en': 'Schrozberg'},
 '497932':{'de': u('Niederstetten W\u00fcrttemberg'), 'en': u('Niederstetten W\u00fcrttemberg')},
 '497933':{'de': 'Creglingen', 'en': 'Creglingen'},
 '497930':{'de': 'Boxberg Baden', 'en': 'Boxberg Baden'},
 '497931':{'de': 'Bad Mergentheim', 'en': 'Bad Mergentheim'},
 '55242723':{'en': 'Campos dos Goitacazes - RJ', 'pt': 'Campos dos Goitacazes - RJ'},
 '55313578':{'en': 'Piedade dos Gerais - MG', 'pt': 'Piedade dos Gerais - MG'},
 '497938':{'de': 'Mulfingen Jagst', 'en': 'Mulfingen Jagst'},
 '497939':{'de': 'Schrozberg-Spielbach', 'en': 'Schrozberg-Spielbach'},
 '498223':{'de': 'Ichenhausen', 'en': 'Ichenhausen'},
 '498222':{'de': 'Burgau Schwaben', 'en': 'Burgau Schwaben'},
 '498221':{'de': u('G\u00fcnzburg'), 'en': u('G\u00fcnzburg')},
 '498226':{'de': 'Bibertal', 'en': 'Bibertal'},
 '498225':{'de': 'Jettingen-Scheppach', 'en': 'Jettingen-Scheppach'},
 '498224':{'de': 'Offingen Donau', 'en': 'Offingen Donau'},
 '49671':{'de': 'Bad Kreuznach', 'en': 'Bad Kreuznach'},
 '499571':{'de': 'Lichtenfels Bayern', 'en': 'Lichtenfels Bayern'},
 '499572':{'de': 'Burgkunstadt', 'en': 'Burgkunstadt'},
 '499573':{'de': 'Staffelstein Oberfranken', 'en': 'Staffelstein Oberfranken'},
 '499574':{'de': 'Marktzeuln', 'en': 'Marktzeuln'},
 '499575':{'de': 'Weismain', 'en': 'Weismain'},
 '499576':{'de': 'Lichtenfels-Isling', 'en': 'Lichtenfels-Isling'},
 '499962':{'de': 'Schwarzach Niederbayern', 'en': 'Schwarzach Niederbayern'},
 '55212719':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313528':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313529':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313837':{'en': u('Bar\u00e3o de Cocais - MG'), 'pt': u('Bar\u00e3o de Cocais - MG')},
 '55313253':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313251':{'en': u('Santana do Para\u00edso - MG'), 'pt': u('Santana do Para\u00edso - MG')},
 '55313524':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313254':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183918':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55312128':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183913':{'en': u('Montalv\u00e3o - SP'), 'pt': u('Montalv\u00e3o - SP')},
 '55183911':{'en': 'Eneida - SP', 'pt': 'Eneida - SP'},
 '49491':{'de': 'Leer Ostfriesland', 'en': 'Leer Ostfriesland'},
 '55183917':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '52626':{'en': 'Ojinaga, CHIH', 'es': 'Ojinaga, CHIH'},
 '52627':{'en': 'Parral, CHIH', 'es': 'Parral, CHIH'},
 '52624':{'en': 'Baja California Sur', 'es': 'Baja California Sur'},
 '52625':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52622':{'en': 'Guaymas/San Carlos, SON', 'es': 'Guaymas/San Carlos, SON'},
 '52623':{'en': 'Sonora', 'es': 'Sonora'},
 '55193425':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '52621':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '55193399':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55193429':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193428':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '52628':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52629':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '55113737':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113736':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113735':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313523':{'en': u('S\u00edtio Novo - MG'), 'pt': u('S\u00edtio Novo - MG')},
 '55113733':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113732':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113731':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113739':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313624':{'en': u('Ribeir\u00e3o das Neves - MG'), 'pt': u('Ribeir\u00e3o das Neves - MG')},
 '55114961':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55193647':{'en': 'Itobi - SP', 'pt': 'Itobi - SP'},
 '55193646':{'en': u('S\u00e3o Sebasti\u00e3o da Grama - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o da Grama - SP')},
 '55193643':{'en': 'Vargem Grande do Sul - SP', 'pt': 'Vargem Grande do Sul - SP'},
 '55193642':{'en': u('\u00c1guas da Prata - SP'), 'pt': u('\u00c1guas da Prata - SP')},
 '55193641':{'en': 'Vargem Grande do Sul - SP', 'pt': 'Vargem Grande do Sul - SP'},
 '55193649':{'en': u('\u00c1guas da Prata - SP'), 'pt': u('\u00c1guas da Prata - SP')},
 '55312122':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55113617':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183916':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55115539':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115538':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222031':{'en': 'Saquarema - RJ', 'pt': 'Saquarema - RJ'},
 '55112068':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495650':{'de': 'Cornberg', 'en': 'Cornberg'},
 '495301':{'de': 'Lehre-Essenrode', 'en': 'Lehre-Essenrode'},
 '495652':{'de': 'Bad Sooden-Allendorf', 'en': 'Bad Sooden-Allendorf'},
 '495307':{'de': 'Braunschweig-Wenden', 'en': 'Braunschweig-Wenden'},
 '495306':{'de': 'Cremlingen', 'en': 'Cremlingen'},
 '495305':{'de': 'Sickte', 'en': 'Sickte'},
 '495304':{'de': 'Meine', 'en': 'Meine'},
 '55112060':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112061':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112063':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112064':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112065':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112066':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112067':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115533':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112643':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123949':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123948':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123946':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123945':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123944':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123943':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '495594':{'de': 'Bovenden-Reyershausen', 'en': 'Bovenden-Reyershausen'},
 '55123941':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55193394':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55212868':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112217':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193396':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '495593':{'de': 'Bovenden-Lenglern', 'en': 'Bovenden-Lenglern'},
 '55192118':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55192119':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55115535':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497653':{'de': 'Lenzkirch', 'en': 'Lenzkirch'},
 '497652':{'de': 'Hinterzarten', 'en': 'Hinterzarten'},
 '497651':{'de': 'Titisee-Neustadt', 'en': 'Titisee-Neustadt'},
 '55115534':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497657':{'de': 'Eisenbach Hochschwarzwald', 'en': 'Eisenbach Hochschwarzwald'},
 '497656':{'de': 'Schluchsee', 'en': 'Schluchsee'},
 '497655':{'de': u('Feldberg-Altglash\u00fctten'), 'en': u('Feldberg-Altglash\u00fctten')},
 '497654':{'de': u('L\u00f6ffingen'), 'en': u('L\u00f6ffingen')},
 '55133847':{'en': 'Miracatu - SP', 'pt': 'Miracatu - SP'},
 '55133846':{'en': 'Pedro Barros - SP', 'pt': 'Pedro Barros - SP'},
 '52276':{'en': 'Puebla', 'es': 'Puebla'},
 '55133843':{'en': 'Ilha Comprida - SP', 'pt': 'Ilha Comprida - SP'},
 '55133842':{'en': 'Ilha Comprida - SP', 'pt': 'Ilha Comprida - SP'},
 '55133841':{'en': 'Iguape - SP', 'pt': 'Iguape - SP'},
 '55222621':{'en': u('S\u00e3o Pedro da Aldeia - RJ'), 'pt': u('S\u00e3o Pedro da Aldeia - RJ')},
 '55222622':{'en': 'Arraial do Cabo - RJ', 'pt': 'Arraial do Cabo - RJ'},
 '55222623':{'en': u('Arma\u00e7\u00e3o dos B\u00fazios - RJ'), 'pt': u('Arma\u00e7\u00e3o dos B\u00fazios - RJ')},
 '55222529':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55222624':{'en': 'Iguaba Grande - RJ', 'pt': 'Iguaba Grande - RJ'},
 '55222528':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '496650':{'de': 'Hosenfeld', 'en': 'Hosenfeld'},
 '496651':{'de': 'Rasdorf', 'en': 'Rasdorf'},
 '496652':{'de': u('H\u00fcnfeld'), 'en': u('H\u00fcnfeld')},
 '496653':{'de': 'Burghaun', 'en': 'Burghaun'},
 '496654':{'de': u('Gersfeld Rh\u00f6n'), 'en': u('Gersfeld Rh\u00f6n')},
 '496655':{'de': 'Neuhof Kreis Fulda', 'en': 'Neuhof Kreis Fulda'},
 '496308':{'de': u('Olsbr\u00fccken'), 'en': u('Olsbr\u00fccken')},
 '496657':{'de': 'Hofbieber', 'en': 'Hofbieber'},
 '496874':{'de': 'Wadern-Nunkirchen', 'en': 'Wadern-Nunkirchen'},
 '496875':{'de': 'Nonnweiler-Primstal', 'en': 'Nonnweiler-Primstal'},
 '496304':{'de': 'Wolfstein Pfalz', 'en': 'Wolfstein Pfalz'},
 '496305':{'de': 'Hochspeyer', 'en': 'Hochspeyer'},
 '496302':{'de': 'Winnweiler', 'en': 'Winnweiler'},
 '496871':{'de': 'Wadern', 'en': 'Wadern'},
 '496872':{'de': 'Losheim am See', 'en': 'Losheim am See'},
 '496301':{'de': 'Otterbach Pfalz', 'en': 'Otterbach Pfalz'},
 '55222523':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '494298':{'de': 'Lilienthal', 'en': 'Lilienthal'},
 '55222522':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55272101':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55272102':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55272103':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55323314':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55273722':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55273727':{'en': u('S\u00e3o Gabriel da Palha - ES'), 'pt': u('S\u00e3o Gabriel da Palha - ES')},
 '55323311':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55223854':{'en': u('Santo Ant\u00f4nio de P\u00e1dua - RJ'), 'pt': u('Santo Ant\u00f4nio de P\u00e1dua - RJ')},
 '55223855':{'en': 'Rio de Janeiro', 'pt': 'Rio de Janeiro'},
 '55313067':{'en': 'Itabira - MG', 'pt': 'Itabira - MG'},
 '55223850':{'en': 'Miracema - RJ', 'pt': 'Miracema - RJ'},
 '55223851':{'en': u('Santo Ant\u00f4nio de P\u00e1dua - RJ'), 'pt': u('Santo Ant\u00f4nio de P\u00e1dua - RJ')},
 '55223852':{'en': 'Miracema - RJ', 'pt': 'Miracema - RJ'},
 '55223853':{'en': u('Santo Ant\u00f4nio de P\u00e1dua - RJ'), 'pt': u('Santo Ant\u00f4nio de P\u00e1dua - RJ')},
 '55273724':{'en': u('Maril\u00e2ndia - ES'), 'pt': u('Maril\u00e2ndia - ES')},
 '55113122':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113120':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52438':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52433':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '52432':{'en': 'Ciudad Manuel Doblado/Romita, GTO', 'es': 'Ciudad Manuel Doblado/Romita, GTO'},
 '52431':{'en': 'Jalostotitlan/Villa Obregon, JAL', 'es': u('Jalostotitl\u00e1n/Villa Obreg\u00f3n, JAL')},
 '55113129':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52437':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '52436':{'en': 'Zacapu, MICH', 'es': 'Zacapu, MICH'},
 '52435':{'en': 'Huetamo/San Lucas, MICH', 'es': 'Huetamo/San Lucas, MICH'},
 '52434':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55213779':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55173551':{'en': u('Ibir\u00e1 - SP'), 'pt': u('Ibir\u00e1 - SP')},
 '55173553':{'en': u('S\u00e3o Jo\u00e3o de Itagua\u00e7u - SP'), 'pt': u('S\u00e3o Jo\u00e3o de Itagua\u00e7u - SP')},
 '55173552':{'en': u('Urup\u00eas - SP'), 'pt': u('Urup\u00eas - SP')},
 '55173557':{'en': 'Sales - SP', 'pt': 'Sales - SP'},
 '55173556':{'en': u('Irapu\u00e3 - SP'), 'pt': u('Irapu\u00e3 - SP')},
 '55173395':{'en': 'Terra Roxa - SP', 'pt': 'Terra Roxa - SP'},
 '494468':{'de': 'Friedeburg-Reepsholt', 'en': 'Friedeburg-Reepsholt'},
 '498564':{'de': 'Johanniskirchen', 'en': 'Johanniskirchen'},
 '498565':{'de': 'Dietersburg-Baumgarten', 'en': 'Dietersburg-Baumgarten'},
 '55113384':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113383':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498562':{'de': 'Triftern', 'en': 'Triftern'},
 '498563':{'de': 'Bad Birnbach Rottal', 'en': 'Bad Birnbach Rottal'},
 '55113389':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222748':{'en': u('Travess\u00e3o - RJ'), 'pt': u('Travess\u00e3o - RJ')},
 '55213806':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323031':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55213803':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55213809':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499963':{'de': 'Konzell', 'en': 'Konzell'},
 '55112396':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '499961':{'de': 'Mitterfels', 'en': 'Mitterfels'},
 '55153327':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '499966':{'de': 'Wiesenfelden', 'en': 'Wiesenfelden'},
 '499965':{'de': 'Sankt Englmar', 'en': 'Sankt Englmar'},
 '55112465':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112466':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112467':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55163942':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '499202':{'de': 'Waischenfeld', 'en': 'Waischenfeld'},
 '494462':{'de': 'Wittmund', 'en': 'Wittmund'},
 '499203':{'de': 'Neudrossenfeld', 'en': 'Neudrossenfeld'},
 '55112463':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112653':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112652':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112651':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112657':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55115976':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112655':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112654':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115979':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112658':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '495754':{'de': 'Extertal-Bremke', 'en': 'Extertal-Bremke'},
 '55113858':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113675':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123971':{'en': u('S\u00e3o Bento do Sapuca\u00ed - SP'), 'pt': u('S\u00e3o Bento do Sapuca\u00ed - SP')},
 '55163461':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '495755':{'de': 'Kalletal-Varenholz', 'en': 'Kalletal-Varenholz'},
 '55113678':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55223201':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55113855':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55223205':{'en': 'Saquarema - RJ', 'pt': 'Saquarema - RJ'},
 '55112475':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112473':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55112472':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112471':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55123686':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123687':{'en': 'Quiririm - SP', 'pt': 'Quiririm - SP'},
 '55123681':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55112479':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '542357':{'en': 'Carlos Tejedor, Buenos Aires', 'es': 'Carlos Tejedor, Buenos Aires'},
 '55212298':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212299':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '543574':{'en': u('R\u00edo Primero, C\u00f3rdoba'), 'es': u('R\u00edo Primero, C\u00f3rdoba')},
 '543575':{'en': u('La Puerta, C\u00f3rdoba'), 'es': u('La Puerta, C\u00f3rdoba')},
 '543576':{'en': u('Arroyito, C\u00f3rdoba'), 'es': u('Arroyito, C\u00f3rdoba')},
 '55212291':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212296':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '543571':{'en': u('R\u00edo Tercero, C\u00f3rdoba'), 'es': u('R\u00edo Tercero, C\u00f3rdoba')},
 '543572':{'en': u('R\u00edo Segundo, C\u00f3rdoba'), 'es': u('R\u00edo Segundo, C\u00f3rdoba')},
 '543573':{'en': u('Villa del Rosario, C\u00f3rdoba'), 'es': u('Villa del Rosario, C\u00f3rdoba')},
 '55163946':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '543549':{'en': u('Cruz del Eje, C\u00f3rdoba'), 'es': u('Cruz del Eje, C\u00f3rdoba')},
 '55242252':{'en': u('Tr\u00eas Rios - RJ'), 'pt': u('Tr\u00eas Rios - RJ')},
 '55123974':{'en': 'Paraibuna - SP', 'pt': 'Paraibuna - SP'},
 '55242251':{'en': u('Tr\u00eas Rios - RJ'), 'pt': u('Tr\u00eas Rios - RJ')},
 '55173807':{'en': 'Ubarana - SP', 'pt': 'Ubarana - SP'},
 '496467':{'de': 'Hatzfeld Eder', 'en': 'Hatzfeld Eder'},
 '54294':{'en': u('San Carlos de Bariloche, R\u00edo Negro'), 'es': u('San Carlos de Bariloche, R\u00edo Negro')},
 '54297':{'en': 'Comodoro Rivadavia, Chubut', 'es': 'Comodoro Rivadavia, Chubut'},
 '496464':{'de': 'Angelburg', 'en': 'Angelburg'},
 '54291':{'en': u('Bah\u00eda Blanca, Buenos Aires'), 'es': u('Bah\u00eda Blanca, Buenos Aires')},
 '496462':{'de': 'Gladenbach', 'en': 'Gladenbach'},
 '496461':{'de': 'Biedenkopf', 'en': 'Biedenkopf'},
 '498723':{'de': 'Arnstorf', 'en': 'Arnstorf'},
 '55242257':{'en': 'Areal - RJ', 'pt': 'Areal - RJ'},
 '54299':{'en': u('Neuqu\u00e9n, Neuqu\u00e9n'), 'es': u('Neuqu\u00e9n, Neuqu\u00e9n')},
 '54298':{'en': u('General Roca, R\u00edo Negro'), 'es': u('General Roca, R\u00edo Negro')},
 '496468':{'de': 'Dautphetal-Mornshausen', 'en': 'Dautphetal-Mornshausen'},
 '55183277':{'en': 'Sandovalina - SP', 'pt': 'Sandovalina - SP'},
 '495653':{'de': 'Sontra', 'en': 'Sontra'},
 '55183275':{'en': u('Martin\u00f3polis - SP'), 'pt': u('Martin\u00f3polis - SP')},
 '55183274':{'en': u('Te\u00e7aind\u00e1 - SP'), 'pt': u('Te\u00e7aind\u00e1 - SP')},
 '55183273':{'en': u('\u00c1lvares Machado - SP'), 'pt': u('\u00c1lvares Machado - SP')},
 '55183272':{'en': 'Presidente Venceslau - SP', 'pt': 'Presidente Venceslau - SP'},
 '55183271':{'en': 'Presidente Venceslau - SP', 'pt': 'Presidente Venceslau - SP'},
 '55123975':{'en': 'Santa Branca - SP', 'pt': 'Santa Branca - SP'},
 '55163944':{'en': 'Dumont - SP', 'pt': 'Dumont - SP'},
 '55183279':{'en': u('Regente Feij\u00f3 - SP'), 'pt': u('Regente Feij\u00f3 - SP')},
 '55183278':{'en': u('Caiu\u00e1 - SP'), 'pt': u('Caiu\u00e1 - SP')},
 '495751':{'de': 'Rinteln', 'en': 'Rinteln'},
 '55224141':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '498725':{'de': 'Wurmannsquick', 'en': 'Wurmannsquick'},
 '55242259':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55212005':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313883':{'en': 'Rio Doce - MG', 'pt': 'Rio Doce - MG'},
 '55114738':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114739':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55313887':{'en': 'Acaiaca - MG', 'pt': 'Acaiaca - MG'},
 '55183117':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55313885':{'en': u('Vi\u00e7osa - MG'), 'pt': u('Vi\u00e7osa - MG')},
 '55163514':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55313889':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '542982497':{'en': 'San Francisco de Bellocq, Buenos Aires', 'es': 'San Francisco de Bellocq, Buenos Aires'},
 '55114736':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114735':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55173256':{'en': 'Santa Luzia - SP', 'pt': 'Santa Luzia - SP'},
 '55312111':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55173257':{'en': u('Bagua\u00e7u - SP'), 'pt': u('Bagua\u00e7u - SP')},
 '55173254':{'en': 'Mirassol - SP', 'pt': 'Mirassol - SP'},
 '495753':{'de': 'Auetal-Bernsen', 'en': 'Auetal-Bernsen'},
 '55163519':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55173251':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '497222':{'de': 'Rastatt', 'en': 'Rastatt'},
 '497223':{'de': u('B\u00fchl Baden'), 'en': u('B\u00fchl Baden')},
 '497220':{'de': 'Forbach-Hundsbach', 'en': 'Forbach-Hundsbach'},
 '497221':{'de': 'Baden-Baden', 'en': 'Baden-Baden'},
 '497226':{'de': u('B\u00fchl-Sand'), 'en': u('B\u00fchl-Sand')},
 '497227':{'de': 'Lichtenau Baden', 'en': 'Lichtenau Baden'},
 '497224':{'de': 'Gernsbach', 'en': 'Gernsbach'},
 '497225':{'de': 'Gaggenau', 'en': 'Gaggenau'},
 '497228':{'de': 'Forbach', 'en': 'Forbach'},
 '497229':{'de': 'Iffezheim', 'en': 'Iffezheim'},
 '55312572':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '495844':{'de': 'Clenze', 'en': 'Clenze'},
 '495845':{'de': 'Bergen Dumme', 'en': 'Bergen Dumme'},
 '495846':{'de': 'Gartow Niedersachsen', 'en': 'Gartow Niedersachsen'},
 '495840':{'de': 'Schnackenburg', 'en': 'Schnackenburg'},
 '495841':{'de': u('L\u00fcchow Wendland'), 'en': u('L\u00fcchow Wendland')},
 '495842':{'de': 'Schnega', 'en': 'Schnega'},
 '495843':{'de': 'Wustrow Wendland', 'en': 'Wustrow Wendland'},
 '495848':{'de': 'Trebel', 'en': 'Trebel'},
 '495849':{'de': 'Waddeweitz', 'en': 'Waddeweitz'},
 '55173301':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173302':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55242292':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55212712':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55153519':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153511':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55212711':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55322104':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55322102':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55322101':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '498021':{'de': 'Waakirchen', 'en': 'Waakirchen'},
 '498020':{'de': 'Weyarn', 'en': 'Weyarn'},
 '498023':{'de': 'Bayrischzell', 'en': 'Bayrischzell'},
 '498022':{'de': 'Tegernsee', 'en': 'Tegernsee'},
 '498025':{'de': 'Miesbach', 'en': 'Miesbach'},
 '498024':{'de': 'Holzkirchen', 'en': 'Holzkirchen'},
 '498027':{'de': 'Dietramszell', 'en': 'Dietramszell'},
 '498026':{'de': 'Hausham', 'en': 'Hausham'},
 '498029':{'de': 'Kreuth bei Tegernsee', 'en': 'Kreuth bei Tegernsee'},
 '498028':{'de': 'Fischbachau', 'en': 'Fischbachau'},
 '495651':{'de': 'Eschwege', 'en': 'Eschwege'},
 '499778':{'de': 'Fladungen', 'en': 'Fladungen'},
 '499779':{'de': u('Nordheim von der Rh\u00f6n'), 'en': u('Nordheim von der Rh\u00f6n')},
 '499776':{'de': 'Mellrichstadt', 'en': 'Mellrichstadt'},
 '499777':{'de': u('Ostheim von der Rh\u00f6n'), 'en': u('Ostheim von der Rh\u00f6n')},
 '499774':{'de': 'Oberelsbach', 'en': 'Oberelsbach'},
 '499775':{'de': u('Sch\u00f6nau an der Brend'), 'en': u('Sch\u00f6nau an der Brend')},
 '499772':{'de': u('Bischofsheim an der Rh\u00f6n'), 'en': u('Bischofsheim an der Rh\u00f6n')},
 '499773':{'de': 'Unsleben', 'en': 'Unsleben'},
 '499771':{'de': 'Bad Neustadt an der Saale', 'en': 'Bad Neustadt an der Saale'},
 '495300':{'de': u('Salzgitter-\u00dcfingen'), 'en': u('Salzgitter-\u00dcfingen')},
 '55212717':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '495655':{'de': 'Wanfried', 'en': 'Wanfried'},
 '495654':{'de': 'Herleshausen', 'en': 'Herleshausen'},
 '55163253':{'en': 'Taquaritinga - SP', 'pt': 'Taquaritinga - SP'},
 '55163252':{'en': 'Taquaritinga - SP', 'pt': 'Taquaritinga - SP'},
 '55163251':{'en': 'Guariba - SP', 'pt': 'Guariba - SP'},
 '55163257':{'en': u('C\u00e2ndido Rodrigues - SP'), 'pt': u('C\u00e2ndido Rodrigues - SP')},
 '495657':{'de': 'Meissner', 'en': 'Meissner'},
 '55163254':{'en': 'Guariroba - SP', 'pt': 'Guariroba - SP'},
 '495656':{'de': 'Waldkappel', 'en': 'Waldkappel'},
 '495659':{'de': 'Ringgau', 'en': 'Ringgau'},
 '495658':{'de': 'Wehretal', 'en': 'Wehretal'},
 '495309':{'de': 'Lehre-Wendhausen', 'en': 'Lehre-Wendhausen'},
 '495308':{'de': 'Lehre', 'en': 'Lehre'},
 '55183268':{'en': 'Nantes - SP', 'pt': 'Nantes - SP'},
 '49651':{'de': 'Trier', 'en': 'Trier'},
 '55183269':{'en': 'Pirapozinho - SP', 'pt': 'Pirapozinho - SP'},
 '55213860':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212715':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212513':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212512':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183255':{'en': 'Rancharia - SP', 'pt': 'Rancharia - SP'},
 '55212714':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313508':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313507':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313504':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55312101':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '5161':{'en': 'Ucayali'},
 '5162':{'en': u('Hu\u00e1nuco')},
 '5163':{'en': 'Pasco'},
 '5164':{'en': u('Jun\u00edn')},
 '5165':{'en': 'Loreto'},
 '5166':{'en': 'Ayacucho'},
 '5167':{'en': 'Huancavelica'},
 '55193401':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55143629':{'en': 'Potunduva - SP', 'pt': 'Potunduva - SP'},
 '55193402':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193405':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55193404':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55193407':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55193406':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55113249':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113248':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113719':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113718':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113715':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113714':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113241':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113716':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113246':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113713':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113712':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55224009':{'en': 'Campos dos Goitacazes - RJ', 'pt': 'Campos dos Goitacazes - RJ'},
 '55223058':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '55223054':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55223056':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55223051':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55123942':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55193669':{'en': u('Divinol\u00e2ndia - SP'), 'pt': u('Divinol\u00e2ndia - SP')},
 '55193665':{'en': 'Mococa - SP', 'pt': 'Mococa - SP'},
 '55193667':{'en': 'Mococa - SP', 'pt': 'Mococa - SP'},
 '55193661':{'en': u('Esp\u00edrito Santo do Pinhal - SP'), 'pt': u('Esp\u00edrito Santo do Pinhal - SP')},
 '55193663':{'en': u('Divinol\u00e2ndia - SP'), 'pt': u('Divinol\u00e2ndia - SP')},
 '55193662':{'en': 'Caconde - SP', 'pt': 'Caconde - SP'},
 '55313723':{'en': 'Casa Grande - MG', 'pt': 'Casa Grande - MG'},
 '55313375':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55314113':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55314114':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55213002':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55314115':{'en': 'Lagoa Santa - MG', 'pt': 'Lagoa Santa - MG'},
 '55212710':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313376':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112048':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112049':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495673':{'de': 'Immenhausen Hessen', 'en': 'Immenhausen Hessen'},
 '495672':{'de': 'Bad Karlshafen', 'en': 'Bad Karlshafen'},
 '495671':{'de': 'Hofgeismar', 'en': 'Hofgeismar'},
 '55313725':{'en': u('Carana\u00edba - MG'), 'pt': u('Carana\u00edba - MG')},
 '495677':{'de': 'Calden-Westuffeln', 'en': 'Calden-Westuffeln'},
 '495676':{'de': 'Liebenau Hessen', 'en': 'Liebenau Hessen'},
 '55112040':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495674':{'de': 'Grebenstein', 'en': 'Grebenstein'},
 '55123965':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123211':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55123966':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123961':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123962':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55313894':{'en': 'Araponga - MG', 'pt': 'Araponga - MG'},
 '55313895':{'en': 'Teixeiras - MG', 'pt': 'Teixeiras - MG'},
 '55313896':{'en': 'Pedra do Anta - MG', 'pt': 'Pedra do Anta - MG'},
 '55313897':{'en': u('S\u00e3o Miguel do Anta - MG'), 'pt': u('S\u00e3o Miguel do Anta - MG')},
 '55192138':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192111':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55192137':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '496788':{'de': 'Sien', 'en': 'Sien'},
 '55192113':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55192114':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '543743':{'en': 'Puerto Rico, Misiones', 'es': 'Puerto Rico, Misiones'},
 '543741':{'en': 'Bernardo de Irigoyen, Misiones', 'es': 'Bernardo de Irigoyen, Misiones'},
 '55192117':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55163515':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55223084':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '52723':{'en': 'Coatepec Harinas, MEX', 'es': 'Coatepec Harinas, MEX'},
 '52722':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55193524':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '496328':{'de': 'Elmstein', 'en': 'Elmstein'},
 '496329':{'de': 'Weidenthal Pfalz', 'en': 'Weidenthal Pfalz'},
 '496638':{'de': 'Schwalmtal-Renzendorf', 'en': 'Schwalmtal-Renzendorf'},
 '496639':{'de': 'Ottrau', 'en': 'Ottrau'},
 '55333221':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55243421':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55212713':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '496633':{'de': 'Homberg Ohm', 'en': 'Homberg Ohm'},
 '496322':{'de': u('Bad D\u00fcrkheim'), 'en': u('Bad D\u00fcrkheim')},
 '496323':{'de': 'Edenkoben', 'en': 'Edenkoben'},
 '496324':{'de': 'Hassloch', 'en': 'Hassloch'},
 '496637':{'de': 'Feldatal', 'en': 'Feldatal'},
 '496634':{'de': u('Gem\u00fcnden Felda'), 'en': u('Gem\u00fcnden Felda')},
 '496635':{'de': 'Kirtorf', 'en': 'Kirtorf'},
 '55193032':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193521':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55313835':{'en': 'Itabira - MG', 'pt': 'Itabira - MG'},
 '55113321':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113322':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113451':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273533':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55113325':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193984':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '52356':{'en': 'Tanhuato/Yurecuaro, MICH', 'es': u('Tanhuato/Yur\u00e9cuaro, MICH')},
 '55113454':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52357':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55113455':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52354':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55133591':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55113024':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133227':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133594':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133224':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '52352':{'en': 'La Piedad, MICH', 'es': 'La Piedad, MICH'},
 '52353':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55114441':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114442':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114443':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114444':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114445':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114446':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '55114448':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '55114449':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55213351':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55333268':{'en': u('Aimor\u00e9s - MG'), 'pt': u('Aimor\u00e9s - MG')},
 '55213353':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55222778':{'en': 'Casimiro de Abreu - RJ', 'pt': 'Casimiro de Abreu - RJ'},
 '55213354':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55133048':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55213357':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55114196':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114194':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114195':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114192':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114193':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55173531':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55114191':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114198':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '52417':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55213828':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213398':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498586':{'de': 'Hauzenberg', 'en': 'Hauzenberg'},
 '55213395':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498584':{'de': 'Breitenberg Niederbayern', 'en': 'Breitenberg Niederbayern'},
 '498585':{'de': 'Grainet', 'en': 'Grainet'},
 '498582':{'de': u('R\u00f6hrnbach'), 'en': u('R\u00f6hrnbach')},
 '498583':{'de': 'Neureichenau', 'en': 'Neureichenau'},
 '55213392':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498581':{'de': 'Waldkirchen Niederbayern', 'en': 'Waldkirchen Niederbayern'},
 '55323274':{'en': 'Rio Novo - MG', 'pt': 'Rio Novo - MG'},
 '55153302':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55213412':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153653':{'en': u('Cap\u00e3o Bonito - SP'), 'pt': u('Cap\u00e3o Bonito - SP')},
 '55153307':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153305':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '55183694':{'en': 'Zacarias - SP', 'pt': 'Zacarias - SP'},
 '52451':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52453':{'en': 'Apatzingan, MICH', 'es': u('Apatzing\u00e1n, MICH')},
 '52452':{'en': 'Nuevo San Juan Parangaricutiro/Uruapan, MICH', 'es': 'Nuevo San Juan Parangaricutiro/Uruapan, MICH'},
 '52455':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52454':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52457':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '52456':{'en': 'Valle de Santiago, GTO', 'es': 'Valle de Santiago, GTO'},
 '52459':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52458':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '55144009':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55112679':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112678':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112671':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112673':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112672':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112675':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112674':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112676':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499185':{'de': u('M\u00fchlhausen Oberpfalz'), 'en': u('M\u00fchlhausen Oberpfalz')},
 '499184':{'de': 'Deining Oberpfalz', 'en': 'Deining Oberpfalz'},
 '499187':{'de': u('Altdorf bei N\u00fcrnberg'), 'en': u('Altdorf bei N\u00fcrnberg')},
 '499186':{'de': 'Lauterhofen Oberpfalz', 'en': 'Lauterhofen Oberpfalz'},
 '499181':{'de': 'Neumarkt in der Oberpfalz', 'en': 'Neumarkt in der Oberpfalz'},
 '499180':{'de': 'Pyrbaum', 'en': 'Pyrbaum'},
 '499183':{'de': 'Burgthann', 'en': 'Burgthann'},
 '499182':{'de': 'Velburg', 'en': 'Velburg'},
 '55323278':{'en': 'Pequeri - MG', 'pt': 'Pequeri - MG'},
 '499189':{'de': 'Berg bei Neumarkt in der Oberpfalz', 'en': 'Berg bei Neumarkt in der Oberpfalz'},
 '499188':{'de': 'Postbauer-Heng', 'en': 'Postbauer-Heng'},
 '55123512':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55112909':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112908':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112458':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55115489':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55112903':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112902':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112901':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112900':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112451':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112906':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112905':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112452':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '49821':{'de': 'Augsburg', 'en': 'Augsburg'},
 '5042429':{'en': 'San Alejo/Mesapa'},
 '499841':{'de': 'Bad Windsheim', 'en': 'Bad Windsheim'},
 '5042423':{'en': 'La Ceiba'},
 '499235':{'de': 'Thierstein', 'en': 'Thierstein'},
 '499234':{'de': 'Neusorg', 'en': 'Neusorg'},
 '499233':{'de': 'Arzberg Oberfranken', 'en': 'Arzberg Oberfranken'},
 '499232':{'de': 'Wunsiedel', 'en': 'Wunsiedel'},
 '499231':{'de': 'Marktredwitz', 'en': 'Marktredwitz'},
 '5042425':{'en': 'Utila, Bay Islands'},
 '55212270':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212272':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499843':{'de': 'Burgbernheim', 'en': 'Burgbernheim'},
 '55212274':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212275':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212276':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212277':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212278':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499844':{'de': 'Obernzenn', 'en': 'Obernzenn'},
 '55173802':{'en': 'Paulo de Faria - SP', 'pt': 'Paulo de Faria - SP'},
 '55113971':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113797':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496401':{'de': u('Gr\u00fcnberg Hessen'), 'en': u('Gr\u00fcnberg Hessen')},
 '496400':{'de': u('M\u00fccke'), 'en': u('M\u00fccke')},
 '496403':{'de': 'Linden Hessen', 'en': 'Linden Hessen'},
 '55113972':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496405':{'de': 'Laubach Hessen', 'en': 'Laubach Hessen'},
 '496404':{'de': 'Lich Hessen', 'en': 'Lich Hessen'},
 '496407':{'de': 'Rabenau Hessen', 'en': 'Rabenau Hessen'},
 '496406':{'de': 'Lollar', 'en': 'Lollar'},
 '496409':{'de': 'Biebertal', 'en': 'Biebertal'},
 '496408':{'de': 'Buseck', 'en': 'Buseck'},
 '55143451':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55143457':{'en': 'Oscar Bressane - SP', 'pt': 'Oscar Bressane - SP'},
 '55143456':{'en': 'Oriente - SP', 'pt': 'Oriente - SP'},
 '55143454':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55113501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113502':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113505':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113507':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212632':{'en': 'Guapimirim - RJ', 'pt': 'Guapimirim - RJ'},
 '496656':{'de': 'Ebersburg', 'en': 'Ebersburg'},
 '55222134':{'en': 'Iguaba Grande - RJ', 'pt': 'Iguaba Grande - RJ'},
 '496306':{'de': 'Trippstadt', 'en': 'Trippstadt'},
 '496307':{'de': 'Schopp', 'en': 'Schopp'},
 '55212633':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '496876':{'de': 'Weiskirchen Saar', 'en': 'Weiskirchen Saar'},
 '55212501':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55333203':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '496303':{'de': 'Enkenbach-Alsenborn', 'en': 'Enkenbach-Alsenborn'},
 '55212634':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '496873':{'de': 'Nonnweiler', 'en': 'Nonnweiler'},
 '49971':{'de': 'Bad Kissingen', 'en': 'Bad Kissingen'},
 '497204':{'de': u('Malsch-V\u00f6lkersbach'), 'en': u('Malsch-V\u00f6lkersbach')},
 '497754':{'de': u('G\u00f6rwihl'), 'en': u('G\u00f6rwihl')},
 '497755':{'de': 'Weilheim Kreis Waldshut', 'en': 'Weilheim Kreis Waldshut'},
 '497753':{'de': 'Albbruck', 'en': 'Albbruck'},
 '497202':{'de': 'Karlsbad', 'en': 'Karlsbad'},
 '497203':{'de': 'Walzbachtal', 'en': 'Walzbachtal'},
 '495531':{'de': 'Holzminden', 'en': 'Holzminden'},
 '495532':{'de': 'Stadtoldendorf', 'en': 'Stadtoldendorf'},
 '495533':{'de': 'Bodenwerder', 'en': 'Bodenwerder'},
 '495534':{'de': 'Eschershausen an der Lenne', 'en': 'Eschershausen an der Lenne'},
 '495535':{'de': 'Polle', 'en': 'Polle'},
 '495536':{'de': 'Holzminden-Neuhaus', 'en': 'Holzminden-Neuhaus'},
 '55213630':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55213639':{'en': u('Itabora\u00ed - RJ'), 'pt': u('Itabora\u00ed - RJ')},
 '55173322':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173323':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173321':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173326':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173324':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173325':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173328':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '504257':{'en': u('B\u00fafalo')},
 '504251':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '55212637':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '55223844':{'en': u('Porci\u00fancula - RJ'), 'pt': u('Porci\u00fancula - RJ')},
 '55333025':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55153535':{'en': 'Nova Campina - SP', 'pt': 'Nova Campina - SP'},
 '55153534':{'en': u('Taquariva\u00ed - SP'), 'pt': u('Taquariva\u00ed - SP')},
 '55153537':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153531':{'en': u('Itarar\u00e9 - SP'), 'pt': u('Itarar\u00e9 - SP')},
 '55153533':{'en': u('Bom Sucesso de Itarar\u00e9 - SP'), 'pt': u('Bom Sucesso de Itarar\u00e9 - SP')},
 '55153532':{'en': u('Itarar\u00e9 - SP'), 'pt': u('Itarar\u00e9 - SP')},
 '55213089':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '543826':{'en': 'Chamical, La Rioja', 'es': 'Chamical, La Rioja'},
 '543827':{'en': 'Aimogasta, La Rioja', 'es': 'Aimogasta, La Rioja'},
 '543825':{'en': 'Chilecito, La Rioja', 'es': 'Chilecito, La Rioja'},
 '543821':{'en': 'Chepes, La Rioja', 'es': 'Chepes, La Rioja'},
 '52846':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55115103':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52844':{'en': 'Saltillo, COAH', 'es': 'Saltillo, COAH'},
 '52845':{'en': 'Ebano/Ponciano Arriaga, SLP', 'es': 'Ebano/Ponciano Arriaga, SLP'},
 '52842':{'en': 'Coahuila', 'es': 'Coahuila'},
 '52841':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '55313533':{'en': u('Ibirit\u00e9 - MG'), 'pt': u('Ibirit\u00e9 - MG')},
 '55313450':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313451':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '497972':{'de': 'Gschwend bei Gaildorf', 'en': 'Gschwend bei Gaildorf'},
 '497973':{'de': 'Obersontheim', 'en': 'Obersontheim'},
 '55163273':{'en': u('It\u00e1polis - SP'), 'pt': u('It\u00e1polis - SP')},
 '497971':{'de': 'Gaildorf', 'en': 'Gaildorf'},
 '497976':{'de': 'Sulzbach-Laufen', 'en': 'Sulzbach-Laufen'},
 '497977':{'de': 'Oberrot bei Gaildorf', 'en': 'Oberrot bei Gaildorf'},
 '497974':{'de': u('B\u00fchlerzell'), 'en': u('B\u00fchlerzell')},
 '497975':{'de': u('Untergr\u00f6ningen'), 'en': u('Untergr\u00f6ningen')},
 '55113885':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113884':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113887':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113886':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113881':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113883':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113882':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114092':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55113889':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113888':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313455':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313741':{'en': 'Ouro Branco - MG', 'pt': 'Ouro Branco - MG'},
 '55313742':{'en': 'Ouro Branco - MG', 'pt': 'Ouro Branco - MG'},
 '55313746':{'en': 'Piranga - MG', 'pt': 'Piranga - MG'},
 '55313749':{'en': 'Ouro Branco - MG', 'pt': 'Ouro Branco - MG'},
 '55313457':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55282102':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55282101':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55113089':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113088':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113085':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113087':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113086':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113083':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113082':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114278':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55313292':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313561':{'en': 'Itabirito - MG', 'pt': 'Itabirito - MG'},
 '55313562':{'en': 'Itabirito - MG', 'pt': 'Itabirito - MG'},
 '55313291':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114273':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114272':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114275':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55143604':{'en': 'Barra Bonita - SP', 'pt': 'Barra Bonita - SP'},
 '55143602':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55193469':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55143601':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55193467':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55193466':{'en': 'Nova Odessa - SP', 'pt': 'Nova Odessa - SP'},
 '5144':{'en': 'La Libertad'},
 '55193464':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '5142':{'en': u('San Mart\u00edn')},
 '5143':{'en': 'Ancash'},
 '55193461':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '5141':{'en': 'Amazonas'},
 '55113263':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113262':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113265':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113264':{'en': 'Salvador - BA', 'pt': 'Salvador - BA'},
 '55113266':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113269':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113268':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52661':{'en': 'Primo Tapia/Rosarito, BCN', 'es': 'Primo Tapia/Rosarito, BCN'},
 '52667':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '52665':{'en': 'Tecate, BCN', 'es': 'Tecate, BCN'},
 '55212205':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212204':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499534':{'de': 'Burgpreppach', 'en': 'Burgpreppach'},
 '499535':{'de': 'Pfarrweisach', 'en': 'Pfarrweisach'},
 '499536':{'de': 'Kirchlauter', 'en': 'Kirchlauter'},
 '494725':{'de': 'Helgoland', 'en': 'Helgoland'},
 '494722':{'de': 'Cuxhaven-Altenbruch', 'en': 'Cuxhaven-Altenbruch'},
 '499531':{'de': 'Ebern', 'en': 'Ebern'},
 '499532':{'de': 'Maroldsweisach', 'en': 'Maroldsweisach'},
 '494721':{'de': 'Cuxhaven', 'en': 'Cuxhaven'},
 '55193683':{'en': 'Santa Cruz das Palmeiras - SP', 'pt': 'Santa Cruz das Palmeiras - SP'},
 '55193682':{'en': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP')},
 '55193681':{'en': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP')},
 '55212203':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193684':{'en': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP')},
 '55222758':{'en': u('S\u00e3o Fid\u00e9lis - RJ'), 'pt': u('S\u00e3o Fid\u00e9lis - RJ')},
 '55222759':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55123884':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123885':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55213020':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112024':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112025':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112027':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112021':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112023':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112028':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222757':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55124715':{'en': u('Alum\u00ednio - SP'), 'pt': u('Alum\u00ednio - SP')},
 '55112952':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212489':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212488':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212483':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212482':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212481':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212480':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212487':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212486':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212484':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323461':{'en': 'Angustura - MG', 'pt': 'Angustura - MG'},
 '55313064':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313061':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '496342':{'de': 'Schweigen-Rechtenbach', 'en': 'Schweigen-Rechtenbach'},
 '496343':{'de': 'Bad Bergzabern', 'en': 'Bad Bergzabern'},
 '496340':{'de': u('W\u00f6rth-Schaidt'), 'en': u('W\u00f6rth-Schaidt')},
 '496341':{'de': 'Landau in der Pfalz', 'en': 'Landau in der Pfalz'},
 '496346':{'de': 'Annweiler am Trifels', 'en': 'Annweiler am Trifels'},
 '496347':{'de': 'Hochstadt Pfalz', 'en': 'Hochstadt Pfalz'},
 '496344':{'de': 'Schwegenheim', 'en': 'Schwegenheim'},
 '496345':{'de': 'Albersweiler', 'en': 'Albersweiler'},
 '496348':{'de': 'Offenbach an der Queich', 'en': 'Offenbach an der Queich'},
 '496349':{'de': 'Billigheim-Ingenheim', 'en': 'Billigheim-Ingenheim'},
 '55243401':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55273080':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55273081':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55212730':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183021':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55212734':{'en': 'Rio Bonito - RJ', 'pt': 'Rio Bonito - RJ'},
 '5527':{'en': 'Espirito Santo', 'pt': 'Espirito Santo'},
 '5528':{'en': 'Espirito Santo', 'pt': 'Espirito Santo'},
 '55183703':{'en': 'Bairro Formosa - SP', 'pt': 'Bairro Formosa - SP'},
 '55183702':{'en': 'Andradina - SP', 'pt': 'Andradina - SP'},
 '55183701':{'en': u('Mirand\u00f3polis - SP'), 'pt': u('Mirand\u00f3polis - SP')},
 '55193842':{'en': 'Serra Negra - SP', 'pt': 'Serra Negra - SP'},
 '55183706':{'en': u('Suzan\u00e1polis - SP'), 'pt': u('Suzan\u00e1polis - SP')},
 '55183705':{'en': u('Guara\u00e7a\u00ed - SP'), 'pt': u('Guara\u00e7a\u00ed - SP')},
 '55183704':{'en': 'Pereira Barreto - SP', 'pt': 'Pereira Barreto - SP'},
 '55193845':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55183708':{'en': u('Primeira Alian\u00e7a - SP'), 'pt': u('Primeira Alian\u00e7a - SP')},
 '55272144':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55193847':{'en': u('Jaguari\u00fana - SP'), 'pt': u('Jaguari\u00fana - SP')},
 '55193846':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55114331':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55143308':{'en': 'Fartura - SP', 'pt': 'Fartura - SP'},
 '55114462':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114463':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114461':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '499334':{'de': 'Giebelstadt', 'en': 'Giebelstadt'},
 '55114468':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114469':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '497565':{'de': 'Aichstetten Kreis Ravensburg', 'en': 'Aichstetten Kreis Ravensburg'},
 '497564':{'de': 'Bad Wurzach', 'en': 'Bad Wurzach'},
 '497567':{'de': 'Leutkirch-Friesenhofen', 'en': 'Leutkirch-Friesenhofen'},
 '497566':{'de': u('Argenb\u00fchl'), 'en': u('Argenb\u00fchl')},
 '497561':{'de': u('Leutkirch im Allg\u00e4u'), 'en': u('Leutkirch im Allg\u00e4u')},
 '497563':{'de': 'Kisslegg', 'en': 'Kisslegg'},
 '497562':{'de': u('Isny im Allg\u00e4u'), 'en': u('Isny im Allg\u00e4u')},
 '497569':{'de': 'Isny-Eisenbach', 'en': 'Isny-Eisenbach'},
 '497568':{'de': 'Bad Wurzach-Hauerz', 'en': 'Bad Wurzach-Hauerz'},
 '55193112':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55153492':{'en': 'Salto de Pirapora - SP', 'pt': 'Salto de Pirapora - SP'},
 '55153491':{'en': 'Salto de Pirapora - SP', 'pt': 'Salto de Pirapora - SP'},
 '55153494':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55173044':{'en': 'Bebedouro - SP', 'pt': 'Bebedouro - SP'},
 '494269':{'de': 'Ahausen-Kirchwalsede', 'en': 'Ahausen-Kirchwalsede'},
 '494268':{'de': u('B\u00f6tersen'), 'en': u('B\u00f6tersen')},
 '496192':{'de': 'Hofheim am Taunus', 'en': 'Hofheim am Taunus'},
 '494263':{'de': 'Scheessel', 'en': 'Scheessel'},
 '494262':{'de': u('Visselh\u00f6vede'), 'en': u('Visselh\u00f6vede')},
 '494261':{'de': u('Rotenburg W\u00fcmme'), 'en': u('Rotenburg W\u00fcmme')},
 '494260':{'de': u('Visselh\u00f6vede-Wittorf'), 'en': u('Visselh\u00f6vede-Wittorf')},
 '494267':{'de': u('Lauenbr\u00fcck'), 'en': u('Lauenbr\u00fcck')},
 '494266':{'de': 'Brockel', 'en': 'Brockel'},
 '494265':{'de': 'Fintel', 'en': 'Fintel'},
 '494264':{'de': 'Sottrum Kreis Rotenburg', 'en': 'Sottrum Kreis Rotenburg'},
 '55133209':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133208':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '496190':{'de': 'Hattersheim am Main', 'en': 'Hattersheim am Main'},
 '55133201':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133203':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133202':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55243365':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55243366':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55142122':{'en': u('Avar\u00e9 - SP'), 'pt': u('Avar\u00e9 - SP')},
 '55243369':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '52478':{'en': 'Calera Victor Rosales, ZAC', 'es': 'Calera Victor Rosales, ZAC'},
 '52477':{'en': 'Leon, GTO', 'es': u('Le\u00f3n, GTO')},
 '52476':{'en': 'San Francisco Del Rincon, GTO', 'es': u('San Francisco del Rinc\u00f3n, GTO')},
 '52475':{'en': 'Bajio de San Jose/Encarnacion de Diaz, JAL', 'es': u('Baj\u00edo de San Jos\u00e9/Encarnaci\u00f3n de Diaz, JAL')},
 '52474':{'en': 'Lagos de Moreno/Paso de Cuarenta, JAL', 'es': 'Lagos de Moreno/Paso de Cuarenta, JAL'},
 '52473':{'en': 'Guanajuato, GTO', 'es': 'Guanajuato, GTO'},
 '52472':{'en': 'Silao, GTO', 'es': 'Silao, GTO'},
 '52471':{'en': 'Purepero/Tlazazalca, MICH', 'es': 'Purepero/Tlazazalca, MICH'},
 '55112618':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115934':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115933':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112612':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115931':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112610':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '49591':{'de': 'Lingen (Ems)', 'en': 'Lingen (Ems)'},
 '55212133':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212132':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212136':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213833':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163421':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55112921':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112923':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55185871':{'en': 'Panorama - SP', 'pt': 'Panorama - SP'},
 '55112928':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55283155':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55143298':{'en': 'Macatuba - SP', 'pt': 'Macatuba - SP'},
 '499251':{'de': u('M\u00fcnchberg'), 'en': u('M\u00fcnchberg')},
 '55143294':{'en': 'Iacanga - SP', 'pt': 'Iacanga - SP'},
 '499253':{'de': 'Weissenstadt', 'en': 'Weissenstadt'},
 '499252':{'de': 'Helmbrechts', 'en': 'Helmbrechts'},
 '499255':{'de': 'Marktleugast', 'en': 'Marktleugast'},
 '499254':{'de': 'Gefrees', 'en': 'Gefrees'},
 '499257':{'de': 'Zell Oberfranken', 'en': 'Zell Oberfranken'},
 '499256':{'de': 'Stammbach', 'en': 'Stammbach'},
 '55113698':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113699':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55212254':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212255':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212252':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212253':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212251':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55113692':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113693':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113694':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113695':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113696':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113697':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55163943':{'en': 'Barrinha - SP', 'pt': 'Barrinha - SP'},
 '498847':{'de': u('Obers\u00f6chering'), 'en': u('Obers\u00f6chering')},
 '55333293':{'en': u('S\u00e3o Jos\u00e9 da Safira - MG'), 'pt': u('S\u00e3o Jos\u00e9 da Safira - MG')},
 '55163941':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '5331':{'en': 'Las Tunas Province'},
 '5333':{'en': u('Ciego de \u00c1vila Province')},
 '5332':{'en': u('Camag\u00fcey Province')},
 '55143475':{'en': u('Ocau\u00e7u - SP'), 'pt': u('Ocau\u00e7u - SP')},
 '55143474':{'en': u('Lup\u00e9rcio - SP'), 'pt': u('Lup\u00e9rcio - SP')},
 '55143477':{'en': u('Arco-\u00cdris - SP'), 'pt': u('Arco-\u00cdris - SP')},
 '55143476':{'en': 'Campos Novos Paulista - SP', 'pt': 'Campos Novos Paulista - SP'},
 '496423':{'de': 'Wetter Hessen', 'en': 'Wetter Hessen'},
 '496422':{'de': 'Kirchhain', 'en': 'Kirchhain'},
 '496421':{'de': 'Marburg', 'en': 'Marburg'},
 '496420':{'de': 'Lahntal', 'en': 'Lahntal'},
 '496427':{'de': u('C\u00f6lbe-Sch\u00f6nstadt'), 'en': u('C\u00f6lbe-Sch\u00f6nstadt')},
 '496426':{'de': 'Fronhausen', 'en': 'Fronhausen'},
 '496425':{'de': 'Rauschenberg Hessen', 'en': 'Rauschenberg Hessen'},
 '496424':{'de': 'Ebsdorfergrund', 'en': 'Ebsdorfergrund'},
 '55163945':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55113528':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113529':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113526':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113527':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113524':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113525':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113523':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113521':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55223533':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '543466':{'en': 'Barrancas, Santa Fe', 'es': 'Barrancas, Santa Fe'},
 '543467':{'en': u('Cruz Alta, C\u00f3rdoba/San Jos\u00e9 de la Esquina, Santa Fe'), 'es': u('Cruz Alta, C\u00f3rdoba/San Jos\u00e9 de la Esquina, Santa Fe')},
 '543464':{'en': 'Casilda, Santa Fe', 'es': 'Casilda, Santa Fe'},
 '543465':{'en': 'Firmat, Santa Fe', 'es': 'Firmat, Santa Fe'},
 '543462':{'en': 'Venado Tuerto, Santa Fe', 'es': 'Venado Tuerto, Santa Fe'},
 '543463':{'en': u('Canals, C\u00f3rdoba'), 'es': u('Canals, C\u00f3rdoba')},
 '543460':{'en': 'Santa Teresa, Santa Fe', 'es': 'Santa Teresa, Santa Fe'},
 '543468':{'en': u('Corral de Bustos, C\u00f3rdoba'), 'es': u('Corral de Bustos, C\u00f3rdoba')},
 '543469':{'en': 'Acebal, Santa Fe', 'es': 'Acebal, Santa Fe'},
 '495082':{'de': 'Langlingen', 'en': 'Langlingen'},
 '495083':{'de': 'Hohne bei Celle', 'en': 'Hohne bei Celle'},
 '495084':{'de': u('Hamb\u00fchren'), 'en': u('Hamb\u00fchren')},
 '495085':{'de': 'Burgdorf-Ehlershausen', 'en': 'Burgdorf-Ehlershausen'},
 '495086':{'de': 'Celle-Scheuen', 'en': 'Celle-Scheuen'},
 '495734':{'de': 'Bergkirchen Westfalen', 'en': 'Bergkirchen Westfalen'},
 '495732':{'de': u('L\u00f6hne'), 'en': u('L\u00f6hne')},
 '495733':{'de': 'Vlotho', 'en': 'Vlotho'},
 '495731':{'de': 'Bad Oeynhausen', 'en': 'Bad Oeynhausen'},
 '496287':{'de': 'Limbach Baden', 'en': 'Limbach Baden'},
 '496286':{'de': u('Walld\u00fcrn-Rippberg'), 'en': u('Walld\u00fcrn-Rippberg')},
 '496285':{'de': u('Walld\u00fcrn-Altheim'), 'en': u('Walld\u00fcrn-Altheim')},
 '496284':{'de': 'Mudau', 'en': 'Mudau'},
 '496283':{'de': 'Hardheim Odenwald', 'en': 'Hardheim Odenwald'},
 '496282':{'de': u('Walld\u00fcrn'), 'en': u('Walld\u00fcrn')},
 '496281':{'de': 'Buchen Odenwald', 'en': 'Buchen Odenwald'},
 '498561':{'de': 'Pfarrkirchen Niederbayern', 'en': 'Pfarrkirchen Niederbayern'},
 '55313452':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '497771':{'de': 'Stockach', 'en': 'Stockach'},
 '497773':{'de': 'Bodman-Ludwigshafen', 'en': 'Bodman-Ludwigshafen'},
 '497774':{'de': 'Eigeltingen', 'en': 'Eigeltingen'},
 '497775':{'de': u('M\u00fchlingen'), 'en': u('M\u00fchlingen')},
 '497777':{'de': 'Sauldorf', 'en': 'Sauldorf'},
 '495552':{'de': 'Katlenburg', 'en': 'Katlenburg'},
 '495553':{'de': 'Kalefeld', 'en': 'Kalefeld'},
 '495882':{'de': 'Gorleben', 'en': 'Gorleben'},
 '495551':{'de': 'Northeim', 'en': 'Northeim'},
 '495556':{'de': 'Lindau Harz', 'en': 'Lindau Harz'},
 '495554':{'de': 'Moringen', 'en': 'Moringen'},
 '495555':{'de': 'Moringen-Fredelsloh', 'en': 'Moringen-Fredelsloh'},
 '55112198':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213154':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497482':{'de': 'Horb-Dettingen', 'en': 'Horb-Dettingen'},
 '497483':{'de': u('Horb-M\u00fchringen'), 'en': u('Horb-M\u00fchringen')},
 '497486':{'de': 'Horb-Altheim', 'en': 'Horb-Altheim'},
 '497484':{'de': 'Simmersfeld', 'en': 'Simmersfeld'},
 '497485':{'de': 'Empfingen', 'en': 'Empfingen'},
 '55213152':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313454':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213153':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213150':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55115693':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115691':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115696':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115695':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313346':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55323032':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '52864':{'en': 'Coahuila', 'es': 'Coahuila'},
 '52866':{'en': 'Castanos/Monclova, COAH', 'es': u('Casta\u00f1os/Monclova, COAH')},
 '52867':{'en': 'Nuevo Leon/Tamaulipas', 'es': u('Nuevo Le\u00f3n/Tamaulipas')},
 '52861':{'en': 'Nueva Rosita/Sabinas, COAH', 'es': 'Nueva Rosita/Sabinas, COAH'},
 '52862':{'en': 'Coahuila', 'es': 'Coahuila'},
 '55213159':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52868':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52869':{'en': 'Cuatro Cienegas/San Buenaventura, COAH', 'es': u('Cuatro Ci\u00e9negas/San Buenaventura, COAH')},
 '55193805':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '497954':{'de': 'Kirchberg an der Jagst', 'en': 'Kirchberg an der Jagst'},
 '497955':{'de': u('Wallhausen W\u00fcrttemberg'), 'en': u('Wallhausen W\u00fcrttemberg')},
 '497957':{'de': 'Kressberg', 'en': 'Kressberg'},
 '497950':{'de': 'Schnelldorf', 'en': 'Schnelldorf'},
 '497951':{'de': 'Crailsheim', 'en': 'Crailsheim'},
 '497952':{'de': 'Gerabronn', 'en': 'Gerabronn'},
 '497953':{'de': 'Blaufelden', 'en': 'Blaufelden'},
 '497958':{'de': 'Rot Am See-Brettheim', 'en': 'Rot Am See-Brettheim'},
 '497959':{'de': 'Frankenhardt', 'en': 'Frankenhardt'},
 '55163214':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55153321':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '498281':{'de': 'Thannhausen Schwaben', 'en': 'Thannhausen Schwaben'},
 '498283':{'de': 'Neuburg an der Kammel', 'en': 'Neuburg an der Kammel'},
 '498282':{'de': 'Krumbach Schwaben', 'en': 'Krumbach Schwaben'},
 '498285':{'de': 'Burtenbach', 'en': 'Burtenbach'},
 '498284':{'de': 'Ziemetshausen', 'en': 'Ziemetshausen'},
 '55193807':{'en': 'Amparo - SP', 'pt': 'Amparo - SP'},
 '499964':{'de': 'Stallwang', 'en': 'Stallwang'},
 '55313764':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55313762':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55313763':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55313761':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55313768':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55313769':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55113063':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113061':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113060':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113067':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113066':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113065':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113064':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52392':{'en': 'Jamay/Ocotlan, JAL', 'es': u('Jamay/Ocotl\u00e1n, JAL')},
 '52393':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52391':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52394':{'en': 'Cotija de la Paz, MICH', 'es': 'Cotija de la Paz, MICH'},
 '52395':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55323239':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55313542':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '55313543':{'en': 'Raposos - MG', 'pt': 'Raposos - MG'},
 '55323231':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55313541':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '55323237':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323236':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55313544':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313545':{'en': 'Rio Acima - MG', 'pt': 'Rio Acima - MG'},
 '499732':{'de': 'Hammelburg', 'en': 'Hammelburg'},
 '499733':{'de': u('M\u00fcnnerstadt'), 'en': u('M\u00fcnnerstadt')},
 '55313538':{'en': 'Esmeraldas - MG', 'pt': 'Esmeraldas - MG'},
 '499736':{'de': 'Oberthulba', 'en': 'Oberthulba'},
 '499737':{'de': 'Wartmannsroth', 'en': 'Wartmannsroth'},
 '499734':{'de': 'Burkardroth', 'en': 'Burkardroth'},
 '499735':{'de': 'Massbach', 'en': 'Massbach'},
 '55213324':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499738':{'de': 'Rottershausen', 'en': 'Rottershausen'},
 '55193445':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '52641':{'en': 'Benjamin Hill/Santa Ana, SON', 'es': u('Benjam\u00edn Hill/Santa Ana, SON')},
 '52642':{'en': 'Navojoa/Pueblo Mayo, SON', 'es': 'Navojoa/Pueblo Mayo, SON'},
 '52643':{'en': 'Sonora', 'es': 'Sonora'},
 '52644':{'en': 'Sonora', 'es': 'Sonora'},
 '52645':{'en': 'Cananea, SON', 'es': 'Cananea, SON'},
 '52646':{'en': 'Baja California', 'es': 'Baja California'},
 '52647':{'en': 'Sonora', 'es': 'Sonora'},
 '52648':{'en': 'Boquilla/Ciudad Camargo, CHIH', 'es': 'Boquilla/Ciudad Camargo, CHIH'},
 '52649':{'en': 'Chihuahua/Durango', 'es': 'Chihuahua/Durango'},
 '55193448':{'en': 'Ibitiruna - SP', 'pt': 'Ibitiruna - SP'},
 '55113207':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498424':{'de': 'Nassenfels', 'en': 'Nassenfels'},
 '498427':{'de': 'Wellheim', 'en': 'Wellheim'},
 '498426':{'de': u('Walting Kreis Eichst\u00e4tt'), 'en': u('Walting Kreis Eichst\u00e4tt')},
 '498421':{'de': u('Eichst\u00e4tt Bayern'), 'en': u('Eichst\u00e4tt Bayern')},
 '55113202':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498423':{'de': 'Titting', 'en': 'Titting'},
 '498422':{'de': 'Dollnstein', 'en': 'Dollnstein'},
 '55313531':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55113209':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113208':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273021':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55313537':{'en': 'Serra Azul - MG', 'pt': 'Serra Azul - MG'},
 '55313536':{'en': 'Florestal - MG', 'pt': 'Florestal - MG'},
 '494702':{'de': 'Sandstedt', 'en': 'Sandstedt'},
 '494703':{'de': 'Loxstedt-Donnern', 'en': 'Loxstedt-Donnern'},
 '494704':{'de': 'Drangstedt', 'en': 'Drangstedt'},
 '494705':{'de': 'Wremen', 'en': 'Wremen'},
 '494706':{'de': 'Schiffdorf', 'en': 'Schiffdorf'},
 '494707':{'de': 'Langen-Neuenwalde', 'en': 'Langen-Neuenwalde'},
 '494708':{'de': 'Ringstedt', 'en': 'Ringstedt'},
 '499085':{'de': 'Alerheim', 'en': 'Alerheim'},
 '499086':{'de': 'Fremdingen', 'en': 'Fremdingen'},
 '499087':{'de': 'Marktoffingen', 'en': 'Marktoffingen'},
 '499080':{'de': 'Harburg Schwaben', 'en': 'Harburg Schwaben'},
 '499081':{'de': u('N\u00f6rdlingen'), 'en': u('N\u00f6rdlingen')},
 '499082':{'de': 'Oettingen in Bayern', 'en': 'Oettingen in Bayern'},
 '499083':{'de': u('M\u00f6ttingen'), 'en': u('M\u00f6ttingen')},
 '55153115':{'en': 'Boituva - SP', 'pt': 'Boituva - SP'},
 '55143668':{'en': 'Itaju - SP', 'pt': 'Itaju - SP'},
 '55143664':{'en': u('Itapu\u00ed - SP'), 'pt': u('Itapu\u00ed - SP')},
 '55143666':{'en': 'Bocaina - SP', 'pt': 'Bocaina - SP'},
 '55143667':{'en': 'Itaju - SP', 'pt': 'Itaju - SP'},
 '55143662':{'en': 'Bariri - SP', 'pt': 'Bariri - SP'},
 '55312112':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112558':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112559':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112551':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112552':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112553':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112554':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112555':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112556':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112557':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113258':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49781':{'de': 'Offenburg', 'en': 'Offenburg'},
 '55115508':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113259':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115509':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115971':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495585':{'de': 'Herzberg-Sieber', 'en': 'Herzberg-Sieber'},
 '55193415':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55112227':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115504':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193413':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55112225':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115975':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193411':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55163987':{'en': 'Serrana - SP', 'pt': 'Serrana - SP'},
 '55163986':{'en': u('Lu\u00eds Ant\u00f4nio - SP'), 'pt': u('Lu\u00eds Ant\u00f4nio - SP')},
 '55163984':{'en': u('S\u00e3o Sim\u00e3o - SP'), 'pt': u('S\u00e3o Sim\u00e3o - SP')},
 '55163983':{'en': u('Lu\u00eds Ant\u00f4nio - SP'), 'pt': u('Lu\u00eds Ant\u00f4nio - SP')},
 '55163982':{'en': 'Serra Azul - SP', 'pt': 'Serra Azul - SP'},
 '55163981':{'en': u('Prad\u00f3polis - SP'), 'pt': u('Prad\u00f3polis - SP')},
 '495582':{'de': 'Sankt Andreasberg', 'en': 'Sankt Andreasberg'},
 '55133877':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '543786':{'en': u('Ituzaing\u00f3, Corrientes'), 'es': u('Ituzaing\u00f3, Corrientes')},
 '52618':{'en': 'Colonia Hidalgo/Durango, DGO', 'es': 'Colonia Hidalgo/Durango, DGO'},
 '55313891':{'en': u('Vi\u00e7osa - MG'), 'pt': u('Vi\u00e7osa - MG')},
 '543782':{'en': 'Saladas, Corrientes', 'es': 'Saladas, Corrientes'},
 '543781':{'en': u('Ca\u00e1 Cat\u00ed, Corrientes'), 'es': u('Ca\u00e1 Cat\u00ed, Corrientes')},
 '55113706':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183354':{'en': 'Platina - SP', 'pt': 'Platina - SP'},
 '55183355':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183356':{'en': u('Echapor\u00e3 - SP'), 'pt': u('Echapor\u00e3 - SP')},
 '55113707':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55124159':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55124158':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55113704':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113705':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '495945':{'de': 'Wilsum', 'en': 'Wilsum'},
 '495944':{'de': 'Hoogstede', 'en': 'Hoogstede'},
 '495947':{'de': 'Laar Vechte', 'en': 'Laar Vechte'},
 '495946':{'de': 'Georgsdorf', 'en': 'Georgsdorf'},
 '495941':{'de': 'Neuenhaus Dinkel', 'en': 'Neuenhaus Dinkel'},
 '495943':{'de': 'Emlichheim', 'en': 'Emlichheim'},
 '495942':{'de': 'Uelsen', 'en': 'Uelsen'},
 '495948':{'de': 'Itterbeck', 'en': 'Itterbeck'},
 '55222633':{'en': u('Arma\u00e7\u00e3o dos B\u00fazios - RJ'), 'pt': u('Arma\u00e7\u00e3o dos B\u00fazios - RJ')},
 '55123878':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123876':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55313893':{'en': 'Porto Firme - MG', 'pt': 'Porto Firme - MG'},
 '55114899':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '496364':{'de': u('Nu\u00dfbach Pfalz'), 'en': 'Nussbach Pfalz'},
 '55114892':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55114891':{'en': u('Bom Jesus dos Perd\u00f5es - SP'), 'pt': u('Bom Jesus dos Perd\u00f5es - SP')},
 '55114897':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '496361':{'de': 'Rockenhausen', 'en': 'Rockenhausen'},
 '496362':{'de': 'Alsenz', 'en': 'Alsenz'},
 '496363':{'de': 'Niederkirchen', 'en': 'Niederkirchen'},
 '55212756':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55212755':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55212753':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55212752':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55212751':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55222519':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55183721':{'en': 'Andradina - SP', 'pt': 'Andradina - SP'},
 '55183723':{'en': 'Andradina - SP', 'pt': 'Andradina - SP'},
 '55183722':{'en': 'Andradina - SP', 'pt': 'Andradina - SP'},
 '55115676':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193948':{'en': 'Louveira - SP', 'pt': 'Louveira - SP'},
 '55273717':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55143883':{'en': 'Bofete - SP', 'pt': 'Bofete - SP'},
 '55114408':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '55114409':{'en': u('Jacar\u00e9 - SP'), 'pt': u('Jacar\u00e9 - SP')},
 '55114405':{'en': 'Piracaia - SP', 'pt': 'Piracaia - SP'},
 '55173281':{'en': u('Ol\u00edmpia - SP'), 'pt': u('Ol\u00edmpia - SP')},
 '55173280':{'en': u('Ol\u00edmpia - SP'), 'pt': u('Ol\u00edmpia - SP')},
 '55114402':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114403':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55163463':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55143886':{'en': 'Pardinho - SP', 'pt': 'Pardinho - SP'},
 '55213408':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143888':{'en': 'Pereiras - SP', 'pt': 'Pereiras - SP'},
 '55213400':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497546':{'de': 'Oberteuringen', 'en': 'Oberteuringen'},
 '497545':{'de': 'Immenstaad am Bodensee', 'en': 'Immenstaad am Bodensee'},
 '497544':{'de': 'Markdorf', 'en': 'Markdorf'},
 '497543':{'de': 'Kressbronn am Bodensee', 'en': 'Kressbronn am Bodensee'},
 '497542':{'de': 'Tettnang', 'en': 'Tettnang'},
 '497541':{'de': 'Friedrichshafen', 'en': 'Friedrichshafen'},
 '55213407':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498638':{'de': 'Waldkraiburg', 'en': 'Waldkraiburg'},
 '498639':{'de': 'Neumarkt-Sankt Veit', 'en': 'Neumarkt-Sankt Veit'},
 '498630':{'de': 'Oberneukirchen', 'en': 'Oberneukirchen'},
 '498631':{'de': u('M\u00fchldorf am Inn'), 'en': u('M\u00fchldorf am Inn')},
 '498633':{'de': u('T\u00fc\u00dfling'), 'en': u('T\u00fcssling')},
 '498634':{'de': 'Garching an der Alz', 'en': 'Garching an der Alz'},
 '498635':{'de': 'Pleiskirchen', 'en': 'Pleiskirchen'},
 '498636':{'de': 'Ampfing', 'en': 'Ampfing'},
 '498637':{'de': 'Lohkirchen', 'en': 'Lohkirchen'},
 '494936':{'de': 'Grossheide', 'en': 'Grossheide'},
 '494935':{'de': 'Juist', 'en': 'Juist'},
 '494934':{'de': 'Marienhafe', 'en': 'Marienhafe'},
 '494933':{'de': 'Dornum Ostfriesland', 'en': 'Dornum Ostfriesland'},
 '494932':{'de': 'Norderney', 'en': 'Norderney'},
 '494931':{'de': 'Norden', 'en': 'Norden'},
 '55153478':{'en': 'Pilar do Sul - SP', 'pt': 'Pilar do Sul - SP'},
 '494939':{'de': 'Baltrum', 'en': 'Baltrum'},
 '494938':{'de': 'Hagermarsch', 'en': 'Hagermarsch'},
 '55133269':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133268':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133261':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55313151':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55313153':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55313152':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55142106':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55142107':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55142104':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55142105':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55132138':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55142108':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55142109':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55283310':{'en': 'Castelo - ES', 'pt': 'Castelo - ES'},
 '55242483':{'en': 'Miguel Pereira - RJ', 'pt': 'Miguel Pereira - RJ'},
 '55112635':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113841':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112636':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112631':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112633':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112632':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113842':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113845':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49571':{'de': 'Minden Westfalen', 'en': 'Minden Westfalen'},
 '55163409':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55113847':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163403':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55113846':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163406':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163405':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55123682':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '499273':{'de': 'Bad Berneck im Fichtelgebirge', 'en': 'Bad Berneck im Fichtelgebirge'},
 '499272':{'de': 'Fichtelberg', 'en': 'Fichtelberg'},
 '499271':{'de': 'Thurnau-Alladorf', 'en': 'Thurnau-Alladorf'},
 '55112944':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499277':{'de': 'Warmensteinach', 'en': 'Warmensteinach'},
 '55112942':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499275':{'de': 'Speichersdorf', 'en': 'Speichersdorf'},
 '499274':{'de': 'Hollfeld', 'en': 'Hollfeld'},
 '499279':{'de': 'Mistelgau', 'en': 'Mistelgau'},
 '496239':{'de': 'Bobenheim-Roxheim', 'en': 'Bobenheim-Roxheim'},
 '55112949':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112948':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143273':{'en': u('Fern\u00e3o - SP'), 'pt': u('Fern\u00e3o - SP')},
 '496236':{'de': 'Neuhofen Pfalz', 'en': 'Neuhofen Pfalz'},
 '55193788':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193789':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55143277':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143276':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143275':{'en': u('Paulist\u00e2nia - SP'), 'pt': u('Paulist\u00e2nia - SP')},
 '496237':{'de': 'Maxdorf', 'en': 'Maxdorf'},
 '55193782':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193783':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55143279':{'en': u('Tibiri\u00e7\u00e1 - SP'), 'pt': u('Tibiri\u00e7\u00e1 - SP')},
 '55143278':{'en': u('Len\u00e7\u00f3is Paulista - SP'), 'pt': u('Len\u00e7\u00f3is Paulista - SP')},
 '55212230':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193787':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212232':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193785':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55313572':{'en': u('Itatiaiu\u00e7u - MG'), 'pt': u('Itatiaiu\u00e7u - MG')},
 '55212292':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212293':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52676':{'en': 'Durango', 'es': 'Durango'},
 '55212290':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143417':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55143416':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55143415':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55143414':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55143413':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55212294':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143411':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55212585':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212588':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212295':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113544':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113545':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113546':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113541':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113542':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113543':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113548':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113549':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112499':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112498':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55223512':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55112490':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55112493':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55112492':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112497':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112496':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55273385':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55114093':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '543442':{'en': u('Concepci\u00f3n del Uruguay, Entre R\u00edos'), 'es': u('Concepci\u00f3n del Uruguay, Entre R\u00edos')},
 '543444':{'en': u('Gualeguay, Entre R\u00edos'), 'es': u('Gualeguay, Entre R\u00edos')},
 '543445':{'en': u('Rosario del Tala, Entre R\u00edos'), 'es': u('Rosario del Tala, Entre R\u00edos')},
 '543446':{'en': u('Gualeguaych\u00fa, Entre R\u00edos'), 'es': u('Gualeguaych\u00fa, Entre R\u00edos')},
 '543447':{'en': u('Col\u00f3n, Entre R\u00edos'), 'es': u('Col\u00f3n, Entre R\u00edos')},
 '55114794':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '497183':{'de': u('Rudersberg W\u00fcrttemberg'), 'en': u('Rudersberg W\u00fcrttemberg')},
 '55114796':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114797':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114790':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114091':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114792':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '497182':{'de': 'Welzheim', 'en': 'Welzheim'},
 '55162111':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '543855':{'en': 'Suncho Corral, Santiago del Estero', 'es': 'Suncho Corral, Santiago del Estero'},
 '55114096':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114094':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55323453':{'en': u('Dona Eus\u00e9bia - MG'), 'pt': u('Dona Eus\u00e9bia - MG')},
 '55323452':{'en': 'Itamarati de Minas - MG', 'pt': 'Itamarati de Minas - MG'},
 '55323451':{'en': 'Astolfo Dutra - MG', 'pt': 'Astolfo Dutra - MG'},
 '55163508':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '495574':{'de': 'Oberweser', 'en': 'Oberweser'},
 '495571':{'de': 'Uslar', 'en': 'Uslar'},
 '495572':{'de': 'Bodenfelde', 'en': 'Bodenfelde'},
 '495573':{'de': 'Uslar-Volpriehausen', 'en': 'Uslar-Volpriehausen'},
 '55123119':{'en': 'Campos de Cunha - SP', 'pt': 'Campos de Cunha - SP'},
 '55123111':{'en': 'Cunha - SP', 'pt': 'Cunha - SP'},
 '55123112':{'en': 'Potim - SP', 'pt': 'Potim - SP'},
 '55123115':{'en': u('Arape\u00ed - SP'), 'pt': u('Arape\u00ed - SP')},
 '55123116':{'en': 'Bananal - SP', 'pt': 'Bananal - SP'},
 '55123117':{'en': u('S\u00e3o Jos\u00e9 do Barreiro - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Barreiro - SP')},
 '497503':{'de': u('Wilhelmsdorf W\u00fcrttemberg'), 'en': u('Wilhelmsdorf W\u00fcrttemberg')},
 '497054':{'de': u('Wildberg W\u00fcrttemberg'), 'en': u('Wildberg W\u00fcrttemberg')},
 '55115670':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115671':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115674':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115675':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113904':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496466':{'de': 'Dautphetal-Friedensdorf', 'en': 'Dautphetal-Friedensdorf'},
 '55115678':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115679':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497504':{'de': 'Horgenzell', 'en': 'Horgenzell'},
 '496465':{'de': 'Breidenbach bei Biedenkopf', 'en': 'Breidenbach bei Biedenkopf'},
 '55324101':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '543862':{'en': u('Trancas, Tucum\u00e1n'), 'es': u('Trancas, Tucum\u00e1n')},
 '543863':{'en': u('Monteros, Tucum\u00e1n'), 'es': u('Monteros, Tucum\u00e1n')},
 '543861':{'en': 'Nueva Esperanza, Santiago del Estero', 'es': 'Nueva Esperanza, Santiago del Estero'},
 '543867':{'en': u('Taf\u00ed del Valle, Tucum\u00e1n'), 'es': u('Taf\u00ed del Valle, Tucum\u00e1n')},
 '543865':{'en': u('Concepci\u00f3n, Tucum\u00e1n'), 'es': u('Concepci\u00f3n, Tucum\u00e1n')},
 '543868':{'en': 'Cafayate, Salta', 'es': 'Cafayate, Salta'},
 '543869':{'en': u('Ranchillos y San Miguel, Tucum\u00e1n'), 'es': u('Ranchillos y San Miguel, Tucum\u00e1n')},
 '55333084':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333087':{'en': u('Te\u00f3filo Otoni - MG'), 'pt': u('Te\u00f3filo Otoni - MG')},
 '496004':{'de': 'Lich-Eberstadt', 'en': 'Lich-Eberstadt'},
 '496007':{'de': 'Rosbach-Rodheim', 'en': 'Rosbach-Rodheim'},
 '496003':{'de': u('Rosbach von der H\u00f6he'), 'en': u('Rosbach von der H\u00f6he')},
 '496002':{'de': u('Ober-M\u00f6rlen'), 'en': u('Ober-M\u00f6rlen')},
 '496008':{'de': 'Echzell', 'en': 'Echzell'},
 '499461':{'de': 'Roding', 'en': 'Roding'},
 '55183276':{'en': 'Piquerobi - SP', 'pt': 'Piquerobi - SP'},
 '499466':{'de': 'Stamsried', 'en': 'Stamsried'},
 '499467':{'de': 'Michelsneukirchen', 'en': 'Michelsneukirchen'},
 '55163234':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163236':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163231':{'en': 'Guariba - SP', 'pt': 'Guariba - SP'},
 '499396':{'de': 'Urspringen bei Lohr', 'en': 'Urspringen bei Lohr'},
 '499397':{'de': 'Wertheim-Dertingen', 'en': 'Wertheim-Dertingen'},
 '55274007':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55274003':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55274002':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55333089':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55112073':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183571':{'en': u('Fl\u00f3rida Paulista - SP'), 'pt': u('Fl\u00f3rida Paulista - SP')},
 '495665':{'de': 'Guxhagen', 'en': 'Guxhagen'},
 '55113901':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113049':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113041':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113045':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113044':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113046':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495663':{'de': 'Spangenberg', 'en': 'Spangenberg'},
 '55323211':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323213':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323212':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323215':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55194126':{'en': 'Itapira - SP', 'pt': 'Itapira - SP'},
 '55323217':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323216':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323218':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '494892':{'de': 'Schenefeld Mittelholstein', 'en': 'Schenefeld Mittelholstein'},
 '494893':{'de': 'Hohenaspe', 'en': 'Hohenaspe'},
 '55114233':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '499868':{'de': u('Schillingsf\u00fcrst'), 'en': u('Schillingsf\u00fcrst')},
 '55114230':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '494546':{'de': 'Mustin Lauenburg', 'en': 'Mustin Lauenburg'},
 '494547':{'de': 'Gudow Lauenburg', 'en': 'Gudow Lauenburg'},
 '494544':{'de': 'Berkenthin', 'en': 'Berkenthin'},
 '494545':{'de': 'Seedorf Lauenburg', 'en': 'Seedorf Lauenburg'},
 '494542':{'de': u('M\u00f6lln Lauenburg'), 'en': u('M\u00f6lln Lauenburg')},
 '494543':{'de': 'Nusse', 'en': 'Nusse'},
 '494541':{'de': 'Ratzeburg', 'en': 'Ratzeburg'},
 '55113959':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113229':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113228':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113225':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113952':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113227':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113226':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113221':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113220':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113223':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113222':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498407':{'de': 'Grossmehring', 'en': 'Grossmehring'},
 '498406':{'de': u('B\u00f6hmfeld'), 'en': u('B\u00f6hmfeld')},
 '498405':{'de': 'Stammham bei Ingolstadt', 'en': 'Stammham bei Ingolstadt'},
 '498404':{'de': 'Oberdolling', 'en': 'Oberdolling'},
 '498403':{'de': u('Pf\u00f6rring'), 'en': u('Pf\u00f6rring')},
 '498402':{'de': u('M\u00fcnchsm\u00fcnster'), 'en': u('M\u00fcnchsm\u00fcnster')},
 '55153289':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55153288':{'en': 'Cerquilho - SP', 'pt': 'Cerquilho - SP'},
 '55153283':{'en': 'Laranjal Paulista - SP', 'pt': 'Laranjal Paulista - SP'},
 '55153282':{'en': u('Tiet\u00ea - SP'), 'pt': u('Tiet\u00ea - SP')},
 '55153281':{'en': u('Ara\u00e7oiaba da Serra - SP'), 'pt': u('Ara\u00e7oiaba da Serra - SP')},
 '55153287':{'en': 'Laranjal Paulista - SP', 'pt': 'Laranjal Paulista - SP'},
 '55153286':{'en': 'Jumirim - SP', 'pt': 'Jumirim - SP'},
 '55153285':{'en': u('Tiet\u00ea - SP'), 'pt': u('Tiet\u00ea - SP')},
 '55153284':{'en': 'Cerquilho - SP', 'pt': 'Cerquilho - SP'},
 '494768':{'de': 'Hipstedt', 'en': 'Hipstedt'},
 '494769':{'de': u('Bremerv\u00f6rde-Iselersheim'), 'en': u('Bremerv\u00f6rde-Iselersheim')},
 '494762':{'de': 'Kutenholz', 'en': 'Kutenholz'},
 '494763':{'de': 'Gnarrenburg', 'en': 'Gnarrenburg'},
 '494761':{'de': u('Bremerv\u00f6rde'), 'en': u('Bremerv\u00f6rde')},
 '494766':{'de': 'Basdahl', 'en': 'Basdahl'},
 '494767':{'de': u('Bremerv\u00f6rde-Bevern'), 'en': u('Bremerv\u00f6rde-Bevern')},
 '494764':{'de': 'Gnarrenburg-Klenkendorf', 'en': 'Gnarrenburg-Klenkendorf'},
 '494765':{'de': u('Ebersdorf bei Bremerv\u00f6rde'), 'en': u('Ebersdorf bei Bremerv\u00f6rde')},
 '55313326':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112798':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112793':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112790':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112791':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112796':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112797':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112795':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313327':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55143642':{'en': 'Barra Bonita - SP', 'pt': 'Barra Bonita - SP'},
 '55183993':{'en': u('Cuiab\u00e1 Paulista - SP'), 'pt': u('Cuiab\u00e1 Paulista - SP')},
 '55143641':{'en': 'Barra Bonita - SP', 'pt': 'Barra Bonita - SP'},
 '55143646':{'en': u('Mineiros do Tiet\u00ea - SP'), 'pt': u('Mineiros do Tiet\u00ea - SP')},
 '55183997':{'en': 'Taciba - SP', 'pt': 'Taciba - SP'},
 '55143644':{'en': u('Igara\u00e7u do Tiet\u00ea - SP'), 'pt': u('Igara\u00e7u do Tiet\u00ea - SP')},
 '55183995':{'en': 'Indiana - SP', 'pt': 'Indiana - SP'},
 '55193311':{'en': u('Jaguari\u00fana - SP'), 'pt': u('Jaguari\u00fana - SP')},
 '55313384':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183998':{'en': u('Jo\u00e3o Ramalho - SP'), 'pt': u('Jo\u00e3o Ramalho - SP')},
 '55143649':{'en': 'Barra Bonita - SC', 'pt': 'Barra Bonita - SC'},
 '55273422':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '55313324':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313736':{'en': 'Desterro de Entre Rios - MG', 'pt': 'Desterro de Entre Rios - MG'},
 '55112578':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112579':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495383':{'de': 'Lutter am Barenberge', 'en': 'Lutter am Barenberge'},
 '55112577':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112574':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112575':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112572':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112573':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495384':{'de': u('Seesen-Gro\u00df Rh\u00fcden'), 'en': u('Seesen-Gross Rh\u00fcden')},
 '55273395':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55213383':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55242522':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55313881':{'en': 'Ponte Nova - MG', 'pt': 'Ponte Nova - MG'},
 '55133467':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55313886':{'en': 'Diogo de Vasconcelos - MG', 'pt': 'Diogo de Vasconcelos - MG'},
 '542902':{'en': u('R\u00edo Turbio, Santa Cruz'), 'es': u('R\u00edo Turbio, Santa Cruz')},
 '542903':{'en': u('R\u00edo Mayo, Chubut'), 'es': u('R\u00edo Mayo, Chubut')},
 '542901':{'en': 'Ushuaia, Tierra del Fuego', 'es': 'Ushuaia, Tierra del Fuego'},
 '55313738':{'en': u('S\u00e3o Br\u00e1s do Sua\u00e7u\u00ed - MG'), 'pt': u('S\u00e3o Br\u00e1s do Sua\u00e7u\u00ed - MG')},
 '55114731':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55313323':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183379':{'en': u('S\u00e3o Jos\u00e9 Laranjeiras - SP'), 'pt': u('S\u00e3o Jos\u00e9 Laranjeiras - SP')},
 '55183376':{'en': u('Cruz\u00e1lia - SP'), 'pt': u('Cruz\u00e1lia - SP')},
 '55183377':{'en': u('Flor\u00ednia - SP'), 'pt': u('Flor\u00ednia - SP')},
 '55183375':{'en': 'Pedrinhas Paulista - SP', 'pt': 'Pedrinhas Paulista - SP'},
 '55183373':{'en': u('Tarum\u00e3 - SP'), 'pt': u('Tarum\u00e3 - SP')},
 '55183371':{'en': u('Maraca\u00ed - SP'), 'pt': u('Maraca\u00ed - SP')},
 '495966':{'de': 'Meppen-Apeldorn', 'en': 'Meppen-Apeldorn'},
 '495965':{'de': 'Klein Berssen', 'en': 'Klein Berssen'},
 '495964':{'de': u('L\u00e4hden'), 'en': u('L\u00e4hden')},
 '495963':{'de': 'Bawinkel', 'en': 'Bawinkel'},
 '495962':{'de': 'Herzlake', 'en': 'Herzlake'},
 '495961':{'de': u('Hasel\u00fcnne'), 'en': u('Hasel\u00fcnne')},
 '55212774':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55212771':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55212772':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55193024':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55113449':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113448':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55312103':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55113445':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '494875':{'de': 'Stafstedt', 'en': 'Stafstedt'},
 '542658':{'en': 'Buena Esperanza, San Luis', 'es': 'Buena Esperanza, San Luis'},
 '55113332':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542656':{'en': 'Merlo, San Luis', 'es': 'Merlo, San Luis'},
 '542657':{'en': 'Villa Mercedes, San Luis', 'es': 'Villa Mercedes, San Luis'},
 '55183745':{'en': 'Itapura - SP', 'pt': 'Itapura - SP'},
 '542655':{'en': 'La Toma, San Luis', 'es': 'La Toma, San Luis'},
 '542652':{'en': 'San Luis Province', 'es': 'Provincia de San Luis'},
 '55113331':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183741':{'en': 'Castilho - SP', 'pt': 'Castilho - SP'},
 '542651':{'en': 'San Francisco del Monte de Oro, San Luis', 'es': 'San Francisco del Monte de Oro, San Luis'},
 '55193966':{'en': 'Conchal - SP', 'pt': 'Conchal - SP'},
 '55193965':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55134010':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113441':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113336':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113335':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213792':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55113334':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173263':{'en': u('Mirassol\u00e2ndia - SP'), 'pt': u('Mirassol\u00e2ndia - SP')},
 '55173262':{'en': 'Nova Granada - SP', 'pt': 'Nova Granada - SP'},
 '55173261':{'en': 'Nova Granada - SP', 'pt': 'Nova Granada - SP'},
 '55114421':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55173267':{'en': u('Guapia\u00e7u - SP'), 'pt': u('Guapia\u00e7u - SP')},
 '55114427':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114424':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55173264':{'en': u('B\u00e1lsamo - SP'), 'pt': u('B\u00e1lsamo - SP')},
 '55114428':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55173268':{'en': 'Onda Verde - SP', 'pt': 'Onda Verde - SP'},
 '497034':{'de': 'Ehningen', 'en': 'Ehningen'},
 '497033':{'de': 'Weil Der Stadt', 'en': 'Weil Der Stadt'},
 '497032':{'de': 'Herrenberg', 'en': 'Herrenberg'},
 '497031':{'de': u('B\u00f6blingen'), 'en': u('B\u00f6blingen')},
 '497529':{'de': u('Waldburg W\u00fcrttemberg'), 'en': u('Waldburg W\u00fcrttemberg')},
 '497528':{'de': 'Neukirch bei Tettnang', 'en': 'Neukirch bei Tettnang'},
 '55213426':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497520':{'de': 'Bodnegg', 'en': 'Bodnegg'},
 '55213424':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497522':{'de': u('Wangen im Allg\u00e4u'), 'en': u('Wangen im Allg\u00e4u')},
 '497525':{'de': 'Aulendorf', 'en': 'Aulendorf'},
 '497524':{'de': 'Bad Waldsee', 'en': 'Bad Waldsee'},
 '497527':{'de': 'Wolfegg', 'en': 'Wolfegg'},
 '55213421':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494951':{'de': 'Weener', 'en': 'Weener'},
 '494950':{'de': 'Holtland', 'en': 'Holtland'},
 '494953':{'de': 'Bunde', 'en': 'Bunde'},
 '494952':{'de': 'Rhauderfehn', 'en': 'Rhauderfehn'},
 '494955':{'de': 'Westoverledingen', 'en': 'Westoverledingen'},
 '494954':{'de': 'Moormerland', 'en': 'Moormerland'},
 '494957':{'de': 'Detern', 'en': 'Detern'},
 '494956':{'de': 'Uplengen', 'en': 'Uplengen'},
 '494959':{'de': 'Dollart', 'en': 'Dollart'},
 '494958':{'de': 'Jemgum', 'en': 'Jemgum'},
 '55193426':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55153459':{'en': u('Iper\u00f3 - SP'), 'pt': u('Iper\u00f3 - SP')},
 '55323241':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55115089':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115088':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115083':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115082':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115080':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115087':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115086':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115085':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313132':{'en': 'Esmeraldas - MG', 'pt': 'Esmeraldas - MG'},
 '55313130':{'en': 'Matozinhos - MG', 'pt': 'Matozinhos - MG'},
 '55312108':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55242463':{'en': 'Engenheiro Paulo de Frontin - RJ', 'pt': 'Engenheiro Paulo de Frontin - RJ'},
 '55242465':{'en': 'Mendes - RJ', 'pt': 'Mendes - RJ'},
 '55163398':{'en': u('Fazenda Babil\u00f4nia - SP'), 'pt': u('Fazenda Babil\u00f4nia - SP')},
 '55163392':{'en': u('Am\u00e9rico Brasiliense - SP'), 'pt': u('Am\u00e9rico Brasiliense - SP')},
 '55163393':{'en': u('Am\u00e9rico Brasiliense - SP'), 'pt': u('Am\u00e9rico Brasiliense - SP')},
 '55163396':{'en': u('Santa L\u00facia - SP'), 'pt': u('Santa L\u00facia - SP')},
 '55163397':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163394':{'en': u('Mat\u00e3o - SP'), 'pt': u('Mat\u00e3o - SP')},
 '55163395':{'en': u('Rinc\u00e3o - SP'), 'pt': u('Rinc\u00e3o - SP')},
 '498652':{'de': 'Berchtesgaden', 'en': 'Berchtesgaden'},
 '498650':{'de': 'Marktschellenberg', 'en': 'Marktschellenberg'},
 '498651':{'de': 'Bad Reichenhall', 'en': 'Bad Reichenhall'},
 '498656':{'de': 'Anger', 'en': 'Anger'},
 '498657':{'de': 'Ramsau bei Berchtesgaden', 'en': 'Ramsau bei Berchtesgaden'},
 '498654':{'de': 'Freilassing', 'en': 'Freilassing'},
 '494371':{'de': 'Burg auf Fehmarn', 'en': 'Burg auf Fehmarn'},
 '49551':{'de': u('G\u00f6ttingen'), 'en': u('G\u00f6ttingen')},
 '494372':{'de': 'Westfehmarn', 'en': 'Westfehmarn'},
 '55212173':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213888':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213889':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213884':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213885':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213886':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213887':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213882':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49881':{'de': 'Weilheim in Oberbayern', 'en': 'Weilheim in Oberbayern'},
 '499295':{'de': u('T\u00f6pen'), 'en': u('T\u00f6pen')},
 '499294':{'de': 'Regnitzlosau', 'en': 'Regnitzlosau'},
 '55242249':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55143252':{'en': 'Pederneiras - SP', 'pt': 'Pederneiras - SP'},
 '499293':{'de': 'Berg Oberfranken', 'en': 'Berg Oberfranken'},
 '499292':{'de': 'Konradsreuth', 'en': 'Konradsreuth'},
 '55212212':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193761':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212210':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212211':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212216':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193765':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212214':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212215':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193768':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193769':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55212219':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498326':{'de': u('Fischen im Allg\u00e4u'), 'en': u('Fischen im Allg\u00e4u')},
 '498327':{'de': 'Rettenberg', 'en': 'Rettenberg'},
 '498456':{'de': 'Lenting', 'en': 'Lenting'},
 '55143433':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55143432':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '55113568':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498325':{'de': 'Oberstaufen-Thalkirchdorf', 'en': 'Oberstaufen-Thalkirchdorf'},
 '55113562':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113563':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113566':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113567':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113564':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113565':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55213229':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498452':{'de': 'Geisenfeld', 'en': 'Geisenfeld'},
 '55333233':{'en': 'Tarumirim - MG', 'pt': 'Tarumirim - MG'},
 '55213221':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213222':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113903':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213224':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273145':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55213227':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494357':{'de': 'Sehestedt Eider', 'en': 'Sehestedt Eider'},
 '55333231':{'en': 'Itanhomi - MG', 'pt': 'Itanhomi - MG'},
 '55112969':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494356':{'de': 'Gross Wittensee', 'en': 'Gross Wittensee'},
 '55112965':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112964':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112967':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112966':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112961':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494355':{'de': 'Rieseby', 'en': 'Rieseby'},
 '55112963':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112962':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55162138':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '494354':{'de': 'Fleckeby', 'en': 'Fleckeby'},
 '55193424':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '499101':{'de': 'Langenzenn', 'en': 'Langenzenn'},
 '55162133':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55162132':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55162137':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55113909':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212700':{'en': u('Itagua\u00ed - RJ'), 'pt': u('Itagua\u00ed - RJ')},
 '499103':{'de': 'Cadolzburg', 'en': 'Cadolzburg'},
 '496645':{'de': 'Ulrichstein', 'en': 'Ulrichstein'},
 '495772':{'de': 'Espelkamp', 'en': 'Espelkamp'},
 '495773':{'de': 'Stemwede-Wehdem', 'en': 'Stemwede-Wehdem'},
 '495771':{'de': 'Rahden Westfalen', 'en': 'Rahden Westfalen'},
 '495776':{'de': u('Preussisch Str\u00f6hen'), 'en': u('Preussisch Str\u00f6hen')},
 '495777':{'de': 'Diepenau-Essern', 'en': 'Diepenau-Essern'},
 '495774':{'de': u('Wagenfeld-Str\u00f6hen'), 'en': u('Wagenfeld-Str\u00f6hen')},
 '495775':{'de': 'Diepenau', 'en': 'Diepenau'},
 '496867':{'de': 'Perl', 'en': 'Perl'},
 '496866':{'de': 'Perl-Nennig', 'en': 'Perl-Nennig'},
 '496641':{'de': 'Lauterbach Hessen', 'en': 'Lauterbach Hessen'},
 '55212707':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '497738':{'de': 'Steisslingen', 'en': 'Steisslingen'},
 '497739':{'de': 'Hilzingen', 'en': 'Hilzingen'},
 '497734':{'de': 'Gailingen', 'en': 'Gailingen'},
 '497735':{'de': u('\u00d6hningen'), 'en': u('\u00d6hningen')},
 '497736':{'de': 'Tengen', 'en': 'Tengen'},
 '55313829':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '497731':{'de': 'Singen Hohentwiel', 'en': 'Singen Hohentwiel'},
 '497732':{'de': 'Radolfzell am Bodensee', 'en': 'Radolfzell am Bodensee'},
 '497733':{'de': 'Engen Hegau', 'en': 'Engen Hegau'},
 '55112219':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112218':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112213':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115532':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112211':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495592':{'de': 'Gleichen-Bremke', 'en': 'Gleichen-Bremke'},
 '55112216':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112215':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112214':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496238':{'de': 'Dirmstein', 'en': 'Dirmstein'},
 '5042228':{'en': 'Kennedy, Tegucigalpa'},
 '5042229':{'en': 'El Ocotal'},
 '5042224':{'en': 'Cerro Grande'},
 '5042225':{'en': 'La Granja'},
 '5042226':{'en': 'Loarque'},
 '5042227':{'en': u('Res. Centro Am\u00e9rica, Tegucigalpa')},
 '55123132':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123133':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123131':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55333014':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '497191':{'de': 'Backnang', 'en': 'Backnang'},
 '497192':{'de': 'Murrhardt', 'en': 'Murrhardt'},
 '497193':{'de': 'Sulzbach an der Murr', 'en': 'Sulzbach an der Murr'},
 '497194':{'de': 'Spiegelberg', 'en': 'Spiegelberg'},
 '497195':{'de': 'Winnenden', 'en': 'Winnenden'},
 '55242255':{'en': u('Tr\u00eas Rios - RJ'), 'pt': u('Tr\u00eas Rios - RJ')},
 '55242254':{'en': 'Comendador Levy Gasparian - RJ', 'pt': 'Comendador Levy Gasparian - RJ'},
 '543844':{'en': u('A\u00f1atuya, Santiago del Estero'), 'es': u('A\u00f1atuya, Santiago del Estero')},
 '543845':{'en': 'Loreto, Santiago del Estero', 'es': 'Loreto, Santiago del Estero'},
 '543846':{'en': 'Tintina, Santiago del Estero', 'es': 'Tintina, Santiago del Estero'},
 '55242258':{'en': 'Bemposta - RJ', 'pt': 'Bemposta - RJ'},
 '543841':{'en': 'Monte Quemado, Santiago del Estero', 'es': 'Monte Quemado, Santiago del Estero'},
 '543843':{'en': u('Quimil\u00ed, Santiago del Estero'), 'es': u('Quimil\u00ed, Santiago del Estero')},
 '52828':{'en': 'Cadereyta, NL', 'es': 'Cadereyta, NL'},
 '52829':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52821':{'en': 'Hualahuises/Linares, NL', 'es': 'Hualahuises/Linares, NL'},
 '52823':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52824':{'en': 'Sabinas Hidalgo, NL', 'es': 'Sabinas Hidalgo, NL'},
 '52825':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52826':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '496029':{'de': u('M\u00f6mbris'), 'en': u('M\u00f6mbris')},
 '496028':{'de': 'Sulzbach am Main', 'en': 'Sulzbach am Main'},
 '496027':{'de': 'Stockstadt am Main', 'en': 'Stockstadt am Main'},
 '496026':{'de': 'Grossostheim', 'en': 'Grossostheim'},
 '496024':{'de': u('Sch\u00f6llkrippen'), 'en': u('Sch\u00f6llkrippen')},
 '496023':{'de': 'Alzenau in Unterfranken', 'en': 'Alzenau in Unterfranken'},
 '496022':{'de': 'Obernburg am Main', 'en': 'Obernburg am Main'},
 '496021':{'de': 'Aschaffenburg', 'en': 'Aschaffenburg'},
 '496020':{'de': u('Heigenbr\u00fccken'), 'en': u('Heigenbr\u00fccken')},
 '55313722':{'en': 'Queluzito - MG', 'pt': 'Queluzito - MG'},
 '54376':{'en': 'Posadas, Misiones', 'es': 'Posadas, Misiones'},
 '55183558':{'en': 'Sagres - SP', 'pt': 'Sagres - SP'},
 '55313721':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '55313726':{'en': 'Santana dos Montes - MG', 'pt': 'Santana dos Montes - MG'},
 '55313727':{'en': 'Capela Nova - MG', 'pt': 'Capela Nova - MG'},
 '55313724':{'en': 'Cristiano Otoni - MG', 'pt': 'Cristiano Otoni - MG'},
 '55273151':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55183552':{'en': 'Pracinha - SP', 'pt': 'Pracinha - SP'},
 '55313447':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313728':{'en': 'Buarque de Macedo - MG', 'pt': 'Buarque de Macedo - MG'},
 '55183551':{'en': u('Luc\u00e9lia - SP'), 'pt': u('Luc\u00e9lia - SP')},
 '55183556':{'en': u('In\u00fabia Paulista - SP'), 'pt': u('In\u00fabia Paulista - SP')},
 '55183557':{'en': u('Salmour\u00e3o - SP'), 'pt': u('Salmour\u00e3o - SP')},
 '54370':{'en': 'Formosa, Formosa', 'es': 'Formosa, Formosa'},
 '52358':{'en': 'Tamazula/Zapoltitic, JAL', 'es': 'Tamazula/Zapotiltic, JAL'},
 '55113028':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113027':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113026':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113025':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52355':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55113023':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113022':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113021':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52351':{'en': 'Ario de Rayon/Zamora, MICH', 'es': u('Ario de Ray\u00f3n/Zamora, MICH')},
 '55323277':{'en': u('Ch\u00e1cara - MG'), 'pt': u('Ch\u00e1cara - MG')},
 '55323276':{'en': 'Mar de Espanha - MG', 'pt': 'Mar de Espanha - MG'},
 '55323275':{'en': 'Santana do Deserto - MG', 'pt': 'Santana do Deserto - MG'},
 '55143313':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55323273':{'en': 'Matias Barbosa - MG', 'pt': 'Matias Barbosa - MG'},
 '55323272':{'en': u('Sim\u00e3o Pereira - MG'), 'pt': u('Sim\u00e3o Pereira - MG')},
 '55323271':{'en': 'Bicas - MG', 'pt': 'Bicas - MG'},
 '55313581':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '55114217':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55313589':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '499848':{'de': 'Simmershofen', 'en': 'Simmershofen'},
 '494561':{'de': 'Neustadt in Holstein', 'en': 'Neustadt in Holstein'},
 '494562':{'de': u('Gr\u00f6mitz'), 'en': u('Gr\u00f6mitz')},
 '494563':{'de': 'Scharbeutz-Haffkrug', 'en': 'Scharbeutz-Haffkrug'},
 '494564':{'de': 'Schashagen', 'en': 'Schashagen'},
 '499845':{'de': 'Oberdachstetten', 'en': 'Oberdachstetten'},
 '499846':{'de': 'Ipsheim', 'en': 'Ipsheim'},
 '499847':{'de': 'Ergersheim', 'en': 'Ergersheim'},
 '55113795':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113794':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113973':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113796':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113975':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113974':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113793':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113976':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113978':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113798':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498469':{'de': 'Freystadt-Burggriesbach', 'en': 'Freystadt-Burggriesbach'},
 '498468':{'de': 'Altmannstein-Pondorf', 'en': 'Altmannstein-Pondorf'},
 '498461':{'de': 'Beilngries', 'en': 'Beilngries'},
 '498460':{'de': 'Berching-Holnstein', 'en': 'Berching-Holnstein'},
 '498463':{'de': 'Greding', 'en': 'Greding'},
 '498462':{'de': 'Berching', 'en': 'Berching'},
 '498465':{'de': 'Kipfenberg', 'en': 'Kipfenberg'},
 '498464':{'de': u('Dietfurt an der Altm\u00fchl'), 'en': u('Dietfurt an der Altm\u00fchl')},
 '498467':{'de': 'Kinding', 'en': 'Kinding'},
 '498466':{'de': 'Denkendorf Oberbayern', 'en': 'Denkendorf Oberbayern'},
 '494744':{'de': 'Loxstedt', 'en': 'Loxstedt'},
 '494745':{'de': 'Bad Bederkesa', 'en': 'Bad Bederkesa'},
 '494746':{'de': 'Hagen bei Bremerhaven', 'en': 'Hagen bei Bremerhaven'},
 '494747':{'de': 'Beverstedt', 'en': 'Beverstedt'},
 '494740':{'de': 'Loxstedt-Dedesdorf', 'en': 'Loxstedt-Dedesdorf'},
 '494741':{'de': 'Nordholz bei Bremerhaven', 'en': 'Nordholz bei Bremerhaven'},
 '494742':{'de': 'Dorum', 'en': 'Dorum'},
 '494743':{'de': 'Langen bei Bremerhaven', 'en': 'Langen bei Bremerhaven'},
 '494748':{'de': 'Stubben bei Bremerhaven', 'en': 'Stubben bei Bremerhaven'},
 '494749':{'de': 'Schiffdorf-Geestenseth', 'en': 'Schiffdorf-Geestenseth'},
 '55182104':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55115477':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55193848':{'en': 'Louveira - SP', 'pt': 'Louveira - SP'},
 '55313224':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112771':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112772':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112773':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123895':{'en': 'Ilhabela - SP', 'pt': 'Ilhabela - SP'},
 '52686':{'en': 'Baja California', 'es': 'Baja California'},
 '52687':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '55193377':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193375':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193374':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193373':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193371':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55123893':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55123892':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '499336':{'de': u('B\u00fctthard'), 'en': u('B\u00fctthard')},
 '499337':{'de': u('Gauk\u00f6nigshofen'), 'en': u('Gauk\u00f6nigshofen')},
 '55112516':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499335':{'de': u('Aub Kreis W\u00fcrzburg'), 'en': u('Aub Kreis W\u00fcrzburg')},
 '499332':{'de': 'Marktbreit', 'en': 'Marktbreit'},
 '499333':{'de': 'Sommerhausen', 'en': 'Sommerhausen'},
 '499331':{'de': 'Ochsenfurt', 'en': 'Ochsenfurt'},
 '55112518':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499338':{'de': u('R\u00f6ttingen Unterfranken'), 'en': u('R\u00f6ttingen Unterfranken')},
 '499339':{'de': 'Ippesheim', 'en': 'Ippesheim'},
 '55163618':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163612':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163611':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163610':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163617':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163615':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '542920':{'en': u('Viedma, R\u00edo Negro'), 'es': u('Viedma, R\u00edo Negro')},
 '542921':{'en': 'Coronel Dorrego, Buenos Aires', 'es': 'Coronel Dorrego, Buenos Aires'},
 '542922':{'en': 'Coronel Pringles, Buenos Aires', 'es': 'Coronel Pringles, Buenos Aires'},
 '542923':{'en': u('Pig\u00fc\u00e9, Buenos Aires'), 'es': u('Pig\u00fc\u00e9, Buenos Aires')},
 '542924':{'en': 'Darregueira, Buenos Aires', 'es': 'Darregueira, Buenos Aires'},
 '542925':{'en': 'Villa Iris, Buenos Aires', 'es': 'Villa Iris, Buenos Aires'},
 '542926':{'en': u('Coronel Su\u00e1rez, Buenos Aires'), 'es': u('Coronel Su\u00e1rez, Buenos Aires')},
 '542927':{'en': u('M\u00e9danos, Buenos Aires'), 'es': u('M\u00e9danos, Buenos Aires')},
 '542928':{'en': 'Pedro Luro, Buenos Aires', 'es': 'Pedro Luro, Buenos Aires'},
 '542929':{'en': u('Guamin\u00ed, Buenos Aires'), 'es': u('Guamin\u00ed, Buenos Aires')},
 '55163949':{'en': 'Cruz das Posses - SP', 'pt': 'Cruz das Posses - SP'},
 '55183311':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '5255':{'en': 'Mexico City, FD', 'es': u('Ciudad de M\u00e9xico, CDMX')},
 '55193593':{'en': 'Descalvado - SP', 'pt': 'Descalvado - SP'},
 '55193592':{'en': 'Santa Rita do Passa Quatro - SP', 'pt': 'Santa Rita do Passa Quatro - SP'},
 '5258':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55193597':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193594':{'en': 'Descalvado - SP', 'pt': 'Descalvado - SP'},
 '55124110':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55124448':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '495909':{'de': 'Wettrup', 'en': 'Wettrup'},
 '495908':{'de': 'Wietmarschen-Lohne', 'en': 'Wietmarschen-Lohne'},
 '495901':{'de': u('F\u00fcrstenau bei Bramsche'), 'en': u('F\u00fcrstenau bei Bramsche')},
 '495903':{'de': u('Emsb\u00fcren'), 'en': u('Emsb\u00fcren')},
 '495902':{'de': 'Freren', 'en': 'Freren'},
 '495905':{'de': 'Beesten', 'en': 'Beesten'},
 '495904':{'de': 'Lengerich Emsl', 'en': 'Lengerich Emsl'},
 '495907':{'de': 'Geeste', 'en': 'Geeste'},
 '495906':{'de': u('L\u00fcnne'), 'en': u('L\u00fcnne')},
 '55123836':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123835':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123834':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123833':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123832':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55223842':{'en': u('Porci\u00fancula - RJ'), 'pt': u('Porci\u00fancula - RJ')},
 '55212792':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55212791':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55212796':{'en': 'Mesquita - RJ', 'pt': 'Mesquita - RJ'},
 '5532':{'en': 'Minas Gerais', 'pt': 'Minas Gerais'},
 '55193781':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55312146':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55193839':{'en': 'Amparo - SP', 'pt': 'Amparo - SP'},
 '55313305':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55193834':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193129':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55193909':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55193835':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193904':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '55193907':{'en': 'Amparo - SP', 'pt': 'Amparo - SP'},
 '55193836':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55193902':{'en': 'Holambra - SP', 'pt': 'Holambra - SP'},
 '55193903':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55193837':{'en': u('Jaguari\u00fana - SP'), 'pt': u('Jaguari\u00fana - SP')},
 '55193833':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55173249':{'en': 'Potirendaba - SP', 'pt': 'Potirendaba - SP'},
 '55173248':{'en': u('Mendon\u00e7a - SP'), 'pt': u('Mendon\u00e7a - SP')},
 '55173243':{'en': 'Mirassol - SP', 'pt': 'Mirassol - SP'},
 '55173242':{'en': 'Mirassol - SP', 'pt': 'Mirassol - SP'},
 '55173245':{'en': u('Jos\u00e9 Bonif\u00e1cio - SP'), 'pt': u('Jos\u00e9 Bonif\u00e1cio - SP')},
 '497051':{'de': 'Calw', 'en': 'Calw'},
 '497502':{'de': 'Wolpertswende', 'en': 'Wolpertswende'},
 '497053':{'de': 'Bad Teinach-Zavelstein', 'en': 'Bad Teinach-Zavelstein'},
 '497052':{'de': 'Bad Liebenzell', 'en': 'Bad Liebenzell'},
 '497055':{'de': 'Neuweiler Kreis Calw', 'en': 'Neuweiler Kreis Calw'},
 '497506':{'de': 'Wangen-Leupolz', 'en': 'Wangen-Leupolz'},
 '497505':{'de': 'Fronreute', 'en': 'Fronreute'},
 '497056':{'de': 'Gechingen', 'en': 'Gechingen'},
 '55213445':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499326':{'de': 'Markt Einersheim', 'en': 'Markt Einersheim'},
 '55112503':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213448':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499323':{'de': 'Iphofen', 'en': 'Iphofen'},
 '55153431':{'en': u('Itarar\u00e9 - SP'), 'pt': u('Itarar\u00e9 - SP')},
 '494973':{'de': 'Wittmund-Burhafe', 'en': 'Wittmund-Burhafe'},
 '494972':{'de': 'Langeoog', 'en': 'Langeoog'},
 '494971':{'de': 'Esens', 'en': 'Esens'},
 '494977':{'de': 'Blomberg Ostfriesland', 'en': 'Blomberg Ostfriesland'},
 '494976':{'de': 'Spiekeroog', 'en': 'Spiekeroog'},
 '494975':{'de': 'Westerholt Ostfriesland', 'en': 'Westerholt Ostfriesland'},
 '494974':{'de': 'Neuharlingersiel', 'en': 'Neuharlingersiel'},
 '55133519':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133513':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55153383':{'en': 'Laranjal Paulista - SP', 'pt': 'Laranjal Paulista - SP'},
 '55153384':{'en': 'Cerquilho - SP', 'pt': 'Cerquilho - SP'},
 '55153388':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55324009':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55242447':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55242444':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55242445':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55242442':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55242443':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55163371':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163372':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163373':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163374':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163375':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163376':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163377':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163378':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163379':{'en': u('Fazenda Babil\u00f4nia - SP'), 'pt': u('Fazenda Babil\u00f4nia - SP')},
 '498851':{'de': 'Kochel am See', 'en': 'Kochel am See'},
 '498678':{'de': 'Marktl', 'en': 'Marktl'},
 '498679':{'de': 'Burgkirchen an der Alz', 'en': 'Burgkirchen an der Alz'},
 '498856':{'de': 'Penzberg', 'en': 'Penzberg'},
 '498857':{'de': 'Benediktbeuern', 'en': 'Benediktbeuern'},
 '498858':{'de': 'Kochel-Walchensee', 'en': 'Kochel-Walchensee'},
 '498677':{'de': 'Burghausen Salzach', 'en': 'Burghausen Salzach'},
 '498670':{'de': u('Reischach Kreis Alt\u00f6tting'), 'en': u('Reischach Kreis Alt\u00f6tting')},
 '498671':{'de': u('Alt\u00f6tting'), 'en': u('Alt\u00f6tting')},
 '49531':{'de': 'Braunschweig', 'en': 'Braunschweig'},
 '494358':{'de': u('Loose bei Eckernf\u00f6rde'), 'en': u('Loose bei Eckernf\u00f6rde')},
 '499105':{'de': 'Grosshabersdorf', 'en': 'Grosshabersdorf'},
 '499104':{'de': 'Emskirchen', 'en': 'Emskirchen'},
 '499107':{'de': 'Trautskirchen', 'en': 'Trautskirchen'},
 '499106':{'de': 'Markt Erlbach', 'en': 'Markt Erlbach'},
 '494353':{'de': 'Ascheffel', 'en': 'Ascheffel'},
 '494352':{'de': 'Damp', 'en': 'Damp'},
 '494351':{'de': u('Eckernf\u00f6rde'), 'en': u('Eckernf\u00f6rde')},
 '499102':{'de': 'Wilhermsdorf', 'en': 'Wilhermsdorf'},
 '55212153':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212152':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55313449':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313118':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313116':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313111':{'en': u('S\u00e3o Joaquim de Bicas - MG'), 'pt': u('S\u00e3o Joaquim de Bicas - MG')},
 '55313446':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313445':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313444':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55314003':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55143239':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143238':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143237':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143236':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143234':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143233':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143232':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143231':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55193294':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193295':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193296':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193743':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193298':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55163256':{'en': 'Santa Ernestina - SP', 'pt': 'Santa Ernestina - SP'},
 '55313084':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114009':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114000':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55163621':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55114005':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114007':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163258':{'en': 'Fernando Prestes - SP', 'pt': 'Fernando Prestes - SP'},
 '55193123':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '54230':{'en': 'Pilar, Buenos Aires', 'es': 'Pilar, Buenos Aires'},
 '54237':{'en': 'Moreno, Buenos Aires', 'es': 'Moreno, Buenos Aires'},
 '54236':{'en': u('Jun\u00edn, Buenos Aires'), 'es': u('Jun\u00edn, Buenos Aires')},
 '55193124':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55113581':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113583':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113584':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113585':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163973':{'en': u('Guatapar\u00e1 - SP'), 'pt': u('Guatapar\u00e1 - SP')},
 '55213208':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213207':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213202':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213201':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112983':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112982':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112981':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112980':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112987':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112986':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112989':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49521':{'de': 'Bielefeld', 'en': 'Bielefeld'},
 '55213142':{'en': u('Itabora\u00ed - RJ'), 'pt': u('Itabora\u00ed - RJ')},
 '55112189':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112188':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495028':{'de': 'Pennigsehl', 'en': 'Pennigsehl'},
 '55112183':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495027':{'de': 'Linsburg', 'en': 'Linsburg'},
 '495024':{'de': 'Rohrsen Kreis Nienburg Weser', 'en': 'Rohrsen Kreis Nienburg Weser'},
 '495025':{'de': 'Estorf Weser', 'en': 'Estorf Weser'},
 '55112187':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112186':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495752':{'de': 'Auetal-Hattendorf', 'en': 'Auetal-Hattendorf'},
 '55112184':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193278':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55313162':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55193279':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55112231':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115510':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112233':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112232':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112235':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112234':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115517':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112236':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112239':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112238':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173841':{'en': u('Arab\u00e1 - SP'), 'pt': u('Arab\u00e1 - SP')},
 '5042209':{'en': u('Res. Centro Am\u00e9rica, Tegucigalpa')},
 '543404':{'en': 'Las Colonias Dept., Santa Fe', 'es': 'Dpto. Las Colonias, Santa Fe'},
 '543405':{'en': 'San Javier, Santa Fe', 'es': 'San Javier, Santa Fe'},
 '543406':{'en': 'San Jorge, Santa Fe', 'es': 'San Jorge, Santa Fe'},
 '543407':{'en': 'Ramallo, Buenos Aires', 'es': 'Ramallo, Buenos Aires'},
 '543400':{'en': u('Villa Constituci\u00f3n, Santa Fe'), 'es': u('Villa Constituci\u00f3n, Santa Fe')},
 '543401':{'en': u('El Tr\u00e9bol, Santa Fe'), 'es': u('El Tr\u00e9bol, Santa Fe')},
 '543402':{'en': 'Arroyo Seco, Santa Fe', 'es': 'Arroyo Seco, Santa Fe'},
 '55123153':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '543408':{'en': u('San Crist\u00f3bal, Santa Fe'), 'es': u('San Crist\u00f3bal, Santa Fe')},
 '543409':{'en': u('Mois\u00e9s Ville, Santa Fe'), 'es': u('Mois\u00e9s Ville, Santa Fe')},
 '55313164':{'en': 'Santa Luzia - MG', 'pt': 'Santa Luzia - MG'},
 '55115634':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115635':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115631':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115632':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183302':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55173848':{'en': u('Gast\u00e3o Vidigal - SP'), 'pt': u('Gast\u00e3o Vidigal - SP')},
 '55212416':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313165':{'en': 'Santa Luzia - MG', 'pt': 'Santa Luzia - MG'},
 '55212638':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '495026':{'de': 'Steimbke', 'en': 'Steimbke'},
 '496229':{'de': 'Neckarsteinach', 'en': 'Neckarsteinach'},
 '496228':{'de': u('Sch\u00f6nau Odenwald'), 'en': u('Sch\u00f6nau Odenwald')},
 '496599':{'de': 'Weidenbach bei Gerolstein', 'en': 'Weidenbach bei Gerolstein'},
 '55112182':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496597':{'de': u('J\u00fcnkerath'), 'en': u('J\u00fcnkerath')},
 '496224':{'de': 'Sandhausen Baden', 'en': 'Sandhausen Baden'},
 '496227':{'de': 'Walldorf Baden', 'en': 'Walldorf Baden'},
 '496226':{'de': 'Meckesheim', 'en': 'Meckesheim'},
 '496221':{'de': 'Heidelberg', 'en': 'Heidelberg'},
 '496220':{'de': 'Wilhelmsfeld', 'en': 'Wilhelmsfeld'},
 '496223':{'de': u('Neckargem\u00fcnd'), 'en': u('Neckargem\u00fcnd')},
 '496222':{'de': 'Wiesloch', 'en': 'Wiesloch'},
 '495022':{'de': 'Wietzen', 'en': 'Wietzen'},
 '55313166':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '495023':{'de': 'Liebenau Kreis Nieburg Weser', 'en': 'Liebenau Kreis Nieburg Weser'},
 '55115182':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115183':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115181':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112185':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115184':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495021':{'de': 'Nienburg Weser', 'en': 'Nienburg Weser'},
 '55273259':{'en': 'Santa Teresa - ES', 'pt': 'Santa Teresa - ES'},
 '55273258':{'en': u('Jo\u00e3o Neiva - ES'), 'pt': u('Jo\u00e3o Neiva - ES')},
 '55273253':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55273251':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55273250':{'en': 'Coqueiral - ES', 'pt': 'Coqueiral - ES'},
 '55273257':{'en': u('Ibira\u00e7u - ES'), 'pt': u('Ibira\u00e7u - ES')},
 '55273256':{'en': 'Aracruz - ES', 'pt': 'Aracruz - ES'},
 '55273255':{'en': 'Viana - ES', 'pt': 'Viana - ES'},
 '55273254':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '496049':{'de': 'Kefenrod', 'en': 'Kefenrod'},
 '496048':{'de': u('B\u00fcdingen-Eckartshausen'), 'en': u('B\u00fcdingen-Eckartshausen')},
 '55313851':{'en': u('Jo\u00e3o Monlevade - MG'), 'pt': u('Jo\u00e3o Monlevade - MG')},
 '496041':{'de': 'Glauburg', 'en': 'Glauburg'},
 '496043':{'de': 'Nidda', 'en': 'Nidda'},
 '496042':{'de': u('B\u00fcdingen Hessen'), 'en': u('B\u00fcdingen Hessen')},
 '496045':{'de': 'Gedern', 'en': 'Gedern'},
 '496044':{'de': 'Schotten Hessen', 'en': 'Schotten Hessen'},
 '496047':{'de': 'Altenstadt Hessen', 'en': 'Altenstadt Hessen'},
 '496046':{'de': 'Ortenberg Hessen', 'en': 'Ortenberg Hessen'},
 '55153336':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55313852':{'en': u('Jo\u00e3o Monlevade - MG'), 'pt': u('Jo\u00e3o Monlevade - MG')},
 '55213317':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55314136':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114588':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114585':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114584':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114587':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114586':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114581':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114583':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114582':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55313853':{'en': 'Bela Vista de Minas - MG', 'pt': 'Bela Vista de Minas - MG'},
 '55242271':{'en': 'Sapucaia - RJ', 'pt': 'Sapucaia - RJ'},
 '55144104':{'en': u('Gar\u00e7a - SP'), 'pt': u('Gar\u00e7a - SP')},
 '55144103':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55323258':{'en': 'Coronel Pacheco - MG', 'pt': 'Coronel Pacheco - MG'},
 '498191':{'de': 'Landsberg am Lech', 'en': 'Landsberg am Lech'},
 '55323254':{'en': 'Piau - MG', 'pt': 'Piau - MG'},
 '498193':{'de': 'Geltendorf', 'en': 'Geltendorf'},
 '498192':{'de': 'Schondorf am Ammersee', 'en': 'Schondorf am Ammersee'},
 '498195':{'de': 'Weil Kreis Landsberg am Lech', 'en': 'Weil Kreis Landsberg am Lech'},
 '498194':{'de': 'Vilgertshofen', 'en': 'Vilgertshofen'},
 '55323253':{'en': 'Tabuleiro - MG', 'pt': 'Tabuleiro - MG'},
 '498196':{'de': u('P\u00fcrgen'), 'en': u('P\u00fcrgen')},
 '494502':{'de': u('L\u00fcbeck-Travem\u00fcnde'), 'en': u('L\u00fcbeck-Travem\u00fcnde')},
 '494503':{'de': 'Timmendorfer Strand', 'en': 'Timmendorfer Strand'},
 '499820':{'de': 'Lehrberg', 'en': 'Lehrberg'},
 '494501':{'de': 'Kastorf Holstein', 'en': 'Kastorf Holstein'},
 '494506':{'de': 'Stockelsdorf-Krumbeck', 'en': 'Stockelsdorf-Krumbeck'},
 '499827':{'de': 'Lichtenau Mittelfranken', 'en': 'Lichtenau Mittelfranken'},
 '499824':{'de': 'Dietenhofen', 'en': 'Dietenhofen'},
 '499825':{'de': 'Herrieden', 'en': 'Herrieden'},
 '499828':{'de': u('R\u00fcgland'), 'en': u('R\u00fcgland')},
 '499829':{'de': 'Flachslanden', 'en': 'Flachslanden'},
 '55113917':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498334':{'de': u('Bad Gr\u00f6nenbach'), 'en': u('Bad Gr\u00f6nenbach')},
 '55113915':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498336':{'de': 'Erkheim', 'en': 'Erkheim'},
 '498331':{'de': 'Memmingen', 'en': 'Memmingen'},
 '498330':{'de': 'Legau', 'en': 'Legau'},
 '55113911':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498332':{'de': 'Ottobeuren', 'en': 'Ottobeuren'},
 '498338':{'de': u('B\u00f6hen'), 'en': u('B\u00f6hen')},
 '55113919':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113918':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213923':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213313':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52375':{'en': 'Ameca, JAL', 'es': 'Ameca, JAL'},
 '52377':{'en': 'Cocula/Estipac, JAL', 'es': 'Cocula/Estipac, JAL'},
 '55133463':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55313309':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55133462':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55143621':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55133465':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55313303':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55143622':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55112754':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143623':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55112752':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112753':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112751':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143624':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55133466':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55143625':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55143626':{'en': u('Ja\u00fa - SP'), 'pt': u('Ja\u00fa - SP')},
 '55312106':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '55312109':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '55193351':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55193353':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55193352':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55115511':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112532':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112533':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112536':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115513':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112535':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115512':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115515':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115514':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115516':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499194':{'de': 'Ebermannstadt', 'en': 'Ebermannstadt'},
 '55163630':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163633':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163632':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163635':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163637':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163636':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163639':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '499192':{'de': u('Gr\u00e4fenberg'), 'en': u('Gr\u00e4fenberg')},
 '499193':{'de': u('H\u00f6chstadt an der Aisch'), 'en': u('H\u00f6chstadt an der Aisch')},
 '542948':{'en': u('Chos Malal, Neuqu\u00e9n'), 'es': u('Chos Malal, Neuqu\u00e9n')},
 '55133864':{'en': 'Jacupiranga - SP', 'pt': 'Jacupiranga - SP'},
 '542942':{'en': u('Zapala, Neuqu\u00e9n'), 'es': u('Zapala, Neuqu\u00e9n')},
 '542940':{'en': u('Ingeniero Jacobacci, R\u00edo Negro'), 'es': u('Ingeniero Jacobacci, R\u00edo Negro')},
 '499191':{'de': 'Forchheim Oberfranken', 'en': 'Forchheim Oberfranken'},
 '542946':{'en': u('Choele Choel, R\u00edo Negro'), 'es': u('Choele Choel, R\u00edo Negro')},
 '542945':{'en': 'Esquel, Chubut', 'es': 'Esquel, Chubut'},
 '55113243':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113242':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183841':{'en': u('Junqueir\u00f3polis - SP'), 'pt': u('Junqueir\u00f3polis - SP')},
 '55143572':{'en': u('Piraju\u00ed - SP'), 'pt': u('Piraju\u00ed - SP')},
 '55183334':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55212403':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212402':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212401':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113240':{'en': 'Salvador - BA', 'pt': 'Salvador - BA'},
 '55212407':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212406':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212405':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212404':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212409':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '5233':{'en': 'Guadalajara, JAL', 'es': 'Guadalajara, JAL'},
 '55123156':{'en': 'Piquete - SP', 'pt': 'Piquete - SP'},
 '5237':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55123157':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '499198':{'de': 'Heiligenstadt in Oberfranken', 'en': 'Heiligenstadt in Oberfranken'},
 '55113244':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123151':{'en': 'Canas - SP', 'pt': 'Canas - SP'},
 '55123152':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '496698':{'de': 'Schrecksbach', 'en': 'Schrecksbach'},
 '496694':{'de': u('Neukirchen Kn\u00fcll'), 'en': u('Neukirchen Kn\u00fcll')},
 '496695':{'de': 'Jesberg', 'en': 'Jesberg'},
 '496696':{'de': 'Gilserberg', 'en': 'Gilserberg'},
 '496697':{'de': 'Willingshausen', 'en': 'Willingshausen'},
 '496691':{'de': 'Schwalmstadt', 'en': 'Schwalmstadt'},
 '496692':{'de': 'Neustadt Hessen', 'en': 'Neustadt Hessen'},
 '496693':{'de': 'Neuental', 'en': 'Neuental'},
 '55123159':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '55163969':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163968':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55273213':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '55163961':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55323531':{'en': u('Ub\u00e1 - MG'), 'pt': u('Ub\u00e1 - MG')},
 '55163963':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163962':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163965':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163964':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163967':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163966':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55314133':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55193235':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193927':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193924':{'en': u('\u00c1guas de Lind\u00f3ia - SP'), 'pt': u('\u00c1guas de Lind\u00f3ia - SP')},
 '55193929':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '495255':{'de': 'Altenbeken', 'en': 'Altenbeken'},
 '495254':{'de': 'Paderborn-Schloss Neuhaus', 'en': 'Paderborn-Schloss Neuhaus'},
 '495921':{'de': 'Nordhorn', 'en': 'Nordhorn'},
 '495251':{'de': 'Paderborn', 'en': 'Paderborn'},
 '495926':{'de': 'Engden', 'en': 'Engden'},
 '495925':{'de': 'Wietmarschen', 'en': 'Wietmarschen'},
 '495924':{'de': 'Bad Bentheim-Gildehaus', 'en': 'Bad Bentheim-Gildehaus'},
 '495259':{'de': 'Bad Driburg-Neuenheerse', 'en': 'Bad Driburg-Neuenheerse'},
 '495258':{'de': 'Salzkotten', 'en': 'Salzkotten'},
 '55173229':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173227':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173226':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173225':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173224':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173223':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55114312':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55213468':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213469':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497073':{'de': 'Ammerbuch', 'en': 'Ammerbuch'},
 '497072':{'de': 'Gomaringen', 'en': 'Gomaringen'},
 '497071':{'de': u('T\u00fcbingen'), 'en': u('T\u00fcbingen')},
 '55213466':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213467':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213464':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213465':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153412':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153411':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153416':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '55153417':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153414':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153415':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153418':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55133579':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55183746':{'en': 'Pereira Barreto - SP', 'pt': 'Pereira Barreto - SP'},
 '55133576':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55112442':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112443':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112440':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112446':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112447':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112444':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112445':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55163357':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163354':{'en': 'Guarapiranga - SP', 'pt': 'Guarapiranga - SP'},
 '55163352':{'en': 'Ibitinga - SP', 'pt': 'Ibitinga - SP'},
 '55163353':{'en': u('Ibat\u00e9 - SP'), 'pt': u('Ibat\u00e9 - SP')},
 '55163351':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163358':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55214118':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313685':{'en': u('Nova Uni\u00e3o - MG'), 'pt': u('Nova Uni\u00e3o - MG')},
 '55313684':{'en': u('Taquara\u00e7u de Minas - MG'), 'pt': u('Taquara\u00e7u de Minas - MG')},
 '55313686':{'en': 'Confins - MG', 'pt': 'Confins - MG'},
 '55214117':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55313683':{'en': 'Jaboticatubas - MG', 'pt': 'Jaboticatubas - MG'},
 '5042438':{'en': 'Bonito Oriental'},
 '494339':{'de': 'Christiansholm', 'en': 'Christiansholm'},
 '494338':{'de': 'Alt Duvenstedt', 'en': 'Alt Duvenstedt'},
 '55113835':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494331':{'de': 'Rendsburg', 'en': 'Rendsburg'},
 '49511':{'de': 'Hannover', 'en': 'Hannover'},
 '494333':{'de': 'Erfde', 'en': 'Erfde'},
 '494332':{'de': 'Hamdorf bei Rendsburg', 'en': 'Hamdorf bei Rendsburg'},
 '494335':{'de': 'Hohn bei Rendsburg', 'en': 'Hohn bei Rendsburg'},
 '494334':{'de': 'Bredenbek bei Rendsburg', 'en': 'Bredenbek bei Rendsburg'},
 '494337':{'de': 'Jevenstedt', 'en': 'Jevenstedt'},
 '494336':{'de': 'Owschlag', 'en': 'Owschlag'},
 '499228':{'de': 'Thurnau', 'en': 'Thurnau'},
 '55113837':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5042434':{'en': 'Trujillo'},
 '55133392':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133391':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55113831':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495934':{'de': u('Haren-R\u00fctenbrock'), 'en': u('Haren-R\u00fctenbrock')},
 '55113832':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495247':{'de': 'Harsewinkel', 'en': 'Harsewinkel'},
 '55113833':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495936':{'de': 'Twist', 'en': 'Twist'},
 '55114398':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114399':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '495937':{'de': 'Geeste-Gross Hesepe', 'en': 'Geeste-Gross Hesepe'},
 '55313464':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313466':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114390':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114391':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55143811':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55114393':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114394':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114396':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114397':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55143214':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55193728':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55143212':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55113838':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193726':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '495933':{'de': 'Lathen', 'en': 'Lathen'},
 '55143218':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55193722':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113839':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113611':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113612':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113613':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113614':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113615':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113616':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496596':{'de': u('\u00dcdersdorf'), 'en': u('\u00dcdersdorf')},
 '55113618':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113619':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496595':{'de': 'Dockweiler', 'en': 'Dockweiler'},
 '496594':{'de': 'Birresborn', 'en': 'Birresborn'},
 '55223717':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '496593':{'de': 'Hillesheim Eifel', 'en': 'Hillesheim Eifel'},
 '496592':{'de': 'Daun', 'en': 'Daun'},
 '499127':{'de': 'Rosstal Mittelfrankenanken', 'en': 'Rosstal Mittelfrankenanken'},
 '499126':{'de': 'Eckental', 'en': 'Eckental'},
 '499123':{'de': 'Lauf an der Pegnitz', 'en': 'Lauf an der Pegnitz'},
 '499122':{'de': 'Schwabach', 'en': 'Schwabach'},
 '55114028':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55114029':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55114026':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114027':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55114024':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114025':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114022':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114023':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '499129':{'de': 'Wendelstein', 'en': 'Wendelstein'},
 '55114021':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55212280':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212025':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212282':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499872':{'de': 'Heilsbronn', 'en': 'Heilsbronn'},
 '55213263':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153584':{'en': u('Taquariva\u00ed - SP'), 'pt': u('Taquariva\u00ed - SP')},
 '55173663':{'en': 'Santa Clara D\'Oeste - SP', 'pt': 'Santa Clara D\'Oeste - SP'},
 '55173662':{'en': 'Santa Salete - SP', 'pt': 'Santa Salete - SP'},
 '55173661':{'en': u('Rubin\u00e9ia - SP'), 'pt': u('Rubin\u00e9ia - SP')},
 '55123311':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '542283':{'en': u('Tapalqu\u00e9, Buenos Aires'), 'es': u('Tapalqu\u00e9, Buenos Aires')},
 '55115187':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55174004':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55174003':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55174009':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55213694':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '55213691':{'en': 'Japeri - RJ', 'pt': 'Japeri - RJ'},
 '55213693':{'en': 'Paracambi - RJ', 'pt': 'Paracambi - RJ'},
 '55213699':{'en': 'Queimados - RJ', 'pt': 'Queimados - RJ'},
 '55112257':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112256':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112255':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115189':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112253':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112252':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112251':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112259':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112258':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222664':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55222665':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55222666':{'en': u('S\u00e3o Vicente de Paula - RJ'), 'pt': u('S\u00e3o Vicente de Paula - RJ')},
 '55222667':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55222661':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55222662':{'en': 'Arraial do Cabo - RJ', 'pt': 'Arraial do Cabo - RJ'},
 '55222668':{'en': 'Silva Jardim - RJ', 'pt': 'Silva Jardim - RJ'},
 '55115612':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115611':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115616':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115614':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115615':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496207':{'de': 'Wald-Michelbach', 'en': 'Wald-Michelbach'},
 '496206':{'de': 'Lampertheim', 'en': 'Lampertheim'},
 '496205':{'de': 'Hockenheim', 'en': 'Hockenheim'},
 '496204':{'de': 'Viernheim', 'en': 'Viernheim'},
 '496203':{'de': 'Ladenburg', 'en': 'Ladenburg'},
 '496202':{'de': 'Schwetzingen', 'en': 'Schwetzingen'},
 '496201':{'de': 'Weinheim Bergstr', 'en': 'Weinheim Bergstr'},
 '55243076':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '496209':{'de': u('M\u00f6rlenbach'), 'en': u('M\u00f6rlenbach')},
 '55212618':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212619':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212616':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212612':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212613':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212610':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55212611':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '496063':{'de': u('Bad K\u00f6nig'), 'en': u('Bad K\u00f6nig')},
 '496062':{'de': 'Erbach Odenwald', 'en': 'Erbach Odenwald'},
 '496061':{'de': 'Michelstadt', 'en': 'Michelstadt'},
 '55273272':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55273275':{'en': 'Aracruz - ES', 'pt': 'Aracruz - ES'},
 '496066':{'de': 'Michelstadt-Vielbrunn', 'en': 'Michelstadt-Vielbrunn'},
 '55273277':{'en': u('Timbu\u00ed - ES'), 'pt': u('Timbu\u00ed - ES')},
 '55273276':{'en': u('Guaran\u00e1 - ES'), 'pt': u('Guaran\u00e1 - ES')},
 '55114620':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55273278':{'en': 'Acioli - ES', 'pt': 'Acioli - ES'},
 '55114622':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '496068':{'de': 'Beerfelden', 'en': 'Beerfelden'},
 '55114624':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55133494':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133495':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133491':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133493':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133499':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55114566':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '495675':{'de': 'Trendelburg', 'en': 'Trendelburg'},
 '494528':{'de': u('Sch\u00f6nwalde am Bungsberg'), 'en': u('Sch\u00f6nwalde am Bungsberg')},
 '494529':{'de': u('S\u00fcsel-Bujendorf'), 'en': u('S\u00fcsel-Bujendorf')},
 '494838':{'de': 'Tellingstedt', 'en': 'Tellingstedt'},
 '494839':{'de': u('W\u00f6hrden Dithmarschen'), 'en': u('W\u00f6hrden Dithmarschen')},
 '499804':{'de': 'Aurach', 'en': 'Aurach'},
 '494525':{'de': u('Ahrensb\u00f6k'), 'en': u('Ahrensb\u00f6k')},
 '494526':{'de': 'Ascheberg Holstein', 'en': 'Ascheberg Holstein'},
 '494527':{'de': 'Bosau', 'en': 'Bosau'},
 '494832':{'de': 'Meldorf', 'en': 'Meldorf'},
 '494521':{'de': 'Eutin', 'en': 'Eutin'},
 '499802':{'de': 'Ansbach-Katterbach', 'en': 'Ansbach-Katterbach'},
 '499803':{'de': 'Colmberg', 'en': 'Colmberg'},
 '497331':{'de': 'Geislingen an der Steige', 'en': 'Geislingen an der Steige'},
 '497332':{'de': 'Lauterstein', 'en': 'Lauterstein'},
 '497333':{'de': 'Laichingen', 'en': 'Laichingen'},
 '497334':{'de': 'Deggingen', 'en': 'Deggingen'},
 '497335':{'de': 'Wiesensteig', 'en': 'Wiesensteig'},
 '497336':{'de': 'Lonsee', 'en': 'Lonsee'},
 '497337':{'de': 'Nellingen Alb', 'en': 'Nellingen Alb'},
 '55313090':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313094':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '55313096':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '494833':{'de': 'Wesselburen', 'en': 'Wesselburen'},
 '52312':{'en': 'Colima/Los Tepames, COL', 'es': 'Colima/Los Tepames, COL'},
 '52313':{'en': 'Colima', 'es': 'Colima'},
 '52311':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52316':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52317':{'en': 'Autlan/El Chante, JAL', 'es': u('Autl\u00e1n/El Chante, JAL')},
 '52314':{'en': 'Manzanillo/Pena Colorada, COL', 'es': u('Manzanillo/Pe\u00f1a Colorada, COL')},
 '52315':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52319':{'en': 'Nayarit', 'es': 'Nayarit'},
 '55112739':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112734':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112883':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55112736':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112886':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112887':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55112884':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55112885':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55313392':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55273177':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55113938':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113289':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113288':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113935':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113934':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113285':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113936':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113283':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113281':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113932':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112086':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112087':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112085':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112088':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112089':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273091':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '55114130':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '499378':{'de': u('Eichenb\u00fchl-Riedern'), 'en': u('Eichenb\u00fchl-Riedern')},
 '55112836':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499372':{'de': 'Klingenberg am Main', 'en': 'Klingenberg am Main'},
 '499373':{'de': 'Amorbach', 'en': 'Amorbach'},
 '499371':{'de': 'Miltenberg', 'en': 'Miltenberg'},
 '499376':{'de': 'Collenberg', 'en': 'Collenberg'},
 '499377':{'de': 'Freudenberg-Boxtal', 'en': 'Freudenberg-Boxtal'},
 '499374':{'de': 'Eschau', 'en': 'Eschau'},
 '499375':{'de': 'Freudenberg Baden', 'en': 'Freudenberg Baden'},
 '55112834':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114136':{'en': u('Ara\u00e7ariguama - SP'), 'pt': u('Ara\u00e7ariguama - SP')},
 '55193456':{'en': u('Iracem\u00e1polis - SP'), 'pt': u('Iracem\u00e1polis - SP')},
 '55163659':{'en': 'Brodowski - SP', 'pt': 'Brodowski - SP'},
 '55163025':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55212429':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212428':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143003':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143004':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55314138':{'en': 'Vespasiano - MG', 'pt': 'Vespasiano - MG'},
 '55143556':{'en': u('Cafel\u00e2ndia - SP'), 'pt': u('Cafel\u00e2ndia - SP')},
 '55143554':{'en': u('Cafel\u00e2ndia - SP'), 'pt': u('Cafel\u00e2ndia - SP')},
 '55212422':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143552':{'en': 'Getulina - SP', 'pt': 'Getulina - SP'},
 '55143553':{'en': u('Guaimb\u00ea - SP'), 'pt': u('Guaimb\u00ea - SP')},
 '55212427':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183861':{'en': 'Irapuru - SP', 'pt': 'Irapuru - SP'},
 '55113429':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55124408':{'en': 'Polvilho - SP', 'pt': 'Polvilho - SP'},
 '55113423':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113422':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55113421':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55113427':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55113426':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55113425':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55113424':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55193545':{'en': 'Santa Gertrudes - SP', 'pt': 'Santa Gertrudes - SP'},
 '55313339':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273064':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55273065':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '55212465':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213410':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193541':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55114813':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114812':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '55114811':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114817':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114816':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114815':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114819':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114818':{'en': 'Terra Preta - SP', 'pt': 'Terra Preta - SP'},
 '55212464':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495493':{'de': 'Neuenkirchen Kreis Vechta', 'en': 'Neuenkirchen Kreis Vechta'},
 '495492':{'de': 'Steinfeld Oldenburg', 'en': 'Steinfeld Oldenburg'},
 '495491':{'de': u('Damme D\u00fcmmer'), 'en': u('Damme D\u00fcmmer')},
 '542962':{'en': u('Puerto San Juli\u00e1n, Santa Cruz'), 'es': u('Puerto San Juli\u00e1n, Santa Cruz')},
 '495494':{'de': 'Holdorf Niedersachsen', 'en': 'Holdorf Niedersachsen'},
 '55163904':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55323512':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55163902':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55323511':{'en': u('Muria\u00e9 - MG'), 'pt': u('Muria\u00e9 - MG')},
 '55193457':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55113304':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113305':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212466':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113303':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55244004':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '495278':{'de': u('H\u00f6xter-Ovenhausen'), 'en': u('H\u00f6xter-Ovenhausen')},
 '495277':{'de': u('H\u00f6xter-F\u00fcrstenau'), 'en': u('H\u00f6xter-F\u00fcrstenau')},
 '495276':{'de': u('Marienm\u00fcnster'), 'en': u('Marienm\u00fcnster')},
 '495275':{'de': u('H\u00f6xter-Ottbergen'), 'en': u('H\u00f6xter-Ottbergen')},
 '55113301':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495273':{'de': 'Beverungen', 'en': 'Beverungen'},
 '495272':{'de': 'Brakel Westfalen', 'en': 'Brakel Westfalen'},
 '495271':{'de': u('H\u00f6xter'), 'en': u('H\u00f6xter')},
 '55173201':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173203':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173202':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173209':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55323401':{'en': 'Leopoldina - MG', 'pt': 'Leopoldina - MG'},
 '55212460':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213481':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213483':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213484':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213485':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323255':{'en': u('Ewbank da C\u00e2mara - MG'), 'pt': u('Ewbank da C\u00e2mara - MG')},
 '55323257':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55163010':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55323256':{'en': 'Aracitaba - MG', 'pt': 'Aracitaba - MG'},
 '55163014':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55213232':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323251':{'en': 'Santos Dumont - MG', 'pt': 'Santos Dumont - MG'},
 '55323250':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55222627':{'en': u('S\u00e3o Pedro da Aldeia - RJ'), 'pt': u('S\u00e3o Pedro da Aldeia - RJ')},
 '55323252':{'en': 'Santos Dumont - MG', 'pt': 'Santos Dumont - MG'},
 '499822':{'de': 'Bechhofen an der Heide', 'en': 'Bechhofen an der Heide'},
 '499823':{'de': 'Leutershausen', 'en': 'Leutershausen'},
 '55242401':{'en': u('Barra do Pira\u00ed - RJ'), 'pt': u('Barra do Pira\u00ed - RJ')},
 '55242404':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55163338':{'en': u('Gavi\u00e3o Peixoto - SP'), 'pt': u('Gavi\u00e3o Peixoto - SP')},
 '55163339':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163334':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '499826':{'de': 'Weidenbach Mittelfranken', 'en': 'Weidenbach Mittelfranken'},
 '55163336':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163337':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163331':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163332':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163333':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '494504':{'de': 'Ratekau', 'en': 'Ratekau'},
 '494505':{'de': 'Stockelsdorf-Curau', 'en': 'Stockelsdorf-Curau'},
 '55313663':{'en': 'Pedro Leopoldo - MG', 'pt': 'Pedro Leopoldo - MG'},
 '55313662':{'en': 'Pedro Leopoldo - MG', 'pt': 'Pedro Leopoldo - MG'},
 '55214133':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55313660':{'en': 'Pedro Leopoldo - MG', 'pt': 'Pedro Leopoldo - MG'},
 '55313667':{'en': 'Coronel Fabriciano - MG', 'pt': 'Coronel Fabriciano - MG'},
 '55214137':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55214139':{'en': u('Maric\u00e1 - RJ'), 'pt': u('Maric\u00e1 - RJ')},
 '55214138':{'en': 'Queimados - RJ', 'pt': 'Queimados - RJ'},
 '494508':{'de': 'Krummesse', 'en': 'Krummesse'},
 '494509':{'de': u('Gro\u00df Gr\u00f6nau'), 'en': u('Gross Gr\u00f6nau')},
 '55163482':{'en': 'Cravinhos - SP', 'pt': 'Cravinhos - SP'},
 '55242246':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '55163488':{'en': u('S\u00e3o Sim\u00e3o - SP'), 'pt': u('S\u00e3o Sim\u00e3o - SP')},
 '55163489':{'en': 'Serrana - SP', 'pt': 'Serrana - SP'},
 '55323351':{'en': 'Barroso - MG', 'pt': 'Barroso - MG'},
 '55323353':{'en': 'Dores de Campos - MG', 'pt': 'Dores de Campos - MG'},
 '55323354':{'en': 'Resende Costa - MG', 'pt': 'Resende Costa - MG'},
 '55323355':{'en': 'Tiradentes - MG', 'pt': 'Tiradentes - MG'},
 '55323356':{'en': u('Rit\u00e1polis - MG'), 'pt': u('Rit\u00e1polis - MG')},
 '55323357':{'en': 'Coronel Xavier Chaves - MG', 'pt': 'Coronel Xavier Chaves - MG'},
 '55313402':{'en': 'Nova Lima - MG', 'pt': 'Nova Lima - MG'},
 '496841':{'de': 'Homburg Saar', 'en': 'Homburg Saar'},
 '55313409':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313408':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55193702':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55193251':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193252':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193253':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193254':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193255':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193256':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193257':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193258':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193259':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193708':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193709':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113636':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113637':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498764':{'de': 'Mauern Kreis Freising', 'en': 'Mauern Kreis Freising'},
 '498765':{'de': 'Bruckberg Niederbayern', 'en': 'Bruckberg Niederbayern'},
 '498762':{'de': 'Wartenberg Oberbayern', 'en': 'Wartenberg Oberbayern'},
 '55113633':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498662':{'de': 'Siegsdorf Kreis Traunstein', 'en': 'Siegsdorf Kreis Traunstein'},
 '498845':{'de': 'Bad Kohlgrub', 'en': 'Bad Kohlgrub'},
 '55113638':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542393':{'en': 'Salazar, Buenos Aires', 'es': 'Salazar, Buenos Aires'},
 '542392':{'en': 'Trenque Lauquen, Buenos Aires', 'es': 'Trenque Lauquen, Buenos Aires'},
 '542396':{'en': u('Pehuaj\u00f3, Buenos Aires'), 'es': u('Pehuaj\u00f3, Buenos Aires')},
 '542395':{'en': 'Carlos Casares, Buenos Aires', 'es': 'Carlos Casares, Buenos Aires'},
 '542394':{'en': u('Tres Lomas/Salliquel\u00f3, Buenos Aires'), 'es': u('Tres Lomas/Salliquel\u00f3, Buenos Aires')},
 '55313697':{'en': 'Bairro Eldorado - Sete Lagoas MG', 'pt': 'Bairro Eldorado - Sete Lagoas MG'},
 '499141':{'de': u('Wei\u00dfenburg in Bayern'), 'en': 'Weissenburg in Bayern'},
 '494644':{'de': 'Karby', 'en': 'Karby'},
 '499143':{'de': 'Pappenheim Mittelfranken', 'en': 'Pappenheim Mittelfranken'},
 '499142':{'de': 'Treuchtlingen', 'en': 'Treuchtlingen'},
 '499145':{'de': 'Solnhofen', 'en': 'Solnhofen'},
 '499144':{'de': 'Pleinfeld', 'en': 'Pleinfeld'},
 '499147':{'de': 'Nennslingen', 'en': 'Nennslingen'},
 '499146':{'de': 'Markt Berolzheim', 'en': 'Markt Berolzheim'},
 '499149':{'de': 'Weissenburg-Suffersheim', 'en': 'Weissenburg-Suffersheim'},
 '499148':{'de': 'Ettenstatt', 'en': 'Ettenstatt'},
 '55114048':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114049':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '498335':{'de': 'Fellheim', 'en': 'Fellheim'},
 '498442':{'de': 'Wolnzach', 'en': 'Wolnzach'},
 '498337':{'de': 'Altenstadt Iller', 'en': 'Altenstadt Iller'},
 '55323729':{'en': u('Muria\u00e9 - MG'), 'pt': u('Muria\u00e9 - MG')},
 '55323728':{'en': u('Muria\u00e9 - MG'), 'pt': u('Muria\u00e9 - MG')},
 '55323721':{'en': u('Muria\u00e9 - MG'), 'pt': u('Muria\u00e9 - MG')},
 '55323723':{'en': u('Ros\u00e1rio da Limeira - MG'), 'pt': u('Ros\u00e1rio da Limeira - MG')},
 '55323722':{'en': u('Muria\u00e9 - MG'), 'pt': u('Muria\u00e9 - MG')},
 '55323725':{'en': u('Ant\u00f4nio Prado de Minas - MG'), 'pt': u('Ant\u00f4nio Prado de Minas - MG')},
 '55323724':{'en': u('Eugen\u00f3polis - MG'), 'pt': u('Eugen\u00f3polis - MG')},
 '55323727':{'en': u('Bar\u00e3o de Monte Alto - MG'), 'pt': u('Bar\u00e3o de Monte Alto - MG')},
 '498446':{'de': u('P\u00f6rnbach'), 'en': u('P\u00f6rnbach')},
 '495505':{'de': 'Hardegsen', 'en': 'Hardegsen'},
 '498333':{'de': 'Babenhausen Schwaben', 'en': 'Babenhausen Schwaben'},
 '495504':{'de': u('Friedland Kreis G\u00f6ttingen'), 'en': u('Friedland Kreis G\u00f6ttingen')},
 '498444':{'de': 'Schweitenkirchen', 'en': 'Schweitenkirchen'},
 '495851':{'de': 'Dahlenburg', 'en': 'Dahlenburg'},
 '55143769':{'en': 'Holambra II - SP', 'pt': 'Holambra II - SP'},
 '55143768':{'en': 'Jurumirim - SP', 'pt': 'Jurumirim - SP'},
 '495850':{'de': 'Neetze', 'en': 'Neetze'},
 '55212584':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499131':{'de': 'Erlangen', 'en': 'Erlangen'},
 '55143761':{'en': u('Ita\u00ed - SP'), 'pt': u('Ita\u00ed - SP')},
 '55213620':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55143762':{'en': 'Taquarituba - SP', 'pt': 'Taquarituba - SP'},
 '55143765':{'en': u('\u00c1guas de Santa B\u00e1rbara - SP'), 'pt': u('\u00c1guas de Santa B\u00e1rbara - SP')},
 '499132':{'de': 'Herzogenaurach', 'en': 'Herzogenaurach'},
 '55143767':{'en': 'Coronel Macedo - SP', 'pt': 'Coronel Macedo - SP'},
 '55143766':{'en': 'Arandu - SP', 'pt': 'Arandu - SP'},
 '499133':{'de': 'Baiersdorf Mittelfrankenanken', 'en': 'Baiersdorf Mittelfrankenanken'},
 '495503':{'de': u('N\u00f6rten-Hardenberg'), 'en': u('N\u00f6rten-Hardenberg')},
 '499134':{'de': 'Neunkirchen am Brand', 'en': 'Neunkirchen am Brand'},
 '495854':{'de': 'Bleckede-Barskamp', 'en': 'Bleckede-Barskamp'},
 '499135':{'de': u('He\u00dfdorf Mittelfrankenanken'), 'en': 'Hessdorf Mittelfrankenanken'},
 '495062':{'de': 'Holle bei Hildesheim', 'en': 'Holle bei Hildesheim'},
 '495063':{'de': 'Bad Salzdetfurth', 'en': 'Bad Salzdetfurth'},
 '495060':{'de': 'Bodenburg', 'en': 'Bodenburg'},
 '55213106':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495066':{'de': 'Sarstedt', 'en': 'Sarstedt'},
 '495067':{'de': 'Bockenem', 'en': 'Bockenem'},
 '495064':{'de': u('Gro\u00df D\u00fcngen'), 'en': u('Gross D\u00fcngen')},
 '495065':{'de': 'Sibbesse', 'en': 'Sibbesse'},
 '495068':{'de': 'Elze Leine', 'en': 'Elze Leine'},
 '495069':{'de': 'Nordstemmen', 'en': 'Nordstemmen'},
 '55213109':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496630':{'de': 'Schwalmtal-Storndorf', 'en': 'Schwalmtal-Storndorf'},
 '496631':{'de': 'Alsfeld', 'en': 'Alsfeld'},
 '496636':{'de': 'Romrod', 'en': 'Romrod'},
 '496325':{'de': 'Lambrecht Pfalz', 'en': 'Lambrecht Pfalz'},
 '495156':{'de': u('Coppenbr\u00fcgge'), 'en': u('Coppenbr\u00fcgge')},
 '496326':{'de': 'Deidesheim', 'en': 'Deidesheim'},
 '495405':{'de': u('Hasbergen Kreis Osnabr\u00fcck'), 'en': u('Hasbergen Kreis Osnabr\u00fcck')},
 '55143496':{'en': u('Tup\u00e3 - SP'), 'pt': u('Tup\u00e3 - SP')},
 '55143495':{'en': u('Tup\u00e3 - SP'), 'pt': u('Tup\u00e3 - SP')},
 '496327':{'de': 'Neustadt-Lachen', 'en': 'Neustadt-Lachen'},
 '55143493':{'en': 'Varpa - SP', 'pt': 'Varpa - SP'},
 '495406':{'de': 'Belm', 'en': 'Belm'},
 '55143491':{'en': u('Tup\u00e3 - SP'), 'pt': u('Tup\u00e3 - SP')},
 '495407':{'de': 'Wallenhorst', 'en': 'Wallenhorst'},
 '55114133':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '495401':{'de': u('Georgsmarienh\u00fctte'), 'en': u('Georgsmarienh\u00fctte')},
 '55112279':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112278':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112275':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112274':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112277':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55112276':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112271':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193312':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55112273':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112272':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49931':{'de': u('W\u00fcrzburg'), 'en': u('W\u00fcrzburg')},
 '55222643':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '5042240':{'en': 'Kennedy, Tegucigalpa'},
 '5042246':{'en': 'La Vega, Tegucigalpa'},
 '55222647':{'en': 'Cabo Frio - RJ', 'pt': 'Cabo Frio - RJ'},
 '5042244':{'en': 'Tegucigalpa'},
 '5042245':{'en': 'La Vega, Tegucigalpa'},
 '495686':{'de': u('Schwarzenborn Kn\u00fcll'), 'en': u('Schwarzenborn Kn\u00fcll')},
 '495684':{'de': 'Frielendorf', 'en': 'Frielendorf'},
 '495685':{'de': u('Kn\u00fcllwald'), 'en': u('Kn\u00fcllwald')},
 '495682':{'de': 'Borken Hessen', 'en': 'Borken Hessen'},
 '495683':{'de': 'Wabern Hessen', 'en': 'Wabern Hessen'},
 '495681':{'de': 'Homberg Efze', 'en': 'Homberg Efze'},
 '55212589':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496261':{'de': 'Mosbach Baden', 'en': 'Mosbach Baden'},
 '496263':{'de': 'Neckargerach', 'en': 'Neckargerach'},
 '496262':{'de': 'Aglasterhausen', 'en': 'Aglasterhausen'},
 '496265':{'de': 'Billigheim Baden', 'en': 'Billigheim Baden'},
 '496264':{'de': 'Neudenau', 'en': 'Neudenau'},
 '496267':{'de': 'Fahrenbach Baden', 'en': 'Fahrenbach Baden'},
 '496266':{'de': 'Hassmersheim', 'en': 'Hassmersheim'},
 '496269':{'de': u('Gundelsheim W\u00fcrttemberg'), 'en': u('Gundelsheim W\u00fcrttemberg')},
 '496268':{'de': u('H\u00fcffenhardt'), 'en': u('H\u00fcffenhardt')},
 '55193885':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55212675':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55212670':{'en': 'Japeri - RJ', 'pt': 'Japeri - RJ'},
 '55212671':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55212673':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55124611':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55193884':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55273215':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55193889':{'en': 'Monte Mor - SP', 'pt': 'Monte Mor - SP'},
 '55193888':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55114608':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55114609':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '496085':{'de': 'Waldsolms', 'en': 'Waldsolms'},
 '496084':{'de': 'Schmitten Taunus', 'en': 'Schmitten Taunus'},
 '496087':{'de': 'Waldems', 'en': 'Waldems'},
 '496086':{'de': u('Gr\u00e4venwiesbach'), 'en': u('Gr\u00e4venwiesbach')},
 '496081':{'de': 'Usingen', 'en': 'Usingen'},
 '55114603':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '496083':{'de': 'Weilrod', 'en': 'Weilrod'},
 '496082':{'de': 'Niederreifenberg', 'en': 'Niederreifenberg'},
 '55193886':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55114549':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114548':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '496887':{'de': 'Schmelz Saar', 'en': 'Schmelz Saar'},
 '496881':{'de': 'Lebach', 'en': 'Lebach'},
 '495052':{'de': 'Hermannsburg', 'en': 'Hermannsburg'},
 '55114543':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114545':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '496888':{'de': 'Lebach-Steinbach', 'en': 'Lebach-Steinbach'},
 '55114547':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114546':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '54343':{'en': u('Paran\u00e1, Entre R\u00edos'), 'es': u('Paran\u00e1, Entre R\u00edos')},
 '55193881':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '54341':{'en': 'Rosario, Santa Fe', 'es': 'Rosario, Santa Fe'},
 '55242235':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '497681':{'de': 'Waldkirch Breisgau', 'en': 'Waldkirch Breisgau'},
 '497682':{'de': 'Elzach', 'en': 'Elzach'},
 '497683':{'de': 'Simonswald', 'en': 'Simonswald'},
 '497684':{'de': 'Glottertal', 'en': 'Glottertal'},
 '497685':{'de': 'Gutach-Bleibach', 'en': 'Gutach-Bleibach'},
 '497138':{'de': 'Schwaigern', 'en': 'Schwaigern'},
 '497139':{'de': 'Neuenstadt am Kocher', 'en': 'Neuenstadt am Kocher'},
 '497136':{'de': 'Bad Friedrichshall', 'en': 'Bad Friedrichshall'},
 '497134':{'de': 'Weinsberg', 'en': 'Weinsberg'},
 '497135':{'de': 'Brackenheim', 'en': 'Brackenheim'},
 '497132':{'de': 'Neckarsulm', 'en': 'Neckarsulm'},
 '497133':{'de': 'Lauffen am Neckar', 'en': 'Lauffen am Neckar'},
 '497130':{'de': u('L\u00f6wenstein W\u00fcrttemberg'), 'en': u('L\u00f6wenstein W\u00fcrttemberg')},
 '497131':{'de': 'Heilbronn Neckar', 'en': 'Heilbronn Neckar'},
 '55213766':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '498158':{'de': 'Tutzing', 'en': 'Tutzing'},
 '55143203':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55323291':{'en': 'Santa Rita de Jacutinga - MG', 'pt': 'Santa Rita de Jacutinga - MG'},
 '498157':{'de': 'Feldafing', 'en': 'Feldafing'},
 '55323292':{'en': 'Bom Jardim de Minas - MG', 'pt': 'Bom Jardim de Minas - MG'},
 '498151':{'de': 'Starnberg', 'en': 'Starnberg'},
 '55323294':{'en': 'Bocaina de Minas - MG', 'pt': 'Bocaina de Minas - MG'},
 '498153':{'de': 'Wessling', 'en': 'Wessling'},
 '498152':{'de': 'Herrsching am Ammersee', 'en': 'Herrsching am Ammersee'},
 '55143201':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143302':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '55213761':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '5017':{'en': 'Toledo District'},
 '55323323':{'en': u('S\u00e3o Jo\u00e3o Del Rei - MG'), 'pt': u('S\u00e3o Jo\u00e3o Del Rei - MG')},
 '55193751':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '497358':{'de': u('Eberhardzell-F\u00fcramoos'), 'en': u('Eberhardzell-F\u00fcramoos')},
 '497352':{'de': 'Ochsenhausen', 'en': 'Ochsenhausen'},
 '497353':{'de': 'Schwendi', 'en': 'Schwendi'},
 '497351':{'de': u('Biberach an der Ri\u00df'), 'en': 'Biberach an der Riss'},
 '497356':{'de': 'Schemmerhofen', 'en': 'Schemmerhofen'},
 '497357':{'de': 'Attenweiler', 'en': 'Attenweiler'},
 '497354':{'de': 'Erolzheim', 'en': 'Erolzheim'},
 '497355':{'de': u('Hochdorf Ri\u00df'), 'en': 'Hochdorf Riss'},
 '498379':{'de': 'Waltenhofen-Oberdorf', 'en': 'Waltenhofen-Oberdorf'},
 '498378':{'de': 'Buchenberg bei Kempten', 'en': 'Buchenberg bei Kempten'},
 '498370':{'de': 'Wiggensbach', 'en': 'Wiggensbach'},
 '498373':{'de': 'Altusried', 'en': 'Altusried'},
 '498372':{'de': u('Oberg\u00fcnzburg'), 'en': u('Oberg\u00fcnzburg')},
 '498375':{'de': 'Weitnau', 'en': 'Weitnau'},
 '498374':{'de': 'Dietmannsried', 'en': 'Dietmannsried'},
 '498377':{'de': 'Unterthingau', 'en': 'Unterthingau'},
 '498376':{'de': u('Sulzberg Allg\u00e4u'), 'en': u('Sulzberg Allg\u00e4u')},
 '55153202':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153207':{'en': 'Gramadinho - SP', 'pt': 'Gramadinho - SP'},
 '55153205':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '52998':{'en': 'Quintana Roo', 'es': 'Quintana Roo'},
 '52999':{'en': 'Conkal/Merida, YUC', 'es': u('Conkal/M\u00e9rida, YUC')},
 '52994':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '52995':{'en': 'Magdalena Tequisistlan/Santa Maria Jalapa Del Marquez, OAX', 'es': u('Magdalena Tequisistl\u00e1n/Santa Maria Jalapa del Marqu\u00e9s, OAX')},
 '52996':{'en': 'Campeche', 'es': 'Campeche'},
 '52997':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52991':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52992':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52993':{'en': 'Tabasco', 'es': 'Tabasco'},
 '55112712':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112861':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112862':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112864':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112717':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313342':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112867':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112719':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133592':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '499682':{'de': 'Erbendorf', 'en': 'Erbendorf'},
 '499683':{'de': 'Friedenfels', 'en': 'Friedenfels'},
 '499681':{'de': 'Windischeschenbach', 'en': 'Windischeschenbach'},
 '55133596':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55193288':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '499426':{'de': 'Oberschneiding', 'en': 'Oberschneiding'},
 '499427':{'de': 'Leiblfing', 'en': 'Leiblfing'},
 '499424':{'de': 'Strasskirchen', 'en': 'Strasskirchen'},
 '499357':{'de': u('Gr\u00e4fendorf Bayern'), 'en': u('Gr\u00e4fendorf Bayern')},
 '499422':{'de': 'Bogen Niederbayern', 'en': 'Bogen Niederbayern'},
 '499423':{'de': u('Geiselh\u00f6ring'), 'en': u('Geiselh\u00f6ring')},
 '499420':{'de': 'Feldkirchen Niederbayern', 'en': 'Feldkirchen Niederbayern'},
 '499421':{'de': 'Straubing', 'en': 'Straubing'},
 '55222779':{'en': u('Concei\u00e7\u00e3o de Macabu - RJ'), 'pt': u('Concei\u00e7\u00e3o de Macabu - RJ')},
 '499358':{'de': u('G\u00f6ssenheim'), 'en': u('G\u00f6ssenheim')},
 '499359':{'de': 'Karlstadt-Wiesenfeld', 'en': 'Karlstadt-Wiesenfeld'},
 '499428':{'de': 'Kirchroth', 'en': 'Kirchroth'},
 '499429':{'de': 'Rain Niederbayern', 'en': 'Rain Niederbayern'},
 '49721':{'de': 'Karlsruhe', 'en': 'Karlsruhe'},
 '55222772':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55222773':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55143026':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '55143535':{'en': u('Pomp\u00e9ia - SP'), 'pt': u('Pomp\u00e9ia - SP')},
 '55143025':{'en': 'Lins - SP', 'pt': 'Lins - SP'},
 '55143022':{'en': u('Avar\u00e9 - SP'), 'pt': u('Avar\u00e9 - SP')},
 '55143532':{'en': 'Lins - SP', 'pt': 'Lins - SP'},
 '55143533':{'en': 'Lins - SP', 'pt': 'Lins - SP'},
 '55212447':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212446':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212445':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212444':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212442':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212441':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212440':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113403':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55113402':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55113404':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55113409':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55113408':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '543585':{'en': u('Adelia Mar\u00eda, C\u00f3rdoba'), 'es': u('Adelia Mar\u00eda, C\u00f3rdoba')},
 '543584':{'en': u('La Carlota, C\u00f3rdoba'), 'es': u('La Carlota, C\u00f3rdoba')},
 '55273047':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '543583':{'en': u('Vicu\u00f1a Mackenna, C\u00f3rdoba'), 'es': u('Vicu\u00f1a Mackenna, C\u00f3rdoba')},
 '543582':{'en': u('Sampacho, C\u00f3rdoba'), 'es': u('Sampacho, C\u00f3rdoba')},
 '55273048':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55273049':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55114837':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323574':{'en': 'Tocantins - MG', 'pt': 'Tocantins - MG'},
 '55323575':{'en': 'Guarani - MG', 'pt': 'Guarani - MG'},
 '55323576':{'en': 'Dores do Turvo - MG', 'pt': 'Dores do Turvo - MG'},
 '55323577':{'en': 'Rodeiro - MG', 'pt': 'Rodeiro - MG'},
 '55323571':{'en': 'Rio Pomba - MG', 'pt': 'Rio Pomba - MG'},
 '55323572':{'en': u('Silveir\u00e2nia - MG'), 'pt': u('Silveir\u00e2nia - MG')},
 '55323573':{'en': u('Pira\u00faba - MG'), 'pt': u('Pira\u00faba - MG')},
 '495475':{'de': 'Bohmte-Hunteburg', 'en': 'Bohmte-Hunteburg'},
 '495474':{'de': 'Stemwede-Dielingen', 'en': 'Stemwede-Dielingen'},
 '495476':{'de': 'Ostercappeln-Venne', 'en': 'Ostercappeln-Venne'},
 '542982':{'en': u('Claromec\u00f3, Buenos Aires'), 'es': u('Claromec\u00f3, Buenos Aires')},
 '542983':{'en': 'Tres Arroyos, Buenos Aires', 'es': 'Tres Arroyos, Buenos Aires'},
 '495473':{'de': 'Ostercappeln', 'en': 'Ostercappeln'},
 '495472':{'de': 'Bad Essen', 'en': 'Bad Essen'},
 '55115973':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213716':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55115972':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222793':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55173016':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173889':{'en': 'Altair - SP', 'pt': 'Altair - SP'},
 '55273756':{'en': u('Barra de S\u00e3o Francisco - ES'), 'pt': u('Barra de S\u00e3o Francisco - ES')},
 '55193441':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55213105':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55243346':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '55163075':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55243347':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '496746':{'de': 'Pfalzfeld', 'en': 'Pfalzfeld'},
 '496747':{'de': 'Emmelshausen', 'en': 'Emmelshausen'},
 '496744':{'de': 'Oberwesel', 'en': 'Oberwesel'},
 '496745':{'de': 'Gondershausen', 'en': 'Gondershausen'},
 '496742':{'de': 'Boppard', 'en': 'Boppard'},
 '496743':{'de': 'Bacharach', 'en': 'Bacharach'},
 '496741':{'de': 'St Goar', 'en': 'St Goar'},
 '55173362':{'en': u('Marcond\u00e9sia - SP'), 'pt': u('Marcond\u00e9sia - SP')},
 '55172136':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55172137':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55212560':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163311':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163315':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55313649':{'en': 'Santa Luzia - MG', 'pt': 'Santa Luzia - MG'},
 '55313641':{'en': 'Santa Luzia - MG', 'pt': 'Santa Luzia - MG'},
 '55212564':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313645':{'en': 'Vespasiano - MG', 'pt': 'Vespasiano - MG'},
 '55212565':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183651':{'en': 'Avanhandava - SP', 'pt': 'Avanhandava - SP'},
 '55183653':{'en': u('Pen\u00e1polis - SP'), 'pt': u('Pen\u00e1polis - SP')},
 '55183652':{'en': u('Pen\u00e1polis - SP'), 'pt': u('Pen\u00e1polis - SP')},
 '55183655':{'en': 'Barbosa - SP', 'pt': 'Barbosa - SP'},
 '55183654':{'en': u('Pen\u00e1polis - SP'), 'pt': u('Pen\u00e1polis - SP')},
 '55183657':{'en': 'Alto Alegre - SP', 'pt': 'Alto Alegre - SP'},
 '55183656':{'en': u('Jatob\u00e1 - SP'), 'pt': u('Jatob\u00e1 - SP')},
 '55183659':{'en': 'Bilac - SP', 'pt': 'Bilac - SP'},
 '55183658':{'en': 'Clementina - SP', 'pt': 'Clementina - SP'},
 '55212567':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52297':{'en': 'Alvarado, VER', 'es': 'Alvarado, VER'},
 '52296':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52294':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55212745':{'en': 'Rio de Janeiro', 'pt': 'Rio de Janeiro'},
 '55133821':{'en': 'Registro - SP', 'pt': 'Registro - SP'},
 '55133822':{'en': 'Registro - SP', 'pt': 'Registro - SP'},
 '55313428':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55323379':{'en': u('S\u00e3o Jo\u00e3o Del Rei - MG'), 'pt': u('S\u00e3o Jo\u00e3o Del Rei - MG')},
 '55323376':{'en': u('S\u00e3o Tiago - MG'), 'pt': u('S\u00e3o Tiago - MG')},
 '55313424':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55323374':{'en': 'Rio das Mortes - MG', 'pt': 'Rio das Mortes - MG'},
 '55313426':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55323372':{'en': u('S\u00e3o Jo\u00e3o Del Rei - MG'), 'pt': u('S\u00e3o Jo\u00e3o Del Rei - MG')},
 '55323373':{'en': u('S\u00e3o Jo\u00e3o Del Rei - MG'), 'pt': u('S\u00e3o Jo\u00e3o Del Rei - MG')},
 '55323371':{'en': u('S\u00e3o Jo\u00e3o Del Rei - MG'), 'pt': u('S\u00e3o Jo\u00e3o Del Rei - MG')},
 '494483':{'de': u('Ovelg\u00f6nne-Gro\u00dfenmeer'), 'en': u('Ovelg\u00f6nne-Grossenmeer')},
 '494482':{'de': 'Hatten', 'en': 'Hatten'},
 '494481':{'de': 'Hatten-Sandkrug', 'en': 'Hatten-Sandkrug'},
 '494480':{'de': u('Ovelg\u00f6nne-Str\u00fcckhausen'), 'en': u('Ovelg\u00f6nne-Str\u00fcckhausen')},
 '494487':{'de': 'Grossenkneten-Huntlosen', 'en': 'Grossenkneten-Huntlosen'},
 '494486':{'de': 'Edewecht-Friedrichsfehn', 'en': 'Edewecht-Friedrichsfehn'},
 '494485':{'de': 'Elsfleth-Huntorf', 'en': 'Elsfleth-Huntorf'},
 '494484':{'de': u('Hude-W\u00fcsting'), 'en': u('Hude-W\u00fcsting')},
 '55134102':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '494489':{'de': 'Apen', 'en': 'Apen'},
 '494488':{'de': 'Westerstede', 'en': 'Westerstede'},
 '55134104':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55193276':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55163266':{'en': 'Borborema - SP', 'pt': 'Borborema - SP'},
 '55193274':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193275':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193272':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113659':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55193271':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113654':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113871':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113872':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113873':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113874':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113651':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113652':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113877':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498741':{'de': 'Vilsbiburg', 'en': 'Vilsbiburg'},
 '498742':{'de': 'Velden Vils', 'en': 'Velden Vils'},
 '498743':{'de': 'Geisenhausen', 'en': 'Geisenhausen'},
 '498744':{'de': 'Gerzen', 'en': 'Gerzen'},
 '498745':{'de': 'Bodenkirchen', 'en': 'Bodenkirchen'},
 '55163638':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163262':{'en': u('It\u00e1polis - SP'), 'pt': u('It\u00e1polis - SP')},
 '55115978':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163263':{'en': u('It\u00e1polis - SP'), 'pt': u('It\u00e1polis - SP')},
 '55114069':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499163':{'de': 'Dachsbach', 'en': 'Dachsbach'},
 '55114062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55173622':{'en': 'Jales - SP', 'pt': 'Jales - SP'},
 '55173621':{'en': 'Jales - SP', 'pt': 'Jales - SP'},
 '55114061':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114066':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114067':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55173624':{'en': 'Jales - SP', 'pt': 'Jales - SP'},
 '55193031':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '494668':{'de': u('Klanxb\u00fcll'), 'en': u('Klanxb\u00fcll')},
 '498443':{'de': 'Hohenwart Paar', 'en': 'Hohenwart Paar'},
 '494666':{'de': 'Ladelund', 'en': 'Ladelund'},
 '494665':{'de': u('Emmelsb\u00fcll-Horsb\u00fcll'), 'en': u('Emmelsb\u00fcll-Horsb\u00fcll')},
 '494664':{'de': u('Neukirchen bei Nieb\u00fcll'), 'en': u('Neukirchen bei Nieb\u00fcll')},
 '499167':{'de': 'Oberscheinfeld', 'en': 'Oberscheinfeld'},
 '494662':{'de': 'Leck', 'en': 'Leck'},
 '494661':{'de': u('Nieb\u00fcll'), 'en': u('Nieb\u00fcll')},
 '499164':{'de': 'Langenfeld Mittelfranken', 'en': 'Langenfeld Mittelfranken'},
 '55323749':{'en': 'Faria Lemos - MG', 'pt': 'Faria Lemos - MG'},
 '55323748':{'en': 'Pedra Dourada - MG', 'pt': 'Pedra Dourada - MG'},
 '55323747':{'en': u('Alto Capara\u00f3 - MG'), 'pt': u('Alto Capara\u00f3 - MG')},
 '55323746':{'en': 'Espera Feliz - MG', 'pt': 'Espera Feliz - MG'},
 '55323745':{'en': 'Caiana - MG', 'pt': 'Caiana - MG'},
 '55323743':{'en': 'Divino - MG', 'pt': 'Divino - MG'},
 '55323742':{'en': 'Fervedouro - MG', 'pt': 'Fervedouro - MG'},
 '55323741':{'en': 'Carangola - MG', 'pt': 'Carangola - MG'},
 '55283518':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55153016':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153017':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153014':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153012':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153013':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55283515':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55153011':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '498441':{'de': 'Pfaffenhofen an der Ilm', 'en': 'Pfaffenhofen an der Ilm'},
 '55193566':{'en': u('Anal\u00e2ndia - SP'), 'pt': u('Anal\u00e2ndia - SP')},
 '55313809':{'en': u('Santa B\u00e1rbara - MG'), 'pt': u('Santa B\u00e1rbara - MG')},
 '495044':{'de': 'Springe-Eldagsen', 'en': 'Springe-Eldagsen'},
 '495045':{'de': 'Springe-Bennigsen', 'en': 'Springe-Bennigsen'},
 '495041':{'de': 'Springe Deister', 'en': 'Springe Deister'},
 '495042':{'de': u('Bad M\u00fcnder am Deister'), 'en': u('Bad M\u00fcnder am Deister')},
 '495043':{'de': 'Lauenau', 'en': 'Lauenau'},
 '55123421':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123351':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123424':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123354':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '497626':{'de': 'Kandern', 'en': 'Kandern'},
 '55273362':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55193186':{'en': 'Charqueada - SP', 'pt': 'Charqueada - SP'},
 '55193187':{'en': 'Santa Maria da Serra - SP', 'pt': 'Santa Maria da Serra - SP'},
 '497624':{'de': 'Grenzach-Wyhlen', 'en': 'Grenzach-Wyhlen'},
 '497625':{'de': 'Zell im Wiesental', 'en': 'Zell im Wiesental'},
 '497622':{'de': 'Schopfheim', 'en': 'Schopfheim'},
 '55223311':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '497623':{'de': 'Rheinfelden Baden', 'en': 'Rheinfelden Baden'},
 '55112293':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112292':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112291':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112297':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497620':{'de': 'Schopfheim-Gersbach', 'en': 'Schopfheim-Gersbach'},
 '55112295':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112294':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213108':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497621':{'de': u('L\u00f6rrach'), 'en': u('L\u00f6rrach')},
 '55183842':{'en': u('Junqueir\u00f3polis - SP'), 'pt': u('Junqueir\u00f3polis - SP')},
 '498445':{'de': 'Gerolsbach', 'en': 'Gerolsbach'},
 '49911':{'de': u('N\u00fcrnberg'), 'en': 'Nuremberg'},
 '55213394':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212380':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213823':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213820':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213397':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213390':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213391':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213824':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213393':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496249':{'de': 'Guntersblum', 'en': 'Guntersblum'},
 '55212659':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55273182':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55114998':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '496535':{'de': 'Osann-Monzel', 'en': 'Osann-Monzel'},
 '496534':{'de': u('M\u00fclheim Mosel'), 'en': u('M\u00fclheim Mosel')},
 '496241':{'de': 'Worms', 'en': 'Worms'},
 '496536':{'de': 'Kleinich', 'en': 'Kleinich'},
 '496531':{'de': 'Bernkastel-Kues', 'en': 'Bernkastel-Kues'},
 '496246':{'de': 'Eich Rheinhessen', 'en': 'Eich Rheinhessen'},
 '496533':{'de': u('Morbach Hunsr\u00fcck'), 'en': u('Morbach Hunsr\u00fcck')},
 '496532':{'de': 'Zeltingen-Rachtig', 'en': 'Zeltingen-Rachtig'},
 '495035':{'de': 'Gross Munzel', 'en': 'Gross Munzel'},
 '495034':{'de': 'Neustadt-Hagen', 'en': 'Neustadt-Hagen'},
 '495037':{'de': 'Bad Rehburg', 'en': 'Bad Rehburg'},
 '55173361':{'en': 'Monte Azul Paulista - SP', 'pt': 'Monte Azul Paulista - SP'},
 '55212408':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273239':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '495033':{'de': 'Wunstorf-Grossenheidorn', 'en': 'Wunstorf-Grossenheidorn'},
 '55273235':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273237':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '495032':{'de': u('Neustadt am R\u00fcbenberge'), 'en': u('Neustadt am R\u00fcbenberge')},
 '55273233':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273232':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55114664':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114665':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114666':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114667':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55193867':{'en': u('Jaguari\u00fana - SP'), 'pt': u('Jaguari\u00fana - SP')},
 '55114661':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114662':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114663':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55193869':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '55193868':{'en': 'Estiva Gerbi - SP', 'pt': 'Estiva Gerbi - SP'},
 '55114668':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114669':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114529':{'en': u('Jacar\u00e9 - SP'), 'pt': u('Jacar\u00e9 - SP')},
 '55114528':{'en': u('Cabre\u00fava - SP'), 'pt': u('Cabre\u00fava - SP')},
 '55114527':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114526':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114525':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114524':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114523':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114522':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114521':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55213528':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213520':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213525':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55114295':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '494873':{'de': 'Aukrug', 'en': 'Aukrug'},
 '494871':{'de': 'Hohenwestedt', 'en': 'Hohenwestedt'},
 '494876':{'de': 'Reher Holstein', 'en': 'Reher Holstein'},
 '494877':{'de': 'Hennstedt bei Itzehoe', 'en': 'Hennstedt bei Itzehoe'},
 '494874':{'de': u('Todenb\u00fcttel'), 'en': u('Todenb\u00fcttel')},
 '55114292':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '497374':{'de': 'Uttenweiler', 'en': 'Uttenweiler'},
 '497375':{'de': 'Obermarchtal', 'en': 'Obermarchtal'},
 '497376':{'de': 'Langenenslingen', 'en': 'Langenenslingen'},
 '497371':{'de': u('Riedlingen W\u00fcrttemberg'), 'en': u('Riedlingen W\u00fcrttemberg')},
 '497373':{'de': 'Zwiefalten', 'en': 'Zwiefalten'},
 '55133451':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133453':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133454':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133455':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133456':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133457':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133458':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55153229':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153228':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153221':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153223':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153222':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153225':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153224':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153227':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153226':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '5042445':{'en': u('Coxin Hole, Roat\u00e1n')},
 '498177':{'de': u('M\u00fcnsing Starnberger See'), 'en': u('M\u00fcnsing Starnberger See')},
 '498176':{'de': 'Egling bei Wolfratshausen', 'en': 'Egling bei Wolfratshausen'},
 '498171':{'de': 'Wolfratshausen', 'en': 'Wolfratshausen'},
 '498170':{'de': u('Stra\u00dflach-Dingharting'), 'en': 'Strasslach-Dingharting'},
 '55115212':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115213':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498179':{'de': 'Eurasburg an der Loisach', 'en': 'Eurasburg an der Loisach'},
 '498178':{'de': 'Icking', 'en': 'Icking'},
 '494296':{'de': 'Schwanewede-Aschwarden', 'en': 'Schwanewede-Aschwarden'},
 '494297':{'de': 'Ottersberg-Posthausen', 'en': 'Ottersberg-Posthausen'},
 '494294':{'de': 'Riede Kreis Verden', 'en': 'Riede Kreis Verden'},
 '494295':{'de': 'Emtinghausen', 'en': 'Emtinghausen'},
 '494292':{'de': 'Ritterhude', 'en': 'Ritterhude'},
 '55112843':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112840':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55112841':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112848':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112849':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497806':{'de': 'Bad Peterstal-Griesbach', 'en': 'Bad Peterstal-Griesbach'},
 '497807':{'de': 'Neuried Ortenaukreis', 'en': 'Neuried Ortenaukreis'},
 '497804':{'de': 'Oppenau', 'en': 'Oppenau'},
 '497805':{'de': 'Appenweier', 'en': 'Appenweier'},
 '497802':{'de': 'Oberkirch Baden', 'en': 'Oberkirch Baden'},
 '497803':{'de': 'Gengenbach', 'en': 'Gengenbach'},
 '497808':{'de': 'Hohberg bei Offenburg', 'en': 'Hohberg bei Offenburg'},
 '55212226':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212016':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49741':{'de': 'Rottweil', 'en': 'Rottweil'},
 '499401':{'de': 'Neutraubling', 'en': 'Neutraubling'},
 '499402':{'de': 'Regenstauf', 'en': 'Regenstauf'},
 '499403':{'de': 'Donaustauf', 'en': 'Donaustauf'},
 '499404':{'de': 'Nittendorf', 'en': 'Nittendorf'},
 '499405':{'de': 'Bad Abbach', 'en': 'Bad Abbach'},
 '499406':{'de': 'Mintraching', 'en': 'Mintraching'},
 '499407':{'de': 'Wenzenbach', 'en': 'Wenzenbach'},
 '499408':{'de': 'Altenthann', 'en': 'Altenthann'},
 '499409':{'de': 'Pielenhofen', 'en': 'Pielenhofen'},
 '55313485':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55115566':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115560':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115561':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163693':{'en': u('Jardin\u00f3polis - SP'), 'pt': u('Jardin\u00f3polis - SP')},
 '55163690':{'en': u('Jardin\u00f3polis - SP'), 'pt': u('Jardin\u00f3polis - SP')},
 '55115562':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115563':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123519':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55313483':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183822':{'en': 'Dracena - SP', 'pt': 'Dracena - SP'},
 '55183823':{'en': 'Dracena - SP', 'pt': 'Dracena - SP'},
 '55183821':{'en': 'Dracena - SP', 'pt': 'Dracena - SP'},
 '499701':{'de': 'Sandberg Unterfranken', 'en': 'Sandberg Unterfranken'},
 '52716':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52671':{'en': 'Durango', 'es': 'Durango'},
 '52714':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52715':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52712':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52713':{'en': 'Santiago Tianguistenco, MEX', 'es': 'Santiago Tianguistenco, MEX'},
 '55212463':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '52711':{'en': 'Mexico/Michoacan', 'es': u('M\u00e9xico/Michoac\u00e1n')},
 '55193519':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '52718':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52719':{'en': 'San Francisco Xonacatlan/Temoaya, MEX', 'es': u('San Francisco Xonacatl\u00e1n/Temoaya, MEX')},
 '55113467':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113466':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113465':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113275':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113463':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113462':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113461':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323539':{'en': u('Ub\u00e1 - MG'), 'pt': u('Ub\u00e1 - MG')},
 '55193706':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55113272':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122126':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55122127':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55122124':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '52674':{'en': 'Durango', 'es': 'Durango'},
 '55323084':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55112599':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323083':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55112594':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112597':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112591':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112592':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193707':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55114853':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114852':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114850':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55323532':{'en': u('Ub\u00e1 - MG'), 'pt': u('Ub\u00e1 - MG')},
 '495457':{'de': 'Hopsten-Schale', 'en': 'Hopsten-Schale'},
 '495456':{'de': 'Westerkappeln-Velpe', 'en': 'Westerkappeln-Velpe'},
 '495455':{'de': 'Tecklenburg-Brochterbeck', 'en': 'Tecklenburg-Brochterbeck'},
 '495454':{'de': u('H\u00f6rstel-Riesenbeck'), 'en': u('H\u00f6rstel-Riesenbeck')},
 '495453':{'de': 'Recke', 'en': 'Recke'},
 '495452':{'de': 'Mettingen Westfalen', 'en': 'Mettingen Westfalen'},
 '495451':{'de': u('Ibbenb\u00fcren'), 'en': u('Ibbenb\u00fcren')},
 '55323534':{'en': u('Br\u00e1s Pires - MG'), 'pt': u('Br\u00e1s Pires - MG')},
 '55323551':{'en': 'Visconde do Rio Branco - MG', 'pt': 'Visconde do Rio Branco - MG'},
 '55323556':{'en': u('S\u00e3o Geraldo - MG'), 'pt': u('S\u00e3o Geraldo - MG')},
 '495459':{'de': u('H\u00f6rstel'), 'en': u('H\u00f6rstel')},
 '495458':{'de': 'Hopsten', 'en': 'Hopsten'},
 '55323536':{'en': 'Senador Firmino - MG', 'pt': 'Senador Firmino - MG'},
 '495181':{'de': 'Alfeld Leine', 'en': 'Alfeld Leine'},
 '495183':{'de': 'Lamspringe', 'en': 'Lamspringe'},
 '495182':{'de': 'Gronau Leine', 'en': 'Gronau Leine'},
 '495185':{'de': 'Duingen', 'en': 'Duingen'},
 '495184':{'de': 'Freden Leine', 'en': 'Freden Leine'},
 '495187':{'de': 'Delligsen', 'en': 'Delligsen'},
 '495186':{'de': 'Salzhemmendorf-Wallensen', 'en': 'Salzhemmendorf-Wallensen'},
 '55313496':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '495233':{'de': 'Steinheim Westfalen', 'en': 'Steinheim Westfalen'},
 '495232':{'de': 'Lage Lippe', 'en': 'Lage Lippe'},
 '495231':{'de': 'Detmold', 'en': 'Detmold'},
 '495237':{'de': 'Augustdorf', 'en': 'Augustdorf'},
 '495236':{'de': 'Blomberg-Grossenmarpe', 'en': 'Blomberg-Grossenmarpe'},
 '495235':{'de': 'Blomberg Lippe', 'en': 'Blomberg Lippe'},
 '495234':{'de': 'Horn-Bad Meinberg', 'en': 'Horn-Bad Meinberg'},
 '55112331':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495238':{'de': 'Nieheim-Himmighausen', 'en': 'Nieheim-Himmighausen'},
 '55112334':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112335':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112336':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313492':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55123653':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123652':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55273773':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '55123655':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123654':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '494433':{'de': u('D\u00f6tlingen'), 'en': u('D\u00f6tlingen')},
 '55323267':{'en': u('S\u00e3o Jo\u00e3o Nepomuceno - MG'), 'pt': u('S\u00e3o Jo\u00e3o Nepomuceno - MG')},
 '55124004':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '497583':{'de': 'Bad Schussenried', 'en': 'Bad Schussenried'},
 '497582':{'de': 'Bad Buchau', 'en': 'Bad Buchau'},
 '497581':{'de': 'Saulgau', 'en': 'Saulgau'},
 '497587':{'de': 'Hosskirch', 'en': 'Hosskirch'},
 '497586':{'de': 'Herbertingen', 'en': 'Herbertingen'},
 '497585':{'de': 'Ostrach', 'en': 'Ostrach'},
 '497584':{'de': 'Altshausen', 'en': 'Altshausen'},
 '496184':{'de': 'Langenselbold', 'en': 'Langenselbold'},
 '496185':{'de': 'Hammersbach Hessen', 'en': 'Hammersbach Hessen'},
 '496186':{'de': 'Grosskrotzenburg', 'en': 'Grosskrotzenburg'},
 '496187':{'de': u('Sch\u00f6neck'), 'en': u('Sch\u00f6neck')},
 '496181':{'de': 'Hanau', 'en': 'Hanau'},
 '496182':{'de': 'Seligenstadt', 'en': 'Seligenstadt'},
 '496183':{'de': 'Erlensee', 'en': 'Erlensee'},
 '496188':{'de': 'Kahl am Main', 'en': 'Kahl am Main'},
 '55114308':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499464':{'de': 'Walderbach', 'en': 'Walderbach'},
 '55115029':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112838':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115021':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112455':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '496762':{'de': 'Kastellaun', 'en': 'Kastellaun'},
 '496763':{'de': u('Kirchberg Hunsr\u00fcck'), 'en': u('Kirchberg Hunsr\u00fcck')},
 '496764':{'de': u('Rheinb\u00f6llen'), 'en': u('Rheinb\u00f6llen')},
 '496765':{'de': u('Gem\u00fcnden Hunsr\u00fcck'), 'en': u('Gem\u00fcnden Hunsr\u00fcck')},
 '496766':{'de': 'Kisselbach', 'en': 'Kisselbach'},
 '55115486':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498705':{'de': 'Altfraunhofen', 'en': 'Altfraunhofen'},
 '55112456':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112453':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '498706':{'de': 'Vilsheim', 'en': 'Vilsheim'},
 '55112904':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313628':{'en': u('Ribeir\u00e3o das Neves - MG'), 'pt': u('Ribeir\u00e3o das Neves - MG')},
 '55313627':{'en': u('Ribeir\u00e3o das Neves - MG'), 'pt': u('Ribeir\u00e3o das Neves - MG')},
 '55313626':{'en': u('Ribeir\u00e3o das Neves - MG'), 'pt': u('Ribeir\u00e3o das Neves - MG')},
 '55313625':{'en': u('Ribeir\u00e3o das Neves - MG'), 'pt': u('Ribeir\u00e3o das Neves - MG')},
 '55112835':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55313623':{'en': u('S\u00e3o Jos\u00e9 da Lapa - MG'), 'pt': u('S\u00e3o Jos\u00e9 da Lapa - MG')},
 '55313622':{'en': 'Vespasiano - MG', 'pt': 'Vespasiano - MG'},
 '55313621':{'en': 'Vespasiano - MG', 'pt': 'Vespasiano - MG'},
 '55183637':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183636':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183634':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '55183631':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55183639':{'en': u('Santo Ant\u00f4nio do Aracangu\u00e1 - SP'), 'pt': u('Santo Ant\u00f4nio do Aracangu\u00e1 - SP')},
 '55183638':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '52279':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52278':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55133849':{'en': 'Iguape - SP', 'pt': 'Iguape - SP'},
 '55133848':{'en': 'Iguape - SP', 'pt': 'Iguape - SP'},
 '52275':{'en': 'Puebla', 'es': 'Puebla'},
 '52274':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '499238':{'de': u('R\u00f6slau'), 'en': u('R\u00f6slau')},
 '52271':{'en': 'Veracruz', 'es': 'Veracruz'},
 '498247':{'de': u('Bad W\u00f6rishofen'), 'en': u('Bad W\u00f6rishofen')},
 '52273':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52272':{'en': 'Maltrata/Orizaba, VER', 'es': 'Maltrata/Orizaba, VER'},
 '498246':{'de': 'Waal', 'en': 'Waal'},
 '499236':{'de': 'Nagel', 'en': 'Nagel'},
 '55113823':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222796':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '499465':{'de': 'Neukirchen-Balbini', 'en': 'Neukirchen-Balbini'},
 '55273723':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '495923':{'de': u('Sch\u00fcttorf'), 'en': u('Sch\u00fcttorf')},
 '55273721':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55273720':{'en': 'Itarana - ES', 'pt': 'Itarana - ES'},
 '55143879':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55273726':{'en': 'Pancas - ES', 'pt': 'Pancas - ES'},
 '55273725':{'en': u('Itagua\u00e7u - ES'), 'pt': u('Itagua\u00e7u - ES')},
 '495922':{'de': 'Bad Bentheim', 'en': 'Bad Bentheim'},
 '55273729':{'en': u('S\u00e3o Roque do Cana\u00e3 - ES'), 'pt': u('S\u00e3o Roque do Cana\u00e3 - ES')},
 '55273728':{'en': u('Vila Val\u00e9rio - ES'), 'pt': u('Vila Val\u00e9rio - ES')},
 '495257':{'de': u('H\u00f6velhof'), 'en': u('H\u00f6velhof')},
 '55222791':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '494469':{'de': 'Wangerooge', 'en': 'Wangerooge'},
 '5042424':{'en': u('Sab\u00e1')},
 '494465':{'de': 'Friedeburg Ostfriesland', 'en': 'Friedeburg Ostfriesland'},
 '494464':{'de': 'Wittmund-Carolinensiel', 'en': 'Wittmund-Carolinensiel'},
 '494467':{'de': 'Wittmund-Funnix', 'en': 'Wittmund-Funnix'},
 '494466':{'de': 'Wittmund-Ardorf', 'en': 'Wittmund-Ardorf'},
 '494461':{'de': 'Jever', 'en': 'Jever'},
 '494463':{'de': 'Wangerland', 'en': 'Wangerland'},
 '495250':{'de': u('Delbr\u00fcck Westfalen'), 'en': u('Delbr\u00fcck Westfalen')},
 '55113672':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113673':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113670':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113676':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495253':{'de': 'Bad Driburg', 'en': 'Bad Driburg'},
 '55113674':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113859':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113856':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113857':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113854':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494524':{'de': u('Scharbeutz-P\u00f6nitz'), 'en': u('Scharbeutz-P\u00f6nitz')},
 '55113852':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113853':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113851':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498702':{'de': u('W\u00f6rth an der Isar'), 'en': u('W\u00f6rth an der Isar')},
 '542356':{'en': 'General Pinto, Buenos Aires', 'es': 'General Pinto, Buenos Aires'},
 '542355':{'en': 'Lincoln, Buenos Aires', 'es': 'Lincoln, Buenos Aires'},
 '542354':{'en': 'Vedia, Buenos Aires', 'es': 'Vedia, Buenos Aires'},
 '542353':{'en': 'General Arenales, Buenos Aires', 'es': 'General Arenales, Buenos Aires'},
 '542352':{'en': 'Chacabuco, Buenos Aires', 'es': 'Chacabuco, Buenos Aires'},
 '498722':{'de': 'Gangkofen', 'en': 'Gangkofen'},
 '537':{'en': 'Havana City'},
 '498721':{'de': 'Eggenfelden', 'en': 'Eggenfelden'},
 '498726':{'de': u('Sch\u00f6nau Niederbayern'), 'en': u('Sch\u00f6nau Niederbayern')},
 '498727':{'de': 'Falkenberg Niederbayern', 'en': 'Falkenberg Niederbayern'},
 '498724':{'de': 'Massing', 'en': 'Massing'},
 '542358':{'en': 'Los Toldos, Buenos Aires', 'es': 'Los Toldos, Buenos Aires'},
 '55114081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114082':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114083':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498703':{'de': 'Essenbach', 'en': 'Essenbach'},
 '494609':{'de': 'Eggebek', 'en': 'Eggebek'},
 '494608':{'de': 'Handewitt', 'en': 'Handewitt'},
 '55212421':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323261':{'en': u('S\u00e3o Jo\u00e3o Nepomuceno - MG'), 'pt': u('S\u00e3o Jo\u00e3o Nepomuceno - MG')},
 '494603':{'de': 'Havetoft', 'en': 'Havetoft'},
 '494602':{'de': 'Freienwill', 'en': 'Freienwill'},
 '494605':{'de': 'Medelby', 'en': 'Medelby'},
 '494604':{'de': 'Grossenwiehe', 'en': 'Grossenwiehe'},
 '494607':{'de': 'Janneby', 'en': 'Janneby'},
 '494606':{'de': 'Wanderup', 'en': 'Wanderup'},
 '55163521':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55193465':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55213288':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55283531':{'en': 'Itapemirim - ES', 'pt': 'Itapemirim - ES'},
 '55283533':{'en': 'Rio Novo do Sul - ES', 'pt': 'Rio Novo do Sul - ES'},
 '55283532':{'en': u('Marata\u00edzes - ES'), 'pt': u('Marata\u00edzes - ES')},
 '55283535':{'en': 'Presidente Kennedy - ES', 'pt': 'Presidente Kennedy - ES'},
 '55283534':{'en': 'Anchieta - ES', 'pt': 'Anchieta - ES'},
 '55283537':{'en': 'Iconha - ES', 'pt': 'Iconha - ES'},
 '55283536':{'en': 'Anchieta - ES', 'pt': 'Anchieta - ES'},
 '55283539':{'en': 'Itaoca - ES', 'pt': 'Itaoca - ES'},
 '55283538':{'en': 'Atilio Vivacqua - ES', 'pt': 'Atilio Vivacqua - ES'},
 '55212423':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143722':{'en': u('Tup\u00e3 - SP'), 'pt': u('Tup\u00e3 - SP')},
 '55193216':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193211':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193212':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193213':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '498320':{'de': 'Missen-Wilhams', 'en': 'Missen-Wilhams'},
 '55223081':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55223087':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55173222':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55112103':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112102':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112107':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112106':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112105':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112104':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112108':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212425':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49681':{'de': u('Saarbr\u00fccken'), 'en': u('Saarbr\u00fccken')},
 '55193462':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '494522':{'de': u('Pl\u00f6n'), 'en': u('Pl\u00f6n')},
 '55115599':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115591':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115593':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115592':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115595':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115594':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115845':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543489':{'en': 'Campana, Buenos Aires', 'es': 'Campana, Buenos Aires'},
 '543487':{'en': u('Z\u00e1rate, Buenos Aires'), 'es': u('Z\u00e1rate, Buenos Aires')},
 '543482':{'en': 'Reconquista, Santa Fe', 'es': 'Reconquista, Santa Fe'},
 '543483':{'en': 'Vera, Santa Fe', 'es': 'Vera, Santa Fe'},
 '55193549':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '54364':{'en': u('Presidencia Roque S\u00e1enz Pe\u00f1a, Chaco'), 'es': u('Presidencia Roque S\u00e1enz Pe\u00f1a, Chaco')},
 '54362':{'en': 'Resistencia, Chaco', 'es': 'Resistencia, Chaco'},
 '55213084':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273269':{'en': 'Alfredo Chaves - ES', 'pt': 'Alfredo Chaves - ES'},
 '55213462':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496402':{'de': 'Hungen', 'en': 'Hungen'},
 '55213463':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55273262':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55213018':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183022':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55143453':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '5522':{'en': 'Rio de Janeiro', 'pt': 'Rio de Janeiro'},
 '55114649':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '5524':{'en': 'Rio de Janeiro', 'pt': 'Rio de Janeiro'},
 '55143452':{'en': u('Pomp\u00e9ia - SP'), 'pt': u('Pomp\u00e9ia - SP')},
 '55193841':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55193843':{'en': 'Itapira - SP', 'pt': 'Itapira - SP'},
 '55114641':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114646':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55193844':{'en': u('Paul\u00ednia - SP'), 'pt': u('Paul\u00ednia - SP')},
 '55114644':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114645':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55213014':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183251':{'en': u('Presidente Epit\u00e1cio - SP'), 'pt': u('Presidente Epit\u00e1cio - SP')},
 '55114505':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114504':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114506':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55333291':{'en': 'Coroaci - MG', 'pt': 'Coroaci - MG'},
 '55333292':{'en': 'Marilac - MG', 'pt': 'Marilac - MG'},
 '55114502':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494674':{'de': 'Ockholm', 'en': 'Ockholm'},
 '55114509':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114508':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497172':{'de': u('Lorch W\u00fcrttemberg'), 'en': u('Lorch W\u00fcrttemberg')},
 '497173':{'de': 'Heubach', 'en': 'Heubach'},
 '497171':{'de': u('Schw\u00e4bisch Gm\u00fcnd'), 'en': u('Schw\u00e4bisch Gm\u00fcnd')},
 '497176':{'de': 'Spraitbach', 'en': 'Spraitbach'},
 '497174':{'de': u('M\u00f6gglingen'), 'en': u('M\u00f6gglingen')},
 '497175':{'de': 'Leinzell', 'en': 'Leinzell'},
 '55213504':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213508':{'en': u('Itabora\u00ed - RJ'), 'pt': u('Itabora\u00ed - RJ')},
 '55173453':{'en': 'Cardoso - SP', 'pt': 'Cardoso - SP'},
 '494858':{'de': 'Sankt Margarethen Holstein', 'en': 'Sankt Margarethen Holstein'},
 '494859':{'de': 'Windbergen', 'en': 'Windbergen'},
 '494854':{'de': 'Friedrichskoog', 'en': 'Friedrichskoog'},
 '494855':{'de': 'Eddelak', 'en': 'Eddelak'},
 '494856':{'de': 'Kronprinzenkoog', 'en': 'Kronprinzenkoog'},
 '494857':{'de': 'Barlt', 'en': 'Barlt'},
 '494851':{'de': 'Marne', 'en': 'Marne'},
 '494852':{'de': u('Brunsb\u00fcttel'), 'en': u('Brunsb\u00fcttel')},
 '494853':{'de': 'Sankt Michaelisdonn', 'en': 'Sankt Michaelisdonn'},
 '497394':{'de': 'Schelklingen', 'en': 'Schelklingen'},
 '497395':{'de': u('Ehingen-D\u00e4chingen'), 'en': u('Ehingen-D\u00e4chingen')},
 '497392':{'de': 'Laupheim', 'en': 'Laupheim'},
 '497393':{'de': 'Munderkingen', 'en': 'Munderkingen'},
 '497391':{'de': 'Ehingen Donau', 'en': 'Ehingen Donau'},
 '55133477':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133474':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133472':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133473':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133471':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133478':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133479':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55153249':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55153248':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '55153247':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '55153246':{'en': u('Ces\u00e1rio Lange - SP'), 'pt': u('Ces\u00e1rio Lange - SP')},
 '55153245':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '55153244':{'en': 'Piedade - SP', 'pt': 'Piedade - SP'},
 '55153243':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '55153242':{'en': 'Votorantim - SP', 'pt': 'Votorantim - SP'},
 '55153241':{'en': u('Ibi\u00fana - SP'), 'pt': u('Ibi\u00fana - SP')},
 '499648':{'de': 'Neustadt am Kulm', 'en': 'Neustadt am Kulm'},
 '499646':{'de': 'Freihung', 'en': 'Freihung'},
 '499647':{'de': 'Kirchenthumbach', 'en': 'Kirchenthumbach'},
 '499644':{'de': 'Pressath', 'en': 'Pressath'},
 '499645':{'de': 'Eschenbach in der Oberpfalz', 'en': 'Eschenbach in der Oberpfalz'},
 '499642':{'de': 'Kemnath Stadt', 'en': 'Kemnath Stadt'},
 '499643':{'de': 'Auerbach in der Oberpfalz', 'en': 'Auerbach in der Oberpfalz'},
 '499641':{'de': u('Grafenw\u00f6hr'), 'en': u('Grafenw\u00f6hr')},
 '497821':{'de': 'Lahr Schwarzwald', 'en': 'Lahr Schwarzwald'},
 '497822':{'de': 'Ettenheim', 'en': 'Ettenheim'},
 '497823':{'de': 'Seelbach Schutter', 'en': 'Seelbach Schutter'},
 '497824':{'de': 'Schwanau', 'en': 'Schwanau'},
 '497825':{'de': 'Kippenheim', 'en': 'Kippenheim'},
 '497826':{'de': 'Schuttertal', 'en': 'Schuttertal'},
 '55222732':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55163501':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163506':{'en': u('Mat\u00e3o - SP'), 'pt': u('Mat\u00e3o - SP')},
 '55113999':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113998':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113997':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163509':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55113994':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113993':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113992':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113991':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113990':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55314062':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55222733':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '499398':{'de': u('Birkenfeld bei W\u00fcrzburg'), 'en': u('Birkenfeld bei W\u00fcrzburg')},
 '499468':{'de': 'Zell Oberpfalz', 'en': 'Zell Oberpfalz'},
 '499469':{'de': u('Roding-Neub\u00e4u'), 'en': u('Roding-Neub\u00e4u')},
 '499462':{'de': 'Falkenstein Oberpfalz', 'en': 'Falkenstein Oberpfalz'},
 '499391':{'de': 'Marktheidenfeld', 'en': 'Marktheidenfeld'},
 '499392':{'de': 'Faulbach Unterfranken', 'en': 'Faulbach Unterfranken'},
 '499393':{'de': 'Rothenfels Unterfranken', 'en': 'Rothenfels Unterfranken'},
 '499394':{'de': 'Esselbach', 'en': 'Esselbach'},
 '499395':{'de': 'Triefenstein', 'en': 'Triefenstein'},
 '49761':{'de': 'Freiburg im Breisgau', 'en': 'Freiburg im Breisgau'},
 '49760':{'de': 'Oberried Breisgau', 'en': 'Oberried Breisgau'},
 '52481':{'en': 'Ciudad Valles, SLP', 'es': 'Ciudad Valles, SLP'},
 '55143546':{'en': 'Sabino - SP', 'pt': 'Sabino - SP'},
 '55113192':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113191':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113198':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313381':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313383':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112828':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112829':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55313388':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313389':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112827':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112822':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55193539':{'en': 'Ajapi - SP', 'pt': 'Ajapi - SP'},
 '55193538':{'en': 'Ajapi - SP', 'pt': 'Ajapi - SP'},
 '55193531':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193533':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193532':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193535':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193534':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193537':{'en': u('Ipe\u00fana - SP'), 'pt': u('Ipe\u00fana - SP')},
 '55193536':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193026':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55113339':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113338':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52738':{'en': 'Mixquiahuala/Tepatepec, HGO', 'es': 'Mixquiahuala/Tepatepec, HGO'},
 '52739':{'en': 'Huitzilac/Tepoztlan, MOR', 'es': 'Huitzilac/Tepoztlan, MOR'},
 '52734':{'en': 'Morelos', 'es': 'Morelos'},
 '52735':{'en': 'Cuautla/Jonacatepec, MOR', 'es': 'Cuautla/Jonacatepec, MOR'},
 '52736':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52737':{'en': 'Morelos', 'es': 'Morelos'},
 '55113337':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52731':{'en': 'Morelos', 'es': 'Morelos'},
 '52732':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52733':{'en': 'Iguala, GRO', 'es': 'Iguala, GRO'},
 '55213348':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213342':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213341':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213340':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213347':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213346':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193557':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193556':{'en': u('Cordeir\u00f3polis - SP'), 'pt': u('Cordeir\u00f3polis - SP')},
 '55193554':{'en': 'Leme - SP', 'pt': 'Leme - SP'},
 '55114871':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114873':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114878':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55193552':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '495431':{'de': u('Quakenbr\u00fcck'), 'en': u('Quakenbr\u00fcck')},
 '495433':{'de': 'Badbergen', 'en': 'Badbergen'},
 '495432':{'de': u('L\u00f6ningen'), 'en': u('L\u00f6ningen')},
 '495435':{'de': u('Berge bei Quakenbr\u00fcck'), 'en': u('Berge bei Quakenbr\u00fcck')},
 '495434':{'de': 'Essen Oldenburg', 'en': 'Essen Oldenburg'},
 '495437':{'de': 'Menslage', 'en': 'Menslage'},
 '495436':{'de': 'Nortrup', 'en': 'Nortrup'},
 '495439':{'de': u('Bersenbr\u00fcck'), 'en': u('Bersenbr\u00fcck')},
 '495438':{'de': u('Bakum-L\u00fcsche'), 'en': u('Bakum-L\u00fcsche')},
 '52758':{'en': 'Petatlan/San Jeronimito, GRO', 'es': 'Petatlan/San Jeronimito, GRO'},
 '52759':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52753':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55213754':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55213755':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55213756':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55213757':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55213752':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55213753':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '55112318':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112319':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112317':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112312':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55123671':{'en': u('S\u00e3o Lu\u00eds do Paraitinga - SP'), 'pt': u('S\u00e3o Lu\u00eds do Paraitinga - SP')},
 '55123894':{'en': 'Ilhabela - SP', 'pt': 'Ilhabela - SP'},
 '55123897':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123672':{'en': u('Trememb\u00e9 - SP'), 'pt': u('Trememb\u00e9 - SP')},
 '55123891':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55123674':{'en': u('Trememb\u00e9 - SP'), 'pt': u('Trememb\u00e9 - SP')},
 '55123677':{'en': 'Natividade da Serra - SP', 'pt': 'Natividade da Serra - SP'},
 '55123676':{'en': u('Reden\u00e7\u00e3o da Serra - SP'), 'pt': u('Reden\u00e7\u00e3o da Serra - SP')},
 '55123678':{'en': 'Natividade da Serra - SP', 'pt': 'Natividade da Serra - SP'},
 '55222741':{'en': u('S\u00e3o Jo\u00e3o da Barra - RJ'), 'pt': u('S\u00e3o Jo\u00e3o da Barra - RJ')},
 '55222747':{'en': u('Farol de S\u00e3o Tom\u00e9 - RJ'), 'pt': u('Farol de S\u00e3o Tom\u00e9 - RJ')},
 '55213870':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323367':{'en': 'Alfredo Vasconcelos - MG', 'pt': 'Alfredo Vasconcelos - MG'},
 '55243373':{'en': 'Paraty - RJ', 'pt': 'Paraty - RJ'},
 '55243372':{'en': 'Paraty - RJ', 'pt': 'Paraty - RJ'},
 '55243371':{'en': 'Paraty - RJ', 'pt': 'Paraty - RJ'},
 '55243370':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55243377':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55323366':{'en': 'Oliveira Fortes - MG', 'pt': 'Oliveira Fortes - MG'},
 '496166':{'de': 'Fischbachtal', 'en': 'Fischbachtal'},
 '496167':{'de': 'Modautal', 'en': 'Modautal'},
 '496164':{'de': 'Reichelsheim Odenwald', 'en': 'Reichelsheim Odenwald'},
 '496165':{'de': 'Breuberg', 'en': 'Breuberg'},
 '496162':{'de': 'Reinheim Odenwald', 'en': 'Reinheim Odenwald'},
 '496163':{'de': u('H\u00f6chst im Odenwald'), 'en': u('H\u00f6chst im Odenwald')},
 '496161':{'de': 'Brensbach', 'en': 'Brensbach'},
 '55115049':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115044':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115042':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115041':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313819':{'en': 'Ponte Nova - MG', 'pt': 'Ponte Nova - MG'},
 '55273371':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55273372':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55273373':{'en': 'Linhares - ES', 'pt': 'Linhares - ES'},
 '55313817':{'en': 'Ponte Nova - MG', 'pt': 'Ponte Nova - MG'},
 '55173843':{'en': 'Ouroeste - SP', 'pt': 'Ouroeste - SP'},
 '55173842':{'en': u('Indiapor\u00e3 - SP'), 'pt': u('Indiapor\u00e3 - SP')},
 '496708':{'de': u('Bad M\u00fcnster am Stein-Ebernburg'), 'en': u('Bad M\u00fcnster am Stein-Ebernburg')},
 '496709':{'de': u('F\u00fcrfeld Kreis Bad Kreuznach'), 'en': u('F\u00fcrfeld Kreis Bad Kreuznach')},
 '55173847':{'en': 'Floreal - SP', 'pt': 'Floreal - SP'},
 '55173846':{'en': 'Mira Estrela - SP', 'pt': 'Mira Estrela - SP'},
 '55173845':{'en': 'Meridiano - SP', 'pt': 'Meridiano - SP'},
 '55173844':{'en': 'Pontes Gestal - SP', 'pt': 'Pontes Gestal - SP'},
 '496703':{'de': u('W\u00f6llstein Rheinhessen'), 'en': u('W\u00f6llstein Rheinhessen')},
 '55173849':{'en': u('Maced\u00f4nia - SP'), 'pt': u('Maced\u00f4nia - SP')},
 '496701':{'de': 'Sprendlingen Rheinhessen', 'en': 'Sprendlingen Rheinhessen'},
 '496706':{'de': 'Wallhausen Nahe', 'en': 'Wallhausen Nahe'},
 '496707':{'de': 'Windesheim', 'en': 'Windesheim'},
 '496704':{'de': 'Langenlonsheim', 'en': 'Langenlonsheim'},
 '55193408':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55273270':{'en': 'Barra do Riacho - ES', 'pt': 'Barra do Riacho - ES'},
 '55133313':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133312':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133311':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133317':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133316':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133862':{'en': u('Coloniza\u00e7\u00e3o - SP'), 'pt': u('Coloniza\u00e7\u00e3o - SP')},
 '55133319':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55323338':{'en': 'Madre de Deus de Minas - MG', 'pt': 'Madre de Deus de Minas - MG'},
 '55323339':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55323332':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55323333':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55323330':{'en': 'Correia de Almeida - MG', 'pt': 'Correia de Almeida - MG'},
 '55323331':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55323336':{'en': 'Desterro do Melo - MG', 'pt': 'Desterro do Melo - MG'},
 '55323337':{'en': u('Merc\u00eas - MG'), 'pt': u('Merc\u00eas - MG')},
 '55323334':{'en': u('Santana do Garamb\u00e9u - MG'), 'pt': u('Santana do Garamb\u00e9u - MG')},
 '55323335':{'en': 'Piedade do Rio Grande - MG', 'pt': 'Piedade do Rio Grande - MG'},
 '494447':{'de': u('Vechta-Langf\u00f6rden'), 'en': u('Vechta-Langf\u00f6rden')},
 '494446':{'de': 'Bakum Kreis Vechta', 'en': 'Bakum Kreis Vechta'},
 '494445':{'de': 'Visbek Kreis Vechta', 'en': 'Visbek Kreis Vechta'},
 '494444':{'de': 'Goldenstedt', 'en': 'Goldenstedt'},
 '494443':{'de': 'Dinklage', 'en': 'Dinklage'},
 '494442':{'de': 'Lohne Oldenburg', 'en': 'Lohne Oldenburg'},
 '494441':{'de': 'Vechta', 'en': 'Vechta'},
 '55114317':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542252':{'en': u('San Clemente del Tuy\u00fa, Buenos Aires'), 'es': u('San Clemente del Tuy\u00fa, Buenos Aires')},
 '542257':{'en': u('Mar de Aj\u00f3, Buenos Aires'), 'es': u('Mar de Aj\u00f3, Buenos Aires')},
 '542254':{'en': 'Pinamar, Buenos Aires', 'es': 'Pinamar, Buenos Aires'},
 '542255':{'en': 'Villa Gesell, Buenos Aires', 'es': 'Villa Gesell, Buenos Aires'},
 '55193887':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '498704':{'de': 'Altdorf-Pfettrach', 'en': 'Altdorf-Pfettrach'},
 '498257':{'de': 'Inchenhofen', 'en': 'Inchenhofen'},
 '498254':{'de': u('Altom\u00fcnster'), 'en': u('Altom\u00fcnster')},
 '498707':{'de': 'Adlkofen', 'en': 'Adlkofen'},
 '498252':{'de': 'Schrobenhausen', 'en': 'Schrobenhausen'},
 '498253':{'de': u('P\u00f6ttmes'), 'en': u('P\u00f6ttmes')},
 '498250':{'de': 'Hilgertshausen-Tandern', 'en': 'Hilgertshausen-Tandern'},
 '498251':{'de': 'Aichach', 'en': 'Aichach'},
 '498708':{'de': 'Weihmichl-Unterneuhausen', 'en': 'Weihmichl-Unterneuhausen'},
 '498709':{'de': 'Eching Niederbayern', 'en': 'Eching Niederbayern'},
 '498258':{'de': 'Sielenbach', 'en': 'Sielenbach'},
 '498259':{'de': 'Schiltberg', 'en': 'Schiltberg'},
 '542331':{'en': u('Realic\u00f3, La Pampa'), 'es': u('Realic\u00f3, La Pampa')},
 '542333':{'en': u('Quem\u00fa Quem\u00fa, La Pampa'), 'es': u('Quem\u00fa Quem\u00fa, La Pampa')},
 '542335':{'en': u('Realic\u00f3/Rancul Dept., La Pampa'), 'es': u('Dpto. Realic\u00f3/Rancul, La Pampa')},
 '542334':{'en': 'Eduardo Castex, La Pampa', 'es': 'Eduardo Castex, La Pampa'},
 '542337':{'en': u('Am\u00e9rica/Rivadavia, Buenos Aires'), 'es': u('Am\u00e9rica/Rivadavia, Buenos Aires')},
 '542336':{'en': u('Huinca Renanc\u00f3/Villa Huidobro, C\u00f3rdoba'), 'es': u('Huinca Renanc\u00f3/Villa Huidobro, C\u00f3rdoba')},
 '542338':{'en': 'Victorica, La Pampa', 'es': 'Victorica, La Pampa'},
 '55313394':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '494623':{'de': u('B\u00f6klund'), 'en': u('B\u00f6klund')},
 '494622':{'de': 'Taarstedt', 'en': 'Taarstedt'},
 '494621':{'de': 'Schleswig', 'en': 'Schleswig'},
 '55173664':{'en': u('Asp\u00e1sia - SP'), 'pt': u('Asp\u00e1sia - SP')},
 '494627':{'de': u('D\u00f6rpstedt'), 'en': u('D\u00f6rpstedt')},
 '494626':{'de': 'Treia', 'en': 'Treia'},
 '494625':{'de': u('J\u00fcbek'), 'en': u('J\u00fcbek')},
 '494624':{'de': 'Kropp', 'en': 'Kropp'},
 '55313681':{'en': 'Lagoa Santa - MG', 'pt': 'Lagoa Santa - MG'},
 '55173271':{'en': 'Neves Paulista - SP', 'pt': 'Neves Paulista - SP'},
 '55312557':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55312559':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '497751':{'de': 'Waldshut', 'en': 'Waldshut'},
 '55283557':{'en': u('Apiac\u00e1 - ES'), 'pt': u('Apiac\u00e1 - ES')},
 '55283556':{'en': u('S\u00e3o Jos\u00e9 do Cal\u00e7ado - ES'), 'pt': u('S\u00e3o Jos\u00e9 do Cal\u00e7ado - ES')},
 '55283555':{'en': 'Mimoso do Sul - ES', 'pt': 'Mimoso do Sul - ES'},
 '55283554':{'en': 'Muqui - ES', 'pt': 'Muqui - ES'},
 '55283553':{'en': u('Gua\u00e7u\u00ed - ES'), 'pt': u('Gua\u00e7u\u00ed - ES')},
 '55283552':{'en': 'Alegre - ES', 'pt': 'Alegre - ES'},
 '55283551':{'en': u('Divino de S\u00e3o Louren\u00e7o - ES'), 'pt': u('Divino de S\u00e3o Louren\u00e7o - ES')},
 '55283559':{'en': 'Dores do Rio Preto - ES', 'pt': 'Dores do Rio Preto - ES'},
 '55283558':{'en': u('Jer\u00f4nimo Monteiro - ES'), 'pt': u('Jer\u00f4nimo Monteiro - ES')},
 '55193232':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193233':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55143473':{'en': u('Alvinl\u00e2ndia - SP'), 'pt': u('Alvinl\u00e2ndia - SP')},
 '55193231':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193236':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193237':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193234':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '494330':{'de': 'Emkendorf', 'en': 'Emkendorf'},
 '55213633':{'en': 'Guapimirim - RJ', 'pt': 'Guapimirim - RJ'},
 '55193238':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193239':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55213632':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55112121':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112123':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112125':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112124':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112127':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112126':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499075':{'de': u('Gl\u00f6tt'), 'en': u('Gl\u00f6tt')},
 '499074':{'de': u('H\u00f6chst\u00e4dt an der Donau'), 'en': u('H\u00f6chst\u00e4dt an der Donau')},
 '499077':{'de': 'Bachhagel', 'en': 'Bachhagel'},
 '499076':{'de': 'Wittislingen', 'en': 'Wittislingen'},
 '499071':{'de': 'Dillingen an der Donau', 'en': 'Dillingen an der Donau'},
 '499070':{'de': 'Tapfheim', 'en': 'Tapfheim'},
 '499073':{'de': 'Gundelfingen an der Donau', 'en': 'Gundelfingen an der Donau'},
 '499072':{'de': 'Lauingen Donau', 'en': 'Lauingen Donau'},
 '499078':{'de': 'Mertingen', 'en': 'Mertingen'},
 '55212722':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55133398':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55193488':{'en': 'Mombuca - SP', 'pt': 'Mombuca - SP'},
 '55212721':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55163711':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55214501':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49951':{'de': 'Bamberg', 'en': 'Bamberg'},
 '5042558':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5042559':{'en': u('Col. Sat\u00e9lite')},
 '5042552':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5042553':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5042550':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5042556':{'en': 'La Puerta'},
 '5042557':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5042555':{'en': 'Rivera Hernandez, San Pedro Sula'},
 '55193498':{'en': 'Nova Odessa - SP', 'pt': 'Nova Odessa - SP'},
 '55193499':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55193496':{'en': 'Rafard - SP', 'pt': 'Rafard - SP'},
 '55193497':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55193494':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55193495':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55193492':{'en': 'Capivari - SP', 'pt': 'Capivari - SP'},
 '55193493':{'en': 'Rio das Pedras - SP', 'pt': 'Rio das Pedras - SP'},
 '55193491':{'en': 'Capivari - SP', 'pt': 'Capivari - SP'},
 '55173329':{'en': 'Alberto Moreira - SP', 'pt': 'Alberto Moreira - SP'},
 '496571':{'de': 'Wittlich', 'en': 'Wittlich'},
 '54342':{'en': 'Santa Fe, Santa Fe', 'es': 'Santa Fe, Santa Fe'},
 '496573':{'de': 'Gillenfeld', 'en': 'Gillenfeld'},
 '496572':{'de': 'Manderscheid Eifel', 'en': 'Manderscheid Eifel'},
 '496575':{'de': 'Landscheid', 'en': 'Landscheid'},
 '496574':{'de': 'Hasborn', 'en': 'Hasborn'},
 '54345':{'en': u('Concordia, Entre R\u00edos'), 'es': u('Concordia, Entre R\u00edos')},
 '55143303':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
 '496578':{'de': 'Salmtal', 'en': 'Salmtal'},
 '54348':{'en': 'Escobar, Buenos Aires', 'es': 'Escobar, Buenos Aires'},
 '55143307':{'en': 'Ibirarema - SP', 'pt': 'Ibirarema - SP'},
 '55143305':{'en': 'Piraju - SP', 'pt': 'Piraju - SP'},
 '55212697':{'en': 'Mesquita - RJ', 'pt': 'Mesquita - RJ'},
 '55212692':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55212693':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55212691':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55333235':{'en': 'Tumiritinga - MG', 'pt': 'Tumiritinga - MG'},
 '55222009':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55193829':{'en': 'Valinhos - SP', 'pt': 'Valinhos - SP'},
 '55193828':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55193827':{'en': 'Artur Nogueira - SP', 'pt': 'Artur Nogueira - SP'},
 '55193826':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55193825':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193824':{'en': u('\u00c1guas de Lind\u00f3ia - SP'), 'pt': u('\u00c1guas de Lind\u00f3ia - SP')},
 '55193822':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55193821':{'en': 'Elias Fausto - SP', 'pt': 'Elias Fausto - SP'},
 '495376':{'de': 'Wesendorf Kreis Gifhorn', 'en': 'Wesendorf Kreis Gifhorn'},
 '495377':{'de': 'Ehra-Lessien', 'en': 'Ehra-Lessien'},
 '495374':{'de': u('Isenb\u00fcttel'), 'en': u('Isenb\u00fcttel')},
 '495375':{'de': u('M\u00fcden Aller'), 'en': u('M\u00fcden Aller')},
 '495372':{'de': 'Meinersen', 'en': 'Meinersen'},
 '495373':{'de': 'Hillerse Kreis Gifhorn', 'en': 'Hillerse Kreis Gifhorn'},
 '495371':{'de': 'Gifhorn', 'en': 'Gifhorn'},
 '495378':{'de': 'Sassenburg-Platendorf', 'en': 'Sassenburg-Platendorf'},
 '495379':{'de': 'Sassenburg-Grussendorf', 'en': 'Sassenburg-Grussendorf'},
 '496395':{'de': u('M\u00fcnchweiler an der Rodalb'), 'en': u('M\u00fcnchweiler an der Rodalb')},
 '496394':{'de': 'Bundenthal', 'en': 'Bundenthal'},
 '496397':{'de': 'Leimen Pfalz', 'en': 'Leimen Pfalz'},
 '496396':{'de': 'Hinterweidenthal', 'en': 'Hinterweidenthal'},
 '496391':{'de': 'Dahn', 'en': 'Dahn'},
 '496393':{'de': 'Fischbach bei Dahn', 'en': 'Fischbach bei Dahn'},
 '496392':{'de': 'Hauenstein Pfalz', 'en': 'Hauenstein Pfalz'},
 '496398':{'de': 'Vorderweidenthal', 'en': 'Vorderweidenthal'},
 '55143813':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55143812':{'en': u('S\u00e3o Manuel - SP'), 'pt': u('S\u00e3o Manuel - SP')},
 '497158':{'de': 'Neuhausen auf den Fildern', 'en': 'Neuhausen auf den Fildern'},
 '497159':{'de': 'Renningen', 'en': 'Renningen'},
 '497628':{'de': 'Efringen-Kirchen', 'en': 'Efringen-Kirchen'},
 '497629':{'de': 'Tegernau Baden', 'en': 'Tegernau Baden'},
 '497154':{'de': 'Kornwestheim', 'en': 'Kornwestheim'},
 '497627':{'de': u('Steinen Kreis L\u00f6rrach'), 'en': u('Steinen Kreis L\u00f6rrach')},
 '497156':{'de': 'Ditzingen', 'en': 'Ditzingen'},
 '497157':{'de': 'Waldenbuch', 'en': 'Waldenbuch'},
 '497150':{'de': u('Korntal-M\u00fcnchingen'), 'en': u('Korntal-M\u00fcnchingen')},
 '497151':{'de': 'Waiblingen', 'en': 'Waiblingen'},
 '497152':{'de': u('Leonberg W\u00fcrttemberg'), 'en': u('Leonberg W\u00fcrttemberg')},
 '497153':{'de': 'Plochingen', 'en': 'Plochingen'},
 '55143815':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55143814':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55213568':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55173472':{'en': 'Nhandeara - SP', 'pt': 'Nhandeara - SP'},
 '55173475':{'en': 'Meridiano - SP', 'pt': 'Meridiano - SP'},
 '55283036':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55283037':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55212681':{'en': u('Serop\u00e9dica - RJ'), 'pt': u('Serop\u00e9dica - RJ')},
 '498728':{'de': 'Geratskirchen', 'en': 'Geratskirchen'},
 '55212680':{'en': 'Mangaratiba - RJ', 'pt': 'Mangaratiba - RJ'},
 '55212682':{'en': u('Serop\u00e9dica - RJ'), 'pt': u('Serop\u00e9dica - RJ')},
 '55133418':{'en': 'Itariri - SP', 'pt': 'Itariri - SP'},
 '55133419':{'en': 'Pedro de Toledo - SP', 'pt': 'Pedro de Toledo - SP'},
 '55212685':{'en': 'Mangaratiba - RJ', 'pt': 'Mangaratiba - RJ'},
 '55133416':{'en': 'Ana Dias - SP', 'pt': 'Ana Dias - SP'},
 '496541':{'de': 'Traben-Trarbach', 'en': 'Traben-Trarbach'},
 '55192112':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55115787':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212687':{'en': u('Itagua\u00ed - RJ'), 'pt': u('Itagua\u00ed - RJ')},
 '55193725':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '54353':{'en': u('Villa Mar\u00eda, C\u00f3rdoba'), 'es': u('Villa Mar\u00eda, C\u00f3rdoba')},
 '55153264':{'en': u('\u00c1guia da Castelo - SP'), 'pt': u('\u00c1guia da Castelo - SP')},
 '55153267':{'en': 'Capela do Alto - SP', 'pt': 'Capela do Alto - SP'},
 '55153266':{'en': u('Iper\u00f3 - SP'), 'pt': u('Iper\u00f3 - SP')},
 '55153261':{'en': 'Porto Feliz - SP', 'pt': 'Porto Feliz - SP'},
 '55153263':{'en': 'Boituva - SP', 'pt': 'Boituva - SP'},
 '55153262':{'en': 'Porto Feliz - SP', 'pt': 'Porto Feliz - SP'},
 '55153268':{'en': 'Boituva - SP', 'pt': 'Boituva - SP'},
 '55193721':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193723':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '52938':{'en': 'Ciudad Del Carmen, CAMP', 'es': 'Ciudad del Carmen, CAMP'},
 '52936':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52937':{'en': 'Cardenas, TAB', 'es': u('C\u00e1rdenas, TAB')},
 '52934':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52932':{'en': 'Chiapas/Tabasco', 'es': 'Chiapas/Tabasco'},
 '52933':{'en': 'Tabasco', 'es': 'Tabasco'},
 '498139':{'de': u('R\u00f6hrmoos'), 'en': u('R\u00f6hrmoos')},
 '498138':{'de': 'Schwabhausen bei Dachau', 'en': 'Schwabhausen bei Dachau'},
 '498133':{'de': 'Haimhausen Oberbayern', 'en': 'Haimhausen Oberbayern'},
 '498131':{'de': 'Dachau', 'en': 'Dachau'},
 '498137':{'de': 'Petershausen', 'en': 'Petershausen'},
 '498136':{'de': 'Markt Indersdorf', 'en': 'Markt Indersdorf'},
 '498135':{'de': 'Sulzemoos', 'en': 'Sulzemoos'},
 '498134':{'de': 'Odelzhausen', 'en': 'Odelzhausen'},
 '499661':{'de': 'Sulzbach-Rosenberg', 'en': 'Sulzbach-Rosenberg'},
 '499662':{'de': 'Vilseck', 'en': 'Vilseck'},
 '499663':{'de': 'Neukirchen bei Sulzbach-Rosenberg', 'en': 'Neukirchen bei Sulzbach-Rosenberg'},
 '499664':{'de': 'Hahnbach', 'en': 'Hahnbach'},
 '499665':{'de': u('K\u00f6nigstein Oberpfalz'), 'en': u('K\u00f6nigstein Oberpfalz')},
 '499666':{'de': 'Illschwang', 'en': 'Illschwang'},
 '497842':{'de': 'Kappelrodeck', 'en': 'Kappelrodeck'},
 '497843':{'de': 'Renchen', 'en': 'Renchen'},
 '497841':{'de': 'Achern', 'en': 'Achern'},
 '55163524':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '497844':{'de': 'Rheinau', 'en': 'Rheinau'},
 '498395':{'de': u('Tannheim W\u00fcrttemberg'), 'en': u('Tannheim W\u00fcrttemberg')},
 '498394':{'de': 'Lautrach', 'en': 'Lautrach'},
 '498393':{'de': u('Holzg\u00fcnz'), 'en': u('Holzg\u00fcnz')},
 '498392':{'de': 'Markt Rettenbach', 'en': 'Markt Rettenbach'},
 '55213987':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313014':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213980':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213982':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183401':{'en': u('Valpara\u00edso - SP'), 'pt': u('Valpara\u00edso - SP')},
 '55183402':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55183406':{'en': 'Guararapes - SP', 'pt': 'Guararapes - SP'},
 '55193526':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55112803':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114129':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114128':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112806':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55112807':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55112805':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114123':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114122':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114121':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112809':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114127':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114126':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114125':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114124':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '5296':{'en': 'Chiapas', 'es': 'Chiapas'},
 '5297':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '55193555':{'en': 'Leme - SP', 'pt': 'Leme - SP'},
 '5295':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '55193000':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55193551':{'en': 'Araras - SP', 'pt': 'Araras - SP'},
 '55113311':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113313':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113312':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113315':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113314':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113316':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113319':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113318':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52751':{'en': 'Morelos', 'es': 'Morelos'},
 '52756':{'en': 'Chilapa/Olinala, GRO', 'es': u('Chilapa/Olinal\u00e1, GRO')},
 '52757':{'en': 'Huamuxtitlan/Tlapa de Comonfort, GRO', 'es': 'Huamuxtitlan/Tlapa de Comonfort, GRO'},
 '52754':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52755':{'en': 'Ixtapa/Zihuatanejo, GRO', 'es': 'Ixtapa/Zihuatanejo, GRO'},
 '55213361':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213363':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213362':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213365':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213364':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193882':{'en': u('Cosm\u00f3polis - SP'), 'pt': u('Cosm\u00f3polis - SP')},
 '55213369':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499444':{'de': 'Siegenburg', 'en': 'Siegenburg'},
 '499445':{'de': 'Neustadt an der Donau', 'en': 'Neustadt an der Donau'},
 '499446':{'de': 'Altmannstein', 'en': 'Altmannstein'},
 '499447':{'de': 'Essing', 'en': 'Essing'},
 '499441':{'de': 'Kelheim', 'en': 'Kelheim'},
 '499442':{'de': 'Riedenburg', 'en': 'Riedenburg'},
 '499443':{'de': 'Abensberg', 'en': 'Abensberg'},
 '499448':{'de': 'Hausen Niederbayern', 'en': 'Hausen Niederbayern'},
 '499120':{'de': 'Leinburg', 'en': 'Leinburg'},
 '55193522':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55193812':{'en': u('Cosm\u00f3polis - SP'), 'pt': u('Cosm\u00f3polis - SP')},
 '55113297':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495149':{'de': 'Wienhausen', 'en': 'Wienhausen'},
 '495148':{'de': 'Steinhorst Niedersachsen', 'en': 'Steinhorst Niedersachsen'},
 '55193813':{'en': 'Itapira - SP', 'pt': 'Itapira - SP'},
 '495145':{'de': 'Beedenbostel', 'en': 'Beedenbostel'},
 '495144':{'de': 'Wathlingen', 'en': 'Wathlingen'},
 '495147':{'de': u('Uetze-H\u00e4nigsen'), 'en': u('Uetze-H\u00e4nigsen')},
 '495146':{'de': 'Wietze', 'en': 'Wietze'},
 '495141':{'de': 'Celle', 'en': 'Celle'},
 '495143':{'de': 'Winsen Aller', 'en': 'Winsen Aller'},
 '495142':{'de': 'Eschede', 'en': 'Eschede'},
 '55115102':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193523':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55113292':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499128':{'de': 'Feucht', 'en': 'Feucht'},
 '55222580':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55213773':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55213774':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55115105':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193818':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55193819':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55112378':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55222760':{'en': 'Rio das Ostras - RJ', 'pt': 'Rio das Ostras - RJ'},
 '55222762':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55222765':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55222764':{'en': 'Rio das Ostras - RJ', 'pt': 'Rio das Ostras - RJ'},
 '55222767':{'en': 'Cambuci - RJ', 'pt': 'Cambuci - RJ'},
 '55222768':{'en': u('Quissam\u00e3 - RJ'), 'pt': u('Quissam\u00e3 - RJ')},
 '55243358':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55243351':{'en': 'Itatiaia - RJ', 'pt': 'Itatiaia - RJ'},
 '55243353':{'en': 'Porto Real - RJ', 'pt': 'Porto Real - RJ'},
 '55243352':{'en': 'Itatiaia - RJ', 'pt': 'Itatiaia - RJ'},
 '55243355':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55243354':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55243357':{'en': 'Resende - RJ', 'pt': 'Resende - RJ'},
 '55243356':{'en': 'Pinheiral - RJ', 'pt': 'Pinheiral - RJ'},
 '55212579':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212578':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212573':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212572':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496142':{'de': u('R\u00fcsselsheim'), 'en': u('R\u00fcsselsheim')},
 '497579':{'de': 'Schwenningen Baden', 'en': 'Schwenningen Baden'},
 '496144':{'de': u('Bischofsheim bei R\u00fcsselsheim'), 'en': u('Bischofsheim bei R\u00fcsselsheim')},
 '496145':{'de': u('Fl\u00f6rsheim am Main'), 'en': u('Fl\u00f6rsheim am Main')},
 '496146':{'de': 'Hochheim am Main', 'en': 'Hochheim am Main'},
 '496147':{'de': 'Trebur', 'en': 'Trebur'},
 '55115066':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115061':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115063':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115068':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496724':{'de': u('Stromberg Hunsr\u00fcck'), 'en': u('Stromberg Hunsr\u00fcck')},
 '496725':{'de': 'Gau-Algesheim', 'en': 'Gau-Algesheim'},
 '496726':{'de': 'Lorch Rheingau', 'en': 'Lorch Rheingau'},
 '496727':{'de': 'Gensingen', 'en': 'Gensingen'},
 '496721':{'de': 'Bingen am Rhein', 'en': 'Bingen am Rhein'},
 '496722':{'de': u('R\u00fcdesheim am Rhein'), 'en': u('R\u00fcdesheim am Rhein')},
 '496723':{'de': 'Oestrich-Winkel', 'en': 'Oestrich-Winkel'},
 '55313836':{'en': u('Itamb\u00e9 do Mato Dentro - MG'), 'pt': u('Itamb\u00e9 do Mato Dentro - MG')},
 '55273357':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273354':{'en': 'Viana - ES', 'pt': 'Viana - ES'},
 '55273355':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '496728':{'de': 'Ober-Hilbersheim', 'en': 'Ober-Hilbersheim'},
 '55313833':{'en': u('S\u00e3o Gon\u00e7alo do Rio Abaixo - MG'), 'pt': u('S\u00e3o Gon\u00e7alo do Rio Abaixo - MG')},
 '55273350':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55313831':{'en': 'Itabira - MG', 'pt': 'Itabira - MG'},
 '55213267':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212571':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313956':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55212570':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212577':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212576':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212575':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212574':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498094':{'de': u('Steinh\u00f6ring'), 'en': u('Steinh\u00f6ring')},
 '498095':{'de': 'Aying', 'en': 'Aying'},
 '55312102':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '498091':{'de': 'Kirchseeon', 'en': 'Kirchseeon'},
 '498092':{'de': u('Grafing bei M\u00fcnchen'), 'en': u('Grafing bei M\u00fcnchen')},
 '498093':{'de': 'Glonn Kreis Ebersberg', 'en': 'Glonn Kreis Ebersberg'},
 '55323342':{'en': 'Santa Rita de Ibitipoca - MG', 'pt': 'Santa Rita de Ibitipoca - MG'},
 '542274':{'en': 'Carlos Spegazzini, Buenos Aires', 'es': 'Carlos Spegazzini, Buenos Aires'},
 '542271':{'en': 'San Miguel del Monte, Buenos Aires', 'es': 'San Miguel del Monte, Buenos Aires'},
 '542272':{'en': 'Navarro, Buenos Aires', 'es': 'Navarro, Buenos Aires'},
 '542273':{'en': 'Carmen de Areco, Buenos Aires', 'es': 'Carmen de Areco, Buenos Aires'},
 '55273767':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '55313486':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273765':{'en': 'Pinheiros - ES', 'pt': 'Pinheiros - ES'},
 '55273764':{'en': u('Pedro Can\u00e1rio - ES'), 'pt': u('Pedro Can\u00e1rio - ES')},
 '55273763':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '55273762':{'en': u('Concei\u00e7\u00e3o da Barra - ES'), 'pt': u('Concei\u00e7\u00e3o da Barra - ES')},
 '55273761':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '494421':{'de': 'Wilhelmshaven', 'en': 'Wilhelmshaven'},
 '55114337':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '494423':{'de': 'Fedderwarden', 'en': 'Fedderwarden'},
 '55114335':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114332':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55173392':{'en': 'Viradouro - SP', 'pt': 'Viradouro - SP'},
 '55114330':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '494426':{'de': 'Wangerland-Horumersiel', 'en': 'Wangerland-Horumersiel'},
 '55163275':{'en': u('Taia\u00e7u - SP'), 'pt': u('Taia\u00e7u - SP')},
 '55114338':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114339':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '497455':{'de': 'Dornhan', 'en': 'Dornhan'},
 '497454':{'de': 'Sulz am Neckar', 'en': 'Sulz am Neckar'},
 '497457':{'de': 'Rottenburg-Ergenzingen', 'en': 'Rottenburg-Ergenzingen'},
 '497456':{'de': 'Haiterbach', 'en': 'Haiterbach'},
 '497451':{'de': 'Horb am Neckar', 'en': 'Horb am Neckar'},
 '55242487':{'en': 'Avelar - RJ', 'pt': 'Avelar - RJ'},
 '497453':{'de': u('Altensteig W\u00fcrttemberg'), 'en': u('Altensteig W\u00fcrttemberg')},
 '497452':{'de': 'Nagold', 'en': 'Nagold'},
 '497459':{'de': 'Nagold-Hochdorf', 'en': 'Nagold-Hochdorf'},
 '497458':{'de': 'Ebhausen', 'en': 'Ebhausen'},
 '498271':{'de': 'Meitingen', 'en': 'Meitingen'},
 '498272':{'de': 'Wertingen', 'en': 'Wertingen'},
 '498273':{'de': 'Nordendorf', 'en': 'Nordendorf'},
 '498274':{'de': 'Buttenwiesen', 'en': 'Buttenwiesen'},
 '498276':{'de': 'Baar Schwaben', 'en': 'Baar Schwaben'},
 '55173648':{'en': u('Paranapu\u00e3 - SP'), 'pt': u('Paranapu\u00e3 - SP')},
 '542317':{'en': '9 de Julio, Buenos Aires', 'es': '9 de Julio, Buenos Aires'},
 '542316':{'en': 'Daireaux, Buenos Aires', 'es': 'Daireaux, Buenos Aires'},
 '55173643':{'en': 'Santa Rita D\'Oeste - SP', 'pt': 'Santa Rita D\'Oeste - SP'},
 '542314':{'en': u('Bol\u00edvar, Buenos Aires'), 'es': u('Bol\u00edvar, Buenos Aires')},
 '494393':{'de': 'Boostedt', 'en': 'Boostedt'},
 '494392':{'de': u('Nortorf bei Neum\u00fcnster'), 'en': u('Nortorf bei Neum\u00fcnster')},
 '55183872':{'en': 'Ouro Verde - SP', 'pt': 'Ouro Verde - SP'},
 '494394':{'de': 'Bokhorst', 'en': 'Bokhorst'},
 '52231':{'en': 'Teteles/Teziutlan, PUE', 'es': u('Teteles/Teziutl\u00e1n, PUE')},
 '52233':{'en': 'Puebla', 'es': 'Puebla'},
 '52232':{'en': 'La Vigueta/Martinez de la Torre, VER', 'es': u('La Vigueta/Mart\u00ednez de la Torre, VER')},
 '52235':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52237':{'en': 'Puebla', 'es': 'Puebla'},
 '52236':{'en': 'Oaxaca/Puebla', 'es': 'Oaxaca/Puebla'},
 '52238':{'en': 'Santiago Miahuatlan/Tehuacan, PUE', 'es': u('Santiago Miahuatl\u00e1n/Tehuac\u00e1n, PUE')},
 '55313228':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313223':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313222':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313221':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313227':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313226':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313225':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '494271':{'de': 'Sulingen', 'en': 'Sulingen'},
 '55212645':{'en': u('Itabora\u00ed - RJ'), 'pt': u('Itabora\u00ed - RJ')},
 '55113819':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113812':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113813':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113811':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113816':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113817':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113814':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113815':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112149':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112148':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112147':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112146':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112145':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112144':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112142':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112141':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113333':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313838':{'en': 'Santa Maria de Itabira - MG', 'pt': 'Santa Maria de Itabira - MG'},
 '55183876':{'en': u('Paulic\u00e9ia - SP'), 'pt': u('Paulic\u00e9ia - SP')},
 '55313839':{'en': 'Itabira - MG', 'pt': 'Itabira - MG'},
 '497635':{'de': 'Schliengen', 'en': 'Schliengen'},
 '497634':{'de': 'Sulzburg', 'en': 'Sulzburg'},
 '55212646':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55313834':{'en': 'Itabira - MG', 'pt': 'Itabira - MG'},
 '55213551':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193744':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '497631':{'de': u('M\u00fcllheim Baden'), 'en': u('M\u00fcllheim Baden')},
 '497633':{'de': 'Staufen im Breisgau', 'en': 'Staufen im Breisgau'},
 '55212641':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '497632':{'de': 'Badenweiler', 'en': 'Badenweiler'},
 '55113768':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113760':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113761':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113762':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113763':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113765':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113766':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213835':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183855':{'en': 'Monte Castelo - SP', 'pt': 'Monte Castelo - SP'},
 '55313161':{'en': u('Ribeir\u00e3o das Neves - MG'), 'pt': u('Ribeir\u00e3o das Neves - MG')},
 '55213837':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55133844':{'en': u('Juqui\u00e1 - SP'), 'pt': u('Juqui\u00e1 - SP')},
 '55123911':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123912':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123913':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123916':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123917':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55273161':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55123919':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55213382':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143321':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '496559':{'de': 'Leidenborn', 'en': 'Leidenborn'},
 '496558':{'de': u('B\u00fcdesheim Eifel'), 'en': u('B\u00fcdesheim Eifel')},
 '55143325':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '55143324':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '55143326':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '496553':{'de': u('Sch\u00f6necken'), 'en': u('Sch\u00f6necken')},
 '496552':{'de': 'Olzheim', 'en': 'Olzheim'},
 '496551':{'de': u('Pr\u00fcm'), 'en': u('Pr\u00fcm')},
 '496550':{'de': 'Irrhausen', 'en': 'Irrhausen'},
 '496557':{'de': 'Hallschlag', 'en': 'Hallschlag'},
 '496556':{'de': 'Pronsfeld', 'en': 'Pronsfeld'},
 '496555':{'de': 'Bleialf', 'en': 'Bleialf'},
 '496554':{'de': 'Waxweiler', 'en': 'Waxweiler'},
 '543734':{'en': 'Machagai/Presidencia de la Plaza, Chaco', 'es': 'Machagai/Presidencia de la Plaza, Chaco'},
 '543735':{'en': u('Villa \u00c1ngela, Chaco'), 'es': u('Villa \u00c1ngela, Chaco')},
 '55273299':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '543731':{'en': 'Charata, Chaco', 'es': 'Charata, Chaco'},
 '55273296':{'en': 'Aracruz - ES', 'pt': 'Aracruz - ES'},
 '55114686':{'en': u('S\u00e3o Louren\u00e7o da Serra - SP'), 'pt': u('S\u00e3o Louren\u00e7o da Serra - SP')},
 '55114687':{'en': u('S\u00e3o Louren\u00e7o da Serra - SP'), 'pt': u('S\u00e3o Louren\u00e7o da Serra - SP')},
 '55114684':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55193806':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '55114682':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55114683':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55114680':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114681':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55212439':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193809':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55193808':{'en': 'Amparo - SP', 'pt': 'Amparo - SP'},
 '55114688':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55213097':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '495351':{'de': 'Helmstedt', 'en': 'Helmstedt'},
 '495352':{'de': u('Sch\u00f6ningen'), 'en': u('Sch\u00f6ningen')},
 '495353':{'de': u('K\u00f6nigslutter am Elm'), 'en': u('K\u00f6nigslutter am Elm')},
 '495354':{'de': 'Jerxheim', 'en': 'Jerxheim'},
 '495355':{'de': 'Frellstedt', 'en': 'Frellstedt'},
 '495356':{'de': 'Helmstedt-Barmke', 'en': 'Helmstedt-Barmke'},
 '495357':{'de': 'Grasleben', 'en': 'Grasleben'},
 '495358':{'de': 'Bahrdorf-Mackendorf', 'en': 'Bahrdorf-Mackendorf'},
 '495607':{'de': 'Fuldatal', 'en': 'Fuldatal'},
 '495604':{'de': 'Grossalmerode', 'en': 'Grossalmerode'},
 '495605':{'de': 'Kaufungen Hessen', 'en': 'Kaufungen Hessen'},
 '495602':{'de': 'Hessisch Lichtenau', 'en': 'Hessisch Lichtenau'},
 '495603':{'de': 'Gudensberg', 'en': 'Gudensberg'},
 '55213099':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '495601':{'de': 'Schauenburg', 'en': 'Schauenburg'},
 '55333251':{'en': u('Santana do Para\u00edso - MG'), 'pt': u('Santana do Para\u00edso - MG')},
 '55333252':{'en': u('Joan\u00e9sia - MG'), 'pt': u('Joan\u00e9sia - MG')},
 '55333253':{'en': 'Belo Oriente - MG', 'pt': 'Belo Oriente - MG'},
 '496809':{'de': 'Grossrosseln', 'en': 'Grossrosseln'},
 '55312107':{'en': 'Sete Lagoas - MG', 'pt': 'Sete Lagoas - MG'},
 '496805':{'de': 'Kleinblittersdorf', 'en': 'Kleinblittersdorf'},
 '496804':{'de': 'Mandelbachtal', 'en': 'Mandelbachtal'},
 '496806':{'de': 'Heusweiler', 'en': 'Heusweiler'},
 '496803':{'de': 'Mandelbachtal-Ommersheim', 'en': 'Mandelbachtal-Ommersheim'},
 '496802':{'de': u('V\u00f6lklingen-Lauterbach'), 'en': u('V\u00f6lklingen-Lauterbach')},
 '55213540':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55213543':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193423':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193422':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '52443':{'en': 'Morelia/Tarimbaro, MICH', 'es': u('Morelia/Tar\u00edmbaro, MICH')},
 '55163176':{'en': 'Furnas Vila Residencial - SP', 'pt': 'Furnas Vila Residencial - SP'},
 '55163172':{'en': 'Igarapava - SP', 'pt': 'Igarapava - SP'},
 '55163173':{'en': 'Igarapava - SP', 'pt': 'Igarapava - SP'},
 '55163171':{'en': 'Pedregulho - SP', 'pt': 'Pedregulho - SP'},
 '55313295':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55193421':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55313563':{'en': 'Itabirito - MG', 'pt': 'Itabirito - MG'},
 '52914':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52916':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52917':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52913':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52918':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52919':{'en': 'Chiapas', 'es': 'Chiapas'},
 '55273388':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55213830':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163142':{'en': u('S\u00e3o Jos\u00e9 da Bela Vista - SP'), 'pt': u('S\u00e3o Jos\u00e9 da Bela Vista - SP')},
 '55193427':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55193749':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55114808':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55133298':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133299':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133296':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133295':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55115929':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212765':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55193468':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55115924':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313034':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55183422':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55115926':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55183421':{'en': 'Assis - SP', 'pt': 'Assis - SP'},
 '55115927':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115576':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193463':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55115575':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115921':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113153':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113152':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113151':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115574':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115922':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115573':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113159':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113158':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115572':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52668':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '499602':{'de': 'Neustadt an der Waldnaab', 'en': 'Neustadt an der Waldnaab'},
 '499603':{'de': 'Floss', 'en': 'Floss'},
 '55114103':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '52669':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '499606':{'de': 'Pfreimd', 'en': 'Pfreimd'},
 '55114104':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499604':{'de': u('Wernberg-K\u00f6blitz'), 'en': u('Wernberg-K\u00f6blitz')},
 '499605':{'de': 'Weiherhammer', 'en': 'Weiherhammer'},
 '55114109':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499608':{'de': 'Kohlberg Oberpfalz', 'en': 'Kohlberg Oberpfalz'},
 '55193575':{'en': 'Itirapina - SP', 'pt': 'Itirapina - SP'},
 '52771':{'en': 'Pachuca/Real Del Monte, HGO', 'es': 'Pachuca/Real del Monte, HGO'},
 '52772':{'en': 'Actopan, HGO', 'es': 'Actopan, HGO'},
 '52773':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52774':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52775':{'en': 'Tulancingo, HGO', 'es': 'Tulancingo, HGO'},
 '52776':{'en': 'Puebla', 'es': 'Puebla'},
 '52777':{'en': 'Morelos', 'es': 'Morelos'},
 '55113481':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52779':{'en': 'Tizayuca, HGO', 'es': 'Tizayuca, HGO'},
 '55113483':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113482':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113485':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113484':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113487':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113486':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113377':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52662':{'en': 'Sonora', 'es': 'Sonora'},
 '55113375':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113374':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55115579':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113371':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113379':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55113378':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55213305':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213304':{'en': 'Belford Roxo - RJ', 'pt': 'Belford Roxo - RJ'},
 '55213303':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55323061':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55213309':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '499931':{'de': 'Plattling', 'en': 'Plattling'},
 '499932':{'de': 'Osterhofen', 'en': 'Osterhofen'},
 '499933':{'de': 'Wallersdorf', 'en': 'Wallersdorf'},
 '499935':{'de': 'Stephansposching', 'en': 'Stephansposching'},
 '499936':{'de': 'Wallerfing', 'en': 'Wallerfing'},
 '499937':{'de': u('Oberp\u00f6ring'), 'en': u('Oberp\u00f6ring')},
 '499938':{'de': 'Moos Niederbayern', 'en': 'Moos Niederbayern'},
 '55163919':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55113103':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495167':{'de': 'Walsrode-Westenholz', 'en': 'Walsrode-Westenholz'},
 '495166':{'de': 'Walsrode-Kirchboitzen', 'en': 'Walsrode-Kirchboitzen'},
 '495165':{'de': 'Rethem Aller', 'en': 'Rethem Aller'},
 '495164':{'de': 'Hodenhagen', 'en': 'Hodenhagen'},
 '495163':{'de': 'Fallingbostel-Dorfmark', 'en': 'Fallingbostel-Dorfmark'},
 '495162':{'de': 'Fallingbostel', 'en': 'Fallingbostel'},
 '495161':{'de': 'Walsrode', 'en': 'Walsrode'},
 '495168':{'de': 'Walsrode-Stellichte', 'en': 'Walsrode-Stellichte'},
 '55112684':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112685':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112687':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112682':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112683':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112688':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55222561':{'en': 'Santa Maria Madalena - RJ', 'pt': 'Santa Maria Madalena - RJ'},
 '55115537':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222566':{'en': 'Bom Jardim - RJ', 'pt': 'Bom Jardim - RJ'},
 '55222565':{'en': 'Bom Jardim - RJ', 'pt': 'Bom Jardim - RJ'},
 '55222564':{'en': 'Trajano de Morais - RJ', 'pt': 'Trajano de Morais - RJ'},
 '55313487':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273769':{'en': u('Jaguar\u00e9 - ES'), 'pt': u('Jaguar\u00e9 - ES')},
 '55273768':{'en': u('Boa Esperan\u00e7a - ES'), 'pt': u('Boa Esperan\u00e7a - ES')},
 '55112429':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '495293':{'de': 'Paderborn-Dahl', 'en': 'Paderborn-Dahl'},
 '495292':{'de': 'Lichtenau-Atteln', 'en': 'Lichtenau-Atteln'},
 '495295':{'de': 'Lichtenau Westfalen', 'en': 'Lichtenau Westfalen'},
 '495294':{'de': u('H\u00f6velhof-Espeln'), 'en': u('H\u00f6velhof-Espeln')},
 '55112352':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112421':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112422':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112425':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112354':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112427':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55313484':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '49851':{'de': 'Passau', 'en': 'Passau'},
 '55123635':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123634':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123637':{'en': u('Moreira C\u00e9sar - SP'), 'pt': u('Moreira C\u00e9sar - SP')},
 '5042453':{'en': 'Guanaja'},
 '5042452':{'en': 'Coyoles Central'},
 '5042451':{'en': 'Sonaguera'},
 '55123632':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55313481':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '498841':{'de': 'Murnau am Staffelsee', 'en': 'Murnau am Staffelsee'},
 '494723':{'de': 'Cuxhaven-Altenwalde', 'en': 'Cuxhaven-Altenwalde'},
 '499533':{'de': 'Untermerzbach', 'en': 'Untermerzbach'},
 '55114334':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '494422':{'de': 'Sande Kreis Friesl', 'en': 'Sande Kreis Friesl'},
 '494425':{'de': 'Wangerland-Hooksiel', 'en': 'Wangerland-Hooksiel'},
 '496122':{'de': 'Hofheim-Wallau', 'en': 'Hofheim-Wallau'},
 '496123':{'de': 'Eltville am Rhein', 'en': 'Eltville am Rhein'},
 '496120':{'de': 'Aarbergen', 'en': 'Aarbergen'},
 '496126':{'de': 'Idstein', 'en': 'Idstein'},
 '496127':{'de': 'Niedernhausen Taunus', 'en': 'Niedernhausen Taunus'},
 '496124':{'de': 'Bad Schwalbach', 'en': 'Bad Schwalbach'},
 '55183221':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '496128':{'de': 'Taunusstein', 'en': 'Taunusstein'},
 '496129':{'de': 'Schlangenbad', 'en': 'Schlangenbad'},
 '55243333':{'en': 'Arrozal - RJ', 'pt': 'Arrozal - RJ'},
 '55243332':{'en': 'Rio Claro - RJ', 'pt': 'Rio Claro - RJ'},
 '55212551':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212550':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212553':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212552':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212555':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212554':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212557':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212556':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212558':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495835':{'de': 'Wahrenholz', 'en': 'Wahrenholz'},
 '495834':{'de': 'Wittingen-Knesebeck', 'en': 'Wittingen-Knesebeck'},
 '495837':{'de': 'Sprakensehl', 'en': 'Sprakensehl'},
 '495836':{'de': 'Wittingen-Radenbeck', 'en': 'Wittingen-Radenbeck'},
 '495831':{'de': 'Wittingen', 'en': 'Wittingen'},
 '495833':{'de': 'Brome', 'en': 'Brome'},
 '495832':{'de': u('Hankensb\u00fcttel'), 'en': u('Hankensb\u00fcttel')},
 '495839':{'de': 'Wittingen-Ohrdorf', 'en': 'Wittingen-Ohrdorf'},
 '495838':{'de': 'Gross Oesingen', 'en': 'Gross Oesingen'},
 '55273742':{'en': u('S\u00e3o Domingos do Norte - ES'), 'pt': u('S\u00e3o Domingos do Norte - ES')},
 '55313854':{'en': 'Rio Piracicaba - MG', 'pt': 'Rio Piracicaba - MG'},
 '55273335':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55313856':{'en': u('S\u00e3o Domingos do Prata - MG'), 'pt': u('S\u00e3o Domingos do Prata - MG')},
 '55114748':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55273331':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55173809':{'en': u('Mendon\u00e7a - SP'), 'pt': u('Mendon\u00e7a - SP')},
 '55173808':{'en': 'Engenheiro Schimidt - SP', 'pt': 'Engenheiro Schimidt - SP'},
 '55114743':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114742':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114741':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114747':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114746':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55173801':{'en': u('Riol\u00e2ndia - SP'), 'pt': u('Riol\u00e2ndia - SP')},
 '55114744':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55212502':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55242484':{'en': 'Miguel Pereira - RJ', 'pt': 'Miguel Pereira - RJ'},
 '55242485':{'en': 'Paty do Alferes - RJ', 'pt': 'Paty do Alferes - RJ'},
 '55173265':{'en': u('Jos\u00e9 Bonif\u00e1cio - SP'), 'pt': u('Jos\u00e9 Bonif\u00e1cio - SP')},
 '55313939':{'en': 'Conselheiro Lafaiete - MG', 'pt': 'Conselheiro Lafaiete - MG'},
 '498076':{'de': 'Pfaffing', 'en': 'Pfaffing'},
 '498074':{'de': 'Schnaitsee', 'en': 'Schnaitsee'},
 '498075':{'de': 'Amerang', 'en': 'Amerang'},
 '498072':{'de': 'Haag in Oberbayern', 'en': 'Haag in Oberbayern'},
 '498073':{'de': 'Gars am Inn', 'en': 'Gars am Inn'},
 '498071':{'de': 'Wasserburg am Inn', 'en': 'Wasserburg am Inn'},
 '55273745':{'en': u('\u00c1guia Branca - ES'), 'pt': u('\u00c1guia Branca - ES')},
 '55143282':{'en': 'Duartina - SP', 'pt': 'Duartina - SP'},
 '55273746':{'en': 'Alto Rio Novo - ES', 'pt': 'Alto Rio Novo - ES'},
 '55114358':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114359':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55273743':{'en': 'Colatina - ES', 'pt': 'Colatina - ES'},
 '55143283':{'en': 'Pederneiras - SP', 'pt': 'Pederneiras - SP'},
 '55114354':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114355':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114356':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114357':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542292':{'en': u('Benito Ju\u00e1rez, Buenos Aires'), 'es': u('Benito Ju\u00e1rez, Buenos Aires')},
 '55114351':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114352':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542291':{'en': 'Miramar, Buenos Aires', 'es': 'Miramar, Buenos Aires'},
 '494409':{'de': 'Westerstede-Ocholt', 'en': 'Westerstede-Ocholt'},
 '494408':{'de': 'Hude Oldenburg', 'en': 'Hude Oldenburg'},
 '494403':{'de': 'Bad Zwischenahn', 'en': 'Bad Zwischenahn'},
 '494402':{'de': 'Rastede', 'en': 'Rastede'},
 '494401':{'de': 'Brake Unterweser', 'en': 'Brake Unterweser'},
 '494407':{'de': 'Wardenburg', 'en': 'Wardenburg'},
 '494406':{'de': 'Berne', 'en': 'Berne'},
 '494405':{'de': 'Edewecht', 'en': 'Edewecht'},
 '494404':{'de': 'Elsfleth', 'en': 'Elsfleth'},
 '55143284':{'en': 'Pederneiras - SP', 'pt': 'Pederneiras - SP'},
 '497478':{'de': 'Hirrlingen', 'en': 'Hirrlingen'},
 '497477':{'de': 'Jungingen bei Hechingen', 'en': 'Jungingen bei Hechingen'},
 '497476':{'de': 'Bisingen', 'en': 'Bisingen'},
 '497475':{'de': 'Burladingen', 'en': 'Burladingen'},
 '497474':{'de': 'Haigerloch', 'en': 'Haigerloch'},
 '497473':{'de': u('M\u00f6ssingen'), 'en': u('M\u00f6ssingen')},
 '497472':{'de': 'Rottenburg am Neckar', 'en': 'Rottenburg am Neckar'},
 '497471':{'de': 'Hechingen', 'en': 'Hechingen'},
 '55212262':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55153542':{'en': u('Cap\u00e3o Bonito - SP'), 'pt': u('Cap\u00e3o Bonito - SP')},
 '55153543':{'en': u('Cap\u00e3o Bonito - SP'), 'pt': u('Cap\u00e3o Bonito - SP')},
 '55153544':{'en': u('Ribeir\u00e3o Grande - SP'), 'pt': u('Ribeir\u00e3o Grande - SP')},
 '55153546':{'en': 'Buri - SP', 'pt': 'Buri - SP'},
 '55153547':{'en': 'Guapiara - SP', 'pt': 'Guapiara - SP'},
 '55153548':{'en': u('Itapirapu\u00e3 Paulista - SP'), 'pt': u('Itapirapu\u00e3 Paulista - SP')},
 '55143632':{'en': u('Dois C\u00f3rregos - SP'), 'pt': u('Dois C\u00f3rregos - SP')},
 '55133359':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133358':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55144004':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55133355':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133354':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133353':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133352':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '498505':{'de': 'Hutthurm', 'en': 'Hutthurm'},
 '55313201':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313202':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313207':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55173641':{'en': u('Santa F\u00e9 do Sul - SP'), 'pt': u('Santa F\u00e9 do Sul - SP')},
 '55173215':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55163286':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163287':{'en': 'Vista Alegre do Alto - SP', 'pt': 'Vista Alegre do Alto - SP'},
 '55173642':{'en': u('Vit\u00f3ria Brasil - SP'), 'pt': u('Vit\u00f3ria Brasil - SP')},
 '55112165':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112164':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112167':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112166':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55112161':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112163':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112162':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112169':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112168':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49621':{'de': 'Mannheim', 'en': 'Mannheim'},
 '55163759':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55163752':{'en': 'Aramina - SP', 'pt': 'Aramina - SP'},
 '55163751':{'en': 'Buritizal - SP', 'pt': 'Buritizal - SP'},
 '55212285':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49991':{'de': 'Deggendorf', 'en': 'Deggendorf'},
 '55183941':{'en': u('Espig\u00e3o - SP'), 'pt': u('Espig\u00e3o - SP')},
 '55183942':{'en': u('Gard\u00eania - SP'), 'pt': u('Gard\u00eania - SP')},
 '55212284':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '49441':{'de': 'Oldenburg', 'en': 'Oldenburg'},
 '55212301':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212303':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113748':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113749':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113746':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113747':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113744':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113745':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113742':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113743':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113740':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113741':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123936':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123937':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123934':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123935':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123933':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123931':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55273273':{'en': 'Sooretama - ES', 'pt': 'Sooretama - ES'},
 '55123938':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123939':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55114916':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143346':{'en': 'Bernardino de Campos - SP', 'pt': 'Bernardino de Campos - SP'},
 '55114914':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143344':{'en': 'Ipaussu - SP', 'pt': 'Ipaussu - SP'},
 '55114912':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143342':{'en': 'Chavantes - SP', 'pt': 'Chavantes - SP'},
 '55193638':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55114911':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193636':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193634':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193635':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193632':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193633':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55193631':{'en': u('S\u00e3o Jo\u00e3o da Boa Vista - SP'), 'pt': u('S\u00e3o Jo\u00e3o da Boa Vista - SP')},
 '55173349':{'en': u('Turv\u00ednia - SP'), 'pt': u('Turv\u00ednia - SP')},
 '496438':{'de': u('H\u00fcnfelden'), 'en': u('H\u00fcnfelden')},
 '496439':{'de': 'Holzappel', 'en': 'Holzappel'},
 '543711':{'en': u('Ingeniero Ju\u00e1rez, Formosa'), 'es': u('Ingeniero Ju\u00e1rez, Formosa')},
 '543715':{'en': 'Las Lomitas, Formosa', 'es': 'Las Lomitas, Formosa'},
 '543716':{'en': 'Comandante Fontana, Formosa', 'es': 'Comandante Fontana, Formosa'},
 '543718':{'en': 'Clorinda, Formosa', 'es': 'Clorinda, Formosa'},
 '55183649':{'en': 'Birigui - SP', 'pt': 'Birigui - SP'},
 '495339':{'de': 'Gielde', 'en': 'Gielde'},
 '495332':{'de': u('Sch\u00f6ppenstedt'), 'en': u('Sch\u00f6ppenstedt')},
 '495621':{'de': 'Bad Wildungen', 'en': 'Bad Wildungen'},
 '495622':{'de': 'Fritzlar', 'en': 'Fritzlar'},
 '495623':{'de': 'Edertal', 'en': 'Edertal'},
 '495624':{'de': 'Bad Emstal', 'en': 'Bad Emstal'},
 '495625':{'de': 'Naumburg Hessen', 'en': 'Naumburg Hessen'},
 '495626':{'de': 'Bad Zwesten', 'en': 'Bad Zwesten'},
 '495335':{'de': 'Schladen', 'en': 'Schladen'},
 '55333276':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333277':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333274':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333275':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333272':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333271':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '499325':{'de': 'Kleinlangheim', 'en': 'Kleinlangheim'},
 '55333278':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333279':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '497662':{'de': 'Vogtsburg im Kaiserstuhl', 'en': 'Vogtsburg im Kaiserstuhl'},
 '497663':{'de': 'Eichstetten', 'en': 'Eichstetten'},
 '497660':{'de': 'St Peter Schwarzwald', 'en': 'St Peter Schwarzwald'},
 '497661':{'de': 'Kirchzarten', 'en': 'Kirchzarten'},
 '497666':{'de': 'Denzlingen', 'en': 'Denzlingen'},
 '497667':{'de': 'Breisach am Rhein', 'en': 'Breisach am Rhein'},
 '497664':{'de': 'Freiburg-Tiengen', 'en': 'Freiburg-Tiengen'},
 '497665':{'de': 'March Breisgau', 'en': 'March Breisgau'},
 '55183857':{'en': u('S\u00e3o Jo\u00e3o do Pau D\'Alho - SP'), 'pt': u('S\u00e3o Jo\u00e3o do Pau D\'Alho - SP')},
 '497668':{'de': 'Ihringen', 'en': 'Ihringen'},
 '497669':{'de': u('St M\u00e4rgen'), 'en': u('St M\u00e4rgen')},
 '55223021':{'en': 'Araruama - RJ', 'pt': 'Araruama - RJ'},
 '55323375':{'en': u('Concei\u00e7\u00e3o da Barra de Minas - MG'), 'pt': u('Concei\u00e7\u00e3o da Barra de Minas - MG')},
 '55163114':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55163116':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55163111':{'en': 'Franca - SP', 'pt': 'Franca - SP'},
 '55243322':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '496827':{'de': 'Eppelborn', 'en': 'Eppelborn'},
 '496826':{'de': 'Bexbach', 'en': 'Bexbach'},
 '496825':{'de': 'Illingen Saar', 'en': 'Illingen Saar'},
 '496824':{'de': 'Ottweiler', 'en': 'Ottweiler'},
 '496821':{'de': 'Neunkirchen Saar', 'en': 'Neunkirchen Saar'},
 '497084':{'de': u('Sch\u00f6mberg bei Neuenb\u00fcrg'), 'en': u('Sch\u00f6mberg bei Neuenb\u00fcrg')},
 '497085':{'de': u('Enzkl\u00f6sterle'), 'en': u('Enzkl\u00f6sterle')},
 '497082':{'de': u('Neuenb\u00fcrg W\u00fcrttemberg'), 'en': u('Neuenb\u00fcrg W\u00fcrttemberg')},
 '497083':{'de': 'Bad Herrenalb', 'en': 'Bad Herrenalb'},
 '497081':{'de': 'Bad Wildbad', 'en': 'Bad Wildbad'},
 '55243323':{'en': 'Barra Mansa - RJ', 'pt': 'Barra Mansa - RJ'},
 '55222526':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55114996':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55163567':{'en': 'Cajuru - SP', 'pt': 'Cajuru - SP'},
 '55314009':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55112814':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55314002':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313055':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313057':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55314007':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55314004':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55183441':{'en': u('Ara\u00e7atuba - SP'), 'pt': u('Ara\u00e7atuba - SP')},
 '55112811':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55113178':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112813':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113171':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113170':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113175':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113177':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498685':{'de': u('Kirchansch\u00f6ring'), 'en': u('Kirchansch\u00f6ring')},
 '498684':{'de': 'Fridolfing', 'en': 'Fridolfing'},
 '498687':{'de': 'Taching-Tengling', 'en': 'Taching-Tengling'},
 '498686':{'de': 'Petting', 'en': 'Petting'},
 '498681':{'de': 'Waging am See', 'en': 'Waging am See'},
 '498683':{'de': 'Tittmoning', 'en': 'Tittmoning'},
 '498682':{'de': 'Laufen Salzach', 'en': 'Laufen Salzach'},
 '55193525':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '55173561':{'en': 'Novais - SP', 'pt': 'Novais - SP'},
 '55173562':{'en': u('Tabapu\u00e3 - SP'), 'pt': u('Tabapu\u00e3 - SP')},
 '55173563':{'en': 'Cajobi - SP', 'pt': 'Cajobi - SP'},
 '55173564':{'en': u('Catigu\u00e1 - SP'), 'pt': u('Catigu\u00e1 - SP')},
 '55173566':{'en': u('Emba\u00faba - SP'), 'pt': u('Emba\u00faba - SP')},
 '55173567':{'en': u('Para\u00edso - SP'), 'pt': u('Para\u00edso - SP')},
 '55114166':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114165':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114164':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '499628':{'de': 'Ursensollen', 'en': 'Ursensollen'},
 '55114162':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114161':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '499624':{'de': 'Ensdorf Oberpfalz', 'en': 'Ensdorf Oberpfalz'},
 '499625':{'de': 'Kastl bei Amberg', 'en': 'Kastl bei Amberg'},
 '499626':{'de': 'Hohenburg', 'en': 'Hohenburg'},
 '499627':{'de': 'Freudenberg Oberpfalz', 'en': 'Freudenberg Oberpfalz'},
 '499621':{'de': 'Amberg Oberpfalz', 'en': 'Amberg Oberpfalz'},
 '55114169':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114168':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55193562':{'en': 'Pirassununga - SP', 'pt': 'Pirassununga - SP'},
 '55113359':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114992':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55193563':{'en': 'Pirassununga - SP', 'pt': 'Pirassununga - SP'},
 '52797':{'en': 'Puebla', 'es': 'Puebla'},
 '55113357':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113353':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52791':{'en': 'Ciudad Sahagun, HGO', 'es': u('Ciudad Sahag\u00fan, HGO')},
 '55193561':{'en': 'Pirassununga - SP', 'pt': 'Pirassununga - SP'},
 '55213329':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213328':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498538':{'de': 'Pocking-Hartkirchen', 'en': 'Pocking-Hartkirchen'},
 '498537':{'de': u('Bad F\u00fcssing-Aigen'), 'en': u('Bad F\u00fcssing-Aigen')},
 '498536':{'de': u('K\u00f6\u00dflarn'), 'en': u('K\u00f6sslarn')},
 '498535':{'de': 'Haarbach', 'en': 'Haarbach'},
 '498534':{'de': 'Tettenweis', 'en': 'Tettenweis'},
 '498533':{'de': u('Rotthalm\u00fcnster'), 'en': u('Rotthalm\u00fcnster')},
 '498532':{'de': 'Griesbach im Rottal', 'en': 'Griesbach im Rottal'},
 '498531':{'de': 'Pocking', 'en': 'Pocking'},
 '55193567':{'en': u('Santa Cruz da Concei\u00e7\u00e3o - SP'), 'pt': u('Santa Cruz da Concei\u00e7\u00e3o - SP')},
 '55153379':{'en': u('S\u00e3o Miguel Arcanjo - SP'), 'pt': u('S\u00e3o Miguel Arcanjo - SP')},
 '55153378':{'en': 'Pilar do Sul - SP', 'pt': 'Pilar do Sul - SP'},
 '55153373':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153372':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153376':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '499480':{'de': u('S\u00fcnching'), 'en': u('S\u00fcnching')},
 '499481':{'de': 'Pfatter', 'en': 'Pfatter'},
 '499482':{'de': u('W\u00f6rth an der Donau'), 'en': u('W\u00f6rth an der Donau')},
 '499951':{'de': 'Landau an der Isar', 'en': 'Landau an der Isar'},
 '499484':{'de': 'Brennberg', 'en': 'Brennberg'},
 '499954':{'de': 'Simbach Niederbayern', 'en': 'Simbach Niederbayern'},
 '499955':{'de': 'Mamming', 'en': 'Mamming'},
 '55114990':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '495101':{'de': 'Pattensen', 'en': 'Pattensen'},
 '55313433':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '495103':{'de': 'Wennigsen Deister', 'en': 'Wennigsen Deister'},
 '495102':{'de': 'Laatzen', 'en': 'Laatzen'},
 '495105':{'de': 'Barsinghausen', 'en': 'Barsinghausen'},
 '495109':{'de': 'Ronnenberg', 'en': 'Ronnenberg'},
 '495108':{'de': 'Gehrden Han', 'en': 'Gehrden Han'},
 '55114991':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55113496':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113497':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222541':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55222540':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55222543':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55123034':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55113494':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113495':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143597':{'en': 'Presidente Alves - SP', 'pt': 'Presidente Alves - SP'},
 '55113492':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498503':{'de': 'Neuhaus am Inn', 'en': 'Neuhaus am Inn'},
 '498501':{'de': 'Thyrnau', 'en': 'Thyrnau'},
 '55223234':{'en': 'Campos dos Goitacazes - RJ', 'pt': 'Campos dos Goitacazes - RJ'},
 '55112408':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112409':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112406':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112407':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112405':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112401':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '49871':{'de': 'Landshut', 'en': 'Landshut'},
 '543524':{'en': u('Villa del Totoral, C\u00f3rdoba'), 'es': u('Villa del Totoral, C\u00f3rdoba')},
 '543522':{'en': u('Villa de Mar\u00eda, C\u00f3rdoba'), 'es': u('Villa de Mar\u00eda, C\u00f3rdoba')},
 '543521':{'en': u('De\u00e1n Funes, C\u00f3rdoba'), 'es': u('De\u00e1n Funes, C\u00f3rdoba')},
 '55222724':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222727':{'en': u('S\u00e3o Francisco de Itabapoana - RJ'), 'pt': u('S\u00e3o Francisco de Itabapoana - RJ')},
 '55222726':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222721':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222720':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222723':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55222722':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '55113499':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55323429':{'en': 'Cataguases - MG', 'pt': 'Cataguases - MG'},
 '55323051':{'en': 'Barbacena - MG', 'pt': 'Barbacena - MG'},
 '55323426':{'en': u('Mira\u00ed - MG'), 'pt': u('Mira\u00ed - MG')},
 '5042780':{'en': 'Choluteca'},
 '55213311':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '5345':{'en': 'Matanzas Province'},
 '5346':{'en': 'Isle of Youth'},
 '5347':{'en': 'Havana Province'},
 '496108':{'de': u('M\u00fchlheim am Main'), 'en': u('M\u00fchlheim am Main')},
 '496109':{'de': 'Frankfurt-Bergen-Enkheim', 'en': 'Frankfurt-Bergen-Enkheim'},
 '5342':{'en': 'Villa Clara Province'},
 '5343':{'en': 'Cienfuegos Province'},
 '496104':{'de': 'Heusenstamm', 'en': 'Heusenstamm'},
 '496105':{'de': u('M\u00f6rfelden-Walldorf'), 'en': u('M\u00f6rfelden-Walldorf')},
 '496454':{'de': 'Lichtenfels-Sachsenberg', 'en': 'Lichtenfels-Sachsenberg'},
 '496107':{'de': 'Kelsterbach', 'en': 'Kelsterbach'},
 '496452':{'de': 'Battenberg Eder', 'en': 'Battenberg Eder'},
 '496101':{'de': 'Bad Vilbel', 'en': 'Bad Vilbel'},
 '496102':{'de': 'Neu-Isenburg', 'en': 'Neu-Isenburg'},
 '496103':{'de': 'Langen Hessen', 'en': 'Langen Hessen'},
 '55212537':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212535':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212534':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212533':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212532':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212531':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212530':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212539':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212538':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55313878':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55313879':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273312':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '55273313':{'en': u('S\u00e3o Mateus - ES'), 'pt': u('S\u00e3o Mateus - ES')},
 '55273311':{'en': 'Vila Velha - ES', 'pt': 'Vila Velha - ES'},
 '55313876':{'en': u('Uruc\u00e2nia - MG'), 'pt': u('Uruc\u00e2nia - MG')},
 '55273317':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273314':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55273315':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55114761':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499453':{'de': 'Thalmassing', 'en': 'Thalmassing'},
 '55173827':{'en': 'Potirendaba - SP', 'pt': 'Potirendaba - SP'},
 '55114762':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499452':{'de': 'Langquaid', 'en': 'Langquaid'},
 '55114759':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55173829':{'en': 'Talhado - SP', 'pt': 'Talhado - SP'},
 '499907':{'de': 'Zenting', 'en': 'Zenting'},
 '55242438':{'en': u('Conservat\u00f3ria - RJ'), 'pt': u('Conservat\u00f3ria - RJ')},
 '55183285':{'en': 'Caiabu - SP', 'pt': 'Caiabu - SP'},
 '55313915':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313916':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313911':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55313913':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55313912':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '55213668':{'en': u('S\u00e3o Jo\u00e3o de Meriti - RJ'), 'pt': u('S\u00e3o Jo\u00e3o de Meriti - RJ')},
 '494836':{'de': 'Hennstedt Dithmarschen', 'en': 'Hennstedt Dithmarschen'},
 '494837':{'de': 'Neuenkirchen Dithmarschen', 'en': 'Neuenkirchen Dithmarschen'},
 '497275':{'de': 'Kandel', 'en': 'Kandel'},
 '497274':{'de': 'Germersheim', 'en': 'Germersheim'},
 '497277':{'de': u('W\u00f6rth-B\u00fcchelberg'), 'en': u('W\u00f6rth-B\u00fcchelberg')},
 '497276':{'de': 'Herxheim bei Landau Pfalz', 'en': 'Herxheim bei Landau Pfalz'},
 '497271':{'de': u('W\u00f6rth am Rhein'), 'en': u('W\u00f6rth am Rhein')},
 '494834':{'de': u('B\u00fcsum'), 'en': u('B\u00fcsum')},
 '497273':{'de': 'Hagenbach Pfalz', 'en': 'Hagenbach Pfalz'},
 '497272':{'de': u('R\u00fclzheim'), 'en': u('R\u00fclzheim')},
 '494835':{'de': 'Albersdorf Holstein', 'en': 'Albersdorf Holstein'},
 '498051':{'de': 'Prien am Chiemsee', 'en': 'Prien am Chiemsee'},
 '498052':{'de': 'Aschau im Chiemgau', 'en': 'Aschau im Chiemgau'},
 '498053':{'de': 'Bad Endorf', 'en': 'Bad Endorf'},
 '498054':{'de': 'Breitbrunn am Chiemsee', 'en': 'Breitbrunn am Chiemsee'},
 '498055':{'de': 'Halfing', 'en': 'Halfing'},
 '498056':{'de': u('Eggst\u00e4tt'), 'en': u('Eggst\u00e4tt')},
 '498057':{'de': 'Aschau-Sachrang', 'en': 'Aschau-Sachrang'},
 '55173353':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55114373':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494830':{'de': u('S\u00fcderhastedt'), 'en': u('S\u00fcderhastedt')},
 '55114374':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55173354':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173359':{'en': u('Col\u00f4mbia - SP'), 'pt': u('Col\u00f4mbia - SP')},
 '494523':{'de': 'Malente', 'en': 'Malente'},
 '55173681':{'en': u('Nova Cana\u00e3 Paulista - SP'), 'pt': u('Nova Cana\u00e3 Paulista - SP')},
 '55333202':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '494681':{'de': u('Wyk auf F\u00f6hr'), 'en': u('Wyk auf F\u00f6hr')},
 '494683':{'de': 'Oldsum', 'en': 'Oldsum'},
 '494682':{'de': 'Amrum', 'en': 'Amrum'},
 '55153562':{'en': u('Itaber\u00e1 - SP'), 'pt': u('Itaber\u00e1 - SP')},
 '494684':{'de': u('Langene\u00df Hallig'), 'en': 'Langeness Hallig'},
 '494305':{'de': 'Westensee', 'en': 'Westensee'},
 '55214125':{'en': 'Belford Roxo - RJ', 'pt': 'Belford Roxo - RJ'},
 '543894':{'en': u('Burruyac\u00fa, Tucum\u00e1n'), 'es': u('Burruyac\u00fa, Tucum\u00e1n')},
 '543892':{'en': u('Amaicha del Valle, Tucum\u00e1n'), 'es': u('Amaicha del Valle, Tucum\u00e1n')},
 '543891':{'en': u('Graneros, Tucum\u00e1n'), 'es': u('Graneros, Tucum\u00e1n')},
 '52899':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '55213602':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55133377':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133372':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '52891':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52892':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52894':{'en': 'Santa Apolonia/Valle Hermoso, TAMPS', 'es': 'Santa Apolonia/Valle Hermoso, TAMPS'},
 '52897':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '55313267':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213601':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313263':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313262':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313261':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55273082':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55313269':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55213604':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '494307':{'de': 'Raisdorf', 'en': 'Raisdorf'},
 '498234':{'de': 'Bobingen', 'en': 'Bobingen'},
 '498236':{'de': 'Fischach', 'en': 'Fischach'},
 '498237':{'de': 'Aindling', 'en': 'Aindling'},
 '498230':{'de': 'Gablingen', 'en': 'Gablingen'},
 '498231':{'de': u('K\u00f6nigsbrunn bei Augsburg'), 'en': u('K\u00f6nigsbrunn bei Augsburg')},
 '498232':{'de': u('Schwabm\u00fcnchen'), 'en': u('Schwabm\u00fcnchen')},
 '498233':{'de': 'Kissing', 'en': 'Kissing'},
 '498238':{'de': 'Gessertshausen', 'en': 'Gessertshausen'},
 '498239':{'de': 'Langenneufnach', 'en': 'Langenneufnach'},
 '499545':{'de': 'Buttenheim', 'en': 'Buttenheim'},
 '499544':{'de': 'Baunach', 'en': 'Baunach'},
 '499547':{'de': 'Zapfendorf', 'en': 'Zapfendorf'},
 '499546':{'de': 'Burgebrach', 'en': 'Burgebrach'},
 '499543':{'de': 'Hirschaid', 'en': 'Hirschaid'},
 '499542':{'de': 'Schesslitz', 'en': 'Schesslitz'},
 '499549':{'de': 'Lisberg', 'en': 'Lisberg'},
 '499548':{'de': u('M\u00fchlhausen Mittelfranken'), 'en': u('M\u00fchlhausen Mittelfranken')},
 '495522':{'de': 'Osterode am Harz', 'en': 'Osterode am Harz'},
 '55312138':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '49461':{'de': 'Flensburg', 'en': 'Flensburg'},
 '49465':{'de': 'Sylt', 'en': 'Sylt'},
 '55143103':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143102':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143104':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55312136':{'en': 'Ipatinga - MG', 'pt': 'Ipatinga - MG'},
 '55143106':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '52635':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52634':{'en': 'Sonora', 'es': 'Sonora'},
 '52637':{'en': 'Altar/Caborca, SON', 'es': 'Altar/Caborca, SON'},
 '52636':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52631':{'en': 'Nogales, SON', 'es': 'Nogales, SON'},
 '55193435':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '52633':{'en': 'Sonora', 'es': 'Sonora'},
 '52632':{'en': 'Imuris/Magdalena, SON', 'es': u('\u00cdmuris/Magdalena, SON')},
 '55193386':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193387':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193384':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55193385':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '52639':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52638':{'en': 'Puerto Penasco, SON', 'es': 'Puerto Penasco, SON'},
 '55183928':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55113724':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113725':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113726':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113727':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113721':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113722':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113723':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113729':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273125':{'en': 'Guarapari - ES', 'pt': 'Guarapari - ES'},
 '55114978':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114979':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114976':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55143366':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55143361':{'en': 'Botucatu - SP', 'pt': 'Botucatu - SP'},
 '55193654':{'en': u('Santo Ant\u00f4nio do Jardim - SP'), 'pt': u('Santo Ant\u00f4nio do Jardim - SP')},
 '55193656':{'en': 'Mococa - SP', 'pt': 'Mococa - SP'},
 '55193657':{'en': 'Tapiratiba - SP', 'pt': 'Tapiratiba - SP'},
 '55193651':{'en': u('Esp\u00edrito Santo do Pinhal - SP'), 'pt': u('Esp\u00edrito Santo do Pinhal - SP')},
 '55193652':{'en': u('Agua\u00ed - SP'), 'pt': u('Agua\u00ed - SP')},
 '55193653':{'en': u('Agua\u00ed - SP'), 'pt': u('Agua\u00ed - SP')},
 '55173667':{'en': 'Turmalina - SP', 'pt': 'Turmalina - SP'},
 '543772':{'en': 'Paso de los Libres, Corrientes', 'es': 'Paso de los Libres, Corrientes'},
 '543773':{'en': 'Mercedes, Corrientes', 'es': 'Mercedes, Corrientes'},
 '543777':{'en': 'Goya, Corrientes', 'es': 'Goya, Corrientes'},
 '543774':{'en': u('Curuz\u00fa Cuati\u00e1, Corrientes'), 'es': u('Curuz\u00fa Cuati\u00e1, Corrientes')},
 '543775':{'en': 'Monte Caseros, Corrientes', 'es': 'Monte Caseros, Corrientes'},
 '495642':{'de': 'Warburg-Scherfede', 'en': 'Warburg-Scherfede'},
 '495643':{'de': 'Borgentreich', 'en': 'Borgentreich'},
 '495641':{'de': 'Warburg', 'en': 'Warburg'},
 '495646':{'de': 'Willebadessen', 'en': 'Willebadessen'},
 '495647':{'de': 'Lichtenau-Kleinenberg', 'en': 'Lichtenau-Kleinenberg'},
 '495644':{'de': 'Willebadessen-Peckelsheim', 'en': 'Willebadessen-Peckelsheim'},
 '495645':{'de': 'Borgentreich-Borgholz', 'en': 'Borgentreich-Borgholz'},
 '495648':{'de': 'Brakel-Gehrden', 'en': 'Brakel-Gehrden'},
 '55123958':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123959':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123954':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123955':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123956':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123957':{'en': u('S\u00e3o Silvestre - SP'), 'pt': u('S\u00e3o Silvestre - SP')},
 '55123951':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123952':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123953':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55273555':{'en': 'Mimoso do Sul - ES', 'pt': 'Mimoso do Sul - ES'},
 '55213589':{'en': 'Mesquita - RJ', 'pt': 'Mesquita - RJ'},
 '497644':{'de': 'Kenzingen', 'en': 'Kenzingen'},
 '497645':{'de': 'Freiamt', 'en': 'Freiamt'},
 '497646':{'de': 'Weisweil Breisgau', 'en': 'Weisweil Breisgau'},
 '497641':{'de': 'Emmendingen', 'en': 'Emmendingen'},
 '497642':{'de': 'Endingen Kaiserstuhl', 'en': 'Endingen Kaiserstuhl'},
 '497643':{'de': 'Herbolzheim Breisgau', 'en': 'Herbolzheim Breisgau'},
 '55213765':{'en': 'Mesquita - RJ', 'pt': 'Mesquita - RJ'},
 '55273553':{'en': u('Gua\u00e7u\u00ed - ES'), 'pt': u('Gua\u00e7u\u00ed - ES')},
 '55143322':{'en': 'Ourinhos - SP', 'pt': 'Ourinhos - SP'},
 '5042648':{'en': 'Progreso/Santa Cruz'},
 '5042647':{'en': 'Progreso'},
 '5042643':{'en': u('Santa B\u00e1rbara')},
 '55213760':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55213763':{'en': 'Mesquita - RJ', 'pt': 'Mesquita - RJ'},
 '55213762':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55163133':{'en': 'Cristais Paulista - SP', 'pt': 'Cristais Paulista - SP'},
 '55163134':{'en': 'Jeriquara - SP', 'pt': 'Jeriquara - SP'},
 '55163135':{'en': 'Rifaina - SP', 'pt': 'Rifaina - SP'},
 '496665':{'de': 'Sinntal-Altengronau', 'en': 'Sinntal-Altengronau'},
 '496664':{'de': 'Sinntal-Sterbfritz', 'en': 'Sinntal-Sterbfritz'},
 '496843':{'de': 'Gersheim', 'en': 'Gersheim'},
 '496666':{'de': 'Freiensteinau', 'en': 'Freiensteinau'},
 '496661':{'de': u('Schl\u00fcchtern'), 'en': u('Schl\u00fcchtern')},
 '496660':{'de': 'Steinau-Marjoss', 'en': 'Steinau-Marjoss'},
 '496663':{'de': u('Steinau an der Stra\u00dfe'), 'en': 'Steinau an der Strasse'},
 '55112735':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496849':{'de': 'Kirkel', 'en': 'Kirkel'},
 '496848':{'de': u('Homburg-Ein\u00f6d'), 'en': u('Homburg-Ein\u00f6d')},
 '55193617':{'en': 'Rio Claro - SP', 'pt': 'Rio Claro - SP'},
 '496669':{'de': 'Neuhof-Hauswurz', 'en': 'Neuhof-Hauswurz'},
 '496668':{'de': 'Birstein-Lichenroth', 'en': 'Birstein-Lichenroth'},
 '55333212':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333213':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55193734':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55112730':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112731':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313320':{'en': 'Ipaba - MG', 'pt': 'Ipaba - MG'},
 '55212529':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55223820':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55223823':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55223822':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55223824':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55223827':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55223826':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55223829':{'en': u('Laje do Muria\u00e9 - RJ'), 'pt': u('Laje do Muria\u00e9 - RJ')},
 '55223828':{'en': 'Boaventura - RJ', 'pt': 'Boaventura - RJ'},
 '55313078':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114497':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114496':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114495':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114494':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114493':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55114492':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55113117':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113115':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113113':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113112':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55313194':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114148':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55173548':{'en': 'Marapoama - SP', 'pt': 'Marapoama - SP'},
 '55114145':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114144':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114147':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114141':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55173543':{'en': 'Novo Horizonte - SP', 'pt': 'Novo Horizonte - SP'},
 '55114143':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114142':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55153324':{'en': u('Tatu\u00ed - SP'), 'pt': u('Tatu\u00ed - SP')},
 '55153325':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '498558':{'de': 'Hohenau Niederbayern', 'en': 'Hohenau Niederbayern'},
 '55213873':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213872':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213875':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213874':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323025':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '498551':{'de': 'Freyung', 'en': 'Freyung'},
 '498550':{'de': 'Philippsreut', 'en': 'Philippsreut'},
 '498553':{'de': 'Spiegelau', 'en': 'Spiegelau'},
 '498552':{'de': 'Grafenau Niederbayern', 'en': 'Grafenau Niederbayern'},
 '498555':{'de': 'Perlesreut', 'en': 'Perlesreut'},
 '498554':{'de': u('Sch\u00f6nberg Niederbayern'), 'en': u('Sch\u00f6nberg Niederbayern')},
 '498557':{'de': 'Mauth', 'en': 'Mauth'},
 '498556':{'de': u('Haidm\u00fchle'), 'en': u('Haidm\u00fchle')},
 '499974':{'de': 'Traitsching', 'en': 'Traitsching'},
 '499975':{'de': u('Waldm\u00fcnchen-Geigant'), 'en': u('Waldm\u00fcnchen-Geigant')},
 '499976':{'de': u('R\u00f6tz'), 'en': u('R\u00f6tz')},
 '499977':{'de': 'Arnschwang', 'en': 'Arnschwang'},
 '55153355':{'en': 'Angatuba - SP', 'pt': 'Angatuba - SP'},
 '499971':{'de': 'Cham', 'en': 'Cham'},
 '499972':{'de': u('Waldm\u00fcnchen'), 'en': u('Waldm\u00fcnchen')},
 '499973':{'de': 'Furth im Wald', 'en': 'Furth im Wald'},
 '499978':{'de': u('Sch\u00f6nthal Oberpfalz'), 'en': u('Sch\u00f6nthal Oberpfalz')},
 '55114032':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '499156':{'de': 'Neuhaus an der Pegnitz', 'en': 'Neuhaus an der Pegnitz'},
 '499157':{'de': 'Alfeld Mittelfranken', 'en': 'Alfeld Mittelfranken'},
 '494302':{'de': 'Kirchbarkau', 'en': 'Kirchbarkau'},
 '494303':{'de': 'Schlesen', 'en': 'Schlesen'},
 '55113287':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495129':{'de': u('S\u00f6hlde'), 'en': u('S\u00f6hlde')},
 '495128':{'de': 'Hohenhameln', 'en': 'Hohenhameln'},
 '55112646':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112647':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495123':{'de': 'Schellerten', 'en': 'Schellerten'},
 '495121':{'de': 'Hildesheim', 'en': 'Hildesheim'},
 '495127':{'de': 'Harsum', 'en': 'Harsum'},
 '495126':{'de': 'Algermissen', 'en': 'Algermissen'},
 '55123014':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55113284':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123011':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123013':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55193804':{'en': 'Mogi Mirim - SP', 'pt': 'Mogi Mirim - SP'},
 '55222527':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55113931':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222525':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55222524':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55123019':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123018':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55222521':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55222520':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55193801':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55193803':{'en': u('Sumar\u00e9 - SP'), 'pt': u('Sumar\u00e9 - SP')},
 '55115111':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193802':{'en': 'Holambra - SP', 'pt': 'Holambra - SP'},
 '55223211':{'en': 'Campos dos Goytacazes - RJ', 'pt': 'Campos dos Goytacazes - RJ'},
 '499206':{'de': 'Mistelgau-Obernsees', 'en': 'Mistelgau-Obernsees'},
 '499207':{'de': u('K\u00f6nigsfeld Oberfranken'), 'en': u('K\u00f6nigsfeld Oberfranken')},
 '499204':{'de': 'Plankenfels', 'en': 'Plankenfels'},
 '499205':{'de': 'Vorbach', 'en': 'Vorbach'},
 '55112392':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112461':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112462':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499201':{'de': 'Gesees', 'en': 'Gesees'},
 '55112468':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112469':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499208':{'de': 'Bindlach', 'en': 'Bindlach'},
 '499209':{'de': 'Emtmannsberg', 'en': 'Emtmannsberg'},
 '543541':{'en': u('Villa Carlos Paz, C\u00f3rdoba'), 'es': u('Villa Carlos Paz, C\u00f3rdoba')},
 '543543':{'en': u('C\u00f3rdoba (Arg\u00fcello), C\u00f3rdoba'), 'es': u('C\u00f3rdoba (Arg\u00fcello), C\u00f3rdoba')},
 '543542':{'en': u('Salsacate, C\u00f3rdoba'), 'es': u('Salsacate, C\u00f3rdoba')},
 '543544':{'en': u('Villa Dolores, C\u00f3rdoba'), 'es': u('Villa Dolores, C\u00f3rdoba')},
 '543547':{'en': u('Alta Gracia, C\u00f3rdoba'), 'es': u('Alta Gracia, C\u00f3rdoba')},
 '543546':{'en': u('Santa Rosa de Calamuchita, C\u00f3rdoba'), 'es': u('Santa Rosa de Calamuchita, C\u00f3rdoba')},
 '49811':{'de': 'Hallbergmoos', 'en': 'Hallbergmoos'},
 '543548':{'en': u('La Falda, C\u00f3rdoba'), 'es': u('La Falda, C\u00f3rdoba')},
 '55163832':{'en': u('Ipu\u00e3 - SP'), 'pt': u('Ipu\u00e3 - SP')},
 '55163831':{'en': u('Guar\u00e1 - SP'), 'pt': u('Guar\u00e1 - SP')},
 '55163830':{'en': 'Ituverava - SP', 'pt': 'Ituverava - SP'},
 '55163835':{'en': u('Miguel\u00f3polis - SP'), 'pt': u('Miguel\u00f3polis - SP')},
 '55163839':{'en': 'Ituverava - SP', 'pt': 'Ituverava - SP'},
 '55163838':{'en': 'Ituverava - SP', 'pt': 'Ituverava - SP'},
 '55173838':{'en': u('Pedran\u00f3polis - SP'), 'pt': u('Pedran\u00f3polis - SP')},
 '496478':{'de': 'Greifenstein-Ulm', 'en': 'Greifenstein-Ulm'},
 '496479':{'de': 'Waldbrunn Westerwald', 'en': 'Waldbrunn Westerwald'},
 '55183266':{'en': 'Alfredo Marcondes - SP', 'pt': 'Alfredo Marcondes - SP'},
 '55183267':{'en': 'Santo Expedito - SP', 'pt': 'Santo Expedito - SP'},
 '55212519':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183261':{'en': u('Ribeir\u00e3o dos \u00cdndios - SP'), 'pt': u('Ribeir\u00e3o dos \u00cdndios - SP')},
 '55183262':{'en': 'Presidente Bernardes - SP', 'pt': 'Presidente Bernardes - SP'},
 '55183263':{'en': u('Santo Anast\u00e1cio - SP'), 'pt': u('Santo Anast\u00e1cio - SP')},
 '55212515':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '496471':{'de': 'Weilburg', 'en': 'Weilburg'},
 '496472':{'de': u('Weilm\u00fcnster'), 'en': u('Weilm\u00fcnster')},
 '496473':{'de': 'Leun', 'en': 'Leun'},
 '496474':{'de': 'Villmar-Aumenau', 'en': 'Villmar-Aumenau'},
 '496475':{'de': u('Weilm\u00fcnster-Wolfenhausen'), 'en': u('Weilm\u00fcnster-Wolfenhausen')},
 '496476':{'de': 'Mengerskirchen', 'en': 'Mengerskirchen'},
 '496477':{'de': 'Greifenstein-Nenderoth', 'en': 'Greifenstein-Nenderoth'},
 '55124242':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55173839':{'en': 'Parisi - SP', 'pt': 'Parisi - SP'},
 '55113444':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495873':{'de': 'Eimke', 'en': 'Eimke'},
 '495872':{'de': 'Stoetze', 'en': 'Stoetze'},
 '495875':{'de': 'Emmendorf', 'en': 'Emmendorf'},
 '495874':{'de': 'Soltendieck', 'en': 'Soltendieck'},
 '496782':{'de': 'Birkenfeld Nahe', 'en': 'Birkenfeld Nahe'},
 '496783':{'de': 'Baumholder', 'en': 'Baumholder'},
 '55313892':{'en': u('Vi\u00e7osa - MG'), 'pt': u('Vi\u00e7osa - MG')},
 '496781':{'de': 'Idar-Oberstein', 'en': 'Idar-Oberstein'},
 '496786':{'de': 'Kempfeld', 'en': 'Kempfeld'},
 '496787':{'de': 'Niederbrombach', 'en': 'Niederbrombach'},
 '496784':{'de': 'Weierbach', 'en': 'Weierbach'},
 '496785':{'de': 'Herrstein', 'en': 'Herrstein'},
 '55313898':{'en': 'Cajuri - MG', 'pt': 'Cajuri - MG'},
 '55313899':{'en': u('Vi\u00e7osa - MG'), 'pt': u('Vi\u00e7osa - MG')},
 '55113447':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '496789':{'de': 'Heimbach Nahe', 'en': 'Heimbach Nahe'},
 '55114707':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55114706':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114705':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114704':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55114703':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114702':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114701':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55213626':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55114708':{'en': 'Mairinque - SP', 'pt': 'Mairinque - SP'},
 '495608':{'de': u('S\u00f6hrewald'), 'en': u('S\u00f6hrewald')},
 '495609':{'de': 'Ahnatal', 'en': 'Ahnatal'},
 '55183695':{'en': 'Planalto - SP', 'pt': 'Planalto - SP'},
 '495606':{'de': 'Zierenberg', 'en': 'Zierenberg'},
 '55183697':{'en': u('Rubi\u00e1cea - SP'), 'pt': u('Rubi\u00e1cea - SP')},
 '55183696':{'en': u('Turi\u00faba - SP'), 'pt': u('Turi\u00faba - SP')},
 '55183691':{'en': 'Buritama - SP', 'pt': 'Buritama - SP'},
 '55183693':{'en': 'Piacatu - SP', 'pt': 'Piacatu - SP'},
 '55183692':{'en': u('Bra\u00fana - SP'), 'pt': u('Bra\u00fana - SP')},
 '495331':{'de': u('Wolfenb\u00fcttel'), 'en': u('Wolfenb\u00fcttel')},
 '55183699':{'en': 'Lourdes - SP', 'pt': 'Lourdes - SP'},
 '55183698':{'en': u('Lav\u00ednia - SP'), 'pt': u('Lav\u00ednia - SP')},
 '497257':{'de': 'Bruchsal-Untergrombach', 'en': 'Bruchsal-Untergrombach'},
 '497256':{'de': 'Philippsburg', 'en': 'Philippsburg'},
 '497255':{'de': 'Graben-Neudorf', 'en': 'Graben-Neudorf'},
 '497254':{'de': u('Wagh\u00e4usel'), 'en': u('Wagh\u00e4usel')},
 '497253':{'de': u('Bad Sch\u00f6nborn'), 'en': u('Bad Sch\u00f6nborn')},
 '497252':{'de': 'Bretten', 'en': 'Bretten'},
 '497251':{'de': 'Bruchsal', 'en': 'Bruchsal'},
 '497250':{'de': 'Kraichtal', 'en': 'Kraichtal'},
 '55212542':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55243348':{'en': 'Volta Redonda - RJ', 'pt': 'Volta Redonda - RJ'},
 '497259':{'de': u('\u00d6stringen-Odenheim'), 'en': u('\u00d6stringen-Odenheim')},
 '497258':{'de': 'Oberderdingen-Flehingen', 'en': 'Oberderdingen-Flehingen'},
 '55213644':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55212541':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213642':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55213643':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55113569':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163204':{'en': 'Jaboticabal - SP', 'pt': 'Jaboticabal - SP'},
 '55113443':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55333022':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333021':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55333254':{'en': u('Perp\u00e9tuo Socorro - MG'), 'pt': u('Perp\u00e9tuo Socorro - MG')},
 '497433':{'de': 'Balingen', 'en': 'Balingen'},
 '497432':{'de': 'Albstadt-Tailfingen', 'en': 'Albstadt-Tailfingen'},
 '497431':{'de': 'Albstadt-Ebingen', 'en': 'Albstadt-Ebingen'},
 '497436':{'de': 'Messstetten-Oberdigisheim', 'en': 'Messstetten-Oberdigisheim'},
 '497435':{'de': 'Albstadt-Laufen', 'en': 'Albstadt-Laufen'},
 '497434':{'de': 'Winterlingen', 'en': 'Winterlingen'},
 '55113442':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163202':{'en': 'Jaboticabal - SP', 'pt': 'Jaboticabal - SP'},
 '55213388':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55163203':{'en': 'Jaboticabal - SP', 'pt': 'Jaboticabal - SP'},
 '55224104':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '55114347':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55333263':{'en': 'Resplendor - MG', 'pt': 'Resplendor - MG'},
 '55163265':{'en': 'Tapinas - SP', 'pt': 'Tapinas - SP'},
 '498032':{'de': 'Rohrdorf Kreis Rosenheim', 'en': 'Rohrdorf Kreis Rosenheim'},
 '498033':{'de': 'Oberaudorf', 'en': 'Oberaudorf'},
 '498031':{'de': 'Rosenheim Oberbayern', 'en': 'Rosenheim Oberbayern'},
 '498036':{'de': 'Stephanskirchen Simssee', 'en': 'Stephanskirchen Simssee'},
 '498034':{'de': 'Brannenburg', 'en': 'Brannenburg'},
 '498035':{'de': 'Raubling', 'en': 'Raubling'},
 '498038':{'de': 'Vogtareuth', 'en': 'Vogtareuth'},
 '498039':{'de': 'Rott am Inn', 'en': 'Rott am Inn'},
 '55163241':{'en': 'Monte Alto - SP', 'pt': 'Monte Alto - SP'},
 '55163242':{'en': 'Monte Alto - SP', 'pt': 'Monte Alto - SP'},
 '55163243':{'en': 'Monte Alto - SP', 'pt': 'Monte Alto - SP'},
 '55163244':{'en': 'Monte Alto - SP', 'pt': 'Monte Alto - SP'},
 '55163246':{'en': u('Tai\u00fava - SP'), 'pt': u('Tai\u00fava - SP')},
 '55313751':{'en': 'Entre Rios de Minas - MG', 'pt': 'Entre Rios de Minas - MG'},
 '498784':{'de': 'Hohenthann', 'en': 'Hohenthann'},
 '498785':{'de': 'Rottenburg-Oberroning', 'en': 'Rottenburg-Oberroning'},
 '498781':{'de': 'Rottenburg an der Laaber', 'en': 'Rottenburg an der Laaber'},
 '498782':{'de': 'Pfeffenhausen', 'en': 'Pfeffenhausen'},
 '498783':{'de': 'Rohr in Niederbayern', 'en': 'Rohr in Niederbayern'},
 '55273341':{'en': 'Serra - ES', 'pt': 'Serra - ES'},
 '49661':{'de': 'Fulda', 'en': 'Fulda'},
 '55313755':{'en': 'Senhora de Oliveira - MG', 'pt': 'Senhora de Oliveira - MG'},
 '499569':{'de': 'Sesslach', 'en': 'Sesslach'},
 '499568':{'de': 'Neustadt bei Coburg', 'en': 'Neustadt bei Coburg'},
 '499567':{'de': u('Se\u00dflach-Gem\u00fcnda'), 'en': u('Sesslach-Gem\u00fcnda')},
 '499566':{'de': 'Meeder', 'en': 'Meeder'},
 '499565':{'de': 'Untersiemau', 'en': 'Untersiemau'},
 '499564':{'de': 'Bad Rodach', 'en': 'Bad Rodach'},
 '499563':{'de': u('R\u00f6dental'), 'en': u('R\u00f6dental')},
 '499562':{'de': 'Sonnefeld', 'en': 'Sonnefeld'},
 '499561':{'de': 'Coburg', 'en': 'Coburg'},
 '499560':{'de': 'Grub am Forst', 'en': 'Grub am Forst'},
 '55173818':{'en': 'Bady Bassitt - SP', 'pt': 'Bady Bassitt - SP'},
 '55173819':{'en': 'Poloni - SP', 'pt': 'Poloni - SP'},
 '55163797':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55273347':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '55123889':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55222102':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '55173814':{'en': 'Adolfo - SP', 'pt': 'Adolfo - SP'},
 '55313539':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55213629':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313249':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313248':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55173815':{'en': 'Guaraci - SP', 'pt': 'Guaraci - SP'},
 '55313245':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313532':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313247':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313530':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313241':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313240':{'en': u('Perp\u00e9tuo Socorro - MG'), 'pt': u('Perp\u00e9tuo Socorro - MG')},
 '55313535':{'en': 'Mateus Leme - MG', 'pt': 'Mateus Leme - MG'},
 '55313534':{'en': u('Igarap\u00e9 - MG'), 'pt': u('Igarap\u00e9 - MG')},
 '55183909':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183908':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183905':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183907':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183906':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183901':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55183903':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '49481':{'de': 'Heide Holstein', 'en': 'Heide Holstein'},
 '52613':{'en': 'Baja California Sur', 'es': 'Baja California Sur'},
 '52612':{'en': 'La Paz/Todos Santos, BCS', 'es': 'La Paz/Todos Santos, BCS'},
 '55113708':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113709':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193412':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '52616':{'en': 'Baja California', 'es': 'Baja California'},
 '52615':{'en': 'Baja California Sur', 'es': 'Baja California Sur'},
 '52614':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '55113251':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113252':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113253':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113254':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113255':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113256':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113257':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213380':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55183862':{'en': 'Pacaembu - SP', 'pt': 'Pacaembu - SP'},
 '55223022':{'en': 'Itaperuna - RJ', 'pt': 'Itaperuna - RJ'},
 '55212424':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212426':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55243379':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55143382':{'en': 'Fartura - SP', 'pt': 'Fartura - SP'},
 '55193678':{'en': 'Canoas - SP', 'pt': 'Canoas - SP'},
 '55193679':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55143387':{'en': u('Sarutai\u00e1 - SP'), 'pt': u('Sarutai\u00e1 - SP')},
 '55143386':{'en': u('Tagua\u00ed - SP'), 'pt': u('Tagua\u00ed - SP')},
 '55143385':{'en': u('Tejup\u00e1 - SP'), 'pt': u('Tejup\u00e1 - SP')},
 '55193672':{'en': 'Santa Cruz das Palmeiras - SP', 'pt': 'Santa Cruz das Palmeiras - SP'},
 '55193673':{'en': u('Tamba\u00fa - SP'), 'pt': u('Tamba\u00fa - SP')},
 '55143389':{'en': 'Timburi - SP', 'pt': 'Timburi - SP'},
 '55193671':{'en': 'Casa Branca - SP', 'pt': 'Casa Branca - SP'},
 '55193674':{'en': 'Casa Branca - SP', 'pt': 'Casa Branca - SP'},
 '55193675':{'en': u('Tamba\u00fa - SP'), 'pt': u('Tamba\u00fa - SP')},
 '52785':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52388':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55123302':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55113078':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213077':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112079':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112078':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '495664':{'de': 'Morschen', 'en': 'Morschen'},
 '55112072':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112071':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112070':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495661':{'de': 'Melsungen', 'en': 'Melsungen'},
 '495662':{'de': 'Felsberg Hessen', 'en': 'Felsberg Hessen'},
 '55112074':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123972':{'en': 'Santa Branca - SP', 'pt': 'Santa Branca - SP'},
 '55123201':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123202':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123203':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123204':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123206':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123207':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55143488':{'en': 'Quintana - SP', 'pt': 'Quintana - SP'},
 '55123978':{'en': 'Jambeiro - SP', 'pt': 'Jambeiro - SP'},
 '55123979':{'en': 'Monteiro Lobato - SP', 'pt': 'Monteiro Lobato - SP'},
 '55323229':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55192108':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55192103':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192102':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192101':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192107':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55192106':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55192105':{'en': 'Piracicaba - SP', 'pt': 'Piracicaba - SP'},
 '55192104':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '543388':{'en': 'General Villegas, Buenos Aires', 'es': 'General Villegas, Buenos Aires'},
 '543754':{'en': 'Leandro N. Alem, Misiones', 'es': 'Leandro N. Alem, Misiones'},
 '543755':{'en': u('Ober\u00e1, Misiones'), 'es': u('Ober\u00e1, Misiones')},
 '543756':{'en': u('Santo Tom\u00e9, Corrientes'), 'es': u('Santo Tom\u00e9, Corrientes')},
 '543757':{'en': u('Puerto Iguaz\u00fa, Misiones'), 'es': u('Puerto Iguaz\u00fa, Misiones')},
 '543751':{'en': 'Eldorado, Misiones', 'es': 'Eldorado, Misiones'},
 '543758':{'en': u('Ap\u00f3stoles, Misiones'), 'es': u('Ap\u00f3stoles, Misiones')},
 '55323222':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55323224':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55313284':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55115851':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115704':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55193746':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55183223':{'en': 'Presidente Prudente - SP', 'pt': 'Presidente Prudente - SP'},
 '55313576':{'en': 'Bonfim - MG', 'pt': 'Bonfim - MG'},
 '55313575':{'en': 'Moeda - MG', 'pt': 'Moeda - MG'},
 '55333232':{'en': u('Sobr\u00e1lia - MG'), 'pt': u('Sobr\u00e1lia - MG')},
 '55212709':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '496869':{'de': 'Merzig-Silwingen', 'en': 'Merzig-Silwingen'},
 '496868':{'de': u('Mettlach-T\u00fcnsdorf'), 'en': u('Mettlach-T\u00fcnsdorf')},
 '55333236':{'en': 'Alpercata - MG', 'pt': 'Alpercata - MG'},
 '55333237':{'en': 'Fernandes Tourinho - MG', 'pt': 'Fernandes Tourinho - MG'},
 '55333234':{'en': 'Engenheiro Caldas - MG', 'pt': 'Engenheiro Caldas - MG'},
 '496648':{'de': 'Bad Salzschlirf', 'en': 'Bad Salzschlirf'},
 '496647':{'de': 'Herbstein-Stockhausen', 'en': 'Herbstein-Stockhausen'},
 '496646':{'de': 'Grebenau', 'en': 'Grebenau'},
 '496861':{'de': 'Merzig', 'en': 'Merzig'},
 '496644':{'de': 'Grebenhain', 'en': 'Grebenhain'},
 '496643':{'de': 'Herbstein', 'en': 'Herbstein'},
 '496642':{'de': 'Schlitz', 'en': 'Schlitz'},
 '496865':{'de': 'Mettlach-Orscholz', 'en': 'Mettlach-Orscholz'},
 '496864':{'de': 'Mettlach', 'en': 'Mettlach'},
 '496245':{'de': 'Biblis', 'en': 'Biblis'},
 '55313571':{'en': 'Brumadinho - MG', 'pt': 'Brumadinho - MG'},
 '496244':{'de': 'Westhofen Rheinhessenen', 'en': 'Westhofen Rheinhessenen'},
 '55313579':{'en': 'Aranha - MG', 'pt': 'Aranha - MG'},
 '55114241':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55133231':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133232':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133236':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133237':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133238':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133239':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55163934':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55115542':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115543':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193324':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55112641':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193325':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55223847':{'en': 'Raposo - RJ', 'pt': 'Raposo - RJ'},
 '55115541':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55223843':{'en': 'Varre-Sai - RJ', 'pt': 'Varre-Sai - RJ'},
 '55193326':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55223841':{'en': 'Natividade - RJ', 'pt': 'Natividade - RJ'},
 '55115547':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55193328':{'en': 'Indaiatuba - SP', 'pt': 'Indaiatuba - SP'},
 '55115816':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115545':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112642':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495195':{'de': 'Neuenkirchen bei Soltau', 'en': 'Neuenkirchen bei Soltau'},
 '55113135':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113133':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113138':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115932':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5156':{'en': 'Ica'},
 '55173524':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55173525':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55173521':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55173522':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55173523':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55173529':{'en': u('Elisi\u00e1rio - SP'), 'pt': u('Elisi\u00e1rio - SP')},
 '55212543':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498432':{'de': 'Burgheim', 'en': 'Burgheim'},
 '498433':{'de': u('K\u00f6nigsmoos'), 'en': u('K\u00f6nigsmoos')},
 '498573':{'de': 'Ering', 'en': 'Ering'},
 '498572':{'de': 'Tann Niederbayern', 'en': 'Tann Niederbayern'},
 '498571':{'de': 'Simbach am Inn', 'en': 'Simbach am Inn'},
 '55313462':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '498574':{'de': 'Wittibreut', 'en': 'Wittibreut'},
 '498431':{'de': 'Neuburg an der Donau', 'en': 'Neuburg an der Donau'},
 '55213816':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213814':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213813':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213818':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '542964':{'en': u('R\u00edo Grande, Tierra del Fuego'), 'es': u('R\u00edo Grande, Tierra del Fuego')},
 '55153335':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153334':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '495403':{'de': 'Bad Iburg', 'en': 'Bad Iburg'},
 '55153330':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55312323':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '542966':{'en': u('R\u00edo Gallegos, Santa Cruz'), 'es': u('R\u00edo Gallegos, Santa Cruz')},
 '55153339':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '52424':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52425':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52426':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52427':{'en': 'Mexico/Quintana Roo', 'es': u('M\u00e9xico/Quintana Roo')},
 '52421':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '52422':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52423':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52428':{'en': 'Ocampo/San Felipe, GTO', 'es': 'Ocampo/San Felipe, GTO'},
 '52429':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '495495':{'de': u('V\u00f6rden Kreis Vechta'), 'en': u('V\u00f6rden Kreis Vechta')},
 '55114184':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '542963':{'en': 'Perito Moreno, Santa Cruz', 'es': 'Perito Moreno, Santa Cruz'},
 '499196':{'de': 'Wiesenttal', 'en': 'Wiesenttal'},
 '499197':{'de': 'Egloffstein', 'en': 'Egloffstein'},
 '55112664':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '499195':{'de': 'Adelsdorf Mittelfranken', 'en': 'Adelsdorf Mittelfranken'},
 '55112662':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112663':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499190':{'de': 'Heroldsbach', 'en': 'Heroldsbach'},
 '55112661':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113701':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112668':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499199':{'de': 'Kunreuth', 'en': 'Kunreuth'},
 '55273753':{'en': u('Vila Pav\u00e3o - ES'), 'pt': u('Vila Pav\u00e3o - ES')},
 '55113399':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55163472':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '55113393':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113392':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113395':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55243363':{'en': 'Angra dos Reis - RJ', 'pt': 'Angra dos Reis - RJ'},
 '55163475':{'en': u('Sert\u00e3ozinho - SP'), 'pt': u('Sert\u00e3ozinho - SP')},
 '55273757':{'en': 'Ponto Belo - ES', 'pt': 'Ponto Belo - ES'},
 '55112918':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112919':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55273754':{'en': 'Montanha - ES', 'pt': 'Montanha - ES'},
 '55112910':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112911':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112912':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112441':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112914':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112915':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112916':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112917':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499220':{'de': 'Kasendorf-Azendorf', 'en': 'Kasendorf-Azendorf'},
 '499221':{'de': 'Kulmbach', 'en': 'Kulmbach'},
 '499222':{'de': 'Presseck', 'en': 'Presseck'},
 '499223':{'de': 'Rugendorf', 'en': 'Rugendorf'},
 '499225':{'de': 'Stadtsteinach', 'en': 'Stadtsteinach'},
 '49831':{'de': u('Kempten Allg\u00e4u'), 'en': u('Kempten Allg\u00e4u')},
 '499227':{'de': 'Neuenmarkt', 'en': 'Neuenmarkt'},
 '5042435':{'en': 'Oakridge'},
 '499229':{'de': 'Mainleus', 'en': 'Mainleus'},
 '5042436':{'en': 'La Masica'},
 '5042431':{'en': u('San Francisco, Atl\u00e1ntida')},
 '5042433':{'en': 'Arenal'},
 '494735':{'de': 'Butjadingen-Stollhamm', 'en': 'Butjadingen-Stollhamm'},
 '55273759':{'en': u('\u00c1gua Doce do Norte - ES'), 'pt': u('\u00c1gua Doce do Norte - ES')},
 '55212289':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212288':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494734':{'de': 'Stadland-Seefeld', 'en': 'Stadland-Seefeld'},
 '543563':{'en': u('Balnearia, C\u00f3rdoba'), 'es': u('Balnearia, C\u00f3rdoba')},
 '543562':{'en': u('Morteros, C\u00f3rdoba'), 'es': u('Morteros, C\u00f3rdoba')},
 '55212287':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212286':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '494737':{'de': 'Stadland-Schwei', 'en': 'Stadland-Schwei'},
 '55212283':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '543564':{'en': u('San Francisco, C\u00f3rdoba'), 'es': u('San Francisco, C\u00f3rdoba')},
 '494731':{'de': 'Nordenham', 'en': 'Nordenham'},
 '55273381':{'en': u('Vit\u00f3ria - ES'), 'pt': u('Vit\u00f3ria - ES')},
 '494733':{'de': 'Butjadingen-Burhave', 'en': 'Butjadingen-Burhave'},
 '494732':{'de': 'Stadland-Rodenkirchen', 'en': 'Stadland-Rodenkirchen'},
 '55213850':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '54280':{'en': 'Trelew/Rawson, Chubut', 'es': 'Trelew/Rawson, Chubut'},
 '55143441':{'en': u('Tup\u00e3 - SP'), 'pt': u('Tup\u00e3 - SP')},
 '55114729':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114728':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114725':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114727':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114726':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114723':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114722':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55163818':{'en': u('S\u00e3o Joaquim da Barra - SP'), 'pt': u('S\u00e3o Joaquim da Barra - SP')},
 '55163811':{'en': u('S\u00e3o Joaquim da Barra - SP'), 'pt': u('S\u00e3o Joaquim da Barra - SP')},
 '55163810':{'en': u('S\u00e3o Joaquim da Barra - SP'), 'pt': u('S\u00e3o Joaquim da Barra - SP')},
 '497231':{'de': 'Pforzheim', 'en': 'Pforzheim'},
 '497233':{'de': u('Niefern-\u00d6schelbronn'), 'en': u('Niefern-\u00d6schelbronn')},
 '497232':{'de': u('K\u00f6nigsbach-Stein'), 'en': u('K\u00f6nigsbach-Stein')},
 '497235':{'de': 'Unterreichenbach Kreis Calw', 'en': 'Unterreichenbach Kreis Calw'},
 '497234':{'de': 'Tiefenbronn', 'en': 'Tiefenbronn'},
 '497237':{'de': 'Neulingen Enzkreis', 'en': 'Neulingen Enzkreis'},
 '497236':{'de': 'Keltern', 'en': 'Keltern'},
 '495853':{'de': 'Neu Darchau', 'en': 'Neu Darchau'},
 '495852':{'de': 'Bleckede', 'en': 'Bleckede'},
 '495507':{'de': u('Eberg\u00f6tzen'), 'en': u('Eberg\u00f6tzen')},
 '495506':{'de': 'Adelebsen', 'en': 'Adelebsen'},
 '495857':{'de': 'Bleckede-Brackede', 'en': 'Bleckede-Brackede'},
 '55213621':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495855':{'de': 'Nahrendorf', 'en': 'Nahrendorf'},
 '495502':{'de': 'Dransfeld', 'en': 'Dransfeld'},
 '495859':{'de': 'Thomasburg', 'en': 'Thomasburg'},
 '495858':{'de': 'Hitzacker-Wietzetze', 'en': 'Hitzacker-Wietzetze'},
 '495509':{'de': u('Rosdorf Kreis G\u00f6ttingen'), 'en': u('Rosdorf Kreis G\u00f6ttingen')},
 '495508':{'de': 'Gleichen-Rittmarshausen', 'en': 'Gleichen-Rittmarshausen'},
 '504261':{'en': u('Choloma, Cort\u00e9s')},
 '55163364':{'en': u('S\u00e3o Carlos - SP'), 'pt': u('S\u00e3o Carlos - SP')},
 '55173312':{'en': 'Barretos - SP', 'pt': 'Barretos - SP'},
 '55173311':{'en': 'Catanduva - SP', 'pt': 'Catanduva - SP'},
 '55143295':{'en': u('Borac\u00e9ia - SP'), 'pt': u('Borac\u00e9ia - SP')},
 '55173811':{'en': u('Nova Alian\u00e7a - SP'), 'pt': u('Nova Alian\u00e7a - SP')},
 '55143297':{'en': 'Bairro de Santa Izabel - SP', 'pt': 'Bairro de Santa Izabel - SP'},
 '55313611':{'en': u('Vi\u00e7osa - MG'), 'pt': u('Vi\u00e7osa - MG')},
 '55143296':{'en': 'Arealva - SP', 'pt': 'Arealva - SP'},
 '55143291':{'en': u('Dom\u00e9lia - SP'), 'pt': u('Dom\u00e9lia - SP')},
 '55143293':{'en': u('Guaian\u00e1s - SP'), 'pt': u('Guaian\u00e1s - SP')},
 '55143292':{'en': 'Pederneiras - SP', 'pt': 'Pederneiras - SP'},
 '55153522':{'en': 'Itapeva - SP', 'pt': 'Itapeva - SP'},
 '55153523':{'en': 'Caputera - SP', 'pt': 'Caputera - SP'},
 '55153521':{'en': 'Itapeva - SP', 'pt': 'Itapeva - SP'},
 '55153526':{'en': 'Itapeva - SP', 'pt': 'Itapeva - SP'},
 '55153527':{'en': 'Itapetininga - SP', 'pt': 'Itapetininga - SP'},
 '55153524':{'en': 'Itapeva - SP', 'pt': 'Itapeva - SP'},
 '55212257':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '495274':{'de': 'Nieheim', 'en': 'Nieheim'},
 '55213852':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212643':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '499765':{'de': 'Trappstadt', 'en': 'Trappstadt'},
 '499764':{'de': u('H\u00f6chheim'), 'en': u('H\u00f6chheim')},
 '499766':{'de': 'Grosswenkheim', 'en': 'Grosswenkheim'},
 '499761':{'de': u('Bad K\u00f6nigshofen im Grabfeld'), 'en': u('Bad K\u00f6nigshofen im Grabfeld')},
 '499763':{'de': 'Sulzdorf an der Lederhecke', 'en': 'Sulzdorf an der Lederhecke'},
 '499762':{'de': 'Saal an der Saale', 'en': 'Saal an der Saale'},
 '55212258':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '497907':{'de': u('Schw\u00e4bisch Hall-Sulzdorf'), 'en': u('Schw\u00e4bisch Hall-Sulzdorf')},
 '497906':{'de': 'Braunsbach', 'en': 'Braunsbach'},
 '497905':{'de': 'Langenburg', 'en': 'Langenburg'},
 '497904':{'de': 'Ilshofen', 'en': 'Ilshofen'},
 '497903':{'de': 'Mainhardt', 'en': 'Mainhardt'},
 '55113892':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113891':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113896':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113897':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113895':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113898':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113899':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212630':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55133291':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55213857':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212704':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '49641':{'de': 'Giessen', 'en': 'Giessen'},
 '499503':{'de': 'Oberhaid Oberfranken', 'en': 'Oberhaid Oberfranken'},
 '499502':{'de': 'Frensdorf', 'en': 'Frensdorf'},
 '499505':{'de': 'Litzendorf', 'en': 'Litzendorf'},
 '499504':{'de': 'Stadelhofen', 'en': 'Stadelhofen'},
 '55113098':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113092':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113093':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113091':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113096':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113097':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113094':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113095':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213856':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55212705':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55313511':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313512':{'en': 'Betim - MG', 'pt': 'Betim - MG'},
 '55313515':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '495252':{'de': 'Bad Lippspringe', 'en': 'Bad Lippspringe'},
 '55313519':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55114264':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55114265':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55213855':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '5173':{'en': 'Piura'},
 '5172':{'en': 'Tumbes'},
 '55193478':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '5176':{'en': 'Cajamarca'},
 '5174':{'en': 'Lambayeque'},
 '55193476':{'en': 'Nova Odessa - SP', 'pt': 'Nova Odessa - SP'},
 '55193477':{'en': 'Americana - SP', 'pt': 'Americana - SP'},
 '55193473':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '55113278':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113276':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113277':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52673':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '52672':{'en': 'Sinaloa', 'es': 'Sinaloa'},
 '52675':{'en': 'Durango', 'es': 'Durango'},
 '55113273':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52677':{'en': 'Durango', 'es': 'Durango'},
 '55113271':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143472':{'en': 'Ubirajara - SP', 'pt': 'Ubirajara - SP'},
 '55133348':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55193695':{'en': 'Mococa - SP', 'pt': 'Mococa - SP'},
 '55193898':{'en': u('Lind\u00f3ia - SP'), 'pt': u('Lind\u00f3ia - SP')},
 '55212631':{'en': u('Mag\u00e9 - RJ'), 'pt': u('Mag\u00e9 - RJ')},
 '55193899':{'en': 'Monte Alegre do Sul - SP', 'pt': 'Monte Alegre do Sul - SP'},
 '55143471':{'en': u('Gar\u00e7a - SP'), 'pt': u('Gar\u00e7a - SP')},
 '55133347':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '496429':{'de': 'Schweinsberg Hessen', 'en': 'Schweinsberg Hessen'},
 '55193892':{'en': 'Serra Negra - SP', 'pt': 'Serra Negra - SP'},
 '496428':{'de': 'Stadtallendorf', 'en': 'Stadtallendorf'},
 '55313039':{'en': u('Tim\u00f3teo - MG'), 'pt': u('Tim\u00f3teo - MG')},
 '55193891':{'en': u('Mogi-Gua\u00e7u - SP'), 'pt': u('Mogi-Gua\u00e7u - SP')},
 '55193896':{'en': u('Santo Ant\u00f4nio de Posse - SP'), 'pt': u('Santo Ant\u00f4nio de Posse - SP')},
 '55193897':{'en': u('Hortol\u00e2ndia - SP'), 'pt': u('Hortol\u00e2ndia - SP')},
 '55143479':{'en': 'Avencas - SP', 'pt': 'Avencas - SP'},
 '55213019':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55143478':{'en': 'Bastos - SP', 'pt': 'Bastos - SP'},
 '55213017':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213016':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213015':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193895':{'en': 'Socorro - SP', 'pt': 'Socorro - SP'},
 '55213013':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213012':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213010':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112057':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112056':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112059':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112058':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123224':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123221':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55192121':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192122':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192127':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55192129':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55333294':{'en': 'Nacip Raydan - MG', 'pt': 'Nacip Raydan - MG'},
 '55212498':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212499':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212490':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212491':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212492':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212493':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212494':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212495':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212496':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212497':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55193030':{'en': 'Vinhedo - SP', 'pt': 'Vinhedo - SP'},
 '55115721':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '496337':{'de': 'Grossbundenbach', 'en': 'Grossbundenbach'},
 '496336':{'de': 'Dellfeld', 'en': 'Dellfeld'},
 '496335':{'de': 'Trulben', 'en': 'Trulben'},
 '496334':{'de': u('Thaleischweiler-Fr\u00f6schen'), 'en': u('Thaleischweiler-Fr\u00f6schen')},
 '496333':{'de': 'Waldfischbach-Burgalben', 'en': 'Waldfischbach-Burgalben'},
 '496332':{'de': u('Zweibr\u00fccken'), 'en': u('Zweibr\u00fccken')},
 '496331':{'de': 'Pirmasens', 'en': 'Pirmasens'},
 '496339':{'de': 'Grosssteinhausen', 'en': 'Grosssteinhausen'},
 '496338':{'de': 'Hornbach Pfalz', 'en': 'Hornbach Pfalz'},
 '496629':{'de': 'Schenklengsfeld', 'en': 'Schenklengsfeld'},
 '496628':{'de': 'Oberaula', 'en': 'Oberaula'},
 '496591':{'de': 'Gerolstein', 'en': 'Gerolstein'},
 '55212728':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '496621':{'de': 'Bad Hersfeld', 'en': 'Bad Hersfeld'},
 '496620':{'de': 'Philippsthal Werra', 'en': 'Philippsthal Werra'},
 '496623':{'de': 'Rotenburg an der Fulda', 'en': 'Rotenburg an der Fulda'},
 '496622':{'de': 'Bebra', 'en': 'Bebra'},
 '496625':{'de': 'Niederaula', 'en': 'Niederaula'},
 '496624':{'de': 'Heringen Werra', 'en': 'Heringen Werra'},
 '496627':{'de': 'Nentershausen Hessen', 'en': 'Nentershausen Hessen'},
 '496626':{'de': 'Wildeck-Obersuhl', 'en': 'Wildeck-Obersuhl'},
 '55173542':{'en': 'Novo Horizonte - SP', 'pt': 'Novo Horizonte - SP'},
 '55133216':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133212':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133213':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133211':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133219':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55223865':{'en': u('S\u00e3o Jo\u00e3o do Para\u00edso - RJ'), 'pt': u('S\u00e3o Jo\u00e3o do Para\u00edso - RJ')},
 '55223864':{'en': u('Aperib\u00e9 - RJ'), 'pt': u('Aperib\u00e9 - RJ')},
 '55223866':{'en': u('S\u00e3o Jos\u00e9 de Ub\u00e1 - RJ'), 'pt': u('S\u00e3o Jos\u00e9 de Ub\u00e1 - RJ')},
 '55223861':{'en': 'Itaocara - RJ', 'pt': 'Itaocara - RJ'},
 '55223863':{'en': u('Jaguaremb\u00e9 - RJ'), 'pt': u('Jaguaremb\u00e9 - RJ')},
 '55223862':{'en': 'Portela - RJ', 'pt': 'Portela - RJ'},
 '55114456':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55114454':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '497576':{'de': 'Krauchenwies', 'en': 'Krauchenwies'},
 '497577':{'de': 'Veringenstadt', 'en': 'Veringenstadt'},
 '497574':{'de': 'Gammertingen', 'en': 'Gammertingen'},
 '497575':{'de': 'Messkirch', 'en': 'Messkirch'},
 '497572':{'de': u('Mengen W\u00fcrttemberg'), 'en': u('Mengen W\u00fcrttemberg')},
 '497573':{'de': 'Stetten am kalten Markt', 'en': 'Stetten am kalten Markt'},
 '497570':{'de': 'Sigmaringen-Gutenstein', 'en': 'Sigmaringen-Gutenstein'},
 '497571':{'de': 'Sigmaringen', 'en': 'Sigmaringen'},
 '496658':{'de': 'Poppenhausen Wasserkuppe', 'en': 'Poppenhausen Wasserkuppe'},
 '497578':{'de': 'Wald Hohenz', 'en': 'Wald Hohenz'},
 '499607':{'de': 'Luhe-Wildenau', 'en': 'Luhe-Wildenau'},
 '55212561':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113804':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114181':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114183':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114182':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114185':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '52592':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55114186':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55113806':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55192146':{'en': 'Capivari - SP', 'pt': 'Capivari - SP'},
 '494274':{'de': 'Varrel bei Sulingen', 'en': 'Varrel bei Sulingen'},
 '55113801':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494276':{'de': 'Borstel bei Sulingen', 'en': 'Borstel bei Sulingen'},
 '494277':{'de': u('Schwaf\u00f6rden'), 'en': u('Schwaf\u00f6rden')},
 '494902':{'de': 'Jemgum-Ditzum', 'en': 'Jemgum-Ditzum'},
 '494903':{'de': 'Wymeer', 'en': 'Wymeer'},
 '494272':{'de': 'Siedenburg', 'en': 'Siedenburg'},
 '494273':{'de': 'Kirchdorf bei Sulingen', 'en': 'Kirchdorf bei Sulingen'},
 '55113803':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213839':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213389':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55113488':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213387':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213386':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213385':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213384':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '498591':{'de': 'Obernzell', 'en': 'Obernzell'},
 '55193577':{'en': u('Corumbata\u00ed - SP'), 'pt': u('Corumbata\u00ed - SP')},
 '498593':{'de': 'Untergriesbach', 'en': 'Untergriesbach'},
 '498592':{'de': 'Wegscheid Niederbayern', 'en': 'Wegscheid Niederbayern'},
 '55193576':{'en': u('Ipe\u00fana - SP'), 'pt': u('Ipe\u00fana - SP')},
 '55193571':{'en': 'Leme - SP', 'pt': 'Leme - SP'},
 '55283322':{'en': 'Cachoeiro de Itapemirim - ES', 'pt': 'Cachoeiro de Itapemirim - ES'},
 '55153311':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55153646':{'en': 'Buri - SP', 'pt': 'Buri - SP'},
 '55153313':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55193573':{'en': 'Leme - SP', 'pt': 'Leme - SP'},
 '55193572':{'en': 'Leme - SP', 'pt': 'Leme - SP'},
 '52442':{'en': 'Queretaro', 'es': u('Quer\u00e9taro')},
 '52778':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52441':{'en': 'Queretaro', 'es': u('Quer\u00e9taro')},
 '52447':{'en': 'Contepec/Maravatio, MICH', 'es': u('Contepec/Maravat\u00edo, MICH')},
 '52444':{'en': 'San Luis Potosi, SLP', 'es': u('San Luis Potos\u00ed, SLP')},
 '52445':{'en': 'Moroleon, GTO', 'es': 'Moroleon, GTO'},
 '52448':{'en': 'Queretaro', 'es': u('Quer\u00e9taro')},
 '52449':{'en': 'Aguascalientes/Jesus Maria, AGS', 'es': u('Aguascalientes/Jes\u00fas Mar\u00eda, AGS')},
 '55115928':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112609':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55213401':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112604':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112605':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112606':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112607':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115920':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112601':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112602':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112603':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49581':{'de': 'Uelzen', 'en': 'Uelzen'},
 '55113376':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212566':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212124':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55163456':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55213403':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55112934':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112933':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112931':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55143288':{'en': 'Bauru - SP', 'pt': 'Bauru - SP'},
 '55222789':{'en': u('S\u00e3o Francisco de Paula - RJ'), 'pt': u('S\u00e3o Francisco de Paula - RJ')},
 '499242':{'de': u('G\u00f6\u00dfweinstein'), 'en': u('G\u00f6ssweinstein')},
 '499243':{'de': 'Pottenstein', 'en': 'Pottenstein'},
 '55222785':{'en': 'Cardoso Moreira - RJ', 'pt': 'Cardoso Moreira - RJ'},
 '499241':{'de': 'Pegnitz', 'en': 'Pegnitz'},
 '499246':{'de': 'Pegnitz-Trockau', 'en': 'Pegnitz-Trockau'},
 '55143287':{'en': u('Ava\u00ed - SP'), 'pt': u('Ava\u00ed - SP')},
 '499244':{'de': 'Betzenstein', 'en': 'Betzenstein'},
 '499245':{'de': 'Obertrubach', 'en': 'Obertrubach'},
 '55212263':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55123929':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55212261':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212260':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212267':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212266':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212265':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212264':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55212268':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55323726':{'en': u('Patroc\u00ednio do Muria\u00e9 - MG'), 'pt': u('Patroc\u00ednio do Muria\u00e9 - MG')},
 '55323322':{'en': 'Nazareno - MG', 'pt': 'Nazareno - MG'},
 '55163847':{'en': 'Nuporanga - SP', 'pt': 'Nuporanga - SP'},
 '5324':{'en': u('Holgu\u00edn Province')},
 '5322':{'en': 'Santiago de Cuba Province'},
 '5323':{'en': 'Granma Province'},
 '5321':{'en': u('Guant\u00e1namo Province')},
 '496434':{'de': 'Bad Camberg', 'en': 'Bad Camberg'},
 '496435':{'de': 'Wallmerod', 'en': 'Wallmerod'},
 '496436':{'de': 'Dornburg Hessen', 'en': 'Dornburg Hessen'},
 '496430':{'de': u('Hahnst\u00e4tten'), 'en': u('Hahnst\u00e4tten')},
 '496431':{'de': 'Limburg an der Lahn', 'en': 'Limburg an der Lahn'},
 '496432':{'de': 'Diez', 'en': 'Diez'},
 '496433':{'de': 'Hadamar', 'en': 'Hadamar'},
 '55113518':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113513':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113512':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113515':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113514':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55222123':{'en': u('Maca\u00e9 - RJ'), 'pt': u('Maca\u00e9 - RJ')},
 '499952':{'de': 'Eichendorf', 'en': 'Eichendorf'},
 '55163335':{'en': 'Araraquara - SP', 'pt': 'Araraquara - SP'},
 '499953':{'de': 'Pilsting', 'en': 'Pilsting'},
 '55163878':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163877':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55323424':{'en': 'Laranjal - MG', 'pt': 'Laranjal - MG'},
 '55323425':{'en': 'Santana de Cataguases - MG', 'pt': 'Santana de Cataguases - MG'},
 '55323422':{'en': 'Cataguases - MG', 'pt': 'Cataguases - MG'},
 '55323423':{'en': 'Cataguases - MG', 'pt': 'Cataguases - MG'},
 '55323421':{'en': 'Cataguases - MG', 'pt': 'Cataguases - MG'},
 '496291':{'de': 'Adelsheim', 'en': 'Adelsheim'},
 '496292':{'de': 'Seckach', 'en': 'Seckach'},
 '496293':{'de': 'Schefflenz', 'en': 'Schefflenz'},
 '496294':{'de': 'Krautheim Jagst', 'en': 'Krautheim Jagst'},
 '496295':{'de': 'Rosenberg Baden', 'en': 'Rosenberg Baden'},
 '496296':{'de': 'Ahorn Baden', 'en': 'Ahorn Baden'},
 '496297':{'de': 'Ravenstein Baden', 'en': 'Ravenstein Baden'},
 '496298':{'de': u('M\u00f6ckm\u00fchl'), 'en': u('M\u00f6ckm\u00fchl')},
 '55313857':{'en': u('Dom Silv\u00e9rio - MG'), 'pt': u('Dom Silv\u00e9rio - MG')},
 '497748':{'de': 'Grafenhausen Hochschwarzwald', 'en': 'Grafenhausen Hochschwarzwald'},
 '497745':{'de': 'Jestetten', 'en': 'Jestetten'},
 '497744':{'de': u('St\u00fchlingen'), 'en': u('St\u00fchlingen')},
 '497747':{'de': 'Berau', 'en': 'Berau'},
 '497746':{'de': u('Wut\u00f6schingen'), 'en': u('Wut\u00f6schingen')},
 '497741':{'de': 'Tiengen Hochrhein', 'en': 'Tiengen Hochrhein'},
 '497743':{'de': u('\u00dchlingen-Birkendorf'), 'en': u('\u00dchlingen-Birkendorf')},
 '497742':{'de': 'Klettgau', 'en': 'Klettgau'},
 '494825':{'de': 'Burg Dithmarschen', 'en': 'Burg Dithmarschen'},
 '55313356':{'en': 'Contagem - MG', 'pt': 'Contagem - MG'},
 '495529':{'de': 'Rhumspringe', 'en': 'Rhumspringe'},
 '495528':{'de': 'Gieboldehausen', 'en': 'Gieboldehausen'},
 '495527':{'de': 'Duderstadt', 'en': 'Duderstadt'},
 '495525':{'de': 'Walkenried', 'en': 'Walkenried'},
 '495524':{'de': 'Bad Lauterberg im Harz', 'en': 'Bad Lauterberg im Harz'},
 '495523':{'de': 'Bad Sachsa', 'en': 'Bad Sachsa'},
 '494531':{'de': 'Bad Oldesloe', 'en': 'Bad Oldesloe'},
 '495521':{'de': 'Herzberg am Harz', 'en': 'Herzberg am Harz'},
 '495520':{'de': 'Braunlage', 'en': 'Braunlage'},
 '55173335':{'en': u('Col\u00f4mbia - SP'), 'pt': u('Col\u00f4mbia - SP')},
 '55173334':{'en': u('S\u00e3o Jos\u00e9 do Rio Preto - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Preto - SP')},
 '55173331':{'en': u('Gua\u00edra - SP'), 'pt': u('Gua\u00edra - SP')},
 '55173330':{'en': u('Gua\u00edra - SP'), 'pt': u('Gua\u00edra - SP')},
 '55173332':{'en': u('Gua\u00edra - SP'), 'pt': u('Gua\u00edra - SP')},
 '494821':{'de': 'Itzehoe', 'en': 'Itzehoe'},
 '504240':{'en': u('Roat\u00e1n, Bay Islands')},
 '55123921':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '494823':{'de': 'Wilster', 'en': 'Wilster'},
 '494822':{'de': 'Kellinghusen', 'en': 'Kellinghusen'},
 '55313661':{'en': 'Pedro Leopoldo - MG', 'pt': 'Pedro Leopoldo - MG'},
 '55123867':{'en': 'Maresias - SP', 'pt': 'Maresias - SP'},
 '55114888':{'en': u('Joan\u00f3polis - SP'), 'pt': u('Joan\u00f3polis - SP')},
 '55313665':{'en': 'Pedro Leopoldo - MG', 'pt': 'Pedro Leopoldo - MG'},
 '55242280':{'en': u('Petr\u00f3polis - RJ'), 'pt': u('Petr\u00f3polis - RJ')},
 '543838':{'en': u('Santa Mar\u00eda, Catamarca'), 'es': u('Santa Mar\u00eda, Catamarca')},
 '543835':{'en': u('Andalgal\u00e1, Catamarca'), 'es': u('Andalgal\u00e1, Catamarca')},
 '543837':{'en': 'Tinogasta, Catamarca', 'es': 'Tinogasta, Catamarca'},
 '543832':{'en': 'Recreo, Catamarca', 'es': 'Recreo, Catamarca'},
 '52878':{'en': 'Piedras Negras, COAH', 'es': 'Piedras Negras, COAH'},
 '52873':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52872':{'en': 'Coahuila/Durango', 'es': 'Coahuila/Durango'},
 '52871':{'en': 'Coahuila', 'es': 'Coahuila'},
 '52877':{'en': 'Ciudad Acuna, COAH', 'es': u('Ciudad Acu\u00f1a, COAH')},
 '55115112':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114881':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55213611':{'en': u('S\u00e3o Gon\u00e7alo - RJ'), 'pt': u('S\u00e3o Gon\u00e7alo - RJ')},
 '55213610':{'en': u('Niter\u00f3i - RJ'), 'pt': u('Niter\u00f3i - RJ')},
 '55163209':{'en': 'Jaboticabal - SP', 'pt': 'Jaboticabal - SP'},
 '497961':{'de': 'Ellwangen Jagst', 'en': 'Ellwangen Jagst'},
 '497963':{'de': 'Adelmannsfelden', 'en': 'Adelmannsfelden'},
 '497962':{'de': 'Fichtenau', 'en': 'Fichtenau'},
 '497965':{'de': u('Ellwangen-R\u00f6hlingen'), 'en': u('Ellwangen-R\u00f6hlingen')},
 '497964':{'de': u('St\u00f6dtlen'), 'en': u('St\u00f6dtlen')},
 '497967':{'de': 'Jagstzell', 'en': 'Jagstzell'},
 '497966':{'de': 'Unterschneidheim', 'en': 'Unterschneidheim'},
 '498292':{'de': 'Dinkelscherben', 'en': 'Dinkelscherben'},
 '498293':{'de': 'Welden bei Augsburg', 'en': 'Welden bei Augsburg'},
 '498291':{'de': 'Zusmarshausen', 'en': 'Zusmarshausen'},
 '498296':{'de': 'Villenbach', 'en': 'Villenbach'},
 '498294':{'de': 'Horgau', 'en': 'Horgau'},
 '498295':{'de': u('Altenm\u00fcnster Schwaben'), 'en': u('Altenm\u00fcnster Schwaben')},
 '55313753':{'en': 'Rio Espera - MG', 'pt': 'Rio Espera - MG'},
 '55313752':{'en': 'Catas Altas da Noruega - MG', 'pt': 'Catas Altas da Noruega - MG'},
 '55183529':{'en': 'Osvaldo Cruz - SP', 'pt': 'Osvaldo Cruz - SP'},
 '55183528':{'en': 'Osvaldo Cruz - SP', 'pt': 'Osvaldo Cruz - SP'},
 '54298242':{'en': 'Orense, Buenos Aires', 'es': 'Orense, Buenos Aires'},
 '54298240':{'en': 'Orense, Buenos Aires', 'es': 'Orense, Buenos Aires'},
 '55313754':{'en': 'Lamim - MG', 'pt': 'Lamim - MG'},
 '55183522':{'en': 'Adamantina - SP', 'pt': 'Adamantina - SP'},
 '55183521':{'en': 'Adamantina - SP', 'pt': 'Adamantina - SP'},
 '55313080':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55212743':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55313521':{'en': u('Ibirit\u00e9 - MG'), 'pt': u('Ibirit\u00e9 - MG')},
 '52389':{'en': 'Nayarit', 'es': 'Nayarit'},
 '55113071':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113073':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113074':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113075':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113076':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113077':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52381':{'en': 'Cojumatlan/San Jose de Gracia, MICH', 'es': 'Cojumatlan/San Jose de Gracia, MICH'},
 '55113079':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52383':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52382':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52385':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52384':{'en': 'Tala/Teuchitlan, JAL', 'es': 'Tala/Teuchitlan, JAL'},
 '52387':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52386':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55323228':{'en': 'Juiz de Fora - MG', 'pt': 'Juiz de Fora - MG'},
 '55313288':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '495883':{'de': 'Lemgow', 'en': 'Lemgow'},
 '55153211':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55313281':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313280':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313283':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313282':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313285':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55153212':{'en': 'Sorocaba - SP', 'pt': 'Sorocaba - SP'},
 '55313287':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '55313286':{'en': 'Belo Horizonte - MG', 'pt': 'Belo Horizonte - MG'},
 '499747':{'de': 'Geroda Bayern', 'en': 'Geroda Bayern'},
 '499746':{'de': 'Zeitlofs', 'en': 'Zeitlofs'},
 '499745':{'de': 'Wildflecken', 'en': 'Wildflecken'},
 '499744':{'de': 'Zeitlofs-Detter', 'en': 'Zeitlofs-Detter'},
 '55313573':{'en': 'Rio Manso - MG', 'pt': 'Rio Manso - MG'},
 '499742':{'de': u('Kalbach Rh\u00f6n'), 'en': u('Kalbach Rh\u00f6n')},
 '499741':{'de': u('Bad Br\u00fcckenau'), 'en': u('Bad Br\u00fcckenau')},
 '55114246':{'en': 'Mairinque - SP', 'pt': 'Mairinque - SP'},
 '55114247':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114243':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '499749':{'de': 'Oberbach Unterfranken', 'en': 'Oberbach Unterfranken'},
 '499748':{'de': 'Motten', 'en': 'Motten'},
 '55193452':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '52656':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '55193451':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '52653':{'en': 'Luis B. Sanchez/San Luis Rio Colorado, SON', 'es': u('Luis B. S\u00e1nchez/San Luis R\u00edo Colorado, SON')},
 '52652':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52651':{'en': 'Sonoita, SON', 'es': 'Sonoita, SON'},
 '55193455':{'en': u('Santa B\u00e1rbara D\'Oeste - SP'), 'pt': u('Santa B\u00e1rbara D\'Oeste - SP')},
 '5151':{'en': 'Puno'},
 '5153':{'en': 'Moquegua'},
 '5152':{'en': 'Tacna'},
 '5154':{'en': 'Arequipa'},
 '52659':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52658':{'en': 'Baja California', 'es': 'Baja California'},
 '55113214':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113215':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498434':{'de': 'Rennertshofen', 'en': 'Rennertshofen'},
 '498435':{'de': 'Ehekirchen', 'en': 'Ehekirchen'},
 '55113210':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113211':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113212':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113213':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113219':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55223066':{'en': 'Nova Friburgo - RJ', 'pt': 'Nova Friburgo - RJ'},
 '499523':{'de': 'Hofheim in Unterfranken', 'en': 'Hofheim in Unterfranken'},
 '499522':{'de': 'Eltmann', 'en': 'Eltmann'},
 '499521':{'de': 'Hassfurt', 'en': 'Hassfurt'},
 '494736':{'de': 'Butjadingen-Tossens', 'en': 'Butjadingen-Tossens'},
 '499527':{'de': 'Knetzgau', 'en': 'Knetzgau'},
 '499526':{'de': 'Riedbach', 'en': 'Riedbach'},
 '499525':{'de': u('K\u00f6nigsberg in Bayern'), 'en': u('K\u00f6nigsberg in Bayern')},
 '499524':{'de': 'Zeil am Main', 'en': 'Zeil am Main'},
 '499529':{'de': 'Oberaurach', 'en': 'Oberaurach'},
 '499528':{'de': 'Donnersdorf', 'en': 'Donnersdorf'},
 '55213035':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213037':{'en': u('Nova Igua\u00e7u - RJ'), 'pt': u('Nova Igua\u00e7u - RJ')},
 '55143458':{'en': 'Queiroz - SP', 'pt': 'Queiroz - SP'},
 '55213030':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213032':{'en': 'Rio de Janeiro - RJ', 'pt': 'Rio de Janeiro - RJ'},
 '55213039':{'en': u('Nil\u00f3polis - RJ'), 'pt': u('Nil\u00f3polis - RJ')},
 '55112037':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112036':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112033':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112032':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112031':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112038':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '54388':{'en': 'San Salvador de Jujuy, Jujuy', 'es': 'San Salvador de Jujuy, Jujuy'},
 '54387':{'en': 'Salta, Salta', 'es': 'Salta, Salta'},
 '54385':{'en': 'Santiago del Estero, Santiago del Estero', 'es': 'Santiago del Estero, Santiago del Estero'},
 '54383':{'en': 'San Fernando del Valle de Catamarca, Catamarca', 'es': 'San Fernando del Valle de Catamarca, Catamarca'},
 '54381':{'en': u('San Miguel de Tucum\u00e1n, Tucum\u00e1n'), 'es': u('San Miguel de Tucum\u00e1n, Tucum\u00e1n')},
 '54380':{'en': 'La Rioja, La Rioja', 'es': 'La Rioja, La Rioja'},
 '52329':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52328':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55333062':{'en': 'Governador Valadares - MG', 'pt': 'Governador Valadares - MG'},
 '55163995':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163996':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '55163993':{'en': u('Ribeir\u00e3o Preto - SP'), 'pt': u('Ribeir\u00e3o Preto - SP')},
 '52324':{'en': 'Nayarit', 'es': 'Nayarit'},
 '55213667':{'en': 'Duque de Caxias - RJ', 'pt': 'Duque de Caxias - RJ'},
 '55193608':{'en': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Rio Pardo - SP')},
 '495956':{'de': 'Rastdorf', 'en': 'Rastdorf'},
 '495957':{'de': 'Lindern Oldenburg', 'en': 'Lindern Oldenburg'},
 '495954':{'de': 'Lorup', 'en': 'Lorup'},
 '495955':{'de': 'Esterwegen', 'en': 'Esterwegen'},
 '495952':{'de': u('S\u00f6gel'), 'en': u('S\u00f6gel')},
 '495953':{'de': u('B\u00f6rger'), 'en': u('B\u00f6rger')},
 '495951':{'de': 'Werlte', 'en': 'Werlte'},
 '55193701':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '55123861':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55123862':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55123863':{'en': 'Maresias - SP', 'pt': 'Maresias - SP'},
 '55123864':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55112350':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55112460':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '496351':{'de': 'Eisenberg Pfalz', 'en': 'Eisenberg Pfalz'},
 '55273090':{'en': 'Cariacica - ES', 'pt': 'Cariacica - ES'},
 '496353':{'de': 'Freinsheim', 'en': 'Freinsheim'},
 '496352':{'de': 'Kirchheimbolanden', 'en': 'Kirchheimbolanden'},
 '496355':{'de': 'Albisheim Pfrimm', 'en': 'Albisheim Pfrimm'},
 '55193704':{'en': 'Limeira - SP', 'pt': 'Limeira - SP'},
 '496357':{'de': u('Standenb\u00fchl'), 'en': u('Standenb\u00fchl')},
 '496356':{'de': 'Carlsberg Pfalz', 'en': 'Carlsberg Pfalz'},
 '496359':{'de': u('Gr\u00fcnstadt'), 'en': u('Gr\u00fcnstadt')},
 '496358':{'de': 'Kriegsfeld', 'en': 'Kriegsfeld'},
 '55114882':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55193705':{'en': 'Campinas - SP', 'pt': 'Campinas - SP'},
 '55114886':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114887':{'en': 'Jarinu - SP', 'pt': 'Jarinu - SP'},
 '55112895':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55212747':{'en': u('Tangu\u00e1 - RJ'), 'pt': u('Tangu\u00e1 - RJ')},
 '55212741':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55212742':{'en': u('Teres\u00f3polis - RJ'), 'pt': u('Teres\u00f3polis - RJ')},
 '55112726':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112725':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112724':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112721':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498766':{'de': 'Gammelsdorf', 'en': 'Gammelsdorf'},
 '55183264':{'en': u('Iep\u00ea - SP'), 'pt': u('Iep\u00ea - SP')},
 '55143318':{'en': u('Mar\u00edlia - SP'), 'pt': u('Mar\u00edlia - SP')},
}
